Class: Google::Cloud::OracleDatabase::V1::AutonomousDatabase

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb

Overview

Defined Under Namespace

Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#admin_password::String

Returns Optional. Immutable. The password for the default ADMIN user. Note: Only one of admin_password_secret_version or admin_password can be populated.

Returns:

  • (::String)

    Optional. Immutable. The password for the default ADMIN user. Note: Only one of admin_password_secret_version or admin_password can be populated.



98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 98

class AutonomousDatabase
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#admin_password_secret_version::String

Returns Optional. Immutable. The resource name of a secret version in Secret Manager which contains the database admin user's password. Format: projects/{project}/secrets/{secret}/versions/{version}. Note: Only one of admin_password_secret_version or admin_password can be populated.

Returns:

  • (::String)

    Optional. Immutable. The resource name of a secret version in Secret Manager which contains the database admin user's password. Format: projects/{project}/secrets/{secret}/versions/{version}. Note: Only one of admin_password_secret_version or admin_password can be populated.



98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 98

class AutonomousDatabase
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#cidr::String

Returns Optional. Immutable. The subnet CIDR range for the Autonomous Database.

Returns:

  • (::String)

    Optional. Immutable. The subnet CIDR range for the Autonomous Database.



98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 98

class AutonomousDatabase
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The date and time that the Autonomous Database was created.

Returns:



98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 98

class AutonomousDatabase
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#database::String

Returns Optional. Immutable. The name of the Autonomous Database. The database name must be unique in the project. The name must begin with a letter and can contain a maximum of 30 alphanumeric characters.

Returns:

  • (::String)

    Optional. Immutable. The name of the Autonomous Database. The database name must be unique in the project. The name must begin with a letter and can contain a maximum of 30 alphanumeric characters.



98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 98

class AutonomousDatabase
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#disaster_recovery_supported_locations::Array<::String> (readonly)

Returns Output only. List of supported GCP region to clone the Autonomous Database for disaster recovery. Format: project/{project}/locations/{location}.

Returns:

  • (::Array<::String>)

    Output only. List of supported GCP region to clone the Autonomous Database for disaster recovery. Format: project/{project}/locations/{location}.



98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 98

class AutonomousDatabase
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#display_name::String

Returns Optional. Immutable. The display name for the Autonomous Database. The name does not have to be unique within your project.

Returns:

  • (::String)

    Optional. Immutable. The display name for the Autonomous Database. The name does not have to be unique within your project.



98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 98

class AutonomousDatabase
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#entitlement_id::String (readonly)

Returns Output only. The ID of the subscription entitlement associated with the Autonomous Database.

Returns:

  • (::String)

    Output only. The ID of the subscription entitlement associated with the Autonomous Database.



98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 98

class AutonomousDatabase
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. The labels or tags associated with the Autonomous Database.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. The labels or tags associated with the Autonomous Database.



98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 98

class AutonomousDatabase
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String

Returns Identifier. The name of the Autonomous Database resource in the following format: projects/{project}/locations/{region}/autonomousDatabases/{autonomous_database}.

Returns:

  • (::String)

    Identifier. The name of the Autonomous Database resource in the following format: projects/{project}/locations/{region}/autonomousDatabases/{autonomous_database}



98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 98

class AutonomousDatabase
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#network::String

Returns Optional. Immutable. The name of the VPC network used by the Autonomous Database in the following format: projects/{project}/global/networks/{network}.

Returns:

  • (::String)

    Optional. Immutable. The name of the VPC network used by the Autonomous Database in the following format: projects/{project}/global/networks/{network}



98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 98

class AutonomousDatabase
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#odb_network::String

Returns Optional. Immutable. The name of the OdbNetwork associated with the Autonomous Database. Format: projects/{project}/locations/{location}/odbNetworks/{odb_network} It is optional but if specified, this should match the parent ODBNetwork of the OdbSubnet.

Returns:

  • (::String)

    Optional. Immutable. The name of the OdbNetwork associated with the Autonomous Database. Format: projects/{project}/locations/{location}/odbNetworks/{odb_network} It is optional but if specified, this should match the parent ODBNetwork of the OdbSubnet.



98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 98

class AutonomousDatabase
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#odb_subnet::String

Returns Optional. Immutable. The name of the OdbSubnet associated with the Autonomous Database. Format: projects/{project}/locations/{location}/odbNetworks/{odb_network}/odbSubnets/{odb_subnet}.

Returns:

  • (::String)

    Optional. Immutable. The name of the OdbSubnet associated with the Autonomous Database. Format: projects/{project}/locations/{location}/odbNetworks/{odb_network}/odbSubnets/{odb_subnet}



98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 98

class AutonomousDatabase
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#peer_autonomous_databases::Array<::String> (readonly)

Returns Output only. The peer Autonomous Database names of the given Autonomous Database.

Returns:

  • (::Array<::String>)

    Output only. The peer Autonomous Database names of the given Autonomous Database.



98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 98

class AutonomousDatabase
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#properties::Google::Cloud::OracleDatabase::V1::AutonomousDatabaseProperties

Returns Optional. The properties of the Autonomous Database.

Returns:



98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 98

class AutonomousDatabase
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#source_config::Google::Cloud::OracleDatabase::V1::SourceConfig

Returns Optional. Immutable. The source Autonomous Database configuration for the standby Autonomous Database. The source Autonomous Database is configured while creating the Peer Autonomous Database and can't be updated after creation.

Returns:

  • (::Google::Cloud::OracleDatabase::V1::SourceConfig)

    Optional. Immutable. The source Autonomous Database configuration for the standby Autonomous Database. The source Autonomous Database is configured while creating the Peer Autonomous Database and can't be updated after creation.



98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 98

class AutonomousDatabase
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end