Class: Google::Cloud::OracleDatabase::V1::AutonomousDatabaseBackupProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/autonomous_db_backup.rb

Overview

Properties of the Autonomous Database Backup resource.

Defined Under Namespace

Modules: State, Type

Instance Attribute Summary collapse

Instance Attribute Details

#available_till_time::Google::Protobuf::Timestamp (readonly)



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_db_backup.rb', line 129

class AutonomousDatabaseBackupProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # // The various lifecycle states of the Autonomous Database Backup.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # Indicates that the resource is in creating state.
    CREATING = 1

    # Indicates that the resource is in active state.
    ACTIVE = 2

    # Indicates that the resource is in deleting state.
    DELETING = 3

    # Indicates that the resource is in deleted state.
    DELETED = 4

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in updating state.
    UPDATING = 7
  end

  # The type of the backup.
  module Type
    # Default unspecified value.
    TYPE_UNSPECIFIED = 0

    # Incremental backups.
    INCREMENTAL = 1

    # Full backups.
    FULL = 2

    # Long term backups.
    LONG_TERM = 3
  end
end

#compartment_id::String (readonly)



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_db_backup.rb', line 129

class AutonomousDatabaseBackupProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # // The various lifecycle states of the Autonomous Database Backup.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # Indicates that the resource is in creating state.
    CREATING = 1

    # Indicates that the resource is in active state.
    ACTIVE = 2

    # Indicates that the resource is in deleting state.
    DELETING = 3

    # Indicates that the resource is in deleted state.
    DELETED = 4

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in updating state.
    UPDATING = 7
  end

  # The type of the backup.
  module Type
    # Default unspecified value.
    TYPE_UNSPECIFIED = 0

    # Incremental backups.
    INCREMENTAL = 1

    # Full backups.
    FULL = 2

    # Long term backups.
    LONG_TERM = 3
  end
end

#database_size_tb::Float (readonly)



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_db_backup.rb', line 129

class AutonomousDatabaseBackupProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # // The various lifecycle states of the Autonomous Database Backup.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # Indicates that the resource is in creating state.
    CREATING = 1

    # Indicates that the resource is in active state.
    ACTIVE = 2

    # Indicates that the resource is in deleting state.
    DELETING = 3

    # Indicates that the resource is in deleted state.
    DELETED = 4

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in updating state.
    UPDATING = 7
  end

  # The type of the backup.
  module Type
    # Default unspecified value.
    TYPE_UNSPECIFIED = 0

    # Incremental backups.
    INCREMENTAL = 1

    # Full backups.
    FULL = 2

    # Long term backups.
    LONG_TERM = 3
  end
end

#db_version::String (readonly)



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_db_backup.rb', line 129

class AutonomousDatabaseBackupProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # // The various lifecycle states of the Autonomous Database Backup.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # Indicates that the resource is in creating state.
    CREATING = 1

    # Indicates that the resource is in active state.
    ACTIVE = 2

    # Indicates that the resource is in deleting state.
    DELETING = 3

    # Indicates that the resource is in deleted state.
    DELETED = 4

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in updating state.
    UPDATING = 7
  end

  # The type of the backup.
  module Type
    # Default unspecified value.
    TYPE_UNSPECIFIED = 0

    # Incremental backups.
    INCREMENTAL = 1

    # Full backups.
    FULL = 2

    # Long term backups.
    LONG_TERM = 3
  end
end

#end_time::Google::Protobuf::Timestamp (readonly)



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_db_backup.rb', line 129

class AutonomousDatabaseBackupProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # // The various lifecycle states of the Autonomous Database Backup.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # Indicates that the resource is in creating state.
    CREATING = 1

    # Indicates that the resource is in active state.
    ACTIVE = 2

    # Indicates that the resource is in deleting state.
    DELETING = 3

    # Indicates that the resource is in deleted state.
    DELETED = 4

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in updating state.
    UPDATING = 7
  end

  # The type of the backup.
  module Type
    # Default unspecified value.
    TYPE_UNSPECIFIED = 0

    # Incremental backups.
    INCREMENTAL = 1

    # Full backups.
    FULL = 2

    # Long term backups.
    LONG_TERM = 3
  end
end

#is_automatic_backup::Boolean (readonly)



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_db_backup.rb', line 129

class AutonomousDatabaseBackupProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # // The various lifecycle states of the Autonomous Database Backup.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # Indicates that the resource is in creating state.
    CREATING = 1

    # Indicates that the resource is in active state.
    ACTIVE = 2

    # Indicates that the resource is in deleting state.
    DELETING = 3

    # Indicates that the resource is in deleted state.
    DELETED = 4

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in updating state.
    UPDATING = 7
  end

  # The type of the backup.
  module Type
    # Default unspecified value.
    TYPE_UNSPECIFIED = 0

    # Incremental backups.
    INCREMENTAL = 1

    # Full backups.
    FULL = 2

    # Long term backups.
    LONG_TERM = 3
  end
end

#is_long_term_backup::Boolean (readonly)



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_db_backup.rb', line 129

class AutonomousDatabaseBackupProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # // The various lifecycle states of the Autonomous Database Backup.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # Indicates that the resource is in creating state.
    CREATING = 1

    # Indicates that the resource is in active state.
    ACTIVE = 2

    # Indicates that the resource is in deleting state.
    DELETING = 3

    # Indicates that the resource is in deleted state.
    DELETED = 4

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in updating state.
    UPDATING = 7
  end

  # The type of the backup.
  module Type
    # Default unspecified value.
    TYPE_UNSPECIFIED = 0

    # Incremental backups.
    INCREMENTAL = 1

    # Full backups.
    FULL = 2

    # Long term backups.
    LONG_TERM = 3
  end
end

#is_restorable::Boolean (readonly)



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_db_backup.rb', line 129

class AutonomousDatabaseBackupProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # // The various lifecycle states of the Autonomous Database Backup.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # Indicates that the resource is in creating state.
    CREATING = 1

    # Indicates that the resource is in active state.
    ACTIVE = 2

    # Indicates that the resource is in deleting state.
    DELETING = 3

    # Indicates that the resource is in deleted state.
    DELETED = 4

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in updating state.
    UPDATING = 7
  end

  # The type of the backup.
  module Type
    # Default unspecified value.
    TYPE_UNSPECIFIED = 0

    # Incremental backups.
    INCREMENTAL = 1

    # Full backups.
    FULL = 2

    # Long term backups.
    LONG_TERM = 3
  end
end

#key_store_id::String



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_db_backup.rb', line 129

class AutonomousDatabaseBackupProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # // The various lifecycle states of the Autonomous Database Backup.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # Indicates that the resource is in creating state.
    CREATING = 1

    # Indicates that the resource is in active state.
    ACTIVE = 2

    # Indicates that the resource is in deleting state.
    DELETING = 3

    # Indicates that the resource is in deleted state.
    DELETED = 4

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in updating state.
    UPDATING = 7
  end

  # The type of the backup.
  module Type
    # Default unspecified value.
    TYPE_UNSPECIFIED = 0

    # Incremental backups.
    INCREMENTAL = 1

    # Full backups.
    FULL = 2

    # Long term backups.
    LONG_TERM = 3
  end
end

#key_store_wallet::String



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_db_backup.rb', line 129

class AutonomousDatabaseBackupProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # // The various lifecycle states of the Autonomous Database Backup.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # Indicates that the resource is in creating state.
    CREATING = 1

    # Indicates that the resource is in active state.
    ACTIVE = 2

    # Indicates that the resource is in deleting state.
    DELETING = 3

    # Indicates that the resource is in deleted state.
    DELETED = 4

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in updating state.
    UPDATING = 7
  end

  # The type of the backup.
  module Type
    # Default unspecified value.
    TYPE_UNSPECIFIED = 0

    # Incremental backups.
    INCREMENTAL = 1

    # Full backups.
    FULL = 2

    # Long term backups.
    LONG_TERM = 3
  end
end

#kms_key_id::String



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_db_backup.rb', line 129

class AutonomousDatabaseBackupProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # // The various lifecycle states of the Autonomous Database Backup.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # Indicates that the resource is in creating state.
    CREATING = 1

    # Indicates that the resource is in active state.
    ACTIVE = 2

    # Indicates that the resource is in deleting state.
    DELETING = 3

    # Indicates that the resource is in deleted state.
    DELETED = 4

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in updating state.
    UPDATING = 7
  end

  # The type of the backup.
  module Type
    # Default unspecified value.
    TYPE_UNSPECIFIED = 0

    # Incremental backups.
    INCREMENTAL = 1

    # Full backups.
    FULL = 2

    # Long term backups.
    LONG_TERM = 3
  end
end

#kms_key_version_id::String



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_db_backup.rb', line 129

class AutonomousDatabaseBackupProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # // The various lifecycle states of the Autonomous Database Backup.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # Indicates that the resource is in creating state.
    CREATING = 1

    # Indicates that the resource is in active state.
    ACTIVE = 2

    # Indicates that the resource is in deleting state.
    DELETING = 3

    # Indicates that the resource is in deleted state.
    DELETED = 4

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in updating state.
    UPDATING = 7
  end

  # The type of the backup.
  module Type
    # Default unspecified value.
    TYPE_UNSPECIFIED = 0

    # Incremental backups.
    INCREMENTAL = 1

    # Full backups.
    FULL = 2

    # Long term backups.
    LONG_TERM = 3
  end
end

#lifecycle_details::String (readonly)



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_db_backup.rb', line 129

class AutonomousDatabaseBackupProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # // The various lifecycle states of the Autonomous Database Backup.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # Indicates that the resource is in creating state.
    CREATING = 1

    # Indicates that the resource is in active state.
    ACTIVE = 2

    # Indicates that the resource is in deleting state.
    DELETING = 3

    # Indicates that the resource is in deleted state.
    DELETED = 4

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in updating state.
    UPDATING = 7
  end

  # The type of the backup.
  module Type
    # Default unspecified value.
    TYPE_UNSPECIFIED = 0

    # Incremental backups.
    INCREMENTAL = 1

    # Full backups.
    FULL = 2

    # Long term backups.
    LONG_TERM = 3
  end
end

#lifecycle_state::Google::Cloud::OracleDatabase::V1::AutonomousDatabaseBackupProperties::State (readonly)



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_db_backup.rb', line 129

class AutonomousDatabaseBackupProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # // The various lifecycle states of the Autonomous Database Backup.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # Indicates that the resource is in creating state.
    CREATING = 1

    # Indicates that the resource is in active state.
    ACTIVE = 2

    # Indicates that the resource is in deleting state.
    DELETING = 3

    # Indicates that the resource is in deleted state.
    DELETED = 4

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in updating state.
    UPDATING = 7
  end

  # The type of the backup.
  module Type
    # Default unspecified value.
    TYPE_UNSPECIFIED = 0

    # Incremental backups.
    INCREMENTAL = 1

    # Full backups.
    FULL = 2

    # Long term backups.
    LONG_TERM = 3
  end
end

#ocid::String (readonly)



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_db_backup.rb', line 129

class AutonomousDatabaseBackupProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # // The various lifecycle states of the Autonomous Database Backup.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # Indicates that the resource is in creating state.
    CREATING = 1

    # Indicates that the resource is in active state.
    ACTIVE = 2

    # Indicates that the resource is in deleting state.
    DELETING = 3

    # Indicates that the resource is in deleted state.
    DELETED = 4

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in updating state.
    UPDATING = 7
  end

  # The type of the backup.
  module Type
    # Default unspecified value.
    TYPE_UNSPECIFIED = 0

    # Incremental backups.
    INCREMENTAL = 1

    # Full backups.
    FULL = 2

    # Long term backups.
    LONG_TERM = 3
  end
end

#retention_period_days::Integer



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_db_backup.rb', line 129

class AutonomousDatabaseBackupProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # // The various lifecycle states of the Autonomous Database Backup.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # Indicates that the resource is in creating state.
    CREATING = 1

    # Indicates that the resource is in active state.
    ACTIVE = 2

    # Indicates that the resource is in deleting state.
    DELETING = 3

    # Indicates that the resource is in deleted state.
    DELETED = 4

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in updating state.
    UPDATING = 7
  end

  # The type of the backup.
  module Type
    # Default unspecified value.
    TYPE_UNSPECIFIED = 0

    # Incremental backups.
    INCREMENTAL = 1

    # Full backups.
    FULL = 2

    # Long term backups.
    LONG_TERM = 3
  end
end

#size_tb::Float (readonly)



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_db_backup.rb', line 129

class AutonomousDatabaseBackupProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # // The various lifecycle states of the Autonomous Database Backup.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # Indicates that the resource is in creating state.
    CREATING = 1

    # Indicates that the resource is in active state.
    ACTIVE = 2

    # Indicates that the resource is in deleting state.
    DELETING = 3

    # Indicates that the resource is in deleted state.
    DELETED = 4

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in updating state.
    UPDATING = 7
  end

  # The type of the backup.
  module Type
    # Default unspecified value.
    TYPE_UNSPECIFIED = 0

    # Incremental backups.
    INCREMENTAL = 1

    # Full backups.
    FULL = 2

    # Long term backups.
    LONG_TERM = 3
  end
end

#start_time::Google::Protobuf::Timestamp (readonly)



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_db_backup.rb', line 129

class AutonomousDatabaseBackupProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # // The various lifecycle states of the Autonomous Database Backup.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # Indicates that the resource is in creating state.
    CREATING = 1

    # Indicates that the resource is in active state.
    ACTIVE = 2

    # Indicates that the resource is in deleting state.
    DELETING = 3

    # Indicates that the resource is in deleted state.
    DELETED = 4

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in updating state.
    UPDATING = 7
  end

  # The type of the backup.
  module Type
    # Default unspecified value.
    TYPE_UNSPECIFIED = 0

    # Incremental backups.
    INCREMENTAL = 1

    # Full backups.
    FULL = 2

    # Long term backups.
    LONG_TERM = 3
  end
end

#type::Google::Cloud::OracleDatabase::V1::AutonomousDatabaseBackupProperties::Type (readonly)



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_db_backup.rb', line 129

class AutonomousDatabaseBackupProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # // The various lifecycle states of the Autonomous Database Backup.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # Indicates that the resource is in creating state.
    CREATING = 1

    # Indicates that the resource is in active state.
    ACTIVE = 2

    # Indicates that the resource is in deleting state.
    DELETING = 3

    # Indicates that the resource is in deleted state.
    DELETED = 4

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in updating state.
    UPDATING = 7
  end

  # The type of the backup.
  module Type
    # Default unspecified value.
    TYPE_UNSPECIFIED = 0

    # Incremental backups.
    INCREMENTAL = 1

    # Full backups.
    FULL = 2

    # Long term backups.
    LONG_TERM = 3
  end
end

#vault_id::String



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_db_backup.rb', line 129

class AutonomousDatabaseBackupProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # // The various lifecycle states of the Autonomous Database Backup.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # Indicates that the resource is in creating state.
    CREATING = 1

    # Indicates that the resource is in active state.
    ACTIVE = 2

    # Indicates that the resource is in deleting state.
    DELETING = 3

    # Indicates that the resource is in deleted state.
    DELETED = 4

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in updating state.
    UPDATING = 7
  end

  # The type of the backup.
  module Type
    # Default unspecified value.
    TYPE_UNSPECIFIED = 0

    # Incremental backups.
    INCREMENTAL = 1

    # Full backups.
    FULL = 2

    # Long term backups.
    LONG_TERM = 3
  end
end