Class: Google::Cloud::OracleDatabase::V1::AutonomousDatabaseCharacterSet

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/autonomous_database_character_set.rb

Overview

Defined Under Namespace

Modules: CharacterSetType

Instance Attribute Summary collapse

Instance Attribute Details

#character_set::String (readonly)



38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database_character_set.rb', line 38

class AutonomousDatabaseCharacterSet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of character set an Autonomous Database can have.
  module CharacterSetType
    # Character set type is not specified.
    CHARACTER_SET_TYPE_UNSPECIFIED = 0

    # Character set type is set to database.
    DATABASE = 1

    # Character set type is set to national.
    NATIONAL = 2
  end
end

#character_set_type::Google::Cloud::OracleDatabase::V1::AutonomousDatabaseCharacterSet::CharacterSetType (readonly)



38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database_character_set.rb', line 38

class AutonomousDatabaseCharacterSet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of character set an Autonomous Database can have.
  module CharacterSetType
    # Character set type is not specified.
    CHARACTER_SET_TYPE_UNSPECIFIED = 0

    # Character set type is set to database.
    DATABASE = 1

    # Character set type is set to national.
    NATIONAL = 2
  end
end

#name::String



38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database_character_set.rb', line 38

class AutonomousDatabaseCharacterSet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of character set an Autonomous Database can have.
  module CharacterSetType
    # Character set type is not specified.
    CHARACTER_SET_TYPE_UNSPECIFIED = 0

    # Character set type is set to database.
    DATABASE = 1

    # Character set type is set to national.
    NATIONAL = 2
  end
end