Class: Google::Cloud::OracleDatabase::V1::CloudExadataInfrastructure
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::CloudExadataInfrastructure
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb
Overview
Represents CloudExadataInfrastructure resource. https://docs.oracle.com/en-us/iaas/api/#/en/database/20160918/CloudExadataInfrastructure/
Defined Under Namespace
Classes: LabelsEntry
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#display_name ⇒ ::String
Optional.
-
#entitlement_id ⇒ ::String
readonly
Output only.
-
#gcp_oracle_zone ⇒ ::String
Optional.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#name ⇒ ::String
Identifier.
-
#properties ⇒ ::Google::Cloud::OracleDatabase::V1::CloudExadataInfrastructureProperties
Optional.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The date and time that the Exadata Infrastructure was created.
52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 52 class CloudExadataInfrastructure include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#display_name ⇒ ::String
Returns Optional. User friendly name for this resource.
52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 52 class CloudExadataInfrastructure include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#entitlement_id ⇒ ::String (readonly)
Returns Output only. Entitlement ID of the private offer against which this infrastructure resource is provisioned.
52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 52 class CloudExadataInfrastructure include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#gcp_oracle_zone ⇒ ::String
Returns Optional. The GCP Oracle zone where Oracle Exadata Infrastructure is hosted. Example: us-east4-b-r2. If not specified, the system will pick a zone based on availability.
52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 52 class CloudExadataInfrastructure include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Labels or tags associated with the resource.
52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 52 class CloudExadataInfrastructure include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Identifier. The name of the Exadata Infrastructure resource with the format: projects/{project}/locations/{region}/cloudExadataInfrastructures/{cloud_exadata_infrastructure}.
52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 52 class CloudExadataInfrastructure include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#properties ⇒ ::Google::Cloud::OracleDatabase::V1::CloudExadataInfrastructureProperties
Returns Optional. Various properties of the infra.
52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 52 class CloudExadataInfrastructure include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |