Class: Google::Cloud::OracleDatabase::V1::CloudExadataInfrastructureProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb

Overview

Various properties of Exadata Infrastructure.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#activated_storage_count::Integer (readonly)

Returns Output only. The requested number of additional storage servers activated for the Exadata Infrastructure.

Returns:

  • (::Integer)

    Output only. The requested number of additional storage servers activated for the Exadata Infrastructure.



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#additional_storage_count::Integer (readonly)

Returns Output only. The requested number of additional storage servers for the Exadata Infrastructure.

Returns:

  • (::Integer)

    Output only. The requested number of additional storage servers for the Exadata Infrastructure.



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#available_storage_size_gb::Integer (readonly)

Returns Output only. The available storage can be allocated to the Exadata Infrastructure resource, in gigabytes (GB).

Returns:

  • (::Integer)

    Output only. The available storage can be allocated to the Exadata Infrastructure resource, in gigabytes (GB).



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#compute_count::Integer

Returns Optional. The number of compute servers for the Exadata Infrastructure.

Returns:

  • (::Integer)

    Optional. The number of compute servers for the Exadata Infrastructure.



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#compute_model::Google::Cloud::OracleDatabase::V1::ComputeModel (readonly)

Returns Output only. The compute model of the Exadata Infrastructure.

Returns:



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#cpu_count::Integer (readonly)

Returns Output only. The number of enabled CPU cores.

Returns:

  • (::Integer)

    Output only. The number of enabled CPU cores.



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#customer_contacts::Array<::Google::Cloud::OracleDatabase::V1::CustomerContact>

Returns Optional. The list of customer contacts.

Returns:



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#data_storage_size_tb::Float (readonly)

Returns Output only. Size, in terabytes, of the DATA disk group.

Returns:

  • (::Float)

    Output only. Size, in terabytes, of the DATA disk group.



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#database_server_type::String (readonly)

Returns Output only. The database server type of the Exadata Infrastructure.

Returns:

  • (::String)

    Output only. The database server type of the Exadata Infrastructure.



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#db_node_storage_size_gb::Integer (readonly)

Returns Output only. The local node storage allocated in GBs.

Returns:

  • (::Integer)

    Output only. The local node storage allocated in GBs.



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#db_server_version::String (readonly)

Returns Output only. The software version of the database servers (dom0) in the Exadata Infrastructure.

Returns:

  • (::String)

    Output only. The software version of the database servers (dom0) in the Exadata Infrastructure.



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#exascale_config::Google::Cloud::OracleDatabase::V1::ExascaleConfig (readonly)

Returns Output only. The Exascale configuration for the Exadata Infrastructure.

Returns:



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#maintenance_window::Google::Cloud::OracleDatabase::V1::MaintenanceWindow

Returns Optional. Maintenance window for repair.

Returns:



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#max_cpu_count::Integer (readonly)

Returns Output only. The total number of CPU cores available.

Returns:

  • (::Integer)

    Output only. The total number of CPU cores available.



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#max_data_storage_tb::Float (readonly)

Returns Output only. The total available DATA disk group size.

Returns:

  • (::Float)

    Output only. The total available DATA disk group size.



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#max_db_node_storage_size_gb::Integer (readonly)

Returns Output only. The total local node storage available in GBs.

Returns:

  • (::Integer)

    Output only. The total local node storage available in GBs.



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#max_memory_gb::Integer (readonly)

Returns Output only. The total memory available in GBs.

Returns:

  • (::Integer)

    Output only. The total memory available in GBs.



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#memory_size_gb::Integer (readonly)

Returns Output only. The memory allocated in GBs.

Returns:

  • (::Integer)

    Output only. The memory allocated in GBs.



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#monthly_db_server_version::String (readonly)

Returns Output only. The monthly software version of the database servers (dom0) in the Exadata Infrastructure. Example: 20.1.15.

Returns:

  • (::String)

    Output only. The monthly software version of the database servers (dom0) in the Exadata Infrastructure. Example: 20.1.15



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#monthly_storage_server_version::String (readonly)

Returns Output only. The monthly software version of the storage servers (cells) in the Exadata Infrastructure. Example: 20.1.15.

Returns:

  • (::String)

    Output only. The monthly software version of the storage servers (cells) in the Exadata Infrastructure. Example: 20.1.15



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#next_maintenance_run_id::String (readonly)

Returns Output only. The OCID of the next maintenance run.

Returns:

  • (::String)

    Output only. The OCID of the next maintenance run.



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#next_maintenance_run_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time when the next maintenance run will occur.

Returns:



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#next_security_maintenance_run_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time when the next security maintenance run will occur.

Returns:



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#oci_url::String (readonly)

Returns Output only. Deep link to the OCI console to view this resource.

Returns:

  • (::String)

    Output only. Deep link to the OCI console to view this resource.



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#ocid::String (readonly)

Returns:



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#shape::String

Returns Required. The shape of the Exadata Infrastructure. The shape determines the amount of CPU, storage, and memory resources allocated to the instance.

Returns:

  • (::String)

    Required. The shape of the Exadata Infrastructure. The shape determines the amount of CPU, storage, and memory resources allocated to the instance.



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#state::Google::Cloud::OracleDatabase::V1::CloudExadataInfrastructureProperties::State (readonly)

Returns Output only. The current lifecycle state of the Exadata Infrastructure.

Returns:



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#storage_count::Integer

Returns Optional. The number of Cloud Exadata storage servers for the Exadata Infrastructure.

Returns:

  • (::Integer)

    Optional. The number of Cloud Exadata storage servers for the Exadata Infrastructure.



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#storage_server_type::String (readonly)

Returns Output only. The storage server type of the Exadata Infrastructure.

Returns:

  • (::String)

    Output only. The storage server type of the Exadata Infrastructure.



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#storage_server_version::String (readonly)

Returns Output only. The software version of the storage servers (cells) in the Exadata Infrastructure.

Returns:

  • (::String)

    Output only. The software version of the storage servers (cells) in the Exadata Infrastructure.



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end

#total_storage_size_gb::Integer

Returns Optional. The total storage allocated to the Exadata Infrastructure resource, in gigabytes (GB).

Returns:

  • (::Integer)

    Optional. The total storage allocated to the Exadata Infrastructure resource, in gigabytes (GB).



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 171

class CloudExadataInfrastructureProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Exadata Infrastructure.
  module State
    # Default unspecified value.
    STATE_UNSPECIFIED = 0

    # The Exadata Infrastructure is being provisioned.
    PROVISIONING = 1

    # The Exadata Infrastructure is available for use.
    AVAILABLE = 2

    # The Exadata Infrastructure is being updated.
    UPDATING = 3

    # The Exadata Infrastructure is being terminated.
    TERMINATING = 4

    # The Exadata Infrastructure is terminated.
    TERMINATED = 5

    # The Exadata Infrastructure is in failed state.
    FAILED = 6

    # The Exadata Infrastructure is in maintenance.
    MAINTENANCE_IN_PROGRESS = 7
  end
end