Class: Google::Cloud::OracleDatabase::V1::CloudVmCluster

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb

Overview

Defined Under Namespace

Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#backup_odb_subnet::String

Returns Optional. The name of the backup OdbSubnet associated with the VM Cluster. Format: projects/{project}/locations/{location}/odbNetworks/{odb_network}/odbSubnets/{odb_subnet}.

Returns:

  • (::String)

    Optional. The name of the backup OdbSubnet associated with the VM Cluster. Format: projects/{project}/locations/{location}/odbNetworks/{odb_network}/odbSubnets/{odb_subnet}



83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 83

class CloudVmCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#backup_subnet_cidr::String

Returns Optional. CIDR range of the backup subnet.

Returns:

  • (::String)

    Optional. CIDR range of the backup subnet.



83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 83

class CloudVmCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#cidr::String

Returns Optional. Network settings. CIDR to use for cluster IP allocation.

Returns:

  • (::String)

    Optional. Network settings. CIDR to use for cluster IP allocation.



83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 83

class CloudVmCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The date and time that the VM cluster was created.

Returns:



83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 83

class CloudVmCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#display_name::String

Returns Optional. User friendly name for this resource.

Returns:

  • (::String)

    Optional. User friendly name for this resource.



83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 83

class CloudVmCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#exadata_infrastructure::String

Returns Required. The name of the Exadata Infrastructure resource on which VM cluster resource is created, in the following format: projects/{project}/locations/{region}/cloudExadataInfrastuctures/{cloud_extradata_infrastructure}.

Returns:

  • (::String)

    Required. The name of the Exadata Infrastructure resource on which VM cluster resource is created, in the following format: projects/{project}/locations/{region}/cloudExadataInfrastuctures/{cloud_extradata_infrastructure}



83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 83

class CloudVmCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#gcp_oracle_zone::String (readonly)

Returns Output only. The GCP Oracle zone where Oracle CloudVmCluster is hosted. This will be the same as the gcp_oracle_zone of the CloudExadataInfrastructure. Example: us-east4-b-r2.

Returns:

  • (::String)

    Output only. The GCP Oracle zone where Oracle CloudVmCluster is hosted. This will be the same as the gcp_oracle_zone of the CloudExadataInfrastructure. Example: us-east4-b-r2.



83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 83

class CloudVmCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#identity_connector::Google::Cloud::OracleDatabase::V1::IdentityConnector (readonly)

Returns Output only. The identity connector details which will allow OCI to securely access the resources in the customer project.

Returns:



83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 83

class CloudVmCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. Labels or tags associated with the VM Cluster.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. Labels or tags associated with the VM Cluster.



83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 83

class CloudVmCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String

Returns Identifier. The name of the VM Cluster resource with the format: projects/{project}/locations/{region}/cloudVmClusters/{cloud_vm_cluster}.

Returns:

  • (::String)

    Identifier. The name of the VM Cluster resource with the format: projects/{project}/locations/{region}/cloudVmClusters/{cloud_vm_cluster}



83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 83

class CloudVmCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#network::String

Returns Optional. The name of the VPC network. Format: projects/{project}/global/networks/{network}.

Returns:

  • (::String)

    Optional. The name of the VPC network. Format: projects/{project}/global/networks/{network}



83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 83

class CloudVmCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#odb_network::String

Returns Optional. The name of the OdbNetwork associated with the VM Cluster. Format: projects/{project}/locations/{location}/odbNetworks/{odb_network} It is optional but if specified, this should match the parent ODBNetwork of the odb_subnet and backup_odb_subnet.

Returns:

  • (::String)

    Optional. The name of the OdbNetwork associated with the VM Cluster. Format: projects/{project}/locations/{location}/odbNetworks/{odb_network} It is optional but if specified, this should match the parent ODBNetwork of the odb_subnet and backup_odb_subnet.



83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 83

class CloudVmCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#odb_subnet::String

Returns Optional. The name of the OdbSubnet associated with the VM Cluster for IP allocation. Format: projects/{project}/locations/{location}/odbNetworks/{odb_network}/odbSubnets/{odb_subnet}.

Returns:

  • (::String)

    Optional. The name of the OdbSubnet associated with the VM Cluster for IP allocation. Format: projects/{project}/locations/{location}/odbNetworks/{odb_network}/odbSubnets/{odb_subnet}



83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 83

class CloudVmCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#properties::Google::Cloud::OracleDatabase::V1::CloudVmClusterProperties

Returns Optional. Various properties of the VM Cluster.

Returns:



83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 83

class CloudVmCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end