Class: Google::Cloud::OracleDatabase::V1::ConfigureExascaleCloudExadataInfrastructureRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb

Overview

The request for CloudExadataInfrastructure.ConfigureExascale.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The name of the Cloud Exadata Infrastructure in the following format: projects/{project}/locations/{location}/cloudExadataInfrastructures/{cloud_exadata_infrastructure}.

Returns:

  • (::String)

    Required. The name of the Cloud Exadata Infrastructure in the following format: projects/{project}/locations/{location}/cloudExadataInfrastructures/{cloud_exadata_infrastructure}.



301
302
303
304
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 301

class ConfigureExascaleCloudExadataInfrastructureRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns Optional. An optional ID to identify the request.

Returns:

  • (::String)

    Optional. An optional ID to identify the request.



301
302
303
304
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 301

class ConfigureExascaleCloudExadataInfrastructureRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#total_storage_size_gb::Integer

Returns Required. The total storage to be allocated to Exascale in GBs.

Returns:

  • (::Integer)

    Required. The total storage to be allocated to Exascale in GBs.



301
302
303
304
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 301

class ConfigureExascaleCloudExadataInfrastructureRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end