Class: Google::Cloud::OracleDatabase::V1::CreateAutonomousDatabaseRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb

Overview

The request for AutonomousDatabase.Create.

Instance Attribute Summary collapse

Instance Attribute Details

#autonomous_database::Google::Cloud::OracleDatabase::V1::AutonomousDatabase

Returns Required. The Autonomous Database being created.

Returns:



502
503
504
505
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 502

class CreateAutonomousDatabaseRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#autonomous_database_id::String

Returns Required. The ID of the Autonomous Database to create. This value is restricted to (^a-z?$) and must be a maximum of 63 characters in length. The value must start with a letter and end with a letter or a number.

Returns:

  • (::String)

    Required. The ID of the Autonomous Database to create. This value is restricted to (^a-z?$) and must be a maximum of 63 characters in length. The value must start with a letter and end with a letter or a number.



502
503
504
505
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 502

class CreateAutonomousDatabaseRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The name of the parent in the following format: projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. The name of the parent in the following format: projects/{project}/locations/{location}.



502
503
504
505
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 502

class CreateAutonomousDatabaseRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns Optional. An optional ID to identify the request. This value is used to identify duplicate requests. If you make a request with the same request ID and the original request is still in progress or completed, the server ignores the second request. This prevents clients from accidentally creating duplicate commitments.

The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).

Returns:

  • (::String)

    Optional. An optional ID to identify the request. This value is used to identify duplicate requests. If you make a request with the same request ID and the original request is still in progress or completed, the server ignores the second request. This prevents clients from accidentally creating duplicate commitments.

    The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).



502
503
504
505
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 502

class CreateAutonomousDatabaseRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end