Class: Google::Cloud::OracleDatabase::V1::CreateDbSystemRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/db_system.rb

Overview

The request for DbSystem.Create.

Instance Attribute Summary collapse

Instance Attribute Details

#db_system::Google::Cloud::OracleDatabase::V1::DbSystem

Returns Required. The resource being created.

Returns:



309
310
311
312
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 309

class CreateDbSystemRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#db_system_id::String

Returns Required. The ID of the DbSystem to create. This value is restricted to (^a-z?$) and must be a maximum of 63 characters in length. The value must start with a letter and end with a letter or a number.

Returns:

  • (::String)

    Required. The ID of the DbSystem to create. This value is restricted to (^a-z?$) and must be a maximum of 63 characters in length. The value must start with a letter and end with a letter or a number.



309
310
311
312
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 309

class CreateDbSystemRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The value for parent of the DbSystem in the following format: projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. The value for parent of the DbSystem in the following format: projects/{project}/locations/{location}.



309
310
311
312
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 309

class CreateDbSystemRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.

For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).

Returns:

  • (::String)

    Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.

    For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

    The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).



309
310
311
312
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 309

class CreateDbSystemRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end