Class: Google::Cloud::OracleDatabase::V1::CreateGoldengateConnectionAssignmentRequest
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::CreateGoldengateConnectionAssignmentRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/goldengate_connection_assignment.rb
Overview
Request message for creating a GoldengateConnectionAssignment.
Instance Attribute Summary collapse
-
#goldengate_connection_assignment ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateConnectionAssignment
Required.
-
#goldengate_connection_assignment_id ⇒ ::String
Required.
-
#parent ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
Instance Attribute Details
#goldengate_connection_assignment ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateConnectionAssignment
Returns Required. The GoldengateConnectionAssignment to create.
195 196 197 198 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection_assignment.rb', line 195 class CreateGoldengateConnectionAssignmentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#goldengate_connection_assignment_id ⇒ ::String
Returns Required. The ID of the GoldengateConnectionAssignment to create.
195 196 197 198 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection_assignment.rb', line 195 class CreateGoldengateConnectionAssignmentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent resource where this GoldengateConnectionAssignment will be created. Format: projects/{project}/locations/{location}.
195 196 197 198 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection_assignment.rb', line 195 class CreateGoldengateConnectionAssignmentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
195 196 197 198 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection_assignment.rb', line 195 class CreateGoldengateConnectionAssignmentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |