Class: Google::Cloud::OracleDatabase::V1::CreateGoldengateDeploymentRequest
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::CreateGoldengateDeploymentRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb
Overview
The request for GoldengateDeployment.Create.
Instance Attribute Summary collapse
-
#goldengate_deployment ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateDeployment
Required.
-
#goldengate_deployment_id ⇒ ::String
Required.
-
#parent ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
Instance Attribute Details
#goldengate_deployment ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateDeployment
Returns Required. The resource being created.
615 616 617 618 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 615 class CreateGoldengateDeploymentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#goldengate_deployment_id ⇒ ::String
Returns Required. The ID of the GoldengateDeployment to create. This value is restricted to (^a-z?$) and must be a maximum of 63 characters in length. The value must start with a letter and end with a letter or a number.
615 616 617 618 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 615 class CreateGoldengateDeploymentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The value for parent of the GoldengateDeployment in the following format: projects/{project}/locations/{location}.
615 616 617 618 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 615 class CreateGoldengateDeploymentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
615 616 617 618 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 615 class CreateGoldengateDeploymentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |