Class: Google::Cloud::OracleDatabase::V1::DataCollectionOptionsCommon

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/common.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#is_diagnostics_events_enabled::Boolean

Returns Optional. Indicates whether to enable data collection for diagnostics.

Returns:

  • (::Boolean)

    Optional. Indicates whether to enable data collection for diagnostics.



79
80
81
82
# File 'proto_docs/google/cloud/oracledatabase/v1/common.rb', line 79

class DataCollectionOptionsCommon
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#is_health_monitoring_enabled::Boolean

Returns Optional. Indicates whether to enable health monitoring.

Returns:

  • (::Boolean)

    Optional. Indicates whether to enable health monitoring.



79
80
81
82
# File 'proto_docs/google/cloud/oracledatabase/v1/common.rb', line 79

class DataCollectionOptionsCommon
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#is_incident_logs_enabled::Boolean

Returns Optional. Indicates whether to enable incident logs and trace collection.

Returns:

  • (::Boolean)

    Optional. Indicates whether to enable incident logs and trace collection.



79
80
81
82
# File 'proto_docs/google/cloud/oracledatabase/v1/common.rb', line 79

class DataCollectionOptionsCommon
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end