Class: Google::Cloud::OracleDatabase::V1::DataCollectionOptionsDbSystem

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/db_system.rb

Overview

Data collection options for DbSystem.

Instance Attribute Summary collapse

Instance Attribute Details

#is_diagnostics_events_enabled::Boolean

Returns Optional. Indicates whether to enable data collection for diagnostics.

Returns:

  • (::Boolean)

    Optional. Indicates whether to enable data collection for diagnostics.



233
234
235
236
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 233

class DataCollectionOptionsDbSystem
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#is_incident_logs_enabled::Boolean

Returns Optional. Indicates whether to enable incident logs and trace collection.

Returns:

  • (::Boolean)

    Optional. Indicates whether to enable incident logs and trace collection.



233
234
235
236
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 233

class DataCollectionOptionsDbSystem
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end