Class: Google::Cloud::OracleDatabase::V1::DatabaseCharacterSet

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/database_character_set.rb

Overview

Details of the Database character set resource.

Defined Under Namespace

Modules: CharacterSetType

Instance Attribute Summary collapse

Instance Attribute Details

#character_set::String (readonly)

Returns Output only. The character set name for the Database which is the ID in the resource name.

Returns:

  • (::String)

    Output only. The character set name for the Database which is the ID in the resource name.



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'proto_docs/google/cloud/oracledatabase/v1/database_character_set.rb', line 37

class DatabaseCharacterSet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of character set a Database can have.
  module CharacterSetType
    # Character set type is not specified.
    CHARACTER_SET_TYPE_UNSPECIFIED = 0

    # Character set type is set to database.
    DATABASE = 1

    # Character set type is set to national.
    NATIONAL = 2
  end
end

#character_set_type::Google::Cloud::OracleDatabase::V1::DatabaseCharacterSet::CharacterSetType (readonly)

Returns Output only. The character set type for the Database.

Returns:



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'proto_docs/google/cloud/oracledatabase/v1/database_character_set.rb', line 37

class DatabaseCharacterSet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of character set a Database can have.
  module CharacterSetType
    # Character set type is not specified.
    CHARACTER_SET_TYPE_UNSPECIFIED = 0

    # Character set type is set to database.
    DATABASE = 1

    # Character set type is set to national.
    NATIONAL = 2
  end
end

#name::String

Returns Identifier. The name of the Database Character Set resource in the following format: projects/{project}/locations/{region}/databaseCharacterSets/{database_character_set}.

Returns:

  • (::String)

    Identifier. The name of the Database Character Set resource in the following format: projects/{project}/locations/{region}/databaseCharacterSets/{database_character_set}



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'proto_docs/google/cloud/oracledatabase/v1/database_character_set.rb', line 37

class DatabaseCharacterSet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of character set a Database can have.
  module CharacterSetType
    # Character set type is not specified.
    CHARACTER_SET_TYPE_UNSPECIFIED = 0

    # Character set type is set to database.
    DATABASE = 1

    # Character set type is set to national.
    NATIONAL = 2
  end
end