Class: Google::Cloud::OracleDatabase::V1::DatabaseProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/database.rb

Overview

The properties of a Database.

Defined Under Namespace

Modules: DatabaseLifecycleState

Instance Attribute Summary collapse

Instance Attribute Details

#database_management_config::Google::Cloud::OracleDatabase::V1::DatabaseManagementConfig (readonly)

Returns Output only. The Database Management config.

Returns:



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 141

class DatabaseProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Database.
  module DatabaseLifecycleState
    # Default unspecified value.
    DATABASE_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in backup in progress state.
    BACKUP_IN_PROGRESS = 4

    # Indicates that the resource is in upgrading state.
    UPGRADING = 5

    # Indicates that the resource is in converting state.
    CONVERTING = 6

    # Indicates that the resource is in terminating state.
    TERMINATING = 7

    # Indicates that the resource is in terminated state.
    TERMINATED = 8

    # Indicates that the resource is in restore failed state.
    RESTORE_FAILED = 9

    # Indicates that the resource is in failed state.
    FAILED = 10
  end
end

#db_backup_config::Google::Cloud::OracleDatabase::V1::DbBackupConfig

Returns Optional. Backup options for the Database.

Returns:



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 141

class DatabaseProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Database.
  module DatabaseLifecycleState
    # Default unspecified value.
    DATABASE_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in backup in progress state.
    BACKUP_IN_PROGRESS = 4

    # Indicates that the resource is in upgrading state.
    UPGRADING = 5

    # Indicates that the resource is in converting state.
    CONVERTING = 6

    # Indicates that the resource is in terminating state.
    TERMINATING = 7

    # Indicates that the resource is in terminated state.
    TERMINATED = 8

    # Indicates that the resource is in restore failed state.
    RESTORE_FAILED = 9

    # Indicates that the resource is in failed state.
    FAILED = 10
  end
end

#db_version::String

Returns Required. The Oracle Database version.

Returns:

  • (::String)

    Required. The Oracle Database version.



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 141

class DatabaseProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Database.
  module DatabaseLifecycleState
    # Default unspecified value.
    DATABASE_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in backup in progress state.
    BACKUP_IN_PROGRESS = 4

    # Indicates that the resource is in upgrading state.
    UPGRADING = 5

    # Indicates that the resource is in converting state.
    CONVERTING = 6

    # Indicates that the resource is in terminating state.
    TERMINATING = 7

    # Indicates that the resource is in terminated state.
    TERMINATED = 8

    # Indicates that the resource is in restore failed state.
    RESTORE_FAILED = 9

    # Indicates that the resource is in failed state.
    FAILED = 10
  end
end

#state::Google::Cloud::OracleDatabase::V1::DatabaseProperties::DatabaseLifecycleState (readonly)

Returns Output only. State of the Database.

Returns:



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 141

class DatabaseProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various lifecycle states of the Database.
  module DatabaseLifecycleState
    # Default unspecified value.
    DATABASE_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in backup in progress state.
    BACKUP_IN_PROGRESS = 4

    # Indicates that the resource is in upgrading state.
    UPGRADING = 5

    # Indicates that the resource is in converting state.
    CONVERTING = 6

    # Indicates that the resource is in terminating state.
    TERMINATING = 7

    # Indicates that the resource is in terminated state.
    TERMINATED = 8

    # Indicates that the resource is in restore failed state.
    RESTORE_FAILED = 9

    # Indicates that the resource is in failed state.
    FAILED = 10
  end
end