Module: Google::Cloud::OracleDatabase::V1::DatabaseProperties::DatabaseLifecycleState

Defined in:
proto_docs/google/cloud/oracledatabase/v1/database.rb

Overview

The various lifecycle states of the Database.

Constant Summary collapse

DATABASE_LIFECYCLE_STATE_UNSPECIFIED =

Default unspecified value.

0
PROVISIONING =

Indicates that the resource is in provisioning state.

1
AVAILABLE =

Indicates that the resource is in available state.

2
UPDATING =

Indicates that the resource is in updating state.

3
BACKUP_IN_PROGRESS =

Indicates that the resource is in backup in progress state.

4
UPGRADING =

Indicates that the resource is in upgrading state.

5
CONVERTING =

Indicates that the resource is in converting state.

6
TERMINATING =

Indicates that the resource is in terminating state.

7
TERMINATED =

Indicates that the resource is in terminated state.

8
RESTORE_FAILED =

Indicates that the resource is in restore failed state.

9
FAILED =

Indicates that the resource is in failed state.

10