Module: Google::Cloud::OracleDatabase::V1::DbBackupConfig::BackupDeletionPolicy

Defined in:
proto_docs/google/cloud/oracledatabase/v1/database.rb

Overview

This defines when the backups will be deleted after Database termination.

Constant Summary collapse

BACKUP_DELETION_POLICY_UNSPECIFIED =

Default unspecified value.

0
DELETE_IMMEDIATELY =

Keeps the backup for predefined time i.e. 72 hours and then delete permanently.

1
DELETE_AFTER_RETENTION_PERIOD =

Keeps the backups as per the policy defined for database backups.

2