Class: Google::Cloud::OracleDatabase::V1::DbSystem

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/db_system.rb

Overview

Defined Under Namespace

Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The date and time that the DbSystem was created.

Returns:



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 67

class DbSystem
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#display_name::String

Returns Required. The display name for the System db. The name does not have to be unique within your project.

Returns:

  • (::String)

    Required. The display name for the System db. The name does not have to be unique within your project.



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 67

class DbSystem
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#entitlement_id::String (readonly)

Returns Output only. The ID of the subscription entitlement associated with the DbSystem.

Returns:

  • (::String)

    Output only. The ID of the subscription entitlement associated with the DbSystem



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 67

class DbSystem
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#gcp_oracle_zone::String

Returns Optional. The GCP Oracle zone where Oracle DbSystem is hosted. Example: us-east4-b-r2. If not specified, the system will pick a zone based on availability.

Returns:

  • (::String)

    Optional. The GCP Oracle zone where Oracle DbSystem is hosted. Example: us-east4-b-r2. If not specified, the system will pick a zone based on availability.



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 67

class DbSystem
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. The labels or tags associated with the DbSystem.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. The labels or tags associated with the DbSystem.



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 67

class DbSystem
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String

Returns Identifier. The name of the DbSystem resource in the following format: projects/{project}/locations/{region}/dbSystems/{db_system}.

Returns:

  • (::String)

    Identifier. The name of the DbSystem resource in the following format: projects/{project}/locations/{region}/dbSystems/{db_system}



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 67

class DbSystem
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#oci_url::String (readonly)

Returns Output only. HTTPS link to OCI resources exposed to Customer via UI Interface.

Returns:

  • (::String)

    Output only. HTTPS link to OCI resources exposed to Customer via UI Interface.



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 67

class DbSystem
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#odb_network::String

Returns Optional. The name of the OdbNetwork associated with the DbSystem. Format: projects/{project}/locations/{location}/odbNetworks/{odb_network} It is optional but if specified, this should match the parent ODBNetwork of the OdbSubnet.

Returns:

  • (::String)

    Optional. The name of the OdbNetwork associated with the DbSystem. Format: projects/{project}/locations/{location}/odbNetworks/{odb_network} It is optional but if specified, this should match the parent ODBNetwork of the OdbSubnet.



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 67

class DbSystem
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#odb_subnet::String

Returns Required. The name of the OdbSubnet associated with the DbSystem for IP allocation. Format: projects/{project}/locations/{location}/odbNetworks/{odb_network}/odbSubnets/{odb_subnet}.

Returns:

  • (::String)

    Required. The name of the OdbSubnet associated with the DbSystem for IP allocation. Format: projects/{project}/locations/{location}/odbNetworks/{odb_network}/odbSubnets/{odb_subnet}



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 67

class DbSystem
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#properties::Google::Cloud::OracleDatabase::V1::DbSystemProperties

Returns Optional. The properties of the DbSystem.

Returns:



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 67

class DbSystem
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end