Class: Google::Cloud::OracleDatabase::V1::DbSystemProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/db_system.rb

Overview

The properties of a DbSystem.

Defined Under Namespace

Modules: ComputeModel, DbSystemDatabaseEdition, DbSystemLifecycleState, LicenseModel

Instance Attribute Summary collapse

Instance Attribute Details

#compute_count::Integer

Returns Required. The number of CPU cores to enable for the DbSystem.

Returns:

  • (::Integer)

    Required. The number of CPU cores to enable for the DbSystem.



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 146

class DbSystemProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The editions available for DbSystem.
  module DbSystemDatabaseEdition
    # The database edition is unspecified.
    DB_SYSTEM_DATABASE_EDITION_UNSPECIFIED = 0

    # The database edition is Standard.
    STANDARD_EDITION = 1

    # The database edition is Enterprise.
    ENTERPRISE_EDITION = 2

    # The database edition is Enterprise Edition.
    ENTERPRISE_EDITION_HIGH_PERFORMANCE = 3
  end

  # The license model of the DbSystem.
  module LicenseModel
    # The license model is unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # The license model is included.
    LICENSE_INCLUDED = 1

    # The license model is bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the DbSystem.
  module DbSystemLifecycleState
    # Default unspecified value.
    DB_SYSTEM_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource has been migrated.
    MIGRATED = 7

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 8

    # Indicates that the resource needs attention.
    NEEDS_ATTENTION = 9

    # Indicates that the resource is upgrading.
    UPGRADING = 10
  end

  # The compute model of the DbSystem.
  module ComputeModel
    # The compute model is unspecified.
    COMPUTE_MODEL_UNSPECIFIED = 0

    # The compute model is virtual.
    ECPU = 1

    # The compute model is physical.
    OCPU = 2
  end
end

#compute_model::Google::Cloud::OracleDatabase::V1::DbSystemProperties::ComputeModel

Returns Optional. The compute model of the DbSystem.

Returns:



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 146

class DbSystemProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The editions available for DbSystem.
  module DbSystemDatabaseEdition
    # The database edition is unspecified.
    DB_SYSTEM_DATABASE_EDITION_UNSPECIFIED = 0

    # The database edition is Standard.
    STANDARD_EDITION = 1

    # The database edition is Enterprise.
    ENTERPRISE_EDITION = 2

    # The database edition is Enterprise Edition.
    ENTERPRISE_EDITION_HIGH_PERFORMANCE = 3
  end

  # The license model of the DbSystem.
  module LicenseModel
    # The license model is unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # The license model is included.
    LICENSE_INCLUDED = 1

    # The license model is bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the DbSystem.
  module DbSystemLifecycleState
    # Default unspecified value.
    DB_SYSTEM_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource has been migrated.
    MIGRATED = 7

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 8

    # Indicates that the resource needs attention.
    NEEDS_ATTENTION = 9

    # Indicates that the resource is upgrading.
    UPGRADING = 10
  end

  # The compute model of the DbSystem.
  module ComputeModel
    # The compute model is unspecified.
    COMPUTE_MODEL_UNSPECIFIED = 0

    # The compute model is virtual.
    ECPU = 1

    # The compute model is physical.
    OCPU = 2
  end
end

#data_collection_options::Google::Cloud::OracleDatabase::V1::DataCollectionOptionsDbSystem

Returns Optional. Data collection options for diagnostics.

Returns:



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 146

class DbSystemProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The editions available for DbSystem.
  module DbSystemDatabaseEdition
    # The database edition is unspecified.
    DB_SYSTEM_DATABASE_EDITION_UNSPECIFIED = 0

    # The database edition is Standard.
    STANDARD_EDITION = 1

    # The database edition is Enterprise.
    ENTERPRISE_EDITION = 2

    # The database edition is Enterprise Edition.
    ENTERPRISE_EDITION_HIGH_PERFORMANCE = 3
  end

  # The license model of the DbSystem.
  module LicenseModel
    # The license model is unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # The license model is included.
    LICENSE_INCLUDED = 1

    # The license model is bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the DbSystem.
  module DbSystemLifecycleState
    # Default unspecified value.
    DB_SYSTEM_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource has been migrated.
    MIGRATED = 7

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 8

    # Indicates that the resource needs attention.
    NEEDS_ATTENTION = 9

    # Indicates that the resource is upgrading.
    UPGRADING = 10
  end

  # The compute model of the DbSystem.
  module ComputeModel
    # The compute model is unspecified.
    COMPUTE_MODEL_UNSPECIFIED = 0

    # The compute model is virtual.
    ECPU = 1

    # The compute model is physical.
    OCPU = 2
  end
end

#data_storage_size_gb::Integer

Returns Optional. The data storage size in GB that is currently available to DbSystems.

Returns:

  • (::Integer)

    Optional. The data storage size in GB that is currently available to DbSystems.



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 146

class DbSystemProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The editions available for DbSystem.
  module DbSystemDatabaseEdition
    # The database edition is unspecified.
    DB_SYSTEM_DATABASE_EDITION_UNSPECIFIED = 0

    # The database edition is Standard.
    STANDARD_EDITION = 1

    # The database edition is Enterprise.
    ENTERPRISE_EDITION = 2

    # The database edition is Enterprise Edition.
    ENTERPRISE_EDITION_HIGH_PERFORMANCE = 3
  end

  # The license model of the DbSystem.
  module LicenseModel
    # The license model is unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # The license model is included.
    LICENSE_INCLUDED = 1

    # The license model is bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the DbSystem.
  module DbSystemLifecycleState
    # Default unspecified value.
    DB_SYSTEM_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource has been migrated.
    MIGRATED = 7

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 8

    # Indicates that the resource needs attention.
    NEEDS_ATTENTION = 9

    # Indicates that the resource is upgrading.
    UPGRADING = 10
  end

  # The compute model of the DbSystem.
  module ComputeModel
    # The compute model is unspecified.
    COMPUTE_MODEL_UNSPECIFIED = 0

    # The compute model is virtual.
    ECPU = 1

    # The compute model is physical.
    OCPU = 2
  end
end

#database_edition::Google::Cloud::OracleDatabase::V1::DbSystemProperties::DbSystemDatabaseEdition

Returns Required. The database edition of the DbSystem.

Returns:



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 146

class DbSystemProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The editions available for DbSystem.
  module DbSystemDatabaseEdition
    # The database edition is unspecified.
    DB_SYSTEM_DATABASE_EDITION_UNSPECIFIED = 0

    # The database edition is Standard.
    STANDARD_EDITION = 1

    # The database edition is Enterprise.
    ENTERPRISE_EDITION = 2

    # The database edition is Enterprise Edition.
    ENTERPRISE_EDITION_HIGH_PERFORMANCE = 3
  end

  # The license model of the DbSystem.
  module LicenseModel
    # The license model is unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # The license model is included.
    LICENSE_INCLUDED = 1

    # The license model is bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the DbSystem.
  module DbSystemLifecycleState
    # Default unspecified value.
    DB_SYSTEM_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource has been migrated.
    MIGRATED = 7

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 8

    # Indicates that the resource needs attention.
    NEEDS_ATTENTION = 9

    # Indicates that the resource is upgrading.
    UPGRADING = 10
  end

  # The compute model of the DbSystem.
  module ComputeModel
    # The compute model is unspecified.
    COMPUTE_MODEL_UNSPECIFIED = 0

    # The compute model is virtual.
    ECPU = 1

    # The compute model is physical.
    OCPU = 2
  end
end

#db_home::Google::Cloud::OracleDatabase::V1::DbHome

Returns Optional. Details for creating a Database Home.

Returns:



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 146

class DbSystemProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The editions available for DbSystem.
  module DbSystemDatabaseEdition
    # The database edition is unspecified.
    DB_SYSTEM_DATABASE_EDITION_UNSPECIFIED = 0

    # The database edition is Standard.
    STANDARD_EDITION = 1

    # The database edition is Enterprise.
    ENTERPRISE_EDITION = 2

    # The database edition is Enterprise Edition.
    ENTERPRISE_EDITION_HIGH_PERFORMANCE = 3
  end

  # The license model of the DbSystem.
  module LicenseModel
    # The license model is unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # The license model is included.
    LICENSE_INCLUDED = 1

    # The license model is bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the DbSystem.
  module DbSystemLifecycleState
    # Default unspecified value.
    DB_SYSTEM_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource has been migrated.
    MIGRATED = 7

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 8

    # Indicates that the resource needs attention.
    NEEDS_ATTENTION = 9

    # Indicates that the resource is upgrading.
    UPGRADING = 10
  end

  # The compute model of the DbSystem.
  module ComputeModel
    # The compute model is unspecified.
    COMPUTE_MODEL_UNSPECIFIED = 0

    # The compute model is virtual.
    ECPU = 1

    # The compute model is physical.
    OCPU = 2
  end
end

#db_system_options::Google::Cloud::OracleDatabase::V1::DbSystemOptions

Returns Optional. The options for the DbSystem.

Returns:



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 146

class DbSystemProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The editions available for DbSystem.
  module DbSystemDatabaseEdition
    # The database edition is unspecified.
    DB_SYSTEM_DATABASE_EDITION_UNSPECIFIED = 0

    # The database edition is Standard.
    STANDARD_EDITION = 1

    # The database edition is Enterprise.
    ENTERPRISE_EDITION = 2

    # The database edition is Enterprise Edition.
    ENTERPRISE_EDITION_HIGH_PERFORMANCE = 3
  end

  # The license model of the DbSystem.
  module LicenseModel
    # The license model is unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # The license model is included.
    LICENSE_INCLUDED = 1

    # The license model is bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the DbSystem.
  module DbSystemLifecycleState
    # Default unspecified value.
    DB_SYSTEM_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource has been migrated.
    MIGRATED = 7

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 8

    # Indicates that the resource needs attention.
    NEEDS_ATTENTION = 9

    # Indicates that the resource is upgrading.
    UPGRADING = 10
  end

  # The compute model of the DbSystem.
  module ComputeModel
    # The compute model is unspecified.
    COMPUTE_MODEL_UNSPECIFIED = 0

    # The compute model is virtual.
    ECPU = 1

    # The compute model is physical.
    OCPU = 2
  end
end

#domain::String

Returns Optional. The host domain name of the DbSystem.

Returns:

  • (::String)

    Optional. The host domain name of the DbSystem.



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 146

class DbSystemProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The editions available for DbSystem.
  module DbSystemDatabaseEdition
    # The database edition is unspecified.
    DB_SYSTEM_DATABASE_EDITION_UNSPECIFIED = 0

    # The database edition is Standard.
    STANDARD_EDITION = 1

    # The database edition is Enterprise.
    ENTERPRISE_EDITION = 2

    # The database edition is Enterprise Edition.
    ENTERPRISE_EDITION_HIGH_PERFORMANCE = 3
  end

  # The license model of the DbSystem.
  module LicenseModel
    # The license model is unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # The license model is included.
    LICENSE_INCLUDED = 1

    # The license model is bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the DbSystem.
  module DbSystemLifecycleState
    # Default unspecified value.
    DB_SYSTEM_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource has been migrated.
    MIGRATED = 7

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 8

    # Indicates that the resource needs attention.
    NEEDS_ATTENTION = 9

    # Indicates that the resource is upgrading.
    UPGRADING = 10
  end

  # The compute model of the DbSystem.
  module ComputeModel
    # The compute model is unspecified.
    COMPUTE_MODEL_UNSPECIFIED = 0

    # The compute model is virtual.
    ECPU = 1

    # The compute model is physical.
    OCPU = 2
  end
end

#hostname::String (readonly)

Returns Output only. The hostname of the DbSystem.

Returns:

  • (::String)

    Output only. The hostname of the DbSystem.



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 146

class DbSystemProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The editions available for DbSystem.
  module DbSystemDatabaseEdition
    # The database edition is unspecified.
    DB_SYSTEM_DATABASE_EDITION_UNSPECIFIED = 0

    # The database edition is Standard.
    STANDARD_EDITION = 1

    # The database edition is Enterprise.
    ENTERPRISE_EDITION = 2

    # The database edition is Enterprise Edition.
    ENTERPRISE_EDITION_HIGH_PERFORMANCE = 3
  end

  # The license model of the DbSystem.
  module LicenseModel
    # The license model is unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # The license model is included.
    LICENSE_INCLUDED = 1

    # The license model is bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the DbSystem.
  module DbSystemLifecycleState
    # Default unspecified value.
    DB_SYSTEM_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource has been migrated.
    MIGRATED = 7

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 8

    # Indicates that the resource needs attention.
    NEEDS_ATTENTION = 9

    # Indicates that the resource is upgrading.
    UPGRADING = 10
  end

  # The compute model of the DbSystem.
  module ComputeModel
    # The compute model is unspecified.
    COMPUTE_MODEL_UNSPECIFIED = 0

    # The compute model is virtual.
    ECPU = 1

    # The compute model is physical.
    OCPU = 2
  end
end

#hostname_prefix::String

Returns Optional. Prefix for DB System host names.

Returns:

  • (::String)

    Optional. Prefix for DB System host names.



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 146

class DbSystemProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The editions available for DbSystem.
  module DbSystemDatabaseEdition
    # The database edition is unspecified.
    DB_SYSTEM_DATABASE_EDITION_UNSPECIFIED = 0

    # The database edition is Standard.
    STANDARD_EDITION = 1

    # The database edition is Enterprise.
    ENTERPRISE_EDITION = 2

    # The database edition is Enterprise Edition.
    ENTERPRISE_EDITION_HIGH_PERFORMANCE = 3
  end

  # The license model of the DbSystem.
  module LicenseModel
    # The license model is unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # The license model is included.
    LICENSE_INCLUDED = 1

    # The license model is bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the DbSystem.
  module DbSystemLifecycleState
    # Default unspecified value.
    DB_SYSTEM_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource has been migrated.
    MIGRATED = 7

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 8

    # Indicates that the resource needs attention.
    NEEDS_ATTENTION = 9

    # Indicates that the resource is upgrading.
    UPGRADING = 10
  end

  # The compute model of the DbSystem.
  module ComputeModel
    # The compute model is unspecified.
    COMPUTE_MODEL_UNSPECIFIED = 0

    # The compute model is virtual.
    ECPU = 1

    # The compute model is physical.
    OCPU = 2
  end
end

#initial_data_storage_size_gb::Integer

Returns Required. The initial data storage size in GB.

Returns:

  • (::Integer)

    Required. The initial data storage size in GB.



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 146

class DbSystemProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The editions available for DbSystem.
  module DbSystemDatabaseEdition
    # The database edition is unspecified.
    DB_SYSTEM_DATABASE_EDITION_UNSPECIFIED = 0

    # The database edition is Standard.
    STANDARD_EDITION = 1

    # The database edition is Enterprise.
    ENTERPRISE_EDITION = 2

    # The database edition is Enterprise Edition.
    ENTERPRISE_EDITION_HIGH_PERFORMANCE = 3
  end

  # The license model of the DbSystem.
  module LicenseModel
    # The license model is unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # The license model is included.
    LICENSE_INCLUDED = 1

    # The license model is bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the DbSystem.
  module DbSystemLifecycleState
    # Default unspecified value.
    DB_SYSTEM_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource has been migrated.
    MIGRATED = 7

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 8

    # Indicates that the resource needs attention.
    NEEDS_ATTENTION = 9

    # Indicates that the resource is upgrading.
    UPGRADING = 10
  end

  # The compute model of the DbSystem.
  module ComputeModel
    # The compute model is unspecified.
    COMPUTE_MODEL_UNSPECIFIED = 0

    # The compute model is virtual.
    ECPU = 1

    # The compute model is physical.
    OCPU = 2
  end
end

#license_model::Google::Cloud::OracleDatabase::V1::DbSystemProperties::LicenseModel

Returns Required. The license model of the DbSystem.

Returns:



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 146

class DbSystemProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The editions available for DbSystem.
  module DbSystemDatabaseEdition
    # The database edition is unspecified.
    DB_SYSTEM_DATABASE_EDITION_UNSPECIFIED = 0

    # The database edition is Standard.
    STANDARD_EDITION = 1

    # The database edition is Enterprise.
    ENTERPRISE_EDITION = 2

    # The database edition is Enterprise Edition.
    ENTERPRISE_EDITION_HIGH_PERFORMANCE = 3
  end

  # The license model of the DbSystem.
  module LicenseModel
    # The license model is unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # The license model is included.
    LICENSE_INCLUDED = 1

    # The license model is bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the DbSystem.
  module DbSystemLifecycleState
    # Default unspecified value.
    DB_SYSTEM_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource has been migrated.
    MIGRATED = 7

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 8

    # Indicates that the resource needs attention.
    NEEDS_ATTENTION = 9

    # Indicates that the resource is upgrading.
    UPGRADING = 10
  end

  # The compute model of the DbSystem.
  module ComputeModel
    # The compute model is unspecified.
    COMPUTE_MODEL_UNSPECIFIED = 0

    # The compute model is virtual.
    ECPU = 1

    # The compute model is physical.
    OCPU = 2
  end
end

#lifecycle_state::Google::Cloud::OracleDatabase::V1::DbSystemProperties::DbSystemLifecycleState (readonly)

Returns Output only. State of the DbSystem.

Returns:



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 146

class DbSystemProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The editions available for DbSystem.
  module DbSystemDatabaseEdition
    # The database edition is unspecified.
    DB_SYSTEM_DATABASE_EDITION_UNSPECIFIED = 0

    # The database edition is Standard.
    STANDARD_EDITION = 1

    # The database edition is Enterprise.
    ENTERPRISE_EDITION = 2

    # The database edition is Enterprise Edition.
    ENTERPRISE_EDITION_HIGH_PERFORMANCE = 3
  end

  # The license model of the DbSystem.
  module LicenseModel
    # The license model is unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # The license model is included.
    LICENSE_INCLUDED = 1

    # The license model is bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the DbSystem.
  module DbSystemLifecycleState
    # Default unspecified value.
    DB_SYSTEM_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource has been migrated.
    MIGRATED = 7

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 8

    # Indicates that the resource needs attention.
    NEEDS_ATTENTION = 9

    # Indicates that the resource is upgrading.
    UPGRADING = 10
  end

  # The compute model of the DbSystem.
  module ComputeModel
    # The compute model is unspecified.
    COMPUTE_MODEL_UNSPECIFIED = 0

    # The compute model is virtual.
    ECPU = 1

    # The compute model is physical.
    OCPU = 2
  end
end

#memory_size_gb::Integer

Returns Optional. The memory size in GB.

Returns:

  • (::Integer)

    Optional. The memory size in GB.



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 146

class DbSystemProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The editions available for DbSystem.
  module DbSystemDatabaseEdition
    # The database edition is unspecified.
    DB_SYSTEM_DATABASE_EDITION_UNSPECIFIED = 0

    # The database edition is Standard.
    STANDARD_EDITION = 1

    # The database edition is Enterprise.
    ENTERPRISE_EDITION = 2

    # The database edition is Enterprise Edition.
    ENTERPRISE_EDITION_HIGH_PERFORMANCE = 3
  end

  # The license model of the DbSystem.
  module LicenseModel
    # The license model is unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # The license model is included.
    LICENSE_INCLUDED = 1

    # The license model is bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the DbSystem.
  module DbSystemLifecycleState
    # Default unspecified value.
    DB_SYSTEM_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource has been migrated.
    MIGRATED = 7

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 8

    # Indicates that the resource needs attention.
    NEEDS_ATTENTION = 9

    # Indicates that the resource is upgrading.
    UPGRADING = 10
  end

  # The compute model of the DbSystem.
  module ComputeModel
    # The compute model is unspecified.
    COMPUTE_MODEL_UNSPECIFIED = 0

    # The compute model is virtual.
    ECPU = 1

    # The compute model is physical.
    OCPU = 2
  end
end

#node_count::Integer

Returns Optional. The number of nodes in the DbSystem.

Returns:

  • (::Integer)

    Optional. The number of nodes in the DbSystem.



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 146

class DbSystemProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The editions available for DbSystem.
  module DbSystemDatabaseEdition
    # The database edition is unspecified.
    DB_SYSTEM_DATABASE_EDITION_UNSPECIFIED = 0

    # The database edition is Standard.
    STANDARD_EDITION = 1

    # The database edition is Enterprise.
    ENTERPRISE_EDITION = 2

    # The database edition is Enterprise Edition.
    ENTERPRISE_EDITION_HIGH_PERFORMANCE = 3
  end

  # The license model of the DbSystem.
  module LicenseModel
    # The license model is unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # The license model is included.
    LICENSE_INCLUDED = 1

    # The license model is bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the DbSystem.
  module DbSystemLifecycleState
    # Default unspecified value.
    DB_SYSTEM_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource has been migrated.
    MIGRATED = 7

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 8

    # Indicates that the resource needs attention.
    NEEDS_ATTENTION = 9

    # Indicates that the resource is upgrading.
    UPGRADING = 10
  end

  # The compute model of the DbSystem.
  module ComputeModel
    # The compute model is unspecified.
    COMPUTE_MODEL_UNSPECIFIED = 0

    # The compute model is virtual.
    ECPU = 1

    # The compute model is physical.
    OCPU = 2
  end
end

#ocid::String (readonly)

Returns Output only. OCID of the DbSystem.

Returns:

  • (::String)

    Output only. OCID of the DbSystem.



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 146

class DbSystemProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The editions available for DbSystem.
  module DbSystemDatabaseEdition
    # The database edition is unspecified.
    DB_SYSTEM_DATABASE_EDITION_UNSPECIFIED = 0

    # The database edition is Standard.
    STANDARD_EDITION = 1

    # The database edition is Enterprise.
    ENTERPRISE_EDITION = 2

    # The database edition is Enterprise Edition.
    ENTERPRISE_EDITION_HIGH_PERFORMANCE = 3
  end

  # The license model of the DbSystem.
  module LicenseModel
    # The license model is unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # The license model is included.
    LICENSE_INCLUDED = 1

    # The license model is bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the DbSystem.
  module DbSystemLifecycleState
    # Default unspecified value.
    DB_SYSTEM_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource has been migrated.
    MIGRATED = 7

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 8

    # Indicates that the resource needs attention.
    NEEDS_ATTENTION = 9

    # Indicates that the resource is upgrading.
    UPGRADING = 10
  end

  # The compute model of the DbSystem.
  module ComputeModel
    # The compute model is unspecified.
    COMPUTE_MODEL_UNSPECIFIED = 0

    # The compute model is virtual.
    ECPU = 1

    # The compute model is physical.
    OCPU = 2
  end
end

#private_ip::String

Returns Optional. The private IP address of the DbSystem.

Returns:

  • (::String)

    Optional. The private IP address of the DbSystem.



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 146

class DbSystemProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The editions available for DbSystem.
  module DbSystemDatabaseEdition
    # The database edition is unspecified.
    DB_SYSTEM_DATABASE_EDITION_UNSPECIFIED = 0

    # The database edition is Standard.
    STANDARD_EDITION = 1

    # The database edition is Enterprise.
    ENTERPRISE_EDITION = 2

    # The database edition is Enterprise Edition.
    ENTERPRISE_EDITION_HIGH_PERFORMANCE = 3
  end

  # The license model of the DbSystem.
  module LicenseModel
    # The license model is unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # The license model is included.
    LICENSE_INCLUDED = 1

    # The license model is bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the DbSystem.
  module DbSystemLifecycleState
    # Default unspecified value.
    DB_SYSTEM_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource has been migrated.
    MIGRATED = 7

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 8

    # Indicates that the resource needs attention.
    NEEDS_ATTENTION = 9

    # Indicates that the resource is upgrading.
    UPGRADING = 10
  end

  # The compute model of the DbSystem.
  module ComputeModel
    # The compute model is unspecified.
    COMPUTE_MODEL_UNSPECIFIED = 0

    # The compute model is virtual.
    ECPU = 1

    # The compute model is physical.
    OCPU = 2
  end
end

#reco_storage_size_gb::Integer

Returns Optional. The reco/redo storage size in GB.

Returns:

  • (::Integer)

    Optional. The reco/redo storage size in GB.



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 146

class DbSystemProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The editions available for DbSystem.
  module DbSystemDatabaseEdition
    # The database edition is unspecified.
    DB_SYSTEM_DATABASE_EDITION_UNSPECIFIED = 0

    # The database edition is Standard.
    STANDARD_EDITION = 1

    # The database edition is Enterprise.
    ENTERPRISE_EDITION = 2

    # The database edition is Enterprise Edition.
    ENTERPRISE_EDITION_HIGH_PERFORMANCE = 3
  end

  # The license model of the DbSystem.
  module LicenseModel
    # The license model is unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # The license model is included.
    LICENSE_INCLUDED = 1

    # The license model is bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the DbSystem.
  module DbSystemLifecycleState
    # Default unspecified value.
    DB_SYSTEM_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource has been migrated.
    MIGRATED = 7

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 8

    # Indicates that the resource needs attention.
    NEEDS_ATTENTION = 9

    # Indicates that the resource is upgrading.
    UPGRADING = 10
  end

  # The compute model of the DbSystem.
  module ComputeModel
    # The compute model is unspecified.
    COMPUTE_MODEL_UNSPECIFIED = 0

    # The compute model is virtual.
    ECPU = 1

    # The compute model is physical.
    OCPU = 2
  end
end

#shape::String

Returns Required. Shape of DB System.

Returns:

  • (::String)

    Required. Shape of DB System.



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 146

class DbSystemProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The editions available for DbSystem.
  module DbSystemDatabaseEdition
    # The database edition is unspecified.
    DB_SYSTEM_DATABASE_EDITION_UNSPECIFIED = 0

    # The database edition is Standard.
    STANDARD_EDITION = 1

    # The database edition is Enterprise.
    ENTERPRISE_EDITION = 2

    # The database edition is Enterprise Edition.
    ENTERPRISE_EDITION_HIGH_PERFORMANCE = 3
  end

  # The license model of the DbSystem.
  module LicenseModel
    # The license model is unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # The license model is included.
    LICENSE_INCLUDED = 1

    # The license model is bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the DbSystem.
  module DbSystemLifecycleState
    # Default unspecified value.
    DB_SYSTEM_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource has been migrated.
    MIGRATED = 7

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 8

    # Indicates that the resource needs attention.
    NEEDS_ATTENTION = 9

    # Indicates that the resource is upgrading.
    UPGRADING = 10
  end

  # The compute model of the DbSystem.
  module ComputeModel
    # The compute model is unspecified.
    COMPUTE_MODEL_UNSPECIFIED = 0

    # The compute model is virtual.
    ECPU = 1

    # The compute model is physical.
    OCPU = 2
  end
end

#ssh_public_keys::Array<::String>

Returns Required. SSH public keys to be stored with the DbSystem.

Returns:

  • (::Array<::String>)

    Required. SSH public keys to be stored with the DbSystem.



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 146

class DbSystemProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The editions available for DbSystem.
  module DbSystemDatabaseEdition
    # The database edition is unspecified.
    DB_SYSTEM_DATABASE_EDITION_UNSPECIFIED = 0

    # The database edition is Standard.
    STANDARD_EDITION = 1

    # The database edition is Enterprise.
    ENTERPRISE_EDITION = 2

    # The database edition is Enterprise Edition.
    ENTERPRISE_EDITION_HIGH_PERFORMANCE = 3
  end

  # The license model of the DbSystem.
  module LicenseModel
    # The license model is unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # The license model is included.
    LICENSE_INCLUDED = 1

    # The license model is bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the DbSystem.
  module DbSystemLifecycleState
    # Default unspecified value.
    DB_SYSTEM_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource has been migrated.
    MIGRATED = 7

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 8

    # Indicates that the resource needs attention.
    NEEDS_ATTENTION = 9

    # Indicates that the resource is upgrading.
    UPGRADING = 10
  end

  # The compute model of the DbSystem.
  module ComputeModel
    # The compute model is unspecified.
    COMPUTE_MODEL_UNSPECIFIED = 0

    # The compute model is virtual.
    ECPU = 1

    # The compute model is physical.
    OCPU = 2
  end
end

#time_zone::Google::Type::TimeZone

Returns Optional. Time zone of the DbSystem.

Returns:



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 146

class DbSystemProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The editions available for DbSystem.
  module DbSystemDatabaseEdition
    # The database edition is unspecified.
    DB_SYSTEM_DATABASE_EDITION_UNSPECIFIED = 0

    # The database edition is Standard.
    STANDARD_EDITION = 1

    # The database edition is Enterprise.
    ENTERPRISE_EDITION = 2

    # The database edition is Enterprise Edition.
    ENTERPRISE_EDITION_HIGH_PERFORMANCE = 3
  end

  # The license model of the DbSystem.
  module LicenseModel
    # The license model is unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # The license model is included.
    LICENSE_INCLUDED = 1

    # The license model is bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the DbSystem.
  module DbSystemLifecycleState
    # Default unspecified value.
    DB_SYSTEM_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource has been migrated.
    MIGRATED = 7

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 8

    # Indicates that the resource needs attention.
    NEEDS_ATTENTION = 9

    # Indicates that the resource is upgrading.
    UPGRADING = 10
  end

  # The compute model of the DbSystem.
  module ComputeModel
    # The compute model is unspecified.
    COMPUTE_MODEL_UNSPECIFIED = 0

    # The compute model is virtual.
    ECPU = 1

    # The compute model is physical.
    OCPU = 2
  end
end