Class: Google::Cloud::OracleDatabase::V1::DeleteDbSystemRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/db_system.rb

Overview

The request for DbSystem.Delete.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The name of the DbSystem in the following format: projects/{project}/locations/{location}/dbSystems/{db_system}.

Returns:

  • (::String)

    Required. The name of the DbSystem in the following format: projects/{project}/locations/{location}/dbSystems/{db_system}.



329
330
331
332
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 329

class DeleteDbSystemRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns Optional. An optional ID to identify the request. This value is used to identify duplicate requests. If you make a request with the same request ID and the original request is still in progress or completed, the server ignores the second request. This prevents clients from accidentally creating duplicate commitments.

The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).

Returns:

  • (::String)

    Optional. An optional ID to identify the request. This value is used to identify duplicate requests. If you make a request with the same request ID and the original request is still in progress or completed, the server ignores the second request. This prevents clients from accidentally creating duplicate commitments.

    The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).



329
330
331
332
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 329

class DeleteDbSystemRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end