Class: Google::Cloud::OracleDatabase::V1::ExadbVmCluster

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb

Overview

ExadbVmCluster represents a cluster of VMs that are used to run Exadata workloads. https://docs.oracle.com/en-us/iaas/api/#/en/database/20160918/ExadbVmCluster/

Defined Under Namespace

Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#backup_odb_subnet::String

Returns Required. Immutable. The name of the backup OdbSubnet associated with the ExadbVmCluster. Format: projects/{project}/locations/{location}/odbNetworks/{odb_network}/odbSubnets/{odb_subnet}.

Returns:

  • (::String)

    Required. Immutable. The name of the backup OdbSubnet associated with the ExadbVmCluster. Format: projects/{project}/locations/{location}/odbNetworks/{odb_network}/odbSubnets/{odb_subnet}



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 72

class ExadbVmCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The date and time that the ExadbVmCluster was created.

Returns:



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 72

class ExadbVmCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#display_name::String

Returns Required. Immutable. The display name for the ExadbVmCluster. The name does not have to be unique within your project. The name must be 1-255 characters long and can only contain alphanumeric characters.

Returns:

  • (::String)

    Required. Immutable. The display name for the ExadbVmCluster. The name does not have to be unique within your project. The name must be 1-255 characters long and can only contain alphanumeric characters.



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 72

class ExadbVmCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#entitlement_id::String (readonly)

Returns Output only. The ID of the subscription entitlement associated with the ExadbVmCluster.

Returns:

  • (::String)

    Output only. The ID of the subscription entitlement associated with the ExadbVmCluster.



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 72

class ExadbVmCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#gcp_oracle_zone::String (readonly)

Returns Output only. Immutable. The GCP Oracle zone where Oracle ExadbVmCluster is hosted. Example: us-east4-b-r2. During creation, the system will pick the zone assigned to the ExascaleDbStorageVault.

Returns:

  • (::String)

    Output only. Immutable. The GCP Oracle zone where Oracle ExadbVmCluster is hosted. Example: us-east4-b-r2. During creation, the system will pick the zone assigned to the ExascaleDbStorageVault.



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 72

class ExadbVmCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. The labels or tags associated with the ExadbVmCluster.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. The labels or tags associated with the ExadbVmCluster.



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 72

class ExadbVmCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String

Returns Identifier. The name of the ExadbVmCluster resource in the following format: projects/{project}/locations/{region}/exadbVmClusters/{exadb_vm_cluster}.

Returns:

  • (::String)

    Identifier. The name of the ExadbVmCluster resource in the following format: projects/{project}/locations/{region}/exadbVmClusters/{exadb_vm_cluster}



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 72

class ExadbVmCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#odb_network::String

Returns Optional. Immutable. The name of the OdbNetwork associated with the ExadbVmCluster. Format: projects/{project}/locations/{location}/odbNetworks/{odb_network} It is optional but if specified, this should match the parent ODBNetwork of the OdbSubnet.

Returns:

  • (::String)

    Optional. Immutable. The name of the OdbNetwork associated with the ExadbVmCluster. Format: projects/{project}/locations/{location}/odbNetworks/{odb_network} It is optional but if specified, this should match the parent ODBNetwork of the OdbSubnet.



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 72

class ExadbVmCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#odb_subnet::String

Returns Required. Immutable. The name of the OdbSubnet associated with the ExadbVmCluster for IP allocation. Format: projects/{project}/locations/{location}/odbNetworks/{odb_network}/odbSubnets/{odb_subnet}.

Returns:

  • (::String)

    Required. Immutable. The name of the OdbSubnet associated with the ExadbVmCluster for IP allocation. Format: projects/{project}/locations/{location}/odbNetworks/{odb_network}/odbSubnets/{odb_subnet}



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 72

class ExadbVmCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#properties::Google::Cloud::OracleDatabase::V1::ExadbVmClusterProperties

Returns Required. The properties of the ExadbVmCluster.

Returns:



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 72

class ExadbVmCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end