Class: Google::Cloud::OracleDatabase::V1::ExadbVmClusterProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb

Overview

The properties of an ExadbVmCluster.

Defined Under Namespace

Modules: ExadbVmClusterLifecycleState, LicenseModel, ShapeAttribute

Instance Attribute Summary collapse

Instance Attribute Details

#additional_ecpu_count_per_node::Integer

Returns Optional. Immutable. The number of additional ECPUs per node for an Exadata VM cluster on exascale infrastructure.

Returns:

  • (::Integer)

    Optional. Immutable. The number of additional ECPUs per node for an Exadata VM cluster on exascale infrastructure.



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 169

class ExadbVmClusterProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The Oracle license model that applies to the ExaScale VM cluster
  module LicenseModel
    # Unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # Default is license included.
    LICENSE_INCLUDED = 1

    # Bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the VM cluster.
  module ExadbVmClusterLifecycleState
    # Default unspecified value.
    EXADB_VM_CLUSTER_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 7
  end

  # The shape attribute of the VM cluster. The type of Exascale storage used
  # for Exadata VM cluster. The default is SMART_STORAGE which supports Oracle
  # Database 23ai and later
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end

#cluster_name::String

Returns Optional. Immutable. The cluster name for Exascale vm cluster. The cluster name must begin with an alphabetic character and may contain hyphens(-) but can not contain underscores(_). It should be not more than 11 characters and is not case sensitive. OCI Cluster name.

Returns:

  • (::String)

    Optional. Immutable. The cluster name for Exascale vm cluster. The cluster name must begin with an alphabetic character and may contain hyphens(-) but can not contain underscores(_). It should be not more than 11 characters and is not case sensitive. OCI Cluster name.



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 169

class ExadbVmClusterProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The Oracle license model that applies to the ExaScale VM cluster
  module LicenseModel
    # Unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # Default is license included.
    LICENSE_INCLUDED = 1

    # Bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the VM cluster.
  module ExadbVmClusterLifecycleState
    # Default unspecified value.
    EXADB_VM_CLUSTER_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 7
  end

  # The shape attribute of the VM cluster. The type of Exascale storage used
  # for Exadata VM cluster. The default is SMART_STORAGE which supports Oracle
  # Database 23ai and later
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end

#data_collection_options::Google::Cloud::OracleDatabase::V1::DataCollectionOptionsCommon

Returns Optional. Immutable. Indicates user preference for data collection options.

Returns:



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 169

class ExadbVmClusterProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The Oracle license model that applies to the ExaScale VM cluster
  module LicenseModel
    # Unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # Default is license included.
    LICENSE_INCLUDED = 1

    # Bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the VM cluster.
  module ExadbVmClusterLifecycleState
    # Default unspecified value.
    EXADB_VM_CLUSTER_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 7
  end

  # The shape attribute of the VM cluster. The type of Exascale storage used
  # for Exadata VM cluster. The default is SMART_STORAGE which supports Oracle
  # Database 23ai and later
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end

#enabled_ecpu_count_per_node::Integer

Returns Required. Immutable. The number of ECPUs enabled per node for an exadata vm cluster on exascale infrastructure.

Returns:

  • (::Integer)

    Required. Immutable. The number of ECPUs enabled per node for an exadata vm cluster on exascale infrastructure.



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 169

class ExadbVmClusterProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The Oracle license model that applies to the ExaScale VM cluster
  module LicenseModel
    # Unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # Default is license included.
    LICENSE_INCLUDED = 1

    # Bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the VM cluster.
  module ExadbVmClusterLifecycleState
    # Default unspecified value.
    EXADB_VM_CLUSTER_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 7
  end

  # The shape attribute of the VM cluster. The type of Exascale storage used
  # for Exadata VM cluster. The default is SMART_STORAGE which supports Oracle
  # Database 23ai and later
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end

#exascale_db_storage_vault::String

Returns Required. Immutable. The name of ExascaleDbStorageVault associated with the ExadbVmCluster. It can refer to an existing ExascaleDbStorageVault. Or a new one can be created during the ExadbVmCluster creation (requires storage_vault_properties to be set). Format: projects/{project}/locations/{location}/exascaleDbStorageVaults/{exascale_db_storage_vault}.

Returns:

  • (::String)

    Required. Immutable. The name of ExascaleDbStorageVault associated with the ExadbVmCluster. It can refer to an existing ExascaleDbStorageVault. Or a new one can be created during the ExadbVmCluster creation (requires storage_vault_properties to be set). Format: projects/{project}/locations/{location}/exascaleDbStorageVaults/{exascale_db_storage_vault}



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 169

class ExadbVmClusterProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The Oracle license model that applies to the ExaScale VM cluster
  module LicenseModel
    # Unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # Default is license included.
    LICENSE_INCLUDED = 1

    # Bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the VM cluster.
  module ExadbVmClusterLifecycleState
    # Default unspecified value.
    EXADB_VM_CLUSTER_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 7
  end

  # The shape attribute of the VM cluster. The type of Exascale storage used
  # for Exadata VM cluster. The default is SMART_STORAGE which supports Oracle
  # Database 23ai and later
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end

#gi_version::String (readonly)

Returns Output only. The Oracle Grid Infrastructure (GI) software version.

Returns:

  • (::String)

    Output only. The Oracle Grid Infrastructure (GI) software version.



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 169

class ExadbVmClusterProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The Oracle license model that applies to the ExaScale VM cluster
  module LicenseModel
    # Unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # Default is license included.
    LICENSE_INCLUDED = 1

    # Bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the VM cluster.
  module ExadbVmClusterLifecycleState
    # Default unspecified value.
    EXADB_VM_CLUSTER_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 7
  end

  # The shape attribute of the VM cluster. The type of Exascale storage used
  # for Exadata VM cluster. The default is SMART_STORAGE which supports Oracle
  # Database 23ai and later
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end

#grid_image_id::String

Returns Required. Immutable. Grid Infrastructure Version.

Returns:

  • (::String)

    Required. Immutable. Grid Infrastructure Version.



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 169

class ExadbVmClusterProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The Oracle license model that applies to the ExaScale VM cluster
  module LicenseModel
    # Unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # Default is license included.
    LICENSE_INCLUDED = 1

    # Bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the VM cluster.
  module ExadbVmClusterLifecycleState
    # Default unspecified value.
    EXADB_VM_CLUSTER_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 7
  end

  # The shape attribute of the VM cluster. The type of Exascale storage used
  # for Exadata VM cluster. The default is SMART_STORAGE which supports Oracle
  # Database 23ai and later
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end

#hostname::String (readonly)

Returns Output only. The hostname of the ExadbVmCluster.

Returns:

  • (::String)

    Output only. The hostname of the ExadbVmCluster.



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 169

class ExadbVmClusterProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The Oracle license model that applies to the ExaScale VM cluster
  module LicenseModel
    # Unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # Default is license included.
    LICENSE_INCLUDED = 1

    # Bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the VM cluster.
  module ExadbVmClusterLifecycleState
    # Default unspecified value.
    EXADB_VM_CLUSTER_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 7
  end

  # The shape attribute of the VM cluster. The type of Exascale storage used
  # for Exadata VM cluster. The default is SMART_STORAGE which supports Oracle
  # Database 23ai and later
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end

#hostname_prefix::String

Returns Required. Immutable. Prefix for VM cluster host names.

Returns:

  • (::String)

    Required. Immutable. Prefix for VM cluster host names.



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 169

class ExadbVmClusterProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The Oracle license model that applies to the ExaScale VM cluster
  module LicenseModel
    # Unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # Default is license included.
    LICENSE_INCLUDED = 1

    # Bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the VM cluster.
  module ExadbVmClusterLifecycleState
    # Default unspecified value.
    EXADB_VM_CLUSTER_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 7
  end

  # The shape attribute of the VM cluster. The type of Exascale storage used
  # for Exadata VM cluster. The default is SMART_STORAGE which supports Oracle
  # Database 23ai and later
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end

#license_model::Google::Cloud::OracleDatabase::V1::ExadbVmClusterProperties::LicenseModel

Returns Optional. Immutable. The license type of the ExadbVmCluster.

Returns:



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 169

class ExadbVmClusterProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The Oracle license model that applies to the ExaScale VM cluster
  module LicenseModel
    # Unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # Default is license included.
    LICENSE_INCLUDED = 1

    # Bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the VM cluster.
  module ExadbVmClusterLifecycleState
    # Default unspecified value.
    EXADB_VM_CLUSTER_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 7
  end

  # The shape attribute of the VM cluster. The type of Exascale storage used
  # for Exadata VM cluster. The default is SMART_STORAGE which supports Oracle
  # Database 23ai and later
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end

#lifecycle_state::Google::Cloud::OracleDatabase::V1::ExadbVmClusterProperties::ExadbVmClusterLifecycleState (readonly)

Returns Output only. State of the cluster.



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 169

class ExadbVmClusterProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The Oracle license model that applies to the ExaScale VM cluster
  module LicenseModel
    # Unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # Default is license included.
    LICENSE_INCLUDED = 1

    # Bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the VM cluster.
  module ExadbVmClusterLifecycleState
    # Default unspecified value.
    EXADB_VM_CLUSTER_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 7
  end

  # The shape attribute of the VM cluster. The type of Exascale storage used
  # for Exadata VM cluster. The default is SMART_STORAGE which supports Oracle
  # Database 23ai and later
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end

#memory_size_gb::Integer (readonly)

Returns Output only. Memory per VM (GB) (Read-only): Shows the amount of memory allocated to each VM. Memory is calculated based on 2.75 GB per Total ECPUs.

Returns:

  • (::Integer)

    Output only. Memory per VM (GB) (Read-only): Shows the amount of memory allocated to each VM. Memory is calculated based on 2.75 GB per Total ECPUs.



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 169

class ExadbVmClusterProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The Oracle license model that applies to the ExaScale VM cluster
  module LicenseModel
    # Unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # Default is license included.
    LICENSE_INCLUDED = 1

    # Bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the VM cluster.
  module ExadbVmClusterLifecycleState
    # Default unspecified value.
    EXADB_VM_CLUSTER_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 7
  end

  # The shape attribute of the VM cluster. The type of Exascale storage used
  # for Exadata VM cluster. The default is SMART_STORAGE which supports Oracle
  # Database 23ai and later
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end

#node_count::Integer

Returns Required. The number of nodes/VMs in the ExadbVmCluster.

Returns:

  • (::Integer)

    Required. The number of nodes/VMs in the ExadbVmCluster.



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 169

class ExadbVmClusterProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The Oracle license model that applies to the ExaScale VM cluster
  module LicenseModel
    # Unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # Default is license included.
    LICENSE_INCLUDED = 1

    # Bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the VM cluster.
  module ExadbVmClusterLifecycleState
    # Default unspecified value.
    EXADB_VM_CLUSTER_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 7
  end

  # The shape attribute of the VM cluster. The type of Exascale storage used
  # for Exadata VM cluster. The default is SMART_STORAGE which supports Oracle
  # Database 23ai and later
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end

#oci_uri::String (readonly)

Returns Output only. Deep link to the OCI console to view this resource.

Returns:

  • (::String)

    Output only. Deep link to the OCI console to view this resource.



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 169

class ExadbVmClusterProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The Oracle license model that applies to the ExaScale VM cluster
  module LicenseModel
    # Unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # Default is license included.
    LICENSE_INCLUDED = 1

    # Bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the VM cluster.
  module ExadbVmClusterLifecycleState
    # Default unspecified value.
    EXADB_VM_CLUSTER_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 7
  end

  # The shape attribute of the VM cluster. The type of Exascale storage used
  # for Exadata VM cluster. The default is SMART_STORAGE which supports Oracle
  # Database 23ai and later
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end

#scan_listener_port_tcp::Integer

Returns Optional. Immutable. SCAN listener port - TCP.

Returns:

  • (::Integer)

    Optional. Immutable. SCAN listener port - TCP



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 169

class ExadbVmClusterProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The Oracle license model that applies to the ExaScale VM cluster
  module LicenseModel
    # Unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # Default is license included.
    LICENSE_INCLUDED = 1

    # Bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the VM cluster.
  module ExadbVmClusterLifecycleState
    # Default unspecified value.
    EXADB_VM_CLUSTER_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 7
  end

  # The shape attribute of the VM cluster. The type of Exascale storage used
  # for Exadata VM cluster. The default is SMART_STORAGE which supports Oracle
  # Database 23ai and later
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end

#shape_attribute::Google::Cloud::OracleDatabase::V1::ExadbVmClusterProperties::ShapeAttribute

Returns Required. Immutable. The shape attribute of the VM cluster. The type of Exascale storage used for Exadata VM cluster. The default is SMART_STORAGE which supports Oracle Database 23ai and later.

Returns:



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 169

class ExadbVmClusterProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The Oracle license model that applies to the ExaScale VM cluster
  module LicenseModel
    # Unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # Default is license included.
    LICENSE_INCLUDED = 1

    # Bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the VM cluster.
  module ExadbVmClusterLifecycleState
    # Default unspecified value.
    EXADB_VM_CLUSTER_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 7
  end

  # The shape attribute of the VM cluster. The type of Exascale storage used
  # for Exadata VM cluster. The default is SMART_STORAGE which supports Oracle
  # Database 23ai and later
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end

#ssh_public_keys::Array<::String>

Returns Required. Immutable. The SSH public keys for the ExadbVmCluster.

Returns:

  • (::Array<::String>)

    Required. Immutable. The SSH public keys for the ExadbVmCluster.



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 169

class ExadbVmClusterProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The Oracle license model that applies to the ExaScale VM cluster
  module LicenseModel
    # Unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # Default is license included.
    LICENSE_INCLUDED = 1

    # Bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the VM cluster.
  module ExadbVmClusterLifecycleState
    # Default unspecified value.
    EXADB_VM_CLUSTER_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 7
  end

  # The shape attribute of the VM cluster. The type of Exascale storage used
  # for Exadata VM cluster. The default is SMART_STORAGE which supports Oracle
  # Database 23ai and later
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end

#time_zone::Google::Type::TimeZone

Returns Optional. Immutable. The time zone of the ExadbVmCluster.

Returns:



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 169

class ExadbVmClusterProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The Oracle license model that applies to the ExaScale VM cluster
  module LicenseModel
    # Unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # Default is license included.
    LICENSE_INCLUDED = 1

    # Bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the VM cluster.
  module ExadbVmClusterLifecycleState
    # Default unspecified value.
    EXADB_VM_CLUSTER_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 7
  end

  # The shape attribute of the VM cluster. The type of Exascale storage used
  # for Exadata VM cluster. The default is SMART_STORAGE which supports Oracle
  # Database 23ai and later
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end

#vm_file_system_storage::Google::Cloud::OracleDatabase::V1::ExadbVmClusterStorageDetails

Returns Required. Immutable. Total storage details for the ExadbVmCluster.

Returns:



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 169

class ExadbVmClusterProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The Oracle license model that applies to the ExaScale VM cluster
  module LicenseModel
    # Unspecified.
    LICENSE_MODEL_UNSPECIFIED = 0

    # Default is license included.
    LICENSE_INCLUDED = 1

    # Bring your own license.
    BRING_YOUR_OWN_LICENSE = 2
  end

  # The various lifecycle states of the VM cluster.
  module ExadbVmClusterLifecycleState
    # Default unspecified value.
    EXADB_VM_CLUSTER_LIFECYCLE_STATE_UNSPECIFIED = 0

    # Indicates that the resource is in provisioning state.
    PROVISIONING = 1

    # Indicates that the resource is in available state.
    AVAILABLE = 2

    # Indicates that the resource is in updating state.
    UPDATING = 3

    # Indicates that the resource is in terminating state.
    TERMINATING = 4

    # Indicates that the resource is in terminated state.
    TERMINATED = 5

    # Indicates that the resource is in failed state.
    FAILED = 6

    # Indicates that the resource is in maintenance in progress state.
    MAINTENANCE_IN_PROGRESS = 7
  end

  # The shape attribute of the VM cluster. The type of Exascale storage used
  # for Exadata VM cluster. The default is SMART_STORAGE which supports Oracle
  # Database 23ai and later
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end