Class: Google::Cloud::OracleDatabase::V1::ExascaleDbStorageVaultProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/exascale_db_storage_vault.rb

Overview

The properties of the ExascaleDbStorageVault. next ID: 12

Defined Under Namespace

Modules: ShapeAttribute, State

Instance Attribute Summary collapse

Instance Attribute Details

#additional_flash_cache_percent::Integer

Returns Optional. The size of additional flash cache in percentage of high capacity database storage.

Returns:

  • (::Integer)

    Optional. The size of additional flash cache in percentage of high capacity database storage.



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'proto_docs/google/cloud/oracledatabase/v1/exascale_db_storage_vault.rb', line 108

class ExascaleDbStorageVaultProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the ExascaleDbStorageVault.
  module State
    # The state of the ExascaleDbStorageVault is unspecified.
    STATE_UNSPECIFIED = 0

    # The ExascaleDbStorageVault is being provisioned.
    PROVISIONING = 1

    # The ExascaleDbStorageVault is available.
    AVAILABLE = 2

    # The ExascaleDbStorageVault is being updated.
    UPDATING = 3

    # The ExascaleDbStorageVault is being deleted.
    TERMINATING = 4

    # The ExascaleDbStorageVault has been deleted.
    TERMINATED = 5

    # The ExascaleDbStorageVault has failed.
    FAILED = 6
  end

  # The shape attribute of the VM clusters attached to the
  # ExascaleDbStorageVault.
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end

#attached_shape_attributes::Array<::Google::Cloud::OracleDatabase::V1::ExascaleDbStorageVaultProperties::ShapeAttribute> (readonly)

Returns Output only. The shape attributes of the VM clusters attached to the ExascaleDbStorageVault.

Returns:



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'proto_docs/google/cloud/oracledatabase/v1/exascale_db_storage_vault.rb', line 108

class ExascaleDbStorageVaultProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the ExascaleDbStorageVault.
  module State
    # The state of the ExascaleDbStorageVault is unspecified.
    STATE_UNSPECIFIED = 0

    # The ExascaleDbStorageVault is being provisioned.
    PROVISIONING = 1

    # The ExascaleDbStorageVault is available.
    AVAILABLE = 2

    # The ExascaleDbStorageVault is being updated.
    UPDATING = 3

    # The ExascaleDbStorageVault is being deleted.
    TERMINATING = 4

    # The ExascaleDbStorageVault has been deleted.
    TERMINATED = 5

    # The ExascaleDbStorageVault has failed.
    FAILED = 6
  end

  # The shape attribute of the VM clusters attached to the
  # ExascaleDbStorageVault.
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end

#available_shape_attributes::Array<::Google::Cloud::OracleDatabase::V1::ExascaleDbStorageVaultProperties::ShapeAttribute> (readonly)

Returns Output only. The shape attributes available for the VM clusters to be attached to the ExascaleDbStorageVault.

Returns:



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'proto_docs/google/cloud/oracledatabase/v1/exascale_db_storage_vault.rb', line 108

class ExascaleDbStorageVaultProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the ExascaleDbStorageVault.
  module State
    # The state of the ExascaleDbStorageVault is unspecified.
    STATE_UNSPECIFIED = 0

    # The ExascaleDbStorageVault is being provisioned.
    PROVISIONING = 1

    # The ExascaleDbStorageVault is available.
    AVAILABLE = 2

    # The ExascaleDbStorageVault is being updated.
    UPDATING = 3

    # The ExascaleDbStorageVault is being deleted.
    TERMINATING = 4

    # The ExascaleDbStorageVault has been deleted.
    TERMINATED = 5

    # The ExascaleDbStorageVault has failed.
    FAILED = 6
  end

  # The shape attribute of the VM clusters attached to the
  # ExascaleDbStorageVault.
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end

#description::String

Returns Optional. The description of the ExascaleDbStorageVault.

Returns:

  • (::String)

    Optional. The description of the ExascaleDbStorageVault.



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'proto_docs/google/cloud/oracledatabase/v1/exascale_db_storage_vault.rb', line 108

class ExascaleDbStorageVaultProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the ExascaleDbStorageVault.
  module State
    # The state of the ExascaleDbStorageVault is unspecified.
    STATE_UNSPECIFIED = 0

    # The ExascaleDbStorageVault is being provisioned.
    PROVISIONING = 1

    # The ExascaleDbStorageVault is available.
    AVAILABLE = 2

    # The ExascaleDbStorageVault is being updated.
    UPDATING = 3

    # The ExascaleDbStorageVault is being deleted.
    TERMINATING = 4

    # The ExascaleDbStorageVault has been deleted.
    TERMINATED = 5

    # The ExascaleDbStorageVault has failed.
    FAILED = 6
  end

  # The shape attribute of the VM clusters attached to the
  # ExascaleDbStorageVault.
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end

#exascale_db_storage_details::Google::Cloud::OracleDatabase::V1::ExascaleDbStorageDetails

Returns Required. The storage details of the ExascaleDbStorageVault.

Returns:



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'proto_docs/google/cloud/oracledatabase/v1/exascale_db_storage_vault.rb', line 108

class ExascaleDbStorageVaultProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the ExascaleDbStorageVault.
  module State
    # The state of the ExascaleDbStorageVault is unspecified.
    STATE_UNSPECIFIED = 0

    # The ExascaleDbStorageVault is being provisioned.
    PROVISIONING = 1

    # The ExascaleDbStorageVault is available.
    AVAILABLE = 2

    # The ExascaleDbStorageVault is being updated.
    UPDATING = 3

    # The ExascaleDbStorageVault is being deleted.
    TERMINATING = 4

    # The ExascaleDbStorageVault has been deleted.
    TERMINATED = 5

    # The ExascaleDbStorageVault has failed.
    FAILED = 6
  end

  # The shape attribute of the VM clusters attached to the
  # ExascaleDbStorageVault.
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end

#oci_uri::String (readonly)

Returns Output only. Deep link to the OCI console to view this resource.

Returns:

  • (::String)

    Output only. Deep link to the OCI console to view this resource.



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'proto_docs/google/cloud/oracledatabase/v1/exascale_db_storage_vault.rb', line 108

class ExascaleDbStorageVaultProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the ExascaleDbStorageVault.
  module State
    # The state of the ExascaleDbStorageVault is unspecified.
    STATE_UNSPECIFIED = 0

    # The ExascaleDbStorageVault is being provisioned.
    PROVISIONING = 1

    # The ExascaleDbStorageVault is available.
    AVAILABLE = 2

    # The ExascaleDbStorageVault is being updated.
    UPDATING = 3

    # The ExascaleDbStorageVault is being deleted.
    TERMINATING = 4

    # The ExascaleDbStorageVault has been deleted.
    TERMINATED = 5

    # The ExascaleDbStorageVault has failed.
    FAILED = 6
  end

  # The shape attribute of the VM clusters attached to the
  # ExascaleDbStorageVault.
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end

#ocid::String (readonly)

Returns Output only. The OCID for the ExascaleDbStorageVault.

Returns:

  • (::String)

    Output only. The OCID for the ExascaleDbStorageVault.



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'proto_docs/google/cloud/oracledatabase/v1/exascale_db_storage_vault.rb', line 108

class ExascaleDbStorageVaultProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the ExascaleDbStorageVault.
  module State
    # The state of the ExascaleDbStorageVault is unspecified.
    STATE_UNSPECIFIED = 0

    # The ExascaleDbStorageVault is being provisioned.
    PROVISIONING = 1

    # The ExascaleDbStorageVault is available.
    AVAILABLE = 2

    # The ExascaleDbStorageVault is being updated.
    UPDATING = 3

    # The ExascaleDbStorageVault is being deleted.
    TERMINATING = 4

    # The ExascaleDbStorageVault has been deleted.
    TERMINATED = 5

    # The ExascaleDbStorageVault has failed.
    FAILED = 6
  end

  # The shape attribute of the VM clusters attached to the
  # ExascaleDbStorageVault.
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end

#state::Google::Cloud::OracleDatabase::V1::ExascaleDbStorageVaultProperties::State (readonly)

Returns Output only. The state of the ExascaleDbStorageVault.

Returns:



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'proto_docs/google/cloud/oracledatabase/v1/exascale_db_storage_vault.rb', line 108

class ExascaleDbStorageVaultProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the ExascaleDbStorageVault.
  module State
    # The state of the ExascaleDbStorageVault is unspecified.
    STATE_UNSPECIFIED = 0

    # The ExascaleDbStorageVault is being provisioned.
    PROVISIONING = 1

    # The ExascaleDbStorageVault is available.
    AVAILABLE = 2

    # The ExascaleDbStorageVault is being updated.
    UPDATING = 3

    # The ExascaleDbStorageVault is being deleted.
    TERMINATING = 4

    # The ExascaleDbStorageVault has been deleted.
    TERMINATED = 5

    # The ExascaleDbStorageVault has failed.
    FAILED = 6
  end

  # The shape attribute of the VM clusters attached to the
  # ExascaleDbStorageVault.
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end

#time_zone::Google::Type::TimeZone (readonly)

Returns Output only. The time zone of the ExascaleDbStorageVault.

Returns:



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'proto_docs/google/cloud/oracledatabase/v1/exascale_db_storage_vault.rb', line 108

class ExascaleDbStorageVaultProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the ExascaleDbStorageVault.
  module State
    # The state of the ExascaleDbStorageVault is unspecified.
    STATE_UNSPECIFIED = 0

    # The ExascaleDbStorageVault is being provisioned.
    PROVISIONING = 1

    # The ExascaleDbStorageVault is available.
    AVAILABLE = 2

    # The ExascaleDbStorageVault is being updated.
    UPDATING = 3

    # The ExascaleDbStorageVault is being deleted.
    TERMINATING = 4

    # The ExascaleDbStorageVault has been deleted.
    TERMINATED = 5

    # The ExascaleDbStorageVault has failed.
    FAILED = 6
  end

  # The shape attribute of the VM clusters attached to the
  # ExascaleDbStorageVault.
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end

#vm_cluster_count::Integer (readonly)

Returns Output only. The number of VM clusters associated with the ExascaleDbStorageVault.

Returns:

  • (::Integer)

    Output only. The number of VM clusters associated with the ExascaleDbStorageVault.



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'proto_docs/google/cloud/oracledatabase/v1/exascale_db_storage_vault.rb', line 108

class ExascaleDbStorageVaultProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the ExascaleDbStorageVault.
  module State
    # The state of the ExascaleDbStorageVault is unspecified.
    STATE_UNSPECIFIED = 0

    # The ExascaleDbStorageVault is being provisioned.
    PROVISIONING = 1

    # The ExascaleDbStorageVault is available.
    AVAILABLE = 2

    # The ExascaleDbStorageVault is being updated.
    UPDATING = 3

    # The ExascaleDbStorageVault is being deleted.
    TERMINATING = 4

    # The ExascaleDbStorageVault has been deleted.
    TERMINATED = 5

    # The ExascaleDbStorageVault has failed.
    FAILED = 6
  end

  # The shape attribute of the VM clusters attached to the
  # ExascaleDbStorageVault.
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end

#vm_cluster_ids::Array<::String> (readonly)

Returns Output only. The list of VM cluster OCIDs associated with the ExascaleDbStorageVault.

Returns:

  • (::Array<::String>)

    Output only. The list of VM cluster OCIDs associated with the ExascaleDbStorageVault.



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'proto_docs/google/cloud/oracledatabase/v1/exascale_db_storage_vault.rb', line 108

class ExascaleDbStorageVaultProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the ExascaleDbStorageVault.
  module State
    # The state of the ExascaleDbStorageVault is unspecified.
    STATE_UNSPECIFIED = 0

    # The ExascaleDbStorageVault is being provisioned.
    PROVISIONING = 1

    # The ExascaleDbStorageVault is available.
    AVAILABLE = 2

    # The ExascaleDbStorageVault is being updated.
    UPDATING = 3

    # The ExascaleDbStorageVault is being deleted.
    TERMINATING = 4

    # The ExascaleDbStorageVault has been deleted.
    TERMINATED = 5

    # The ExascaleDbStorageVault has failed.
    FAILED = 6
  end

  # The shape attribute of the VM clusters attached to the
  # ExascaleDbStorageVault.
  module ShapeAttribute
    # Default unspecified value.
    SHAPE_ATTRIBUTE_UNSPECIFIED = 0

    # Indicates that the resource is in smart storage.
    SMART_STORAGE = 1

    # Indicates that the resource is in block storage.
    BLOCK_STORAGE = 2
  end
end