Class: Google::Cloud::OracleDatabase::V1::FailoverAutonomousDatabaseRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb

Overview

The request for OracleDatabase.FailoverAutonomousDatabase.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The name of the Autonomous Database in the following format: projects/{project}/locations/{location}/autonomousDatabases/{autonomous_database}.

Returns:

  • (::String)

    Required. The name of the Autonomous Database in the following format: projects/{project}/locations/{location}/autonomousDatabases/{autonomous_database}.



619
620
621
622
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 619

class FailoverAutonomousDatabaseRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#peer_autonomous_database::String

Returns Optional. The peer database name to fail over to. Required for cross-region standby, and must be omitted for in-region Data Guard.

Returns:

  • (::String)

    Optional. The peer database name to fail over to. Required for cross-region standby, and must be omitted for in-region Data Guard.



619
620
621
622
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 619

class FailoverAutonomousDatabaseRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end