Class: Google::Cloud::OracleDatabase::V1::GetDatabaseRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/database.rb

Overview

The request for Database.Get.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The name of the Database resource in the following format: projects/{project}/locations/{region}/databases/{database}.

Returns:

  • (::String)

    Required. The name of the Database resource in the following format: projects/{project}/locations/{region}/databases/{database}



307
308
309
310
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 307

class GetDatabaseRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end