Class: Google::Cloud::OracleDatabase::V1::GoldengateAzureSynapseAnalyticsConnectionProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb

Overview

The properties of GoldengateAzureSynapseAnalyticsConnection.

Instance Attribute Summary collapse

Instance Attribute Details

#connection_string::String

Returns Optional. JDBC connection string. e.g.: 'jdbc:sqlserver://.sql.azuresynapse.net:1433;database=;encrypt=true;trustServerCertificate=false;hostNameInCertificate=*.sql.azuresynapse.net;loginTimeout=300;'.

Returns:

  • (::String)

    Optional. JDBC connection string. e.g.: 'jdbc:sqlserver://.sql.azuresynapse.net:1433;database=;encrypt=true;trustServerCertificate=false;hostNameInCertificate=*.sql.azuresynapse.net;loginTimeout=300;'



963
964
965
966
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 963

class GoldengateAzureSynapseAnalyticsConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#password::String

Returns Optional. Input only. The password Oracle Goldengate uses for Azure Synapse Analytics connection in plain text.

Note: The following fields are mutually exclusive: password, password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The password Oracle Goldengate uses for Azure Synapse Analytics connection in plain text.

    Note: The following fields are mutually exclusive: password, password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.



963
964
965
966
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 963

class GoldengateAzureSynapseAnalyticsConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#password_secret_version::String

Returns Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses for Azure Synapse Analytics connection. Format: projects/{project}/secrets/{secret}/versions/{version}.

Note: The following fields are mutually exclusive: password_secret_version, password. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses for Azure Synapse Analytics connection. Format: projects/{project}/secrets/{secret}/versions/{version}.

    Note: The following fields are mutually exclusive: password_secret_version, password. If a field in that set is populated, all other fields in the set will automatically be cleared.



963
964
965
966
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 963

class GoldengateAzureSynapseAnalyticsConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#technology_type::String

Returns Optional. The technology type of AzureSynapseAnalyticsConnection.

Returns:

  • (::String)

    Optional. The technology type of AzureSynapseAnalyticsConnection.



963
964
965
966
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 963

class GoldengateAzureSynapseAnalyticsConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#username::String

Returns Optional. The username Oracle Goldengate uses to connect the associated system of the given technology.

Returns:

  • (::String)

    Optional. The username Oracle Goldengate uses to connect the associated system of the given technology.



963
964
965
966
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 963

class GoldengateAzureSynapseAnalyticsConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end