Class: Google::Cloud::OracleDatabase::V1::GoldengateConnection

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb

Overview

Details of the GoldengateConnection resource.

Defined Under Namespace

Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The date and time that the GoldengateConnection was created.

Returns:



64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 64

class GoldengateConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#entitlement_id::String (readonly)

Returns Output only. The ID of the subscription entitlement associated with the GoldengateConnection.

Returns:

  • (::String)

    Output only. The ID of the subscription entitlement associated with the GoldengateConnection.



64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 64

class GoldengateConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#gcp_oracle_zone::String

Returns Optional. The GCP Oracle zone where Oracle GoldengateConnection is hosted. Example: us-east4-b-r2. If not specified, the system will pick a zone based on availability.

Returns:

  • (::String)

    Optional. The GCP Oracle zone where Oracle GoldengateConnection is hosted. Example: us-east4-b-r2. If not specified, the system will pick a zone based on availability.



64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 64

class GoldengateConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. The labels or tags associated with the GoldengateConnection.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. The labels or tags associated with the GoldengateConnection.



64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 64

class GoldengateConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String

Returns Identifier. The name of the GoldengateConnection resource in the following format: projects/{project}/locations/{region}/goldengateConnections/{goldengate_connection}.

Returns:

  • (::String)

    Identifier. The name of the GoldengateConnection resource in the following format: projects/{project}/locations/{region}/goldengateConnections/{goldengate_connection}



64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 64

class GoldengateConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#oci_url::String (readonly)

Returns Output only. HTTPS link to OCI resources exposed to Customer via UI Interface.

Returns:

  • (::String)

    Output only. HTTPS link to OCI resources exposed to Customer via UI Interface.



64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 64

class GoldengateConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#odb_network::String

Returns Optional. The name of the OdbNetwork associated with the GoldengateConnection. The format is projects/{project}/locations/{location}/odbNetworks/{odb_network}. It is optional but if specified, this should match the parent ODBNetwork of the OdbSubnet.

Returns:

  • (::String)

    Optional. The name of the OdbNetwork associated with the GoldengateConnection. The format is projects/{project}/locations/{location}/odbNetworks/{odb_network}. It is optional but if specified, this should match the parent ODBNetwork of the OdbSubnet.



64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 64

class GoldengateConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#odb_subnet::String

Returns Optional. The name of the OdbSubnet associated with the GoldengateConnection for IP allocation. Format: projects/{project}/locations/{location}/odbNetworks/{odb_network}/odbSubnets/{odb_subnet}.

Returns:

  • (::String)

    Optional. The name of the OdbSubnet associated with the GoldengateConnection for IP allocation. Format: projects/{project}/locations/{location}/odbNetworks/{odb_network}/odbSubnets/{odb_subnet}



64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 64

class GoldengateConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#properties::Google::Cloud::OracleDatabase::V1::GoldengateConnectionProperties

Returns Required. The properties of the GoldengateConnection.

Returns:



64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 64

class GoldengateConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end