Class: Google::Cloud::OracleDatabase::V1::GoldengateDeploymentVersionProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_version.rb

Overview

Properties of GoldengateDeploymentVersion.

Defined Under Namespace

Modules: DeploymentReleaseType, DeploymentType

Instance Attribute Summary collapse

Instance Attribute Details

#deployment_type::Google::Cloud::OracleDatabase::V1::GoldengateDeploymentVersionProperties::DeploymentType (readonly)

Returns Output only. The deployment type of the Goldengate Deployment Version resource.

Returns:



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_version.rb', line 67

class GoldengateDeploymentVersionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The deployment type of the Goldengate Deployment Version resource.
  module DeploymentType
    # Default unspecified value.
    DEPLOYMENT_TYPE_UNSPECIFIED = 0

    # Goldengate Deployment Type category is OGG.
    OGG = 1

    # Goldengate Deployment Type category is DATABASE_ORACLE.
    DATABASE_ORACLE = 2

    # Goldengate Deployment Type category is BIGDATA.
    BIGDATA = 3

    # Goldengate Deployment Type category is DATABASE_MICROSOFT_SQLSERVER.
    DATABASE_MICROSOFT_SQLSERVER = 4

    # Goldengate Deployment Type category is DATABASE_MYSQL.
    DATABASE_MYSQL = 5

    # Goldengate Deployment Type category is DATABASE_POSTGRESQL.
    DATABASE_POSTGRESQL = 6

    # Goldengate Deployment Type category is DATABASE_DB2ZOS.
    DATABASE_DB2ZOS = 7

    # Goldengate Deployment Type category is DATABASE_DB2I.
    DATABASE_DB2I = 8

    # Goldengate Deployment Type category is GGSA.
    GGSA = 9

    # Goldengate Deployment Type category is DATA_TRANSFORMS.
    DATA_TRANSFORMS = 10
  end

  # The release type of the Goldengate Deployment Version resource.
  module DeploymentReleaseType
    # Default unspecified value.
    DEPLOYMENT_RELEASE_TYPE_UNSPECIFIED = 0

    # Goldengate Deployment Version release type is MAJOR.
    MAJOR = 1

    # Goldengate Deployment Version release type is BUNDLE.
    BUNDLE = 2

    # Goldengate Deployment Version release type is MINOR.
    MINOR = 3
  end
end

#ogg_version::String (readonly)

Returns Output only. The OGG version of the Goldengate Deployment Version resource.

Returns:

  • (::String)

    Output only. The OGG version of the Goldengate Deployment Version resource.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_version.rb', line 67

class GoldengateDeploymentVersionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The deployment type of the Goldengate Deployment Version resource.
  module DeploymentType
    # Default unspecified value.
    DEPLOYMENT_TYPE_UNSPECIFIED = 0

    # Goldengate Deployment Type category is OGG.
    OGG = 1

    # Goldengate Deployment Type category is DATABASE_ORACLE.
    DATABASE_ORACLE = 2

    # Goldengate Deployment Type category is BIGDATA.
    BIGDATA = 3

    # Goldengate Deployment Type category is DATABASE_MICROSOFT_SQLSERVER.
    DATABASE_MICROSOFT_SQLSERVER = 4

    # Goldengate Deployment Type category is DATABASE_MYSQL.
    DATABASE_MYSQL = 5

    # Goldengate Deployment Type category is DATABASE_POSTGRESQL.
    DATABASE_POSTGRESQL = 6

    # Goldengate Deployment Type category is DATABASE_DB2ZOS.
    DATABASE_DB2ZOS = 7

    # Goldengate Deployment Type category is DATABASE_DB2I.
    DATABASE_DB2I = 8

    # Goldengate Deployment Type category is GGSA.
    GGSA = 9

    # Goldengate Deployment Type category is DATA_TRANSFORMS.
    DATA_TRANSFORMS = 10
  end

  # The release type of the Goldengate Deployment Version resource.
  module DeploymentReleaseType
    # Default unspecified value.
    DEPLOYMENT_RELEASE_TYPE_UNSPECIFIED = 0

    # Goldengate Deployment Version release type is MAJOR.
    MAJOR = 1

    # Goldengate Deployment Version release type is BUNDLE.
    BUNDLE = 2

    # Goldengate Deployment Version release type is MINOR.
    MINOR = 3
  end
end

#release_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The release time of the Goldengate Deployment Version resource.

Returns:



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_version.rb', line 67

class GoldengateDeploymentVersionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The deployment type of the Goldengate Deployment Version resource.
  module DeploymentType
    # Default unspecified value.
    DEPLOYMENT_TYPE_UNSPECIFIED = 0

    # Goldengate Deployment Type category is OGG.
    OGG = 1

    # Goldengate Deployment Type category is DATABASE_ORACLE.
    DATABASE_ORACLE = 2

    # Goldengate Deployment Type category is BIGDATA.
    BIGDATA = 3

    # Goldengate Deployment Type category is DATABASE_MICROSOFT_SQLSERVER.
    DATABASE_MICROSOFT_SQLSERVER = 4

    # Goldengate Deployment Type category is DATABASE_MYSQL.
    DATABASE_MYSQL = 5

    # Goldengate Deployment Type category is DATABASE_POSTGRESQL.
    DATABASE_POSTGRESQL = 6

    # Goldengate Deployment Type category is DATABASE_DB2ZOS.
    DATABASE_DB2ZOS = 7

    # Goldengate Deployment Type category is DATABASE_DB2I.
    DATABASE_DB2I = 8

    # Goldengate Deployment Type category is GGSA.
    GGSA = 9

    # Goldengate Deployment Type category is DATA_TRANSFORMS.
    DATA_TRANSFORMS = 10
  end

  # The release type of the Goldengate Deployment Version resource.
  module DeploymentReleaseType
    # Default unspecified value.
    DEPLOYMENT_RELEASE_TYPE_UNSPECIFIED = 0

    # Goldengate Deployment Version release type is MAJOR.
    MAJOR = 1

    # Goldengate Deployment Version release type is BUNDLE.
    BUNDLE = 2

    # Goldengate Deployment Version release type is MINOR.
    MINOR = 3
  end
end

#release_type::Google::Cloud::OracleDatabase::V1::GoldengateDeploymentVersionProperties::DeploymentReleaseType (readonly)

Returns Output only. The release type of the Goldengate Deployment Version resource.

Returns:



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_version.rb', line 67

class GoldengateDeploymentVersionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The deployment type of the Goldengate Deployment Version resource.
  module DeploymentType
    # Default unspecified value.
    DEPLOYMENT_TYPE_UNSPECIFIED = 0

    # Goldengate Deployment Type category is OGG.
    OGG = 1

    # Goldengate Deployment Type category is DATABASE_ORACLE.
    DATABASE_ORACLE = 2

    # Goldengate Deployment Type category is BIGDATA.
    BIGDATA = 3

    # Goldengate Deployment Type category is DATABASE_MICROSOFT_SQLSERVER.
    DATABASE_MICROSOFT_SQLSERVER = 4

    # Goldengate Deployment Type category is DATABASE_MYSQL.
    DATABASE_MYSQL = 5

    # Goldengate Deployment Type category is DATABASE_POSTGRESQL.
    DATABASE_POSTGRESQL = 6

    # Goldengate Deployment Type category is DATABASE_DB2ZOS.
    DATABASE_DB2ZOS = 7

    # Goldengate Deployment Type category is DATABASE_DB2I.
    DATABASE_DB2I = 8

    # Goldengate Deployment Type category is GGSA.
    GGSA = 9

    # Goldengate Deployment Type category is DATA_TRANSFORMS.
    DATA_TRANSFORMS = 10
  end

  # The release type of the Goldengate Deployment Version resource.
  module DeploymentReleaseType
    # Default unspecified value.
    DEPLOYMENT_RELEASE_TYPE_UNSPECIFIED = 0

    # Goldengate Deployment Version release type is MAJOR.
    MAJOR = 1

    # Goldengate Deployment Version release type is BUNDLE.
    BUNDLE = 2

    # Goldengate Deployment Version release type is MINOR.
    MINOR = 3
  end
end

#security_fix::Boolean

Returns Optional. Whether the Goldengate Deployment Version resource is a security fix.

Returns:

  • (::Boolean)

    Optional. Whether the Goldengate Deployment Version resource is a security fix.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_version.rb', line 67

class GoldengateDeploymentVersionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The deployment type of the Goldengate Deployment Version resource.
  module DeploymentType
    # Default unspecified value.
    DEPLOYMENT_TYPE_UNSPECIFIED = 0

    # Goldengate Deployment Type category is OGG.
    OGG = 1

    # Goldengate Deployment Type category is DATABASE_ORACLE.
    DATABASE_ORACLE = 2

    # Goldengate Deployment Type category is BIGDATA.
    BIGDATA = 3

    # Goldengate Deployment Type category is DATABASE_MICROSOFT_SQLSERVER.
    DATABASE_MICROSOFT_SQLSERVER = 4

    # Goldengate Deployment Type category is DATABASE_MYSQL.
    DATABASE_MYSQL = 5

    # Goldengate Deployment Type category is DATABASE_POSTGRESQL.
    DATABASE_POSTGRESQL = 6

    # Goldengate Deployment Type category is DATABASE_DB2ZOS.
    DATABASE_DB2ZOS = 7

    # Goldengate Deployment Type category is DATABASE_DB2I.
    DATABASE_DB2I = 8

    # Goldengate Deployment Type category is GGSA.
    GGSA = 9

    # Goldengate Deployment Type category is DATA_TRANSFORMS.
    DATA_TRANSFORMS = 10
  end

  # The release type of the Goldengate Deployment Version resource.
  module DeploymentReleaseType
    # Default unspecified value.
    DEPLOYMENT_RELEASE_TYPE_UNSPECIFIED = 0

    # Goldengate Deployment Version release type is MAJOR.
    MAJOR = 1

    # Goldengate Deployment Version release type is BUNDLE.
    BUNDLE = 2

    # Goldengate Deployment Version release type is MINOR.
    MINOR = 3
  end
end

#support_end_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The support end time of the Goldengate Deployment Version resource.

Returns:



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_version.rb', line 67

class GoldengateDeploymentVersionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The deployment type of the Goldengate Deployment Version resource.
  module DeploymentType
    # Default unspecified value.
    DEPLOYMENT_TYPE_UNSPECIFIED = 0

    # Goldengate Deployment Type category is OGG.
    OGG = 1

    # Goldengate Deployment Type category is DATABASE_ORACLE.
    DATABASE_ORACLE = 2

    # Goldengate Deployment Type category is BIGDATA.
    BIGDATA = 3

    # Goldengate Deployment Type category is DATABASE_MICROSOFT_SQLSERVER.
    DATABASE_MICROSOFT_SQLSERVER = 4

    # Goldengate Deployment Type category is DATABASE_MYSQL.
    DATABASE_MYSQL = 5

    # Goldengate Deployment Type category is DATABASE_POSTGRESQL.
    DATABASE_POSTGRESQL = 6

    # Goldengate Deployment Type category is DATABASE_DB2ZOS.
    DATABASE_DB2ZOS = 7

    # Goldengate Deployment Type category is DATABASE_DB2I.
    DATABASE_DB2I = 8

    # Goldengate Deployment Type category is GGSA.
    GGSA = 9

    # Goldengate Deployment Type category is DATA_TRANSFORMS.
    DATA_TRANSFORMS = 10
  end

  # The release type of the Goldengate Deployment Version resource.
  module DeploymentReleaseType
    # Default unspecified value.
    DEPLOYMENT_RELEASE_TYPE_UNSPECIFIED = 0

    # Goldengate Deployment Version release type is MAJOR.
    MAJOR = 1

    # Goldengate Deployment Version release type is BUNDLE.
    BUNDLE = 2

    # Goldengate Deployment Version release type is MINOR.
    MINOR = 3
  end
end