Class: Google::Cloud::OracleDatabase::V1::GoldengateElasticsearchConnectionProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb

Overview

The properties of GoldengateElasticsearchConnection.

Defined Under Namespace

Modules: ElasticsearchAuthenticationType, ElasticsearchSecurityProtocol

Instance Attribute Summary collapse

Instance Attribute Details

#authentication_type::Google::Cloud::OracleDatabase::V1::GoldengateElasticsearchConnectionProperties::ElasticsearchAuthenticationType

Returns Optional. Authentication type for Elasticsearch.



1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1523

class GoldengateElasticsearchConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security protocol for Elasticsearch.
  module ElasticsearchSecurityProtocol
    # Security protocol not specified.
    ELASTICSEARCH_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2
  end

  # Enum for Authentication type for Elasticsearch.
  module ElasticsearchAuthenticationType
    # Authentication type not specified.
    ELASTICSEARCH_AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # No authentication.
    NONE = 1

    # Basic authentication.
    BASIC = 2
  end
end

#fingerprint::String

Returns Optional. Fingerprint required by TLS security protocol. Eg.: '6152b2dfbff200f973c5074a5b91d06ab3b472c07c09a1ea57bb7fd406cdce9c'.

Returns:

  • (::String)

    Optional. Fingerprint required by TLS security protocol. Eg.: '6152b2dfbff200f973c5074a5b91d06ab3b472c07c09a1ea57bb7fd406cdce9c'



1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1523

class GoldengateElasticsearchConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security protocol for Elasticsearch.
  module ElasticsearchSecurityProtocol
    # Security protocol not specified.
    ELASTICSEARCH_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2
  end

  # Enum for Authentication type for Elasticsearch.
  module ElasticsearchAuthenticationType
    # Authentication type not specified.
    ELASTICSEARCH_AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # No authentication.
    NONE = 1

    # Basic authentication.
    BASIC = 2
  end
end

#password::String

Returns Optional. Input only. The password Oracle Goldengate uses for Elastic Search connection in plain text.

Note: The following fields are mutually exclusive: password, password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The password Oracle Goldengate uses for Elastic Search connection in plain text.

    Note: The following fields are mutually exclusive: password, password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.



1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1523

class GoldengateElasticsearchConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security protocol for Elasticsearch.
  module ElasticsearchSecurityProtocol
    # Security protocol not specified.
    ELASTICSEARCH_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2
  end

  # Enum for Authentication type for Elasticsearch.
  module ElasticsearchAuthenticationType
    # Authentication type not specified.
    ELASTICSEARCH_AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # No authentication.
    NONE = 1

    # Basic authentication.
    BASIC = 2
  end
end

#password_secret_version::String

Returns Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses for Elastic Search connection. Format: projects/{project}/secrets/{secret}/versions/{version}.

Note: The following fields are mutually exclusive: password_secret_version, password. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses for Elastic Search connection. Format: projects/{project}/secrets/{secret}/versions/{version}.

    Note: The following fields are mutually exclusive: password_secret_version, password. If a field in that set is populated, all other fields in the set will automatically be cleared.



1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1523

class GoldengateElasticsearchConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security protocol for Elasticsearch.
  module ElasticsearchSecurityProtocol
    # Security protocol not specified.
    ELASTICSEARCH_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2
  end

  # Enum for Authentication type for Elasticsearch.
  module ElasticsearchAuthenticationType
    # Authentication type not specified.
    ELASTICSEARCH_AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # No authentication.
    NONE = 1

    # Basic authentication.
    BASIC = 2
  end
end

#security_protocol::Google::Cloud::OracleDatabase::V1::GoldengateElasticsearchConnectionProperties::ElasticsearchSecurityProtocol

Returns Optional. Security protocol for Elasticsearch.



1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1523

class GoldengateElasticsearchConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security protocol for Elasticsearch.
  module ElasticsearchSecurityProtocol
    # Security protocol not specified.
    ELASTICSEARCH_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2
  end

  # Enum for Authentication type for Elasticsearch.
  module ElasticsearchAuthenticationType
    # Authentication type not specified.
    ELASTICSEARCH_AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # No authentication.
    NONE = 1

    # Basic authentication.
    BASIC = 2
  end
end

#servers::String

Returns Optional. Comma separated list of Elasticsearch server addresses, specified as host:port entries, where :port is optional. If port is not specified, it defaults to 9200. Example: "server1.example.com:4000,server2.example.com:4000".

Returns:

  • (::String)

    Optional. Comma separated list of Elasticsearch server addresses, specified as host:port entries, where :port is optional. If port is not specified, it defaults to 9200. Example: "server1.example.com:4000,server2.example.com:4000"



1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1523

class GoldengateElasticsearchConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security protocol for Elasticsearch.
  module ElasticsearchSecurityProtocol
    # Security protocol not specified.
    ELASTICSEARCH_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2
  end

  # Enum for Authentication type for Elasticsearch.
  module ElasticsearchAuthenticationType
    # Authentication type not specified.
    ELASTICSEARCH_AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # No authentication.
    NONE = 1

    # Basic authentication.
    BASIC = 2
  end
end

#technology_type::String

Returns Optional. The technology type of ElasticsearchConnection.

Returns:

  • (::String)

    Optional. The technology type of ElasticsearchConnection.



1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1523

class GoldengateElasticsearchConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security protocol for Elasticsearch.
  module ElasticsearchSecurityProtocol
    # Security protocol not specified.
    ELASTICSEARCH_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2
  end

  # Enum for Authentication type for Elasticsearch.
  module ElasticsearchAuthenticationType
    # Authentication type not specified.
    ELASTICSEARCH_AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # No authentication.
    NONE = 1

    # Basic authentication.
    BASIC = 2
  end
end

#username::String

Returns Optional. The username Oracle Goldengate uses to connect the associated system of the given technology.

Returns:

  • (::String)

    Optional. The username Oracle Goldengate uses to connect the associated system of the given technology.



1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1523

class GoldengateElasticsearchConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security protocol for Elasticsearch.
  module ElasticsearchSecurityProtocol
    # Security protocol not specified.
    ELASTICSEARCH_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2
  end

  # Enum for Authentication type for Elasticsearch.
  module ElasticsearchAuthenticationType
    # Authentication type not specified.
    ELASTICSEARCH_AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # No authentication.
    NONE = 1

    # Basic authentication.
    BASIC = 2
  end
end