Class: Google::Cloud::OracleDatabase::V1::GoldengateGoldengateConnectionProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb

Overview

The properties of GoldengateGoldengateConnectionProperties.

Instance Attribute Summary collapse

Instance Attribute Details

#goldengate_deployment_id::String

Returns Optional. The name of the GoldengateDeployment associated with the GoldengateConnection. Format: projects/{project}/locations/{location}/goldengateDeployments/{goldengate_deployment}.

Returns:

  • (::String)

    Optional. The name of the GoldengateDeployment associated with the GoldengateConnection. Format: projects/{project}/locations/{location}/goldengateDeployments/{goldengate_deployment}



492
493
494
495
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 492

class GoldengateGoldengateConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#host::String

Returns Optional. The host of the GoldengateConnection.

Returns:

  • (::String)

    Optional. The host of the GoldengateConnection.



492
493
494
495
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 492

class GoldengateGoldengateConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#password::String

Returns Optional. Input only. The password used to connect to the Oracle Goldengate in plain text.

Note: The following fields are mutually exclusive: password, password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The password used to connect to the Oracle Goldengate in plain text.

    Note: The following fields are mutually exclusive: password, password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.



492
493
494
495
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 492

class GoldengateGoldengateConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#password_secret_version::String

Returns Optional. Input only. The resource name of a secret version in Secret Manager which contains the password used to connect to the Oracle Goldengate. Format: projects/{project}/secrets/{secret}/versions/{version}.

Note: The following fields are mutually exclusive: password_secret_version, password. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The resource name of a secret version in Secret Manager which contains the password used to connect to the Oracle Goldengate. Format: projects/{project}/secrets/{secret}/versions/{version}.

    Note: The following fields are mutually exclusive: password_secret_version, password. If a field in that set is populated, all other fields in the set will automatically be cleared.



492
493
494
495
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 492

class GoldengateGoldengateConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#port::Integer

Returns Optional. The port of the GoldengateConnection.

Returns:

  • (::Integer)

    Optional. The port of the GoldengateConnection.



492
493
494
495
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 492

class GoldengateGoldengateConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#technology_type::String

Returns Optional. The technology type.

Returns:

  • (::String)

    Optional. The technology type.



492
493
494
495
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 492

class GoldengateGoldengateConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#username::String

Returns Optional. The username credential.

Returns:

  • (::String)

    Optional. The username credential.



492
493
494
495
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 492

class GoldengateGoldengateConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end