Class: Google::Cloud::OracleDatabase::V1::GoldengateGoogleBigQueryConnectionProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb

Overview

The properties of GoldengateGoogleBigQueryConnectionProperties.

Instance Attribute Summary collapse

Instance Attribute Details

#service_account_key_file::String

Returns Optional. The base64 encoded content of the service account key file containing the credentials required to use Google BigQuery.

Returns:

  • (::String)

    Optional. The base64 encoded content of the service account key file containing the credentials required to use Google BigQuery.



530
531
532
533
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 530

class GoldengateGoogleBigQueryConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#technology_type::String

Returns Optional. The technology type.

Returns:

  • (::String)

    Optional. The technology type.



530
531
532
533
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 530

class GoldengateGoogleBigQueryConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end