Class: Google::Cloud::OracleDatabase::V1::GoldengateGooglePubsubConnectionProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb

Overview

The properties of GoldengateGooglePubsubConnection.

Instance Attribute Summary collapse

Instance Attribute Details

#service_account_key_file::String

Returns Optional. The base64 encoded content of the service account key file containing the credentials required to use Google Pub/Sub.

Returns:

  • (::String)

    Optional. The base64 encoded content of the service account key file containing the credentials required to use Google Pub/Sub.



1805
1806
1807
1808
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1805

class GoldengateGooglePubsubConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#technology_type::String

Returns Optional. The technology type of GooglePubsubConnection.

Returns:

  • (::String)

    Optional. The technology type of GooglePubsubConnection.



1805
1806
1807
1808
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1805

class GoldengateGooglePubsubConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end