Class: Google::Cloud::OracleDatabase::V1::GoldengateHdfsConnectionProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb

Overview

The properties of GoldengateHdfsConnection.

Instance Attribute Summary collapse

Instance Attribute Details

#core_site_xml::String

Returns Optional. The content of the Hadoop Distributed File System configuration file (core-site.xml).

Returns:

  • (::String)

    Optional. The content of the Hadoop Distributed File System configuration file (core-site.xml).



1156
1157
1158
1159
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1156

class GoldengateHdfsConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#technology_type::String

Returns Optional. The technology type of HdfsConnection.

Returns:

  • (::String)

    Optional. The technology type of HdfsConnection.



1156
1157
1158
1159
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1156

class GoldengateHdfsConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end