Class: Google::Cloud::OracleDatabase::V1::GoldengateKafkaConnectionProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb

Overview

The properties of GoldengateKafkaConnection.

Defined Under Namespace

Modules: KafkaSecurityProtocol

Instance Attribute Summary collapse

Instance Attribute Details

#bootstrap_servers::Array<::Google::Cloud::OracleDatabase::V1::KafkaBootstrapServer>

Returns Optional. Kafka bootstrap. Equivalent of bootstrap.servers configuration property in Kafka: list of KafkaBootstrapServer objects specified by host/port. Used for establishing the initial connection to the Kafka cluster. Example: "server1.example.com:9092,server2.example.com:9092".

Returns:

  • (::Array<::Google::Cloud::OracleDatabase::V1::KafkaBootstrapServer>)

    Optional. Kafka bootstrap. Equivalent of bootstrap.servers configuration property in Kafka: list of KafkaBootstrapServer objects specified by host/port. Used for establishing the initial connection to the Kafka cluster. Example: "server1.example.com:9092,server2.example.com:9092"



725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 725

class GoldengateKafkaConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Kafka.
  module KafkaSecurityProtocol
    # Security type not specified.
    KAFKA_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # SSL security protocol.
    SSL = 1

    # SASL SSL security protocol.
    SASL_SSL = 2

    # Plaintext security protocol.
    PLAINTEXT = 3

    # SASL Plaintext security protocol.
    SASL_PLAINTEXT = 4
  end
end

#cluster_id::String

Returns Optional. The OCID of the Kafka cluster being referenced from OCI Streaming with Apache Kafka.

Returns:

  • (::String)

    Optional. The OCID of the Kafka cluster being referenced from OCI Streaming with Apache Kafka.



725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 725

class GoldengateKafkaConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Kafka.
  module KafkaSecurityProtocol
    # Security type not specified.
    KAFKA_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # SSL security protocol.
    SSL = 1

    # SASL SSL security protocol.
    SASL_SSL = 2

    # Plaintext security protocol.
    PLAINTEXT = 3

    # SASL Plaintext security protocol.
    SASL_PLAINTEXT = 4
  end
end

#consumer_properties_file::String

Returns Optional. The base64 encoded content of the consumer.properties file.

Returns:

  • (::String)

    Optional. The base64 encoded content of the consumer.properties file.



725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 725

class GoldengateKafkaConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Kafka.
  module KafkaSecurityProtocol
    # Security type not specified.
    KAFKA_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # SSL security protocol.
    SSL = 1

    # SASL SSL security protocol.
    SASL_SSL = 2

    # Plaintext security protocol.
    PLAINTEXT = 3

    # SASL Plaintext security protocol.
    SASL_PLAINTEXT = 4
  end
end

#key_store_file::String

Returns Optional. The base64 encoded content of the KeyStore file.

Returns:

  • (::String)

    Optional. The base64 encoded content of the KeyStore file.



725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 725

class GoldengateKafkaConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Kafka.
  module KafkaSecurityProtocol
    # Security type not specified.
    KAFKA_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # SSL security protocol.
    SSL = 1

    # SASL SSL security protocol.
    SASL_SSL = 2

    # Plaintext security protocol.
    PLAINTEXT = 3

    # SASL Plaintext security protocol.
    SASL_PLAINTEXT = 4
  end
end

#key_store_password::String

Returns Optional. Input only. The KeyStore password in plain text.

Note: The following fields are mutually exclusive: key_store_password, key_store_password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The KeyStore password in plain text.

    Note: The following fields are mutually exclusive: key_store_password, key_store_password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.



725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 725

class GoldengateKafkaConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Kafka.
  module KafkaSecurityProtocol
    # Security type not specified.
    KAFKA_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # SSL security protocol.
    SSL = 1

    # SASL SSL security protocol.
    SASL_SSL = 2

    # Plaintext security protocol.
    PLAINTEXT = 3

    # SASL Plaintext security protocol.
    SASL_PLAINTEXT = 4
  end
end

#key_store_password_secret_version::String

Returns Optional. Input only. The resource name of a secret version in Secret Manager which contains the KeyStore password. Format: projects/{project}/secrets/{secret}/versions/{version}.

Note: The following fields are mutually exclusive: key_store_password_secret_version, key_store_password. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The resource name of a secret version in Secret Manager which contains the KeyStore password. Format: projects/{project}/secrets/{secret}/versions/{version}.

    Note: The following fields are mutually exclusive: key_store_password_secret_version, key_store_password. If a field in that set is populated, all other fields in the set will automatically be cleared.



725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 725

class GoldengateKafkaConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Kafka.
  module KafkaSecurityProtocol
    # Security type not specified.
    KAFKA_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # SSL security protocol.
    SSL = 1

    # SASL SSL security protocol.
    SASL_SSL = 2

    # Plaintext security protocol.
    PLAINTEXT = 3

    # SASL Plaintext security protocol.
    SASL_PLAINTEXT = 4
  end
end

#password::String

Returns Optional. Input only. The password for Kafka basic/SASL auth in plain text.

Note: The following fields are mutually exclusive: password, password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The password for Kafka basic/SASL auth in plain text.

    Note: The following fields are mutually exclusive: password, password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.



725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 725

class GoldengateKafkaConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Kafka.
  module KafkaSecurityProtocol
    # Security type not specified.
    KAFKA_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # SSL security protocol.
    SSL = 1

    # SASL SSL security protocol.
    SASL_SSL = 2

    # Plaintext security protocol.
    PLAINTEXT = 3

    # SASL Plaintext security protocol.
    SASL_PLAINTEXT = 4
  end
end

#password_secret_version::String

Returns Optional. Input only. The resource name of a secret version in Secret Manager which contains the password for Kafka basic/SASL auth. Format: projects/{project}/secrets/{secret}/versions/{version}.

Note: The following fields are mutually exclusive: password_secret_version, password. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The resource name of a secret version in Secret Manager which contains the password for Kafka basic/SASL auth. Format: projects/{project}/secrets/{secret}/versions/{version}.

    Note: The following fields are mutually exclusive: password_secret_version, password. If a field in that set is populated, all other fields in the set will automatically be cleared.



725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 725

class GoldengateKafkaConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Kafka.
  module KafkaSecurityProtocol
    # Security type not specified.
    KAFKA_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # SSL security protocol.
    SSL = 1

    # SASL SSL security protocol.
    SASL_SSL = 2

    # Plaintext security protocol.
    PLAINTEXT = 3

    # SASL Plaintext security protocol.
    SASL_PLAINTEXT = 4
  end
end

#producer_properties_file::String

Returns Optional. The base64 encoded content of the producer.properties file.

Returns:

  • (::String)

    Optional. The base64 encoded content of the producer.properties file.



725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 725

class GoldengateKafkaConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Kafka.
  module KafkaSecurityProtocol
    # Security type not specified.
    KAFKA_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # SSL security protocol.
    SSL = 1

    # SASL SSL security protocol.
    SASL_SSL = 2

    # Plaintext security protocol.
    PLAINTEXT = 3

    # SASL Plaintext security protocol.
    SASL_PLAINTEXT = 4
  end
end

#security_protocol::Google::Cloud::OracleDatabase::V1::GoldengateKafkaConnectionProperties::KafkaSecurityProtocol

Returns Optional. Security Type for Kafka.



725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 725

class GoldengateKafkaConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Kafka.
  module KafkaSecurityProtocol
    # Security type not specified.
    KAFKA_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # SSL security protocol.
    SSL = 1

    # SASL SSL security protocol.
    SASL_SSL = 2

    # Plaintext security protocol.
    PLAINTEXT = 3

    # SASL Plaintext security protocol.
    SASL_PLAINTEXT = 4
  end
end

#ssl_key_password::String

Returns Optional. Input only. The password for the cert inside of the KeyStore in plain text.

Note: The following fields are mutually exclusive: ssl_key_password, ssl_key_password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The password for the cert inside of the KeyStore in plain text.

    Note: The following fields are mutually exclusive: ssl_key_password, ssl_key_password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.



725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 725

class GoldengateKafkaConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Kafka.
  module KafkaSecurityProtocol
    # Security type not specified.
    KAFKA_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # SSL security protocol.
    SSL = 1

    # SASL SSL security protocol.
    SASL_SSL = 2

    # Plaintext security protocol.
    PLAINTEXT = 3

    # SASL Plaintext security protocol.
    SASL_PLAINTEXT = 4
  end
end

#ssl_key_password_secret_version::String

Returns Optional. Input only. The resource name of a secret version in Secret Manager which contains the password for the cert inside of the KeyStore. Format: projects/{project}/secrets/{secret}/versions/{version}.

Note: The following fields are mutually exclusive: ssl_key_password_secret_version, ssl_key_password. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The resource name of a secret version in Secret Manager which contains the password for the cert inside of the KeyStore. Format: projects/{project}/secrets/{secret}/versions/{version}.

    Note: The following fields are mutually exclusive: ssl_key_password_secret_version, ssl_key_password. If a field in that set is populated, all other fields in the set will automatically be cleared.



725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 725

class GoldengateKafkaConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Kafka.
  module KafkaSecurityProtocol
    # Security type not specified.
    KAFKA_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # SSL security protocol.
    SSL = 1

    # SASL SSL security protocol.
    SASL_SSL = 2

    # Plaintext security protocol.
    PLAINTEXT = 3

    # SASL Plaintext security protocol.
    SASL_PLAINTEXT = 4
  end
end

#stream_pool_id::String

Returns Optional. The OCID of the stream pool being referenced.

Returns:

  • (::String)

    Optional. The OCID of the stream pool being referenced.



725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 725

class GoldengateKafkaConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Kafka.
  module KafkaSecurityProtocol
    # Security type not specified.
    KAFKA_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # SSL security protocol.
    SSL = 1

    # SASL SSL security protocol.
    SASL_SSL = 2

    # Plaintext security protocol.
    PLAINTEXT = 3

    # SASL Plaintext security protocol.
    SASL_PLAINTEXT = 4
  end
end

#technology_type::String

Returns Optional. The technology type of KafkaConnection.

Returns:

  • (::String)

    Optional. The technology type of KafkaConnection.



725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 725

class GoldengateKafkaConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Kafka.
  module KafkaSecurityProtocol
    # Security type not specified.
    KAFKA_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # SSL security protocol.
    SSL = 1

    # SASL SSL security protocol.
    SASL_SSL = 2

    # Plaintext security protocol.
    PLAINTEXT = 3

    # SASL Plaintext security protocol.
    SASL_PLAINTEXT = 4
  end
end

#trust_store_file::String

Returns Optional. The base64 encoded content of the TrustStore file.

Returns:

  • (::String)

    Optional. The base64 encoded content of the TrustStore file.



725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 725

class GoldengateKafkaConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Kafka.
  module KafkaSecurityProtocol
    # Security type not specified.
    KAFKA_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # SSL security protocol.
    SSL = 1

    # SASL SSL security protocol.
    SASL_SSL = 2

    # Plaintext security protocol.
    PLAINTEXT = 3

    # SASL Plaintext security protocol.
    SASL_PLAINTEXT = 4
  end
end

#trust_store_password::String

Returns Optional. Input only. The TrustStore password in plain text.

Note: The following fields are mutually exclusive: trust_store_password, trust_store_password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The TrustStore password in plain text.

    Note: The following fields are mutually exclusive: trust_store_password, trust_store_password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.



725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 725

class GoldengateKafkaConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Kafka.
  module KafkaSecurityProtocol
    # Security type not specified.
    KAFKA_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # SSL security protocol.
    SSL = 1

    # SASL SSL security protocol.
    SASL_SSL = 2

    # Plaintext security protocol.
    PLAINTEXT = 3

    # SASL Plaintext security protocol.
    SASL_PLAINTEXT = 4
  end
end

#trust_store_password_secret_version::String

Returns Optional. Input only. The resource name of a secret version in Secret Manager which contains the TrustStore password. Format: projects/{project}/secrets/{secret}/versions/{version}.

Note: The following fields are mutually exclusive: trust_store_password_secret_version, trust_store_password. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The resource name of a secret version in Secret Manager which contains the TrustStore password. Format: projects/{project}/secrets/{secret}/versions/{version}.

    Note: The following fields are mutually exclusive: trust_store_password_secret_version, trust_store_password. If a field in that set is populated, all other fields in the set will automatically be cleared.



725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 725

class GoldengateKafkaConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Kafka.
  module KafkaSecurityProtocol
    # Security type not specified.
    KAFKA_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # SSL security protocol.
    SSL = 1

    # SASL SSL security protocol.
    SASL_SSL = 2

    # Plaintext security protocol.
    PLAINTEXT = 3

    # SASL Plaintext security protocol.
    SASL_PLAINTEXT = 4
  end
end

#use_resource_principal::Boolean

Returns Optional. Specifies that the user intends to authenticate to the instance using a resource principal. Applicable only for OCI Streaming connections.

Returns:

  • (::Boolean)

    Optional. Specifies that the user intends to authenticate to the instance using a resource principal. Applicable only for OCI Streaming connections.



725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 725

class GoldengateKafkaConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Kafka.
  module KafkaSecurityProtocol
    # Security type not specified.
    KAFKA_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # SSL security protocol.
    SSL = 1

    # SASL SSL security protocol.
    SASL_SSL = 2

    # Plaintext security protocol.
    PLAINTEXT = 3

    # SASL Plaintext security protocol.
    SASL_PLAINTEXT = 4
  end
end

#username::String

Returns Optional. The username Oracle Goldengate uses to connect the associated system of the given technology.

Returns:

  • (::String)

    Optional. The username Oracle Goldengate uses to connect the associated system of the given technology.



725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 725

class GoldengateKafkaConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Kafka.
  module KafkaSecurityProtocol
    # Security type not specified.
    KAFKA_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # SSL security protocol.
    SSL = 1

    # SASL SSL security protocol.
    SASL_SSL = 2

    # Plaintext security protocol.
    PLAINTEXT = 3

    # SASL Plaintext security protocol.
    SASL_PLAINTEXT = 4
  end
end