Class: Google::Cloud::OracleDatabase::V1::GoldengateKafkaSchemaRegistryConnectionProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb

Overview

The properties of GoldengateKafkaSchemaRegistryConnection.

Defined Under Namespace

Modules: AuthenticationType

Instance Attribute Summary collapse

Instance Attribute Details

#authentication_type::Google::Cloud::OracleDatabase::V1::GoldengateKafkaSchemaRegistryConnectionProperties::AuthenticationType

Returns Optional. Used authentication mechanism to access Schema Registry.

Returns:



822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 822

class GoldengateKafkaSchemaRegistryConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for authentication mechanism to access Schema Registry.
  module AuthenticationType
    # Authentication type not specified.
    AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # No authentication.
    NONE = 1

    # Basic authentication.
    BASIC = 2

    # Mutual authentication.
    MUTUAL = 3
  end
end

#key_store_file::String

Returns Optional. The base64 encoded content of the KeyStore file.

Returns:

  • (::String)

    Optional. The base64 encoded content of the KeyStore file.



822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 822

class GoldengateKafkaSchemaRegistryConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for authentication mechanism to access Schema Registry.
  module AuthenticationType
    # Authentication type not specified.
    AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # No authentication.
    NONE = 1

    # Basic authentication.
    BASIC = 2

    # Mutual authentication.
    MUTUAL = 3
  end
end

#key_store_password::String

Returns Optional. Input only. The KeyStore password in plain text.

Note: The following fields are mutually exclusive: key_store_password, key_store_password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The KeyStore password in plain text.

    Note: The following fields are mutually exclusive: key_store_password, key_store_password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.



822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 822

class GoldengateKafkaSchemaRegistryConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for authentication mechanism to access Schema Registry.
  module AuthenticationType
    # Authentication type not specified.
    AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # No authentication.
    NONE = 1

    # Basic authentication.
    BASIC = 2

    # Mutual authentication.
    MUTUAL = 3
  end
end

#key_store_password_secret_version::String

Returns Optional. Input only. The resource name of a secret version in Secret Manager which contains the KeyStore password. Format: projects/{project}/secrets/{secret}/versions/{version}.

Note: The following fields are mutually exclusive: key_store_password_secret_version, key_store_password. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The resource name of a secret version in Secret Manager which contains the KeyStore password. Format: projects/{project}/secrets/{secret}/versions/{version}.

    Note: The following fields are mutually exclusive: key_store_password_secret_version, key_store_password. If a field in that set is populated, all other fields in the set will automatically be cleared.



822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 822

class GoldengateKafkaSchemaRegistryConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for authentication mechanism to access Schema Registry.
  module AuthenticationType
    # Authentication type not specified.
    AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # No authentication.
    NONE = 1

    # Basic authentication.
    BASIC = 2

    # Mutual authentication.
    MUTUAL = 3
  end
end

#password::String

Returns Optional. Input only. The password to access Schema Registry in plain text.

Note: The following fields are mutually exclusive: password, password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The password to access Schema Registry in plain text.

    Note: The following fields are mutually exclusive: password, password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.



822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 822

class GoldengateKafkaSchemaRegistryConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for authentication mechanism to access Schema Registry.
  module AuthenticationType
    # Authentication type not specified.
    AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # No authentication.
    NONE = 1

    # Basic authentication.
    BASIC = 2

    # Mutual authentication.
    MUTUAL = 3
  end
end

#password_secret_version::String

Returns Optional. Input only. The resource name of a secret version in Secret Manager which contains the password to access Schema Registry using basic authentication. Format: projects/{project}/secrets/{secret}/versions/{version}.

Note: The following fields are mutually exclusive: password_secret_version, password. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The resource name of a secret version in Secret Manager which contains the password to access Schema Registry using basic authentication. Format: projects/{project}/secrets/{secret}/versions/{version}.

    Note: The following fields are mutually exclusive: password_secret_version, password. If a field in that set is populated, all other fields in the set will automatically be cleared.



822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 822

class GoldengateKafkaSchemaRegistryConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for authentication mechanism to access Schema Registry.
  module AuthenticationType
    # Authentication type not specified.
    AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # No authentication.
    NONE = 1

    # Basic authentication.
    BASIC = 2

    # Mutual authentication.
    MUTUAL = 3
  end
end

#ssl_key_password::String

Returns Optional. Input only. The password for the cert inside the KeyStore in plain text.

Note: The following fields are mutually exclusive: ssl_key_password, ssl_key_password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The password for the cert inside the KeyStore in plain text.

    Note: The following fields are mutually exclusive: ssl_key_password, ssl_key_password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.



822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 822

class GoldengateKafkaSchemaRegistryConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for authentication mechanism to access Schema Registry.
  module AuthenticationType
    # Authentication type not specified.
    AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # No authentication.
    NONE = 1

    # Basic authentication.
    BASIC = 2

    # Mutual authentication.
    MUTUAL = 3
  end
end

#ssl_key_password_secret_version::String

Returns Optional. Input only. The resource name of a secret version in Secret Manager which contains the password for the cert inside the KeyStore. Format: projects/{project}/secrets/{secret}/versions/{version}.

Note: The following fields are mutually exclusive: ssl_key_password_secret_version, ssl_key_password. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The resource name of a secret version in Secret Manager which contains the password for the cert inside the KeyStore. Format: projects/{project}/secrets/{secret}/versions/{version}.

    Note: The following fields are mutually exclusive: ssl_key_password_secret_version, ssl_key_password. If a field in that set is populated, all other fields in the set will automatically be cleared.



822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 822

class GoldengateKafkaSchemaRegistryConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for authentication mechanism to access Schema Registry.
  module AuthenticationType
    # Authentication type not specified.
    AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # No authentication.
    NONE = 1

    # Basic authentication.
    BASIC = 2

    # Mutual authentication.
    MUTUAL = 3
  end
end

#technology_type::String

Returns Optional. The technology type of KafkaSchemaRegistryConnection.

Returns:

  • (::String)

    Optional. The technology type of KafkaSchemaRegistryConnection.



822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 822

class GoldengateKafkaSchemaRegistryConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for authentication mechanism to access Schema Registry.
  module AuthenticationType
    # Authentication type not specified.
    AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # No authentication.
    NONE = 1

    # Basic authentication.
    BASIC = 2

    # Mutual authentication.
    MUTUAL = 3
  end
end

#trust_store_file::String

Returns Optional. The base64 encoded content of the TrustStore file.

Returns:

  • (::String)

    Optional. The base64 encoded content of the TrustStore file.



822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 822

class GoldengateKafkaSchemaRegistryConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for authentication mechanism to access Schema Registry.
  module AuthenticationType
    # Authentication type not specified.
    AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # No authentication.
    NONE = 1

    # Basic authentication.
    BASIC = 2

    # Mutual authentication.
    MUTUAL = 3
  end
end

#trust_store_password::String

Returns Optional. Input only. The TrustStore password in plain text.

Note: The following fields are mutually exclusive: trust_store_password, trust_store_password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The TrustStore password in plain text.

    Note: The following fields are mutually exclusive: trust_store_password, trust_store_password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.



822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 822

class GoldengateKafkaSchemaRegistryConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for authentication mechanism to access Schema Registry.
  module AuthenticationType
    # Authentication type not specified.
    AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # No authentication.
    NONE = 1

    # Basic authentication.
    BASIC = 2

    # Mutual authentication.
    MUTUAL = 3
  end
end

#trust_store_password_secret_version::String

Returns Optional. Input only. The resource name of a secret version in Secret Manager which contains the TrustStore password. Format: projects/{project}/secrets/{secret}/versions/{version}.

Note: The following fields are mutually exclusive: trust_store_password_secret_version, trust_store_password. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The resource name of a secret version in Secret Manager which contains the TrustStore password. Format: projects/{project}/secrets/{secret}/versions/{version}.

    Note: The following fields are mutually exclusive: trust_store_password_secret_version, trust_store_password. If a field in that set is populated, all other fields in the set will automatically be cleared.



822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 822

class GoldengateKafkaSchemaRegistryConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for authentication mechanism to access Schema Registry.
  module AuthenticationType
    # Authentication type not specified.
    AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # No authentication.
    NONE = 1

    # Basic authentication.
    BASIC = 2

    # Mutual authentication.
    MUTUAL = 3
  end
end

#url::String

Returns Optional. Kafka Schema Registry URL. e.g.: 'https://server1.us.oracle.com:8081'.

Returns:



822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 822

class GoldengateKafkaSchemaRegistryConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for authentication mechanism to access Schema Registry.
  module AuthenticationType
    # Authentication type not specified.
    AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # No authentication.
    NONE = 1

    # Basic authentication.
    BASIC = 2

    # Mutual authentication.
    MUTUAL = 3
  end
end

#username::String

Returns Optional. The username to access Schema Registry using basic authentication. This value is injected into 'schema.registry.basic.auth.user.info=user:password' configuration property.

Returns:

  • (::String)

    Optional. The username to access Schema Registry using basic authentication. This value is injected into 'schema.registry.basic.auth.user.info=user:password' configuration property.



822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 822

class GoldengateKafkaSchemaRegistryConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for authentication mechanism to access Schema Registry.
  module AuthenticationType
    # Authentication type not specified.
    AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # No authentication.
    NONE = 1

    # Basic authentication.
    BASIC = 2

    # Mutual authentication.
    MUTUAL = 3
  end
end