Class: Google::Cloud::OracleDatabase::V1::GoldengateMicrosoftSqlserverConnectionProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb

Overview

The properties of GoldengateMicrosoftSqlserverConnection.

Defined Under Namespace

Modules: MicrosoftSqlserverSecurityProtocol

Instance Attribute Summary collapse

Instance Attribute Details

#additional_attributes::Array<::Google::Cloud::OracleDatabase::V1::NameValuePair>

Returns Optional. An array of name-value pair attribute entries. Used as additional parameters in connection string.

Returns:



1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1110

class GoldengateMicrosoftSqlserverConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Microsoft SQL Server.
  module MicrosoftSqlserverSecurityProtocol
    # Security type not specified.
    MICROSOFT_SQLSERVER_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2
  end
end

#database::String

Returns Optional. The name of the database.

Returns:

  • (::String)

    Optional. The name of the database.



1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1110

class GoldengateMicrosoftSqlserverConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Microsoft SQL Server.
  module MicrosoftSqlserverSecurityProtocol
    # Security type not specified.
    MICROSOFT_SQLSERVER_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2
  end
end

#host::String

Returns Optional. The name or address of a host.

Returns:

  • (::String)

    Optional. The name or address of a host.



1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1110

class GoldengateMicrosoftSqlserverConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Microsoft SQL Server.
  module MicrosoftSqlserverSecurityProtocol
    # Security type not specified.
    MICROSOFT_SQLSERVER_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2
  end
end

#password::String

Returns Optional. Input only. The password Oracle Goldengate uses for Microsoft SQL Server connection in plain text.

Note: The following fields are mutually exclusive: password, password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The password Oracle Goldengate uses for Microsoft SQL Server connection in plain text.

    Note: The following fields are mutually exclusive: password, password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.



1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1110

class GoldengateMicrosoftSqlserverConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Microsoft SQL Server.
  module MicrosoftSqlserverSecurityProtocol
    # Security type not specified.
    MICROSOFT_SQLSERVER_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2
  end
end

#password_secret_version::String

Returns Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses for Microsoft SQL Server connection. Format: projects/{project}/secrets/{secret}/versions/{version}.

Note: The following fields are mutually exclusive: password_secret_version, password. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses for Microsoft SQL Server connection. Format: projects/{project}/secrets/{secret}/versions/{version}.

    Note: The following fields are mutually exclusive: password_secret_version, password. If a field in that set is populated, all other fields in the set will automatically be cleared.



1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1110

class GoldengateMicrosoftSqlserverConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Microsoft SQL Server.
  module MicrosoftSqlserverSecurityProtocol
    # Security type not specified.
    MICROSOFT_SQLSERVER_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2
  end
end

#port::Integer

Returns Optional. The port of an endpoint usually specified for a connection.

Returns:

  • (::Integer)

    Optional. The port of an endpoint usually specified for a connection.



1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1110

class GoldengateMicrosoftSqlserverConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Microsoft SQL Server.
  module MicrosoftSqlserverSecurityProtocol
    # Security type not specified.
    MICROSOFT_SQLSERVER_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2
  end
end

#security_protocol::Google::Cloud::OracleDatabase::V1::GoldengateMicrosoftSqlserverConnectionProperties::MicrosoftSqlserverSecurityProtocol

Returns Optional. Security Type for Microsoft SQL Server.



1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1110

class GoldengateMicrosoftSqlserverConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Microsoft SQL Server.
  module MicrosoftSqlserverSecurityProtocol
    # Security type not specified.
    MICROSOFT_SQLSERVER_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2
  end
end

#server_certificate_validation_required::Boolean

Returns Optional. If set to true, the driver validates the certificate that is sent by the database server.

Returns:

  • (::Boolean)

    Optional. If set to true, the driver validates the certificate that is sent by the database server.



1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1110

class GoldengateMicrosoftSqlserverConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Microsoft SQL Server.
  module MicrosoftSqlserverSecurityProtocol
    # Security type not specified.
    MICROSOFT_SQLSERVER_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2
  end
end

#ssl_ca_file::String

Returns Optional. Database Certificate - The base64 encoded content of a .pem or .crt file containing the server public key (for 1-way SSL).

Returns:

  • (::String)

    Optional. Database Certificate - The base64 encoded content of a .pem or .crt file containing the server public key (for 1-way SSL).



1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1110

class GoldengateMicrosoftSqlserverConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Microsoft SQL Server.
  module MicrosoftSqlserverSecurityProtocol
    # Security type not specified.
    MICROSOFT_SQLSERVER_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2
  end
end

#technology_type::String

Returns Optional. The technology type of MicrosoftSqlserverConnection.

Returns:

  • (::String)

    Optional. The technology type of MicrosoftSqlserverConnection.



1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1110

class GoldengateMicrosoftSqlserverConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Microsoft SQL Server.
  module MicrosoftSqlserverSecurityProtocol
    # Security type not specified.
    MICROSOFT_SQLSERVER_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2
  end
end

#username::String

Returns Optional. The username Oracle Goldengate uses to connect to the Microsoft SQL Server.

Returns:

  • (::String)

    Optional. The username Oracle Goldengate uses to connect to the Microsoft SQL Server.



1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1110

class GoldengateMicrosoftSqlserverConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for Microsoft SQL Server.
  module MicrosoftSqlserverSecurityProtocol
    # Security type not specified.
    MICROSOFT_SQLSERVER_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2
  end
end