Class: Google::Cloud::OracleDatabase::V1::GoldengateMongodbConnectionProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb

Overview

The properties of GoldengateMongodbConnection.

Defined Under Namespace

Modules: MongodbSecurityProtocol

Instance Attribute Summary collapse

Instance Attribute Details

#connection_string::String

Returns Optional. MongoDB connection string. e.g.: 'mongodb://mongodb0.example.com:27017/recordsrecords'.

Returns:

  • (::String)

    Optional. MongoDB connection string. e.g.: 'mongodb://mongodb0.example.com:27017/recordsrecords'



1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1347

class GoldengateMongodbConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for MongoDB.
  module MongodbSecurityProtocol
    # Security type not specified.
    MONGODB_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2

    # Mutual Transport Layer Security.
    MTLS = 3
  end
end

#database_id::String

Returns Optional. The OCID of the Oracle Autonomous Json Database.

Returns:

  • (::String)

    Optional. The OCID of the Oracle Autonomous Json Database.



1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1347

class GoldengateMongodbConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for MongoDB.
  module MongodbSecurityProtocol
    # Security type not specified.
    MONGODB_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2

    # Mutual Transport Layer Security.
    MTLS = 3
  end
end

#password::String

Returns Optional. Input only. The password Oracle Goldengate uses to connect the Mongodb connection in plain text.

Note: The following fields are mutually exclusive: password, password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The password Oracle Goldengate uses to connect the Mongodb connection in plain text.

    Note: The following fields are mutually exclusive: password, password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.



1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1347

class GoldengateMongodbConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for MongoDB.
  module MongodbSecurityProtocol
    # Security type not specified.
    MONGODB_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2

    # Mutual Transport Layer Security.
    MTLS = 3
  end
end

#password_secret_version::String

Returns Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses to connect the Mongodb connection. Format: projects/{project}/secrets/{secret}/versions/{version}.

Note: The following fields are mutually exclusive: password_secret_version, password. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses to connect the Mongodb connection. Format: projects/{project}/secrets/{secret}/versions/{version}.

    Note: The following fields are mutually exclusive: password_secret_version, password. If a field in that set is populated, all other fields in the set will automatically be cleared.



1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1347

class GoldengateMongodbConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for MongoDB.
  module MongodbSecurityProtocol
    # Security type not specified.
    MONGODB_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2

    # Mutual Transport Layer Security.
    MTLS = 3
  end
end

#security_protocol::Google::Cloud::OracleDatabase::V1::GoldengateMongodbConnectionProperties::MongodbSecurityProtocol

Returns Optional. Security Type for MongoDB.



1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1347

class GoldengateMongodbConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for MongoDB.
  module MongodbSecurityProtocol
    # Security type not specified.
    MONGODB_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2

    # Mutual Transport Layer Security.
    MTLS = 3
  end
end

#technology_type::String

Returns Optional. The technology type of MongodbConnection.

Returns:

  • (::String)

    Optional. The technology type of MongodbConnection.



1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1347

class GoldengateMongodbConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for MongoDB.
  module MongodbSecurityProtocol
    # Security type not specified.
    MONGODB_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2

    # Mutual Transport Layer Security.
    MTLS = 3
  end
end

#tls_ca_file::String

Returns Optional. Database Certificate - The base64 encoded content of a .pem file, containing the server public key (for 1 and 2-way SSL).

Returns:

  • (::String)

    Optional. Database Certificate - The base64 encoded content of a .pem file, containing the server public key (for 1 and 2-way SSL).



1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1347

class GoldengateMongodbConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for MongoDB.
  module MongodbSecurityProtocol
    # Security type not specified.
    MONGODB_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2

    # Mutual Transport Layer Security.
    MTLS = 3
  end
end

#tls_certificate_key_file::String

Returns Optional. Client Certificate - The base64 encoded content of a .pem file, containing the client public key (for 2-way SSL).

Returns:

  • (::String)

    Optional. Client Certificate - The base64 encoded content of a .pem file, containing the client public key (for 2-way SSL).



1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1347

class GoldengateMongodbConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for MongoDB.
  module MongodbSecurityProtocol
    # Security type not specified.
    MONGODB_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2

    # Mutual Transport Layer Security.
    MTLS = 3
  end
end

#tls_certificate_key_file_password::String

Returns Optional. Input only. The Client Certificate key file password in plain text.

Note: The following fields are mutually exclusive: tls_certificate_key_file_password, tls_certificate_key_file_password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The Client Certificate key file password in plain text.

    Note: The following fields are mutually exclusive: tls_certificate_key_file_password, tls_certificate_key_file_password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.



1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1347

class GoldengateMongodbConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for MongoDB.
  module MongodbSecurityProtocol
    # Security type not specified.
    MONGODB_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2

    # Mutual Transport Layer Security.
    MTLS = 3
  end
end

#tls_certificate_key_file_password_secret_version::String

Returns Optional. Input only. The resource name of a secret version in Secret Manager which contains the Client Certificate key file password in Secret Manager. Format: projects/{project}/secrets/{secret}/versions/{version}.

Note: The following fields are mutually exclusive: tls_certificate_key_file_password_secret_version, tls_certificate_key_file_password. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The resource name of a secret version in Secret Manager which contains the Client Certificate key file password in Secret Manager. Format: projects/{project}/secrets/{secret}/versions/{version}.

    Note: The following fields are mutually exclusive: tls_certificate_key_file_password_secret_version, tls_certificate_key_file_password. If a field in that set is populated, all other fields in the set will automatically be cleared.



1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1347

class GoldengateMongodbConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for MongoDB.
  module MongodbSecurityProtocol
    # Security type not specified.
    MONGODB_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2

    # Mutual Transport Layer Security.
    MTLS = 3
  end
end

#username::String

Returns Optional. The username Oracle Goldengate uses to connect to the database.

Returns:

  • (::String)

    Optional. The username Oracle Goldengate uses to connect to the database.



1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1347

class GoldengateMongodbConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for MongoDB.
  module MongodbSecurityProtocol
    # Security type not specified.
    MONGODB_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2

    # Mutual Transport Layer Security.
    MTLS = 3
  end
end