Class: Google::Cloud::OracleDatabase::V1::GoldengateMysqlConnectionProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb

Overview

Properties of GoldengateMysqlConnection.

Defined Under Namespace

Modules: MysqlSecurityProtocol, SSLMode

Instance Attribute Summary collapse

Instance Attribute Details

#additional_attributes::Array<::Google::Cloud::OracleDatabase::V1::NameValuePair>

Returns Optional. An array of name-value pair attribute entries. Used as additional parameters in connection string.

Returns:



594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 594

class GoldengateMysqlConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for MySQL.
  module MysqlSecurityProtocol
    # Security type not specified.
    MYSQL_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2

    # Mutual Transport Layer Security.
    MTLS = 3
  end

  # Enum for SSL modes for MySQL.
  module SSLMode
    # SSL mode not specified.
    SSL_MODE_UNSPECIFIED = 0

    # SSL is disabled.
    DISABLED = 1

    # SSL is preferred.
    PREFERRED = 2

    # SSL is required.
    REQUIRED = 3

    # SSL is required and certificate is verified.
    VERIFY_CA = 4

    # SSL is required and certificate and hostname are verified.
    VERIFY_IDENTITY = 5
  end
end

#database::String

Returns Optional. The name of the database.

Returns:

  • (::String)

    Optional. The name of the database.



594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 594

class GoldengateMysqlConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for MySQL.
  module MysqlSecurityProtocol
    # Security type not specified.
    MYSQL_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2

    # Mutual Transport Layer Security.
    MTLS = 3
  end

  # Enum for SSL modes for MySQL.
  module SSLMode
    # SSL mode not specified.
    SSL_MODE_UNSPECIFIED = 0

    # SSL is disabled.
    DISABLED = 1

    # SSL is preferred.
    PREFERRED = 2

    # SSL is required.
    REQUIRED = 3

    # SSL is required and certificate is verified.
    VERIFY_CA = 4

    # SSL is required and certificate and hostname are verified.
    VERIFY_IDENTITY = 5
  end
end

#db_system_id::String

Returns Optional. The OCID of the database system being referenced.

Returns:

  • (::String)

    Optional. The OCID of the database system being referenced.



594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 594

class GoldengateMysqlConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for MySQL.
  module MysqlSecurityProtocol
    # Security type not specified.
    MYSQL_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2

    # Mutual Transport Layer Security.
    MTLS = 3
  end

  # Enum for SSL modes for MySQL.
  module SSLMode
    # SSL mode not specified.
    SSL_MODE_UNSPECIFIED = 0

    # SSL is disabled.
    DISABLED = 1

    # SSL is preferred.
    PREFERRED = 2

    # SSL is required.
    REQUIRED = 3

    # SSL is required and certificate is verified.
    VERIFY_CA = 4

    # SSL is required and certificate and hostname are verified.
    VERIFY_IDENTITY = 5
  end
end

#host::String

Returns Optional. The name or address of a host.

Returns:

  • (::String)

    Optional. The name or address of a host.



594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 594

class GoldengateMysqlConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for MySQL.
  module MysqlSecurityProtocol
    # Security type not specified.
    MYSQL_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2

    # Mutual Transport Layer Security.
    MTLS = 3
  end

  # Enum for SSL modes for MySQL.
  module SSLMode
    # SSL mode not specified.
    SSL_MODE_UNSPECIFIED = 0

    # SSL is disabled.
    DISABLED = 1

    # SSL is preferred.
    PREFERRED = 2

    # SSL is required.
    REQUIRED = 3

    # SSL is required and certificate is verified.
    VERIFY_CA = 4

    # SSL is required and certificate and hostname are verified.
    VERIFY_IDENTITY = 5
  end
end

#password::String

Returns Optional. Input only. The password Oracle Goldengate uses to connect to MySQL in plain text.

Note: The following fields are mutually exclusive: password, password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The password Oracle Goldengate uses to connect to MySQL in plain text.

    Note: The following fields are mutually exclusive: password, password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.



594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 594

class GoldengateMysqlConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for MySQL.
  module MysqlSecurityProtocol
    # Security type not specified.
    MYSQL_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2

    # Mutual Transport Layer Security.
    MTLS = 3
  end

  # Enum for SSL modes for MySQL.
  module SSLMode
    # SSL mode not specified.
    SSL_MODE_UNSPECIFIED = 0

    # SSL is disabled.
    DISABLED = 1

    # SSL is preferred.
    PREFERRED = 2

    # SSL is required.
    REQUIRED = 3

    # SSL is required and certificate is verified.
    VERIFY_CA = 4

    # SSL is required and certificate and hostname are verified.
    VERIFY_IDENTITY = 5
  end
end

#password_secret_version::String

Returns Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses to connect to MySQL. Format: projects/{project}/secrets/{secret}/versions/{version}.

Note: The following fields are mutually exclusive: password_secret_version, password. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses to connect to MySQL. Format: projects/{project}/secrets/{secret}/versions/{version}.

    Note: The following fields are mutually exclusive: password_secret_version, password. If a field in that set is populated, all other fields in the set will automatically be cleared.



594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 594

class GoldengateMysqlConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for MySQL.
  module MysqlSecurityProtocol
    # Security type not specified.
    MYSQL_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2

    # Mutual Transport Layer Security.
    MTLS = 3
  end

  # Enum for SSL modes for MySQL.
  module SSLMode
    # SSL mode not specified.
    SSL_MODE_UNSPECIFIED = 0

    # SSL is disabled.
    DISABLED = 1

    # SSL is preferred.
    PREFERRED = 2

    # SSL is required.
    REQUIRED = 3

    # SSL is required and certificate is verified.
    VERIFY_CA = 4

    # SSL is required and certificate and hostname are verified.
    VERIFY_IDENTITY = 5
  end
end

#port::Integer

Returns Optional. The port of an endpoint usually specified for a connection.

Returns:

  • (::Integer)

    Optional. The port of an endpoint usually specified for a connection.



594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 594

class GoldengateMysqlConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for MySQL.
  module MysqlSecurityProtocol
    # Security type not specified.
    MYSQL_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2

    # Mutual Transport Layer Security.
    MTLS = 3
  end

  # Enum for SSL modes for MySQL.
  module SSLMode
    # SSL mode not specified.
    SSL_MODE_UNSPECIFIED = 0

    # SSL is disabled.
    DISABLED = 1

    # SSL is preferred.
    PREFERRED = 2

    # SSL is required.
    REQUIRED = 3

    # SSL is required and certificate is verified.
    VERIFY_CA = 4

    # SSL is required and certificate and hostname are verified.
    VERIFY_IDENTITY = 5
  end
end

#security_protocol::Google::Cloud::OracleDatabase::V1::GoldengateMysqlConnectionProperties::MysqlSecurityProtocol

Returns Optional. Security Type for MySQL.



594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 594

class GoldengateMysqlConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for MySQL.
  module MysqlSecurityProtocol
    # Security type not specified.
    MYSQL_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2

    # Mutual Transport Layer Security.
    MTLS = 3
  end

  # Enum for SSL modes for MySQL.
  module SSLMode
    # SSL mode not specified.
    SSL_MODE_UNSPECIFIED = 0

    # SSL is disabled.
    DISABLED = 1

    # SSL is preferred.
    PREFERRED = 2

    # SSL is required.
    REQUIRED = 3

    # SSL is required and certificate is verified.
    VERIFY_CA = 4

    # SSL is required and certificate and hostname are verified.
    VERIFY_IDENTITY = 5
  end
end

#ssl_ca_file::String

Returns Optional. Database Certificate - The base64 encoded content of a .pem or .crt file containing the server public key (for 1 and 2-way SSL).

Returns:

  • (::String)

    Optional. Database Certificate - The base64 encoded content of a .pem or .crt file containing the server public key (for 1 and 2-way SSL).



594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 594

class GoldengateMysqlConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for MySQL.
  module MysqlSecurityProtocol
    # Security type not specified.
    MYSQL_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2

    # Mutual Transport Layer Security.
    MTLS = 3
  end

  # Enum for SSL modes for MySQL.
  module SSLMode
    # SSL mode not specified.
    SSL_MODE_UNSPECIFIED = 0

    # SSL is disabled.
    DISABLED = 1

    # SSL is preferred.
    PREFERRED = 2

    # SSL is required.
    REQUIRED = 3

    # SSL is required and certificate is verified.
    VERIFY_CA = 4

    # SSL is required and certificate and hostname are verified.
    VERIFY_IDENTITY = 5
  end
end

#ssl_cert_file::String

Returns Optional. Client Certificate - The base64 encoded content of a .pem or .crt file containing the client public key (for 2-way SSL).

Returns:

  • (::String)

    Optional. Client Certificate - The base64 encoded content of a .pem or .crt file containing the client public key (for 2-way SSL).



594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 594

class GoldengateMysqlConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for MySQL.
  module MysqlSecurityProtocol
    # Security type not specified.
    MYSQL_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2

    # Mutual Transport Layer Security.
    MTLS = 3
  end

  # Enum for SSL modes for MySQL.
  module SSLMode
    # SSL mode not specified.
    SSL_MODE_UNSPECIFIED = 0

    # SSL is disabled.
    DISABLED = 1

    # SSL is preferred.
    PREFERRED = 2

    # SSL is required.
    REQUIRED = 3

    # SSL is required and certificate is verified.
    VERIFY_CA = 4

    # SSL is required and certificate and hostname are verified.
    VERIFY_IDENTITY = 5
  end
end

#ssl_crl_file::String

Returns Optional. The base64 encoded list of certificates revoked by the trusted certificate authorities (Trusted CA).

Returns:

  • (::String)

    Optional. The base64 encoded list of certificates revoked by the trusted certificate authorities (Trusted CA).



594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 594

class GoldengateMysqlConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for MySQL.
  module MysqlSecurityProtocol
    # Security type not specified.
    MYSQL_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2

    # Mutual Transport Layer Security.
    MTLS = 3
  end

  # Enum for SSL modes for MySQL.
  module SSLMode
    # SSL mode not specified.
    SSL_MODE_UNSPECIFIED = 0

    # SSL is disabled.
    DISABLED = 1

    # SSL is preferred.
    PREFERRED = 2

    # SSL is required.
    REQUIRED = 3

    # SSL is required and certificate is verified.
    VERIFY_CA = 4

    # SSL is required and certificate and hostname are verified.
    VERIFY_IDENTITY = 5
  end
end

#ssl_key_file::String

Returns Optional. Client Key - The base64 encoded content of a .pem or .crt file containing the client private key (for 2-way SSL).

Returns:

  • (::String)

    Optional. Client Key - The base64 encoded content of a .pem or .crt file containing the client private key (for 2-way SSL).



594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 594

class GoldengateMysqlConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for MySQL.
  module MysqlSecurityProtocol
    # Security type not specified.
    MYSQL_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2

    # Mutual Transport Layer Security.
    MTLS = 3
  end

  # Enum for SSL modes for MySQL.
  module SSLMode
    # SSL mode not specified.
    SSL_MODE_UNSPECIFIED = 0

    # SSL is disabled.
    DISABLED = 1

    # SSL is preferred.
    PREFERRED = 2

    # SSL is required.
    REQUIRED = 3

    # SSL is required and certificate is verified.
    VERIFY_CA = 4

    # SSL is required and certificate and hostname are verified.
    VERIFY_IDENTITY = 5
  end
end

#ssl_mode::Google::Cloud::OracleDatabase::V1::GoldengateMysqlConnectionProperties::SSLMode

Returns Optional. SSL modes for MySQL.



594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 594

class GoldengateMysqlConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for MySQL.
  module MysqlSecurityProtocol
    # Security type not specified.
    MYSQL_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2

    # Mutual Transport Layer Security.
    MTLS = 3
  end

  # Enum for SSL modes for MySQL.
  module SSLMode
    # SSL mode not specified.
    SSL_MODE_UNSPECIFIED = 0

    # SSL is disabled.
    DISABLED = 1

    # SSL is preferred.
    PREFERRED = 2

    # SSL is required.
    REQUIRED = 3

    # SSL is required and certificate is verified.
    VERIFY_CA = 4

    # SSL is required and certificate and hostname are verified.
    VERIFY_IDENTITY = 5
  end
end

#technology_type::String

Returns Optional. The technology type of MysqlConnection.

Returns:

  • (::String)

    Optional. The technology type of MysqlConnection.



594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 594

class GoldengateMysqlConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for MySQL.
  module MysqlSecurityProtocol
    # Security type not specified.
    MYSQL_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2

    # Mutual Transport Layer Security.
    MTLS = 3
  end

  # Enum for SSL modes for MySQL.
  module SSLMode
    # SSL mode not specified.
    SSL_MODE_UNSPECIFIED = 0

    # SSL is disabled.
    DISABLED = 1

    # SSL is preferred.
    PREFERRED = 2

    # SSL is required.
    REQUIRED = 3

    # SSL is required and certificate is verified.
    VERIFY_CA = 4

    # SSL is required and certificate and hostname are verified.
    VERIFY_IDENTITY = 5
  end
end

#username::String

Returns Optional. The username Oracle Goldengate uses to connect the associated system of the given technology.

Returns:

  • (::String)

    Optional. The username Oracle Goldengate uses to connect the associated system of the given technology.



594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 594

class GoldengateMysqlConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Security Type for MySQL.
  module MysqlSecurityProtocol
    # Security type not specified.
    MYSQL_SECURITY_PROTOCOL_UNSPECIFIED = 0

    # Plain text communication.
    PLAIN = 1

    # Transport Layer Security.
    TLS = 2

    # Mutual Transport Layer Security.
    MTLS = 3
  end

  # Enum for SSL modes for MySQL.
  module SSLMode
    # SSL mode not specified.
    SSL_MODE_UNSPECIFIED = 0

    # SSL is disabled.
    DISABLED = 1

    # SSL is preferred.
    PREFERRED = 2

    # SSL is required.
    REQUIRED = 3

    # SSL is required and certificate is verified.
    VERIFY_CA = 4

    # SSL is required and certificate and hostname are verified.
    VERIFY_IDENTITY = 5
  end
end