Class: Google::Cloud::OracleDatabase::V1::GoldengateOciObjectStorageConnectionProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb

Overview

The properties of GoldengateOciObjectStorageConnection.

Instance Attribute Summary collapse

Instance Attribute Details

#private_key_file::String

Returns Optional. The content of the private key file (PEM file) corresponding to the API key of the fingerprint.

Returns:

  • (::String)

    Optional. The content of the private key file (PEM file) corresponding to the API key of the fingerprint.



872
873
874
875
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 872

class GoldengateOciObjectStorageConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#private_key_passphrase_secret::String

Returns Optional. The passphrase of the private key.

Returns:

  • (::String)

    Optional. The passphrase of the private key.



872
873
874
875
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 872

class GoldengateOciObjectStorageConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#public_key_fingerprint::String

Returns Optional. The fingerprint of the API Key of the user specified by the userId.

Returns:

  • (::String)

    Optional. The fingerprint of the API Key of the user specified by the userId.



872
873
874
875
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 872

class GoldengateOciObjectStorageConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#region::String

Returns Optional. The name of the region of OCI Object Storage. e.g.: us-ashburn-1 If the region is not provided, backend will default to the default region.

Returns:

  • (::String)

    Optional. The name of the region of OCI Object Storage. e.g.: us-ashburn-1 If the region is not provided, backend will default to the default region.



872
873
874
875
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 872

class GoldengateOciObjectStorageConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#technology_type::String

Returns Optional. The technology type of OciObjectStorageConnection.

Returns:

  • (::String)

    Optional. The technology type of OciObjectStorageConnection.



872
873
874
875
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 872

class GoldengateOciObjectStorageConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tenancy_id::String

Returns Optional. The OCID of the related OCI tenancy.

Returns:

  • (::String)

    Optional. The OCID of the related OCI tenancy.



872
873
874
875
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 872

class GoldengateOciObjectStorageConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#use_resource_principal::Boolean

Returns Optional. Specifies that the user intends to authenticate to the instance using a resource principal.

Returns:

  • (::Boolean)

    Optional. Specifies that the user intends to authenticate to the instance using a resource principal.



872
873
874
875
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 872

class GoldengateOciObjectStorageConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#user_id::String

Returns Optional. The OCID of the OCI user who will access the Object Storage. The user must have write access to the bucket they want to connect to.

Returns:

  • (::String)

    Optional. The OCID of the OCI user who will access the Object Storage. The user must have write access to the bucket they want to connect to.



872
873
874
875
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 872

class GoldengateOciObjectStorageConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end