Class: Google::Cloud::OracleDatabase::V1::GoldengateOracleAIDataPlatformConnectionProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb

Overview

The properties of GoldengateOracleAIDataPlatformConnection.

Instance Attribute Summary collapse

Instance Attribute Details

#connection_url::String

Returns Optional. Connection URL. It must start with 'jdbc:spark://'.

Returns:

  • (::String)

    Optional. Connection URL. It must start with 'jdbc:spark://'



1863
1864
1865
1866
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1863

class GoldengateOracleAIDataPlatformConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#private_key_file::String

Returns Optional. The content of the private key file (PEM file) corresponding to the API key of the fingerprint.

Returns:

  • (::String)

    Optional. The content of the private key file (PEM file) corresponding to the API key of the fingerprint.



1863
1864
1865
1866
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1863

class GoldengateOracleAIDataPlatformConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#private_key_passphrase_secret::String

Returns Optional. The passphrase of the private key.

Returns:

  • (::String)

    Optional. The passphrase of the private key.



1863
1864
1865
1866
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1863

class GoldengateOracleAIDataPlatformConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#public_key_fingerprint::String

Returns Optional. The fingerprint of the API Key of the user specified by the user_id.

Returns:

  • (::String)

    Optional. The fingerprint of the API Key of the user specified by the user_id.



1863
1864
1865
1866
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1863

class GoldengateOracleAIDataPlatformConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#region::String

Returns Optional. The name of the region. e.g.: us-ashburn-1.

Returns:

  • (::String)

    Optional. The name of the region. e.g.: us-ashburn-1



1863
1864
1865
1866
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1863

class GoldengateOracleAIDataPlatformConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#technology_type::String

Returns Optional. The technology type of OracleAiDataPlatformConnection.

Returns:

  • (::String)

    Optional. The technology type of OracleAiDataPlatformConnection.



1863
1864
1865
1866
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1863

class GoldengateOracleAIDataPlatformConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tenancy_id::String

Returns Optional. The OCID of the related OCI tenancy.

Returns:

  • (::String)

    Optional. The OCID of the related OCI tenancy.



1863
1864
1865
1866
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1863

class GoldengateOracleAIDataPlatformConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#use_resource_principal::Boolean

Returns Optional. Specifies that the user intends to authenticate to the instance using a resource principal.

Returns:

  • (::Boolean)

    Optional. Specifies that the user intends to authenticate to the instance using a resource principal.



1863
1864
1865
1866
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1863

class GoldengateOracleAIDataPlatformConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#user_id::String

Returns Optional. The OCID of the OCI user who will access.

Returns:

  • (::String)

    Optional. The OCID of the OCI user who will access.



1863
1864
1865
1866
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1863

class GoldengateOracleAIDataPlatformConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end