Class: Google::Cloud::OracleDatabase::V1::GoldengateOracleConnectionProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb

Overview

The properties of Goldengate Oracle Database Connection.

Defined Under Namespace

Modules: OracleAuthenticationMode, SessionMode

Instance Attribute Summary collapse

Instance Attribute Details

#authentication_mode::Google::Cloud::OracleDatabase::V1::GoldengateOracleConnectionProperties::OracleAuthenticationMode

Returns Optional. Authentication mode.



430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 430

class GoldengateOracleConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Authentication mode.
  module OracleAuthenticationMode
    # Authentication mode not specified.
    ORACLE_AUTHENTICATION_MODE_UNSPECIFIED = 0

    # TLS authentication mode.
    TLS = 1

    # MTLS authentication mode.
    MTLS = 2
  end

  # The various session modes of the GoldengateConnection.
  module SessionMode
    # Default unspecified value.
    SESSION_MODE_UNSPECIFIED = 0

    # Indicates that the resource is using direct session mode.
    DIRECT = 1

    # Indicates that the resource is using redirect session mode.
    REDIRECT = 2
  end
end

#connection_string::String

Returns Optional. Connect descriptor or Easy Connect Naming method used to connect to a database.

Returns:

  • (::String)

    Optional. Connect descriptor or Easy Connect Naming method used to connect to a database.



430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 430

class GoldengateOracleConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Authentication mode.
  module OracleAuthenticationMode
    # Authentication mode not specified.
    ORACLE_AUTHENTICATION_MODE_UNSPECIFIED = 0

    # TLS authentication mode.
    TLS = 1

    # MTLS authentication mode.
    MTLS = 2
  end

  # The various session modes of the GoldengateConnection.
  module SessionMode
    # Default unspecified value.
    SESSION_MODE_UNSPECIFIED = 0

    # Indicates that the resource is using direct session mode.
    DIRECT = 1

    # Indicates that the resource is using redirect session mode.
    REDIRECT = 2
  end
end

#gcp_oracle_database_id::String

Returns Optional. Autonomous AI Database instance id of database in Oracle Database @ Google Cloud. If gcp_oracle_database_id is provided, connection_string must be empty. Format: projects/{project}/locations/{location}/autonomousDatabases/{autonomous_database}.

Returns:

  • (::String)

    Optional. Autonomous AI Database instance id of database in Oracle Database @ Google Cloud. If gcp_oracle_database_id is provided, connection_string must be empty. Format: projects/{project}/locations/{location}/autonomousDatabases/{autonomous_database}



430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 430

class GoldengateOracleConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Authentication mode.
  module OracleAuthenticationMode
    # Authentication mode not specified.
    ORACLE_AUTHENTICATION_MODE_UNSPECIFIED = 0

    # TLS authentication mode.
    TLS = 1

    # MTLS authentication mode.
    MTLS = 2
  end

  # The various session modes of the GoldengateConnection.
  module SessionMode
    # Default unspecified value.
    SESSION_MODE_UNSPECIFIED = 0

    # Indicates that the resource is using direct session mode.
    DIRECT = 1

    # Indicates that the resource is using redirect session mode.
    REDIRECT = 2
  end
end

#password::String

Returns Optional. Input only. The password Oracle Goldengate uses in plain text.

Note: The following fields are mutually exclusive: password, password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The password Oracle Goldengate uses in plain text.

    Note: The following fields are mutually exclusive: password, password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.



430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 430

class GoldengateOracleConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Authentication mode.
  module OracleAuthenticationMode
    # Authentication mode not specified.
    ORACLE_AUTHENTICATION_MODE_UNSPECIFIED = 0

    # TLS authentication mode.
    TLS = 1

    # MTLS authentication mode.
    MTLS = 2
  end

  # The various session modes of the GoldengateConnection.
  module SessionMode
    # Default unspecified value.
    SESSION_MODE_UNSPECIFIED = 0

    # Indicates that the resource is using direct session mode.
    DIRECT = 1

    # Indicates that the resource is using redirect session mode.
    REDIRECT = 2
  end
end

#password_secret_version::String

Returns Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses. Format: projects/{project}/secrets/{secret}/versions/{version}.

Note: The following fields are mutually exclusive: password_secret_version, password. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses. Format: projects/{project}/secrets/{secret}/versions/{version}.

    Note: The following fields are mutually exclusive: password_secret_version, password. If a field in that set is populated, all other fields in the set will automatically be cleared.



430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 430

class GoldengateOracleConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Authentication mode.
  module OracleAuthenticationMode
    # Authentication mode not specified.
    ORACLE_AUTHENTICATION_MODE_UNSPECIFIED = 0

    # TLS authentication mode.
    TLS = 1

    # MTLS authentication mode.
    MTLS = 2
  end

  # The various session modes of the GoldengateConnection.
  module SessionMode
    # Default unspecified value.
    SESSION_MODE_UNSPECIFIED = 0

    # Indicates that the resource is using direct session mode.
    DIRECT = 1

    # Indicates that the resource is using redirect session mode.
    REDIRECT = 2
  end
end

#session_mode::Google::Cloud::OracleDatabase::V1::GoldengateOracleConnectionProperties::SessionMode

Returns Optional. The mode of the database connection session to be established by the data client.

Returns:



430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 430

class GoldengateOracleConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Authentication mode.
  module OracleAuthenticationMode
    # Authentication mode not specified.
    ORACLE_AUTHENTICATION_MODE_UNSPECIFIED = 0

    # TLS authentication mode.
    TLS = 1

    # MTLS authentication mode.
    MTLS = 2
  end

  # The various session modes of the GoldengateConnection.
  module SessionMode
    # Default unspecified value.
    SESSION_MODE_UNSPECIFIED = 0

    # Indicates that the resource is using direct session mode.
    DIRECT = 1

    # Indicates that the resource is using redirect session mode.
    REDIRECT = 2
  end
end

#technology_type::String

Returns Optional. The technology type.

Returns:

  • (::String)

    Optional. The technology type.



430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 430

class GoldengateOracleConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Authentication mode.
  module OracleAuthenticationMode
    # Authentication mode not specified.
    ORACLE_AUTHENTICATION_MODE_UNSPECIFIED = 0

    # TLS authentication mode.
    TLS = 1

    # MTLS authentication mode.
    MTLS = 2
  end

  # The various session modes of the GoldengateConnection.
  module SessionMode
    # Default unspecified value.
    SESSION_MODE_UNSPECIFIED = 0

    # Indicates that the resource is using direct session mode.
    DIRECT = 1

    # Indicates that the resource is using redirect session mode.
    REDIRECT = 2
  end
end

#username::String

Returns Optional. The username Oracle Goldengate uses to connect.

Returns:

  • (::String)

    Optional. The username Oracle Goldengate uses to connect.



430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 430

class GoldengateOracleConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Authentication mode.
  module OracleAuthenticationMode
    # Authentication mode not specified.
    ORACLE_AUTHENTICATION_MODE_UNSPECIFIED = 0

    # TLS authentication mode.
    TLS = 1

    # MTLS authentication mode.
    MTLS = 2
  end

  # The various session modes of the GoldengateConnection.
  module SessionMode
    # Default unspecified value.
    SESSION_MODE_UNSPECIFIED = 0

    # Indicates that the resource is using direct session mode.
    DIRECT = 1

    # Indicates that the resource is using redirect session mode.
    REDIRECT = 2
  end
end

#wallet_file::String

Returns Optional. The wallet contents Oracle Goldengate uses to make connections to a database. This attribute is expected to be base64 encoded.

Returns:

  • (::String)

    Optional. The wallet contents Oracle Goldengate uses to make connections to a database. This attribute is expected to be base64 encoded.



430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 430

class GoldengateOracleConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for Authentication mode.
  module OracleAuthenticationMode
    # Authentication mode not specified.
    ORACLE_AUTHENTICATION_MODE_UNSPECIFIED = 0

    # TLS authentication mode.
    TLS = 1

    # MTLS authentication mode.
    MTLS = 2
  end

  # The various session modes of the GoldengateConnection.
  module SessionMode
    # Default unspecified value.
    SESSION_MODE_UNSPECIFIED = 0

    # Indicates that the resource is using direct session mode.
    DIRECT = 1

    # Indicates that the resource is using redirect session mode.
    REDIRECT = 2
  end
end