Class: Google::Cloud::OracleDatabase::V1::GoldengateSnowflakeConnectionProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb

Overview

The properties of GoldengateSnowflakeConnection.

Defined Under Namespace

Modules: AuthenticationType

Instance Attribute Summary collapse

Instance Attribute Details

#authentication_type::Google::Cloud::OracleDatabase::V1::GoldengateSnowflakeConnectionProperties::AuthenticationType

Returns Optional. Used authentication mechanism to access Snowflake.

Returns:



1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1436

class GoldengateSnowflakeConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for authentication mechanism to access Snowflake.
  module AuthenticationType
    # Authentication type not specified.
    AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # Basic authentication.
    BASIC = 1

    # Key pair authentication.
    KEY_PAIR = 2
  end
end

#connection_url::String

Returns Optional. JDBC connection URL. e.g.: 'jdbc:snowflake://.snowflakecomputing.com/?warehouse=&db='.

Returns:

  • (::String)

    Optional. JDBC connection URL. e.g.: 'jdbc:snowflake://.snowflakecomputing.com/?warehouse=&db='



1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1436

class GoldengateSnowflakeConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for authentication mechanism to access Snowflake.
  module AuthenticationType
    # Authentication type not specified.
    AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # Basic authentication.
    BASIC = 1

    # Key pair authentication.
    KEY_PAIR = 2
  end
end

#password::String

Returns Optional. Input only. The password Oracle Goldengate uses to connect to Snowflake platform in plain text.

Note: The following fields are mutually exclusive: password, password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The password Oracle Goldengate uses to connect to Snowflake platform in plain text.

    Note: The following fields are mutually exclusive: password, password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.



1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1436

class GoldengateSnowflakeConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for authentication mechanism to access Snowflake.
  module AuthenticationType
    # Authentication type not specified.
    AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # Basic authentication.
    BASIC = 1

    # Key pair authentication.
    KEY_PAIR = 2
  end
end

#password_secret_version::String

Returns Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses to connect to Snowflake platform. Format: projects/{project}/secrets/{secret}/versions/{version}.

Note: The following fields are mutually exclusive: password_secret_version, password. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses to connect to Snowflake platform. Format: projects/{project}/secrets/{secret}/versions/{version}.

    Note: The following fields are mutually exclusive: password_secret_version, password. If a field in that set is populated, all other fields in the set will automatically be cleared.



1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1436

class GoldengateSnowflakeConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for authentication mechanism to access Snowflake.
  module AuthenticationType
    # Authentication type not specified.
    AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # Basic authentication.
    BASIC = 1

    # Key pair authentication.
    KEY_PAIR = 2
  end
end

#private_key_file::String

Returns Optional. The content of private key file in PEM format.

Returns:

  • (::String)

    Optional. The content of private key file in PEM format.



1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1436

class GoldengateSnowflakeConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for authentication mechanism to access Snowflake.
  module AuthenticationType
    # Authentication type not specified.
    AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # Basic authentication.
    BASIC = 1

    # Key pair authentication.
    KEY_PAIR = 2
  end
end

#private_key_passphrase_secret::String

Returns Optional. Password if the private key file is encrypted.

Returns:

  • (::String)

    Optional. Password if the private key file is encrypted.



1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1436

class GoldengateSnowflakeConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for authentication mechanism to access Snowflake.
  module AuthenticationType
    # Authentication type not specified.
    AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # Basic authentication.
    BASIC = 1

    # Key pair authentication.
    KEY_PAIR = 2
  end
end

#technology_type::String

Returns Optional. The technology type of SnowflakeConnection.

Returns:

  • (::String)

    Optional. The technology type of SnowflakeConnection.



1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1436

class GoldengateSnowflakeConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for authentication mechanism to access Snowflake.
  module AuthenticationType
    # Authentication type not specified.
    AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # Basic authentication.
    BASIC = 1

    # Key pair authentication.
    KEY_PAIR = 2
  end
end

#username::String

Returns Optional. The username Oracle Goldengate uses to connect to Snowflake.

Returns:

  • (::String)

    Optional. The username Oracle Goldengate uses to connect to Snowflake.



1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1436

class GoldengateSnowflakeConnectionProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for authentication mechanism to access Snowflake.
  module AuthenticationType
    # Authentication type not specified.
    AUTHENTICATION_TYPE_UNSPECIFIED = 0

    # Basic authentication.
    BASIC = 1

    # Key pair authentication.
    KEY_PAIR = 2
  end
end