Class: Google::Cloud::OracleDatabase::V1::GoogleCloudStorageIcebergStorage

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb

Overview

The Google Cloud Storage Iceberg storage.

Instance Attribute Summary collapse

Instance Attribute Details

#bucket::String

Returns Required. The bucket of Google Cloud Storage.

Returns:

  • (::String)

    Required. The bucket of Google Cloud Storage.



2020
2021
2022
2023
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 2020

class GoogleCloudStorageIcebergStorage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project_id::String

Returns Required. The project ID of Google Cloud Storage.

Returns:

  • (::String)

    Required. The project ID of Google Cloud Storage.



2020
2021
2022
2023
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 2020

class GoogleCloudStorageIcebergStorage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#service_account_key_file::String

Returns Optional. The base64 encoded content of the service account key file of Google Cloud Storage.

Returns:

  • (::String)

    Optional. The base64 encoded content of the service account key file of Google Cloud Storage.



2020
2021
2022
2023
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 2020

class GoogleCloudStorageIcebergStorage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end