Class: Google::Cloud::OracleDatabase::V1::IdentityConnector

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/common.rb

Overview

The identity connector details which will allow OCI to securely access the resources in the customer project.

Defined Under Namespace

Modules: ConnectionState

Instance Attribute Summary collapse

Instance Attribute Details

#connection_state::Google::Cloud::OracleDatabase::V1::IdentityConnector::ConnectionState (readonly)

Returns Output only. The connection state of the identity connector.

Returns:



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'proto_docs/google/cloud/oracledatabase/v1/common.rb', line 45

class IdentityConnector
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various connection states of the WorkloadIdentityPoolConnection.
  module ConnectionState
    # Default unspecified value.
    CONNECTION_STATE_UNSPECIFIED = 0

    # The identity pool connection is connected.
    CONNECTED = 1

    # The identity pool connection is partially connected.
    PARTIALLY_CONNECTED = 2

    # The identity pool connection is disconnected.
    DISCONNECTED = 3

    # The identity pool connection is in an unknown state.
    UNKNOWN = 4
  end
end

#service_agent_email::String (readonly)

Returns Output only. A google managed service account on which customers can grant roles to access resources in the customer project. Example: p176944527254-55-75119d87fd8f@gcp-sa-oci.iam.gserviceaccount.com.

Returns:

  • (::String)

    Output only. A google managed service account on which customers can grant roles to access resources in the customer project. Example: p176944527254-55-75119d87fd8f@gcp-sa-oci.iam.gserviceaccount.com



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'proto_docs/google/cloud/oracledatabase/v1/common.rb', line 45

class IdentityConnector
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The various connection states of the WorkloadIdentityPoolConnection.
  module ConnectionState
    # Default unspecified value.
    CONNECTION_STATE_UNSPECIFIED = 0

    # The identity pool connection is connected.
    CONNECTED = 1

    # The identity pool connection is partially connected.
    PARTIALLY_CONNECTED = 2

    # The identity pool connection is disconnected.
    DISCONNECTED = 3

    # The identity pool connection is in an unknown state.
    UNKNOWN = 4
  end
end