Class: Google::Cloud::OracleDatabase::V1::ListCloudExadataInfrastructuresResponse
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::ListCloudExadataInfrastructuresResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb
Overview
The response for CloudExadataInfrastructures.list.
Instance Attribute Summary collapse
-
#cloud_exadata_infrastructures ⇒ ::Array<::Google::Cloud::OracleDatabase::V1::CloudExadataInfrastructure>
The list of Exadata Infrastructures.
-
#next_page_token ⇒ ::String
A token for fetching next page of response.
-
#unreachable ⇒ ::Array<::String>
Unreachable locations when listing resources across all locations using wildcard location '-'.
Instance Attribute Details
#cloud_exadata_infrastructures ⇒ ::Array<::Google::Cloud::OracleDatabase::V1::CloudExadataInfrastructure>
Returns The list of Exadata Infrastructures.
59 60 61 62 |
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 59 class ListCloudExadataInfrastructuresResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token for fetching next page of response.
59 60 61 62 |
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 59 class ListCloudExadataInfrastructuresResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Unreachable locations when listing resources across all locations using wildcard location '-'.
59 60 61 62 |
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 59 class ListCloudExadataInfrastructuresResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |