Class: Google::Cloud::OracleDatabase::V1::ListCloudVmClustersRequest
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::ListCloudVmClustersRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb
Overview
The request for CloudVmCluster.List.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. An expression for filtering the results of the request.
146 147 148 149 |
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 146 class ListCloudVmClustersRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. The number of VM clusters to return. If unspecified, at most 50 VM clusters will be returned. The maximum value is 1,000.
146 147 148 149 |
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 146 class ListCloudVmClustersRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A token identifying the page of results the server returns.
146 147 148 149 |
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 146 class ListCloudVmClustersRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The name of the parent in the following format: projects/{project}/locations/{location}.
146 147 148 149 |
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 146 class ListCloudVmClustersRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |