Class: Google::Cloud::OracleDatabase::V1::ListCloudVmClustersResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb

Overview

The response for CloudVmCluster.List.

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_vm_clusters::Array<::Google::Cloud::OracleDatabase::V1::CloudVmCluster>

Returns The list of VM Clusters.

Returns:



162
163
164
165
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 162

class ListCloudVmClustersResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token to fetch the next page of results.

Returns:

  • (::String)

    A token to fetch the next page of results.



162
163
164
165
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 162

class ListCloudVmClustersResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachable::Array<::String>

Returns Unreachable locations when listing resources across all locations using wildcard location '-'.

Returns:

  • (::Array<::String>)

    Unreachable locations when listing resources across all locations using wildcard location '-'.



162
163
164
165
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 162

class ListCloudVmClustersResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end