Class: Google::Cloud::OracleDatabase::V1::ListDatabaseCharacterSetsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/database_character_set.rb

Overview

The request for DatabaseCharacterSet.List.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. An expression for filtering the results of the request. Only the character_set_type field is supported in the following format: character_set_type="{characterSetType}". Accepted values include DATABASE and NATIONAL.

Returns:

  • (::String)

    Optional. An expression for filtering the results of the request. Only the character_set_type field is supported in the following format: character_set_type="{characterSetType}". Accepted values include DATABASE and NATIONAL.



80
81
82
83
# File 'proto_docs/google/cloud/oracledatabase/v1/database_character_set.rb', line 80

class ListDatabaseCharacterSetsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. The maximum number of DatabaseCharacterSets to return. The service may return fewer than this value. If unspecified, at most 50 DatabaseCharacterSets will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    Optional. The maximum number of DatabaseCharacterSets to return. The service may return fewer than this value. If unspecified, at most 50 DatabaseCharacterSets will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.



80
81
82
83
# File 'proto_docs/google/cloud/oracledatabase/v1/database_character_set.rb', line 80

class ListDatabaseCharacterSetsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous ListDatabaseCharacterSets call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to ListDatabaseCharacterSets must match the call that provided the page token.

Returns:

  • (::String)

    Optional. A page token, received from a previous ListDatabaseCharacterSets call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to ListDatabaseCharacterSets must match the call that provided the page token.



80
81
82
83
# File 'proto_docs/google/cloud/oracledatabase/v1/database_character_set.rb', line 80

class ListDatabaseCharacterSetsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent value for DatabaseCharacterSets in the following format: projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. The parent value for DatabaseCharacterSets in the following format: projects/{project}/locations/{location}.



80
81
82
83
# File 'proto_docs/google/cloud/oracledatabase/v1/database_character_set.rb', line 80

class ListDatabaseCharacterSetsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end