Class: Google::Cloud::OracleDatabase::V1::ListDatabaseCharacterSetsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::ListDatabaseCharacterSetsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/database_character_set.rb
Overview
The response for DatabaseCharacterSet.List.
Instance Attribute Summary collapse
-
#database_character_sets ⇒ ::Array<::Google::Cloud::OracleDatabase::V1::DatabaseCharacterSet>
The list of DatabaseCharacterSets.
-
#next_page_token ⇒ ::String
A token identifying a page of results the server should return.
Instance Attribute Details
#database_character_sets ⇒ ::Array<::Google::Cloud::OracleDatabase::V1::DatabaseCharacterSet>
Returns The list of DatabaseCharacterSets.
92 93 94 95 |
# File 'proto_docs/google/cloud/oracledatabase/v1/database_character_set.rb', line 92 class ListDatabaseCharacterSetsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token identifying a page of results the server should return.
92 93 94 95 |
# File 'proto_docs/google/cloud/oracledatabase/v1/database_character_set.rb', line 92 class ListDatabaseCharacterSetsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |