Class: Google::Cloud::OracleDatabase::V1::ListDatabasesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/database.rb

Overview

The request for Database.List.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. An expression for filtering the results of the request. list for container databases is supported only with a valid dbSystem (full resource name) filter in this format: dbSystem="projects/{project}/locations/{location}/dbSystems/{dbSystemId}".

Returns:

  • (::String)

    Optional. An expression for filtering the results of the request. list for container databases is supported only with a valid dbSystem (full resource name) filter in this format: dbSystem="projects/{project}/locations/{location}/dbSystems/{dbSystemId}"



333
334
335
336
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 333

class ListDatabasesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. The maximum number of items to return. If unspecified, a maximum of 50 Databases will be returned. The maximum value is 1000; values above 1000 will be reset to 1000.

Returns:

  • (::Integer)

    Optional. The maximum number of items to return. If unspecified, a maximum of 50 Databases will be returned. The maximum value is 1000; values above 1000 will be reset to 1000.



333
334
335
336
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 333

class ListDatabasesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A token identifying the requested page of results to return. All fields except the filter should remain the same as in the request that provided this page token.

Returns:

  • (::String)

    Optional. A token identifying the requested page of results to return. All fields except the filter should remain the same as in the request that provided this page token.



333
334
335
336
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 333

class ListDatabasesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource name in the following format: projects/{project}/locations/{region}.

Returns:

  • (::String)

    Required. The parent resource name in the following format: projects/{project}/locations/{region}



333
334
335
336
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 333

class ListDatabasesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end