Class: Google::Cloud::OracleDatabase::V1::ListDatabasesResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/database.rb

Overview

The response for Database.List.

Instance Attribute Summary collapse

Instance Attribute Details

#databases::Array<::Google::Cloud::OracleDatabase::V1::Database>

Returns The list of Databases.

Returns:



345
346
347
348
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 345

class ListDatabasesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token identifying a page of results the server should return.

Returns:

  • (::String)

    A token identifying a page of results the server should return.



345
346
347
348
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 345

class ListDatabasesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end