Class: Google::Cloud::OracleDatabase::V1::ListDbSystemShapesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb

Overview

The request for DbSystemShape.List.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. An expression for filtering the results of the request. Only the gcp_oracle_zone_id field is supported in this format: gcp_oracle_zone_id="{gcp_oracle_zone_id}".

Returns:

  • (::String)

    Optional. An expression for filtering the results of the request. Only the gcp_oracle_zone_id field is supported in this format: gcp_oracle_zone_id="{gcp_oracle_zone_id}".



376
377
378
379
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 376

class ListDbSystemShapesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. The maximum number of items to return. If unspecified, at most 50 database system shapes will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    Optional. The maximum number of items to return. If unspecified, at most 50 database system shapes will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.



376
377
378
379
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 376

class ListDbSystemShapesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A token identifying a page of results the server should return.

Returns:

  • (::String)

    Optional. A token identifying a page of results the server should return.



376
377
378
379
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 376

class ListDbSystemShapesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent value for Database System Shapes in the following format: projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. The parent value for Database System Shapes in the following format: projects/{project}/locations/{location}.



376
377
378
379
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 376

class ListDbSystemShapesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end