Class: Google::Cloud::OracleDatabase::V1::ListDbSystemsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/db_system.rb

Overview

The request for DbSystem.List.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. An expression for filtering the results of the request.

Returns:

  • (::String)

    Optional. An expression for filtering the results of the request.



363
364
365
366
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 363

class ListDbSystemsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. An expression for ordering the results of the request.

Returns:

  • (::String)

    Optional. An expression for ordering the results of the request.



363
364
365
366
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 363

class ListDbSystemsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. The maximum number of items to return. If unspecified, at most 50 DbSystems will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    Optional. The maximum number of items to return. If unspecified, at most 50 DbSystems will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.



363
364
365
366
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 363

class ListDbSystemsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A token identifying a page of results the server should return.

Returns:

  • (::String)

    Optional. A token identifying a page of results the server should return.



363
364
365
366
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 363

class ListDbSystemsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent value for DbSystems in the following format: projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. The parent value for DbSystems in the following format: projects/{project}/locations/{location}.



363
364
365
366
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 363

class ListDbSystemsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end