Class: Google::Cloud::OracleDatabase::V1::ListDbSystemsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/db_system.rb

Overview

The response for DbSystem.List.

Instance Attribute Summary collapse

Instance Attribute Details

#db_systems::Array<::Google::Cloud::OracleDatabase::V1::DbSystem>

Returns The list of DbSystems.

Returns:



379
380
381
382
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 379

class ListDbSystemsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token identifying a page of results the server should return.

Returns:

  • (::String)

    A token identifying a page of results the server should return.



379
380
381
382
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 379

class ListDbSystemsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachable::Array<::String>

Returns Unreachable locations when listing resources across all locations using wildcard location '-'.

Returns:

  • (::Array<::String>)

    Unreachable locations when listing resources across all locations using wildcard location '-'.



379
380
381
382
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system.rb', line 379

class ListDbSystemsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end