Class: Google::Cloud::OracleDatabase::V1::ListDbVersionsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/db_version.rb

Overview

The request for DbVersions.List.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Filter expression that matches a subset of the DbVersions to show. The supported filter for dbSystem creation is db_system_shape = \\{db_system_shape} AND storage_management = \\{storage_management}. If no filter is provided, all DbVersions will be returned.

Returns:

  • (::String)

    Optional. Filter expression that matches a subset of the DbVersions to show. The supported filter for dbSystem creation is db_system_shape = \\{db_system_shape} AND storage_management = \\{storage_management}. If no filter is provided, all DbVersions will be returned.



83
84
85
86
# File 'proto_docs/google/cloud/oracledatabase/v1/db_version.rb', line 83

class ListDbVersionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. The maximum number of items to return. If unspecified, a maximum of 50 DbVersions will be returned. The maximum value is 1000; values above 1000 will be reset to 1000.

Returns:

  • (::Integer)

    Optional. The maximum number of items to return. If unspecified, a maximum of 50 DbVersions will be returned. The maximum value is 1000; values above 1000 will be reset to 1000.



83
84
85
86
# File 'proto_docs/google/cloud/oracledatabase/v1/db_version.rb', line 83

class ListDbVersionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A token identifying the requested page of results to return. All fields except the filter should remain the same as in the request that provided this page token.

Returns:

  • (::String)

    Optional. A token identifying the requested page of results to return. All fields except the filter should remain the same as in the request that provided this page token.



83
84
85
86
# File 'proto_docs/google/cloud/oracledatabase/v1/db_version.rb', line 83

class ListDbVersionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent value for the DbVersion resource with the format: projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. The parent value for the DbVersion resource with the format: projects/{project}/locations/{location}



83
84
85
86
# File 'proto_docs/google/cloud/oracledatabase/v1/db_version.rb', line 83

class ListDbVersionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end