Class: Google::Cloud::OracleDatabase::V1::ListGiVersionsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::ListGiVersionsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb
Overview
The request for GiVersion.List.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. An expression for filtering the results of the request. Only the
shape, gcp_oracle_zone and gi_version fields are supported in this format:
shape="{shape}".
341 342 343 344 |
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 341 class ListGiVersionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. The maximum number of items to return. If unspecified, a maximum of 50 Oracle Grid Infrastructure (GI) versions will be returned. The maximum value is 1000; values above 1000 will be reset to 1000.
341 342 343 344 |
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 341 class ListGiVersionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A token identifying a page of results the server should return.
341 342 343 344 |
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 341 class ListGiVersionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent value for Grid Infrastructure Version in the following format: Format: projects/{project}/locations/{location}.
341 342 343 344 |
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 341 class ListGiVersionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |