Class: Google::Cloud::OracleDatabase::V1::ListGoldengateConnectionAssignmentsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/goldengate_connection_assignment.rb

Overview

Request message for listing GoldengateConnectionAssignments.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. A filter expression that filters GoldengateConnectionAssignments listed in the response.

Returns:

  • (::String)

    Optional. A filter expression that filters GoldengateConnectionAssignments listed in the response.



136
137
138
139
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection_assignment.rb', line 136

class ListGoldengateConnectionAssignmentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. A comma-separated list of fields to order by, sorted in ascending order. Use "DESC" after a field name for descending.

Returns:

  • (::String)

    Optional. A comma-separated list of fields to order by, sorted in ascending order. Use "DESC" after a field name for descending.



136
137
138
139
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection_assignment.rb', line 136

class ListGoldengateConnectionAssignmentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. The maximum number of GoldengateConnectionAssignments to return. The service may return fewer than this value. If unspecified, at most 50 GoldengateConnectionAssignments will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    Optional. The maximum number of GoldengateConnectionAssignments to return. The service may return fewer than this value. If unspecified, at most 50 GoldengateConnectionAssignments will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.



136
137
138
139
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection_assignment.rb', line 136

class ListGoldengateConnectionAssignmentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous ListGoldengateConnectionAssignments call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to ListGoldengateConnectionAssignments must match the call that provided the page token.

Returns:

  • (::String)

    Optional. A page token, received from a previous ListGoldengateConnectionAssignments call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to ListGoldengateConnectionAssignments must match the call that provided the page token.



136
137
138
139
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection_assignment.rb', line 136

class ListGoldengateConnectionAssignmentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent value for the GoldengateConnectionAssignments. Format: projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. The parent value for the GoldengateConnectionAssignments. Format: projects/{project}/locations/{location}



136
137
138
139
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection_assignment.rb', line 136

class ListGoldengateConnectionAssignmentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end