Class: Google::Cloud::OracleDatabase::V1::ListGoldengateDeploymentEnvironmentsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_environment.rb

Overview

Message for listing GoldengateDeploymentEnvironments.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Optional. The maximum number of items to return. If unspecified, at most 50 deployment environments will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    Optional. The maximum number of items to return. If unspecified, at most 50 deployment environments will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.



122
123
124
125
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_environment.rb', line 122

class ListGoldengateDeploymentEnvironmentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A token identifying a page of results the server should return.

Returns:

  • (::String)

    Optional. A token identifying a page of results the server should return.



122
123
124
125
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_environment.rb', line 122

class ListGoldengateDeploymentEnvironmentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent, which owns this collection of GoldengateDeploymentEnvironments. Format: projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. The parent, which owns this collection of GoldengateDeploymentEnvironments. Format: projects/{project}/locations/{location}



122
123
124
125
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_environment.rb', line 122

class ListGoldengateDeploymentEnvironmentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end