Class: Google::Cloud::OracleDatabase::V1::ListGoldengateDeploymentEnvironmentsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_environment.rb

Overview

Message for response to listing GoldengateDeploymentEnvironments

Instance Attribute Summary collapse

Instance Attribute Details

#goldengate_deployment_environments::Array<::Google::Cloud::OracleDatabase::V1::GoldengateDeploymentEnvironment>

Returns The list of GoldengateDeploymentEnvironment.

Returns:



138
139
140
141
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_environment.rb', line 138

class ListGoldengateDeploymentEnvironmentsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token identifying a page of results the server should return. If this field is empty, there are no subsequent pages.

Returns:

  • (::String)

    A token identifying a page of results the server should return. If this field is empty, there are no subsequent pages.



138
139
140
141
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_environment.rb', line 138

class ListGoldengateDeploymentEnvironmentsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachable::Array<::String>

Returns Unordered list. Locations that could not be reached.

Returns:

  • (::Array<::String>)

    Unordered list. Locations that could not be reached.



138
139
140
141
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_environment.rb', line 138

class ListGoldengateDeploymentEnvironmentsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end