Class: Google::Cloud::OracleDatabase::V1::ListGoldengateDeploymentVersionsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_version.rb

Overview

Message for listing GoldengateDeploymentVersions.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. An expression for filtering the results of the request. Either the deployment_id and deployment_type fields must be specified in the format: deployment_id="id" or deployment_type="DATABASE_ORACLE".

Returns:

  • (::String)

    Optional. An expression for filtering the results of the request. Either the deployment_id and deployment_type fields must be specified in the format: deployment_id="id" or deployment_type="DATABASE_ORACLE".



152
153
154
155
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_version.rb', line 152

class ListGoldengateDeploymentVersionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default. The maximum value is 1000; values above 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default. The maximum value is 1000; values above 1000 will be coerced to 1000.



152
153
154
155
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_version.rb', line 152

class ListGoldengateDeploymentVersionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A token identifying a page of results the server should return.

Returns:

  • (::String)

    Optional. A token identifying a page of results the server should return.



152
153
154
155
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_version.rb', line 152

class ListGoldengateDeploymentVersionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. Parent value for ListGoldengateDeploymentVersionsRequest Format: projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. Parent value for ListGoldengateDeploymentVersionsRequest Format: projects/{project}/locations/{location}



152
153
154
155
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_version.rb', line 152

class ListGoldengateDeploymentVersionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end