Class: Google::Cloud::OracleDatabase::V1::ListGoldengateDeploymentVersionsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_version.rb

Overview

Message for response to listing GoldengateDeploymentVersions

Instance Attribute Summary collapse

Instance Attribute Details

#goldengate_deployment_versions::Array<::Google::Cloud::OracleDatabase::V1::GoldengateDeploymentVersion>

Returns The list of GoldengateDeploymentVersion.

Returns:



168
169
170
171
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_version.rb', line 168

class ListGoldengateDeploymentVersionsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



168
169
170
171
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_version.rb', line 168

class ListGoldengateDeploymentVersionsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachable::Array<::String>

Returns Unordered list. Locations that could not be reached.

Returns:

  • (::Array<::String>)

    Unordered list. Locations that could not be reached.



168
169
170
171
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_version.rb', line 168

class ListGoldengateDeploymentVersionsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end