Class: Google::Cloud::OracleDatabase::V1::ListGoldengateDeploymentsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb

Overview

The request for GoldengateDeployment.List.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. An expression for filtering the results of the request.

Returns:

  • (::String)

    Optional. An expression for filtering the results of the request.



670
671
672
673
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 670

class ListGoldengateDeploymentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. An expression for ordering the results of the request.

Returns:

  • (::String)

    Optional. An expression for ordering the results of the request.



670
671
672
673
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 670

class ListGoldengateDeploymentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. The maximum number of items to return. If unspecified, at most 50 GoldengateDeployments will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    Optional. The maximum number of items to return. If unspecified, at most 50 GoldengateDeployments will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.



670
671
672
673
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 670

class ListGoldengateDeploymentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous ListGoldengateDeployments call. Provide this to retrieve the subsequent page.

Returns:

  • (::String)

    Optional. A page token, received from a previous ListGoldengateDeployments call. Provide this to retrieve the subsequent page.



670
671
672
673
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 670

class ListGoldengateDeploymentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent value for GoldengateDeployments in the following format: projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. The parent value for GoldengateDeployments in the following format: projects/{project}/locations/{location}.



670
671
672
673
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 670

class ListGoldengateDeploymentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end