Class: Google::Cloud::OracleDatabase::V1::ListMinorVersionsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/minor_version.rb

Overview

The request for MinorVersion.List.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. An expression for filtering the results of the request. Only shapeFamily and gcp_oracle_zone_id are supported in this format: shape_family="{shapeFamily}" AND gcp_oracle_zone_id="\\{gcp_oracle_zone_id}".

Returns:

  • (::String)

    Optional. An expression for filtering the results of the request. Only shapeFamily and gcp_oracle_zone_id are supported in this format: shape_family="{shapeFamily}" AND gcp_oracle_zone_id="\\{gcp_oracle_zone_id}".



62
63
64
65
# File 'proto_docs/google/cloud/oracledatabase/v1/minor_version.rb', line 62

class ListMinorVersionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. The maximum number of items to return. If unspecified, a maximum of 50 System Versions will be returned. The maximum value is 1000; values above 1000 will be reset to 1000.

Returns:

  • (::Integer)

    Optional. The maximum number of items to return. If unspecified, a maximum of 50 System Versions will be returned. The maximum value is 1000; values above 1000 will be reset to 1000.



62
63
64
65
# File 'proto_docs/google/cloud/oracledatabase/v1/minor_version.rb', line 62

class ListMinorVersionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A token identifying the requested page of results to return. All fields except the filter should remain the same as in the request that provided this page token.

Returns:

  • (::String)

    Optional. A token identifying the requested page of results to return. All fields except the filter should remain the same as in the request that provided this page token.



62
63
64
65
# File 'proto_docs/google/cloud/oracledatabase/v1/minor_version.rb', line 62

class ListMinorVersionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent value for the MinorVersion resource with the format: projects/{project}/locations/{location}/giVersions/{gi_version}.

Returns:

  • (::String)

    Required. The parent value for the MinorVersion resource with the format: projects/{project}/locations/{location}/giVersions/{gi_version}



62
63
64
65
# File 'proto_docs/google/cloud/oracledatabase/v1/minor_version.rb', line 62

class ListMinorVersionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end