Class: Google::Cloud::OracleDatabase::V1::ListOdbSubnetsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/odb_subnet.rb

Overview

The response for OdbSubnet.List.

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns A token identifying a page of results the server should return.

Returns:

  • (::String)

    A token identifying a page of results the server should return.



172
173
174
175
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_subnet.rb', line 172

class ListOdbSubnetsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#odb_subnets::Array<::Google::Cloud::OracleDatabase::V1::OdbSubnet>

Returns The list of ODB Subnets.

Returns:



172
173
174
175
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_subnet.rb', line 172

class ListOdbSubnetsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachable::Array<::String>

Returns Unreachable locations when listing resources across all locations using wildcard location '-'.

Returns:

  • (::Array<::String>)

    Unreachable locations when listing resources across all locations using wildcard location '-'.



172
173
174
175
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_subnet.rb', line 172

class ListOdbSubnetsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end