Class: Google::Cloud::OracleDatabase::V1::ListPluggableDatabasesResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb

Overview

The response for PluggableDatabase.List.

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns A token identifying a page of results the server should return.

Returns:

  • (::String)

    A token identifying a page of results the server should return.



359
360
361
362
# File 'proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb', line 359

class ListPluggableDatabasesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#pluggable_databases::Array<::Google::Cloud::OracleDatabase::V1::PluggableDatabase>

Returns The list of PluggableDatabases.

Returns:



359
360
361
362
# File 'proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb', line 359

class ListPluggableDatabasesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end