Class: Google::Cloud::OracleDatabase::V1::MaintenanceWindow

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb

Overview

Defined Under Namespace

Modules: MaintenanceWindowPreference, PatchingMode

Instance Attribute Summary collapse

Instance Attribute Details

#custom_action_timeout_mins::Integer

Returns Optional. Determines the amount of time the system will wait before the start of each database server patching operation. Custom action timeout is in minutes and valid value is between 15 to 120 (inclusive).

Returns:

  • (::Integer)

    Optional. Determines the amount of time the system will wait before the start of each database server patching operation. Custom action timeout is in minutes and valid value is between 15 to 120 (inclusive).



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 259

class MaintenanceWindow
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Maintenance window preference.
  module MaintenanceWindowPreference
    # Default unspecified value.
    MAINTENANCE_WINDOW_PREFERENCE_UNSPECIFIED = 0

    # Custom preference.
    CUSTOM_PREFERENCE = 1

    # No preference.
    NO_PREFERENCE = 2
  end

  # Patching mode.
  module PatchingMode
    # Default unspecified value.
    PATCHING_MODE_UNSPECIFIED = 0

    # Updates the Cloud Exadata database server hosts in a rolling fashion.
    ROLLING = 1

    # The non-rolling maintenance method first updates your storage servers at
    # the same time, then your database servers at the same time.
    NON_ROLLING = 2
  end
end

#days_of_week::Array<::Google::Type::DayOfWeek>

Returns Optional. Days during the week when maintenance should be performed.

Returns:



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 259

class MaintenanceWindow
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Maintenance window preference.
  module MaintenanceWindowPreference
    # Default unspecified value.
    MAINTENANCE_WINDOW_PREFERENCE_UNSPECIFIED = 0

    # Custom preference.
    CUSTOM_PREFERENCE = 1

    # No preference.
    NO_PREFERENCE = 2
  end

  # Patching mode.
  module PatchingMode
    # Default unspecified value.
    PATCHING_MODE_UNSPECIFIED = 0

    # Updates the Cloud Exadata database server hosts in a rolling fashion.
    ROLLING = 1

    # The non-rolling maintenance method first updates your storage servers at
    # the same time, then your database servers at the same time.
    NON_ROLLING = 2
  end
end

#hours_of_day::Array<::Integer>

Returns Optional. The window of hours during the day when maintenance should be performed. The window is a 4 hour slot. Valid values are: 0 - represents time slot 0:00 - 3:59 UTC 4 - represents time slot 4:00 - 7:59 UTC 8 - represents time slot 8:00 - 11:59 UTC 12 - represents time slot 12:00 - 15:59 UTC 16 - represents time slot 16:00 - 19:59 UTC 20 - represents time slot 20:00 - 23:59 UTC.

Returns:

  • (::Array<::Integer>)

    Optional. The window of hours during the day when maintenance should be performed. The window is a 4 hour slot. Valid values are: 0 - represents time slot 0:00 - 3:59 UTC 4 - represents time slot 4:00 - 7:59 UTC 8 - represents time slot 8:00 - 11:59 UTC 12 - represents time slot 12:00 - 15:59 UTC 16 - represents time slot 16:00 - 19:59 UTC 20 - represents time slot 20:00 - 23:59 UTC



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 259

class MaintenanceWindow
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Maintenance window preference.
  module MaintenanceWindowPreference
    # Default unspecified value.
    MAINTENANCE_WINDOW_PREFERENCE_UNSPECIFIED = 0

    # Custom preference.
    CUSTOM_PREFERENCE = 1

    # No preference.
    NO_PREFERENCE = 2
  end

  # Patching mode.
  module PatchingMode
    # Default unspecified value.
    PATCHING_MODE_UNSPECIFIED = 0

    # Updates the Cloud Exadata database server hosts in a rolling fashion.
    ROLLING = 1

    # The non-rolling maintenance method first updates your storage servers at
    # the same time, then your database servers at the same time.
    NON_ROLLING = 2
  end
end

#is_custom_action_timeout_enabled::Boolean

Returns Optional. If true, enables the configuration of a custom action timeout (waiting period) between database server patching operations.

Returns:

  • (::Boolean)

    Optional. If true, enables the configuration of a custom action timeout (waiting period) between database server patching operations.



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 259

class MaintenanceWindow
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Maintenance window preference.
  module MaintenanceWindowPreference
    # Default unspecified value.
    MAINTENANCE_WINDOW_PREFERENCE_UNSPECIFIED = 0

    # Custom preference.
    CUSTOM_PREFERENCE = 1

    # No preference.
    NO_PREFERENCE = 2
  end

  # Patching mode.
  module PatchingMode
    # Default unspecified value.
    PATCHING_MODE_UNSPECIFIED = 0

    # Updates the Cloud Exadata database server hosts in a rolling fashion.
    ROLLING = 1

    # The non-rolling maintenance method first updates your storage servers at
    # the same time, then your database servers at the same time.
    NON_ROLLING = 2
  end
end

#lead_time_week::Integer

Returns Optional. Lead time window allows user to set a lead time to prepare for a down time. The lead time is in weeks and valid value is between 1 to 4.

Returns:

  • (::Integer)

    Optional. Lead time window allows user to set a lead time to prepare for a down time. The lead time is in weeks and valid value is between 1 to 4.



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 259

class MaintenanceWindow
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Maintenance window preference.
  module MaintenanceWindowPreference
    # Default unspecified value.
    MAINTENANCE_WINDOW_PREFERENCE_UNSPECIFIED = 0

    # Custom preference.
    CUSTOM_PREFERENCE = 1

    # No preference.
    NO_PREFERENCE = 2
  end

  # Patching mode.
  module PatchingMode
    # Default unspecified value.
    PATCHING_MODE_UNSPECIFIED = 0

    # Updates the Cloud Exadata database server hosts in a rolling fashion.
    ROLLING = 1

    # The non-rolling maintenance method first updates your storage servers at
    # the same time, then your database servers at the same time.
    NON_ROLLING = 2
  end
end

#months::Array<::Google::Type::Month>

Returns Optional. Months during the year when maintenance should be performed.

Returns:

  • (::Array<::Google::Type::Month>)

    Optional. Months during the year when maintenance should be performed.



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 259

class MaintenanceWindow
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Maintenance window preference.
  module MaintenanceWindowPreference
    # Default unspecified value.
    MAINTENANCE_WINDOW_PREFERENCE_UNSPECIFIED = 0

    # Custom preference.
    CUSTOM_PREFERENCE = 1

    # No preference.
    NO_PREFERENCE = 2
  end

  # Patching mode.
  module PatchingMode
    # Default unspecified value.
    PATCHING_MODE_UNSPECIFIED = 0

    # Updates the Cloud Exadata database server hosts in a rolling fashion.
    ROLLING = 1

    # The non-rolling maintenance method first updates your storage servers at
    # the same time, then your database servers at the same time.
    NON_ROLLING = 2
  end
end

#patching_mode::Google::Cloud::OracleDatabase::V1::MaintenanceWindow::PatchingMode

Returns Optional. Cloud CloudExadataInfrastructure node patching method, either "ROLLING" or "NONROLLING". Default value is ROLLING.

Returns:



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 259

class MaintenanceWindow
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Maintenance window preference.
  module MaintenanceWindowPreference
    # Default unspecified value.
    MAINTENANCE_WINDOW_PREFERENCE_UNSPECIFIED = 0

    # Custom preference.
    CUSTOM_PREFERENCE = 1

    # No preference.
    NO_PREFERENCE = 2
  end

  # Patching mode.
  module PatchingMode
    # Default unspecified value.
    PATCHING_MODE_UNSPECIFIED = 0

    # Updates the Cloud Exadata database server hosts in a rolling fashion.
    ROLLING = 1

    # The non-rolling maintenance method first updates your storage servers at
    # the same time, then your database servers at the same time.
    NON_ROLLING = 2
  end
end

#preference::Google::Cloud::OracleDatabase::V1::MaintenanceWindow::MaintenanceWindowPreference

Returns Optional. The maintenance window scheduling preference.

Returns:



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 259

class MaintenanceWindow
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Maintenance window preference.
  module MaintenanceWindowPreference
    # Default unspecified value.
    MAINTENANCE_WINDOW_PREFERENCE_UNSPECIFIED = 0

    # Custom preference.
    CUSTOM_PREFERENCE = 1

    # No preference.
    NO_PREFERENCE = 2
  end

  # Patching mode.
  module PatchingMode
    # Default unspecified value.
    PATCHING_MODE_UNSPECIFIED = 0

    # Updates the Cloud Exadata database server hosts in a rolling fashion.
    ROLLING = 1

    # The non-rolling maintenance method first updates your storage servers at
    # the same time, then your database servers at the same time.
    NON_ROLLING = 2
  end
end

#weeks_of_month::Array<::Integer>

Returns Optional. Weeks during the month when maintenance should be performed. Weeks start on the 1st, 8th, 15th, and 22nd days of the month, and have a duration of 7 days. Weeks start and end based on calendar dates, not days of the week.

Returns:

  • (::Array<::Integer>)

    Optional. Weeks during the month when maintenance should be performed. Weeks start on the 1st, 8th, 15th, and 22nd days of the month, and have a duration of 7 days. Weeks start and end based on calendar dates, not days of the week.



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'proto_docs/google/cloud/oracledatabase/v1/exadata_infra.rb', line 259

class MaintenanceWindow
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Maintenance window preference.
  module MaintenanceWindowPreference
    # Default unspecified value.
    MAINTENANCE_WINDOW_PREFERENCE_UNSPECIFIED = 0

    # Custom preference.
    CUSTOM_PREFERENCE = 1

    # No preference.
    NO_PREFERENCE = 2
  end

  # Patching mode.
  module PatchingMode
    # Default unspecified value.
    PATCHING_MODE_UNSPECIFIED = 0

    # Updates the Cloud Exadata database server hosts in a rolling fashion.
    ROLLING = 1

    # The non-rolling maintenance method first updates your storage servers at
    # the same time, then your database servers at the same time.
    NON_ROLLING = 2
  end
end