Class: Google::Cloud::OracleDatabase::V1::PluggableDatabaseConnectionStrings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb

Overview

The connection strings used to connect to the Oracle Database.

Defined Under Namespace

Classes: AllConnectionStringsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#all_connection_strings::Google::Protobuf::Map{::String => ::String}

Returns Optional. All connection strings to use to connect to the pluggable database.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. All connection strings to use to connect to the pluggable database.



213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb', line 213

class PluggableDatabaseConnectionStrings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AllConnectionStringsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#pdb_default::String

Returns Optional. The default connection string to use to connect to the pluggable database.

Returns:

  • (::String)

    Optional. The default connection string to use to connect to the pluggable database.



213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb', line 213

class PluggableDatabaseConnectionStrings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AllConnectionStringsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#pdb_ip_default::String

Returns Optional. The default connection string to use to connect to the pluggable database using IP.

Returns:

  • (::String)

    Optional. The default connection string to use to connect to the pluggable database using IP.



213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb', line 213

class PluggableDatabaseConnectionStrings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AllConnectionStringsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end