Class: Google::Cloud::OracleDatabase::V1::PluggableDatabaseProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb

Overview

The properties of a PluggableDatabase.

Defined Under Namespace

Modules: OperationsInsightsState, PluggableDatabaseLifecycleState Classes: DefinedTagValue, DefinedTagsEntry, FreeformTagsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#compartment_id::String

Returns Required. The OCID of the compartment.

Returns:

  • (::String)

    Required. The OCID of the compartment.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb', line 90

class PluggableDatabaseProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Wrapper message for the value of a defined tag.
  # @!attribute [rw] tags
  #   @return [::Google::Protobuf::Map{::String => ::String}]
  #     The tags within the namespace.
  class DefinedTagValue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] key
    #   @return [::String]
    # @!attribute [rw] value
    #   @return [::String]
    class TagsEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::OracleDatabase::V1::PluggableDatabaseProperties::DefinedTagValue]
  class DefinedTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class FreeformTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The various lifecycle states of the PluggableDatabase.
  module PluggableDatabaseLifecycleState
    # The lifecycle state is unspecified.
    PLUGGABLE_DATABASE_LIFECYCLE_STATE_UNSPECIFIED = 0

    # The pluggable database is provisioning.
    PROVISIONING = 1

    # The pluggable database is available.
    AVAILABLE = 2

    # The pluggable database is terminating.
    TERMINATING = 3

    # The pluggable database is terminated.
    TERMINATED = 4

    # The pluggable database is updating.
    UPDATING = 5

    # The pluggable database is in a failed state.
    FAILED = 6

    # The pluggable database is relocating.
    RELOCATING = 7

    # The pluggable database is relocated.
    RELOCATED = 8

    # The pluggable database is refreshing.
    REFRESHING = 9

    # The pluggable database is restoring.
    RESTORE_IN_PROGRESS = 10

    # The pluggable database restore failed.
    RESTORE_FAILED = 11

    # The pluggable database is backing up.
    BACKUP_IN_PROGRESS = 12

    # The pluggable database is disabled.
    DISABLED = 13
  end

  # The status of Operations Insights for this Database.
  module OperationsInsightsState
    # The status is not specified.
    OPERATIONS_INSIGHTS_STATE_UNSPECIFIED = 0

    # Operations Insights is enabling.
    ENABLING = 1

    # Operations Insights is enabled.
    ENABLED = 2

    # Operations Insights is disabling.
    DISABLING = 3

    # Operations Insights is not enabled.
    NOT_ENABLED = 4

    # Operations Insights failed to enable.
    FAILED_ENABLING = 5

    # Operations Insights failed to disable.
    FAILED_DISABLING = 6
  end
end

#connection_strings::Google::Cloud::OracleDatabase::V1::PluggableDatabaseConnectionStrings

Returns Optional. The Connection strings used to connect to the Oracle Database.

Returns:



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb', line 90

class PluggableDatabaseProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Wrapper message for the value of a defined tag.
  # @!attribute [rw] tags
  #   @return [::Google::Protobuf::Map{::String => ::String}]
  #     The tags within the namespace.
  class DefinedTagValue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] key
    #   @return [::String]
    # @!attribute [rw] value
    #   @return [::String]
    class TagsEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::OracleDatabase::V1::PluggableDatabaseProperties::DefinedTagValue]
  class DefinedTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class FreeformTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The various lifecycle states of the PluggableDatabase.
  module PluggableDatabaseLifecycleState
    # The lifecycle state is unspecified.
    PLUGGABLE_DATABASE_LIFECYCLE_STATE_UNSPECIFIED = 0

    # The pluggable database is provisioning.
    PROVISIONING = 1

    # The pluggable database is available.
    AVAILABLE = 2

    # The pluggable database is terminating.
    TERMINATING = 3

    # The pluggable database is terminated.
    TERMINATED = 4

    # The pluggable database is updating.
    UPDATING = 5

    # The pluggable database is in a failed state.
    FAILED = 6

    # The pluggable database is relocating.
    RELOCATING = 7

    # The pluggable database is relocated.
    RELOCATED = 8

    # The pluggable database is refreshing.
    REFRESHING = 9

    # The pluggable database is restoring.
    RESTORE_IN_PROGRESS = 10

    # The pluggable database restore failed.
    RESTORE_FAILED = 11

    # The pluggable database is backing up.
    BACKUP_IN_PROGRESS = 12

    # The pluggable database is disabled.
    DISABLED = 13
  end

  # The status of Operations Insights for this Database.
  module OperationsInsightsState
    # The status is not specified.
    OPERATIONS_INSIGHTS_STATE_UNSPECIFIED = 0

    # Operations Insights is enabling.
    ENABLING = 1

    # Operations Insights is enabled.
    ENABLED = 2

    # Operations Insights is disabling.
    DISABLING = 3

    # Operations Insights is not enabled.
    NOT_ENABLED = 4

    # Operations Insights failed to enable.
    FAILED_ENABLING = 5

    # Operations Insights failed to disable.
    FAILED_DISABLING = 6
  end
end

#container_database_ocid::String

Returns Required. The OCID of the CDB.

Returns:

  • (::String)

    Required. The OCID of the CDB.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb', line 90

class PluggableDatabaseProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Wrapper message for the value of a defined tag.
  # @!attribute [rw] tags
  #   @return [::Google::Protobuf::Map{::String => ::String}]
  #     The tags within the namespace.
  class DefinedTagValue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] key
    #   @return [::String]
    # @!attribute [rw] value
    #   @return [::String]
    class TagsEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::OracleDatabase::V1::PluggableDatabaseProperties::DefinedTagValue]
  class DefinedTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class FreeformTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The various lifecycle states of the PluggableDatabase.
  module PluggableDatabaseLifecycleState
    # The lifecycle state is unspecified.
    PLUGGABLE_DATABASE_LIFECYCLE_STATE_UNSPECIFIED = 0

    # The pluggable database is provisioning.
    PROVISIONING = 1

    # The pluggable database is available.
    AVAILABLE = 2

    # The pluggable database is terminating.
    TERMINATING = 3

    # The pluggable database is terminated.
    TERMINATED = 4

    # The pluggable database is updating.
    UPDATING = 5

    # The pluggable database is in a failed state.
    FAILED = 6

    # The pluggable database is relocating.
    RELOCATING = 7

    # The pluggable database is relocated.
    RELOCATED = 8

    # The pluggable database is refreshing.
    REFRESHING = 9

    # The pluggable database is restoring.
    RESTORE_IN_PROGRESS = 10

    # The pluggable database restore failed.
    RESTORE_FAILED = 11

    # The pluggable database is backing up.
    BACKUP_IN_PROGRESS = 12

    # The pluggable database is disabled.
    DISABLED = 13
  end

  # The status of Operations Insights for this Database.
  module OperationsInsightsState
    # The status is not specified.
    OPERATIONS_INSIGHTS_STATE_UNSPECIFIED = 0

    # Operations Insights is enabling.
    ENABLING = 1

    # Operations Insights is enabled.
    ENABLED = 2

    # Operations Insights is disabling.
    DISABLING = 3

    # Operations Insights is not enabled.
    NOT_ENABLED = 4

    # Operations Insights failed to enable.
    FAILED_ENABLING = 5

    # Operations Insights failed to disable.
    FAILED_DISABLING = 6
  end
end

#database_management_config::Google::Cloud::OracleDatabase::V1::DatabaseManagementConfig (readonly)

Returns Output only. The configuration of the Database Management service.

Returns:



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb', line 90

class PluggableDatabaseProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Wrapper message for the value of a defined tag.
  # @!attribute [rw] tags
  #   @return [::Google::Protobuf::Map{::String => ::String}]
  #     The tags within the namespace.
  class DefinedTagValue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] key
    #   @return [::String]
    # @!attribute [rw] value
    #   @return [::String]
    class TagsEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::OracleDatabase::V1::PluggableDatabaseProperties::DefinedTagValue]
  class DefinedTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class FreeformTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The various lifecycle states of the PluggableDatabase.
  module PluggableDatabaseLifecycleState
    # The lifecycle state is unspecified.
    PLUGGABLE_DATABASE_LIFECYCLE_STATE_UNSPECIFIED = 0

    # The pluggable database is provisioning.
    PROVISIONING = 1

    # The pluggable database is available.
    AVAILABLE = 2

    # The pluggable database is terminating.
    TERMINATING = 3

    # The pluggable database is terminated.
    TERMINATED = 4

    # The pluggable database is updating.
    UPDATING = 5

    # The pluggable database is in a failed state.
    FAILED = 6

    # The pluggable database is relocating.
    RELOCATING = 7

    # The pluggable database is relocated.
    RELOCATED = 8

    # The pluggable database is refreshing.
    REFRESHING = 9

    # The pluggable database is restoring.
    RESTORE_IN_PROGRESS = 10

    # The pluggable database restore failed.
    RESTORE_FAILED = 11

    # The pluggable database is backing up.
    BACKUP_IN_PROGRESS = 12

    # The pluggable database is disabled.
    DISABLED = 13
  end

  # The status of Operations Insights for this Database.
  module OperationsInsightsState
    # The status is not specified.
    OPERATIONS_INSIGHTS_STATE_UNSPECIFIED = 0

    # Operations Insights is enabling.
    ENABLING = 1

    # Operations Insights is enabled.
    ENABLED = 2

    # Operations Insights is disabling.
    DISABLING = 3

    # Operations Insights is not enabled.
    NOT_ENABLED = 4

    # Operations Insights failed to enable.
    FAILED_ENABLING = 5

    # Operations Insights failed to disable.
    FAILED_DISABLING = 6
  end
end

#defined_tags::Google::Protobuf::Map{::String => ::Google::Cloud::OracleDatabase::V1::PluggableDatabaseProperties::DefinedTagValue}

Returns Optional. Defined tags for this resource. Each key is predefined and scoped to a namespace.

Returns:



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb', line 90

class PluggableDatabaseProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Wrapper message for the value of a defined tag.
  # @!attribute [rw] tags
  #   @return [::Google::Protobuf::Map{::String => ::String}]
  #     The tags within the namespace.
  class DefinedTagValue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] key
    #   @return [::String]
    # @!attribute [rw] value
    #   @return [::String]
    class TagsEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::OracleDatabase::V1::PluggableDatabaseProperties::DefinedTagValue]
  class DefinedTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class FreeformTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The various lifecycle states of the PluggableDatabase.
  module PluggableDatabaseLifecycleState
    # The lifecycle state is unspecified.
    PLUGGABLE_DATABASE_LIFECYCLE_STATE_UNSPECIFIED = 0

    # The pluggable database is provisioning.
    PROVISIONING = 1

    # The pluggable database is available.
    AVAILABLE = 2

    # The pluggable database is terminating.
    TERMINATING = 3

    # The pluggable database is terminated.
    TERMINATED = 4

    # The pluggable database is updating.
    UPDATING = 5

    # The pluggable database is in a failed state.
    FAILED = 6

    # The pluggable database is relocating.
    RELOCATING = 7

    # The pluggable database is relocated.
    RELOCATED = 8

    # The pluggable database is refreshing.
    REFRESHING = 9

    # The pluggable database is restoring.
    RESTORE_IN_PROGRESS = 10

    # The pluggable database restore failed.
    RESTORE_FAILED = 11

    # The pluggable database is backing up.
    BACKUP_IN_PROGRESS = 12

    # The pluggable database is disabled.
    DISABLED = 13
  end

  # The status of Operations Insights for this Database.
  module OperationsInsightsState
    # The status is not specified.
    OPERATIONS_INSIGHTS_STATE_UNSPECIFIED = 0

    # Operations Insights is enabling.
    ENABLING = 1

    # Operations Insights is enabled.
    ENABLED = 2

    # Operations Insights is disabling.
    DISABLING = 3

    # Operations Insights is not enabled.
    NOT_ENABLED = 4

    # Operations Insights failed to enable.
    FAILED_ENABLING = 5

    # Operations Insights failed to disable.
    FAILED_DISABLING = 6
  end
end

#freeform_tags::Google::Protobuf::Map{::String => ::String}

Returns Optional. Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb', line 90

class PluggableDatabaseProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Wrapper message for the value of a defined tag.
  # @!attribute [rw] tags
  #   @return [::Google::Protobuf::Map{::String => ::String}]
  #     The tags within the namespace.
  class DefinedTagValue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] key
    #   @return [::String]
    # @!attribute [rw] value
    #   @return [::String]
    class TagsEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::OracleDatabase::V1::PluggableDatabaseProperties::DefinedTagValue]
  class DefinedTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class FreeformTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The various lifecycle states of the PluggableDatabase.
  module PluggableDatabaseLifecycleState
    # The lifecycle state is unspecified.
    PLUGGABLE_DATABASE_LIFECYCLE_STATE_UNSPECIFIED = 0

    # The pluggable database is provisioning.
    PROVISIONING = 1

    # The pluggable database is available.
    AVAILABLE = 2

    # The pluggable database is terminating.
    TERMINATING = 3

    # The pluggable database is terminated.
    TERMINATED = 4

    # The pluggable database is updating.
    UPDATING = 5

    # The pluggable database is in a failed state.
    FAILED = 6

    # The pluggable database is relocating.
    RELOCATING = 7

    # The pluggable database is relocated.
    RELOCATED = 8

    # The pluggable database is refreshing.
    REFRESHING = 9

    # The pluggable database is restoring.
    RESTORE_IN_PROGRESS = 10

    # The pluggable database restore failed.
    RESTORE_FAILED = 11

    # The pluggable database is backing up.
    BACKUP_IN_PROGRESS = 12

    # The pluggable database is disabled.
    DISABLED = 13
  end

  # The status of Operations Insights for this Database.
  module OperationsInsightsState
    # The status is not specified.
    OPERATIONS_INSIGHTS_STATE_UNSPECIFIED = 0

    # Operations Insights is enabling.
    ENABLING = 1

    # Operations Insights is enabled.
    ENABLED = 2

    # Operations Insights is disabling.
    DISABLING = 3

    # Operations Insights is not enabled.
    NOT_ENABLED = 4

    # Operations Insights failed to enable.
    FAILED_ENABLING = 5

    # Operations Insights failed to disable.
    FAILED_DISABLING = 6
  end
end

#is_restricted::Boolean

Returns Optional. The restricted mode of the pluggable database. If a pluggable database is opened in restricted mode, the user needs both create a session and have restricted session privileges to connect to it.

Returns:

  • (::Boolean)

    Optional. The restricted mode of the pluggable database. If a pluggable database is opened in restricted mode, the user needs both create a session and have restricted session privileges to connect to it.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb', line 90

class PluggableDatabaseProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Wrapper message for the value of a defined tag.
  # @!attribute [rw] tags
  #   @return [::Google::Protobuf::Map{::String => ::String}]
  #     The tags within the namespace.
  class DefinedTagValue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] key
    #   @return [::String]
    # @!attribute [rw] value
    #   @return [::String]
    class TagsEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::OracleDatabase::V1::PluggableDatabaseProperties::DefinedTagValue]
  class DefinedTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class FreeformTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The various lifecycle states of the PluggableDatabase.
  module PluggableDatabaseLifecycleState
    # The lifecycle state is unspecified.
    PLUGGABLE_DATABASE_LIFECYCLE_STATE_UNSPECIFIED = 0

    # The pluggable database is provisioning.
    PROVISIONING = 1

    # The pluggable database is available.
    AVAILABLE = 2

    # The pluggable database is terminating.
    TERMINATING = 3

    # The pluggable database is terminated.
    TERMINATED = 4

    # The pluggable database is updating.
    UPDATING = 5

    # The pluggable database is in a failed state.
    FAILED = 6

    # The pluggable database is relocating.
    RELOCATING = 7

    # The pluggable database is relocated.
    RELOCATED = 8

    # The pluggable database is refreshing.
    REFRESHING = 9

    # The pluggable database is restoring.
    RESTORE_IN_PROGRESS = 10

    # The pluggable database restore failed.
    RESTORE_FAILED = 11

    # The pluggable database is backing up.
    BACKUP_IN_PROGRESS = 12

    # The pluggable database is disabled.
    DISABLED = 13
  end

  # The status of Operations Insights for this Database.
  module OperationsInsightsState
    # The status is not specified.
    OPERATIONS_INSIGHTS_STATE_UNSPECIFIED = 0

    # Operations Insights is enabling.
    ENABLING = 1

    # Operations Insights is enabled.
    ENABLED = 2

    # Operations Insights is disabling.
    DISABLING = 3

    # Operations Insights is not enabled.
    NOT_ENABLED = 4

    # Operations Insights failed to enable.
    FAILED_ENABLING = 5

    # Operations Insights failed to disable.
    FAILED_DISABLING = 6
  end
end

#lifecycle_details::String (readonly)

Returns Output only. Additional information about the current lifecycle state.

Returns:

  • (::String)

    Output only. Additional information about the current lifecycle state.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb', line 90

class PluggableDatabaseProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Wrapper message for the value of a defined tag.
  # @!attribute [rw] tags
  #   @return [::Google::Protobuf::Map{::String => ::String}]
  #     The tags within the namespace.
  class DefinedTagValue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] key
    #   @return [::String]
    # @!attribute [rw] value
    #   @return [::String]
    class TagsEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::OracleDatabase::V1::PluggableDatabaseProperties::DefinedTagValue]
  class DefinedTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class FreeformTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The various lifecycle states of the PluggableDatabase.
  module PluggableDatabaseLifecycleState
    # The lifecycle state is unspecified.
    PLUGGABLE_DATABASE_LIFECYCLE_STATE_UNSPECIFIED = 0

    # The pluggable database is provisioning.
    PROVISIONING = 1

    # The pluggable database is available.
    AVAILABLE = 2

    # The pluggable database is terminating.
    TERMINATING = 3

    # The pluggable database is terminated.
    TERMINATED = 4

    # The pluggable database is updating.
    UPDATING = 5

    # The pluggable database is in a failed state.
    FAILED = 6

    # The pluggable database is relocating.
    RELOCATING = 7

    # The pluggable database is relocated.
    RELOCATED = 8

    # The pluggable database is refreshing.
    REFRESHING = 9

    # The pluggable database is restoring.
    RESTORE_IN_PROGRESS = 10

    # The pluggable database restore failed.
    RESTORE_FAILED = 11

    # The pluggable database is backing up.
    BACKUP_IN_PROGRESS = 12

    # The pluggable database is disabled.
    DISABLED = 13
  end

  # The status of Operations Insights for this Database.
  module OperationsInsightsState
    # The status is not specified.
    OPERATIONS_INSIGHTS_STATE_UNSPECIFIED = 0

    # Operations Insights is enabling.
    ENABLING = 1

    # Operations Insights is enabled.
    ENABLED = 2

    # Operations Insights is disabling.
    DISABLING = 3

    # Operations Insights is not enabled.
    NOT_ENABLED = 4

    # Operations Insights failed to enable.
    FAILED_ENABLING = 5

    # Operations Insights failed to disable.
    FAILED_DISABLING = 6
  end
end

#lifecycle_state::Google::Cloud::OracleDatabase::V1::PluggableDatabaseProperties::PluggableDatabaseLifecycleState (readonly)

Returns Output only. The current state of the pluggable database.

Returns:



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb', line 90

class PluggableDatabaseProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Wrapper message for the value of a defined tag.
  # @!attribute [rw] tags
  #   @return [::Google::Protobuf::Map{::String => ::String}]
  #     The tags within the namespace.
  class DefinedTagValue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] key
    #   @return [::String]
    # @!attribute [rw] value
    #   @return [::String]
    class TagsEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::OracleDatabase::V1::PluggableDatabaseProperties::DefinedTagValue]
  class DefinedTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class FreeformTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The various lifecycle states of the PluggableDatabase.
  module PluggableDatabaseLifecycleState
    # The lifecycle state is unspecified.
    PLUGGABLE_DATABASE_LIFECYCLE_STATE_UNSPECIFIED = 0

    # The pluggable database is provisioning.
    PROVISIONING = 1

    # The pluggable database is available.
    AVAILABLE = 2

    # The pluggable database is terminating.
    TERMINATING = 3

    # The pluggable database is terminated.
    TERMINATED = 4

    # The pluggable database is updating.
    UPDATING = 5

    # The pluggable database is in a failed state.
    FAILED = 6

    # The pluggable database is relocating.
    RELOCATING = 7

    # The pluggable database is relocated.
    RELOCATED = 8

    # The pluggable database is refreshing.
    REFRESHING = 9

    # The pluggable database is restoring.
    RESTORE_IN_PROGRESS = 10

    # The pluggable database restore failed.
    RESTORE_FAILED = 11

    # The pluggable database is backing up.
    BACKUP_IN_PROGRESS = 12

    # The pluggable database is disabled.
    DISABLED = 13
  end

  # The status of Operations Insights for this Database.
  module OperationsInsightsState
    # The status is not specified.
    OPERATIONS_INSIGHTS_STATE_UNSPECIFIED = 0

    # Operations Insights is enabling.
    ENABLING = 1

    # Operations Insights is enabled.
    ENABLED = 2

    # Operations Insights is disabling.
    DISABLING = 3

    # Operations Insights is not enabled.
    NOT_ENABLED = 4

    # Operations Insights failed to enable.
    FAILED_ENABLING = 5

    # Operations Insights failed to disable.
    FAILED_DISABLING = 6
  end
end

#ocid::String (readonly)

Returns Output only. The OCID of the pluggable database.

Returns:

  • (::String)

    Output only. The OCID of the pluggable database.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb', line 90

class PluggableDatabaseProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Wrapper message for the value of a defined tag.
  # @!attribute [rw] tags
  #   @return [::Google::Protobuf::Map{::String => ::String}]
  #     The tags within the namespace.
  class DefinedTagValue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] key
    #   @return [::String]
    # @!attribute [rw] value
    #   @return [::String]
    class TagsEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::OracleDatabase::V1::PluggableDatabaseProperties::DefinedTagValue]
  class DefinedTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class FreeformTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The various lifecycle states of the PluggableDatabase.
  module PluggableDatabaseLifecycleState
    # The lifecycle state is unspecified.
    PLUGGABLE_DATABASE_LIFECYCLE_STATE_UNSPECIFIED = 0

    # The pluggable database is provisioning.
    PROVISIONING = 1

    # The pluggable database is available.
    AVAILABLE = 2

    # The pluggable database is terminating.
    TERMINATING = 3

    # The pluggable database is terminated.
    TERMINATED = 4

    # The pluggable database is updating.
    UPDATING = 5

    # The pluggable database is in a failed state.
    FAILED = 6

    # The pluggable database is relocating.
    RELOCATING = 7

    # The pluggable database is relocated.
    RELOCATED = 8

    # The pluggable database is refreshing.
    REFRESHING = 9

    # The pluggable database is restoring.
    RESTORE_IN_PROGRESS = 10

    # The pluggable database restore failed.
    RESTORE_FAILED = 11

    # The pluggable database is backing up.
    BACKUP_IN_PROGRESS = 12

    # The pluggable database is disabled.
    DISABLED = 13
  end

  # The status of Operations Insights for this Database.
  module OperationsInsightsState
    # The status is not specified.
    OPERATIONS_INSIGHTS_STATE_UNSPECIFIED = 0

    # Operations Insights is enabling.
    ENABLING = 1

    # Operations Insights is enabled.
    ENABLED = 2

    # Operations Insights is disabling.
    DISABLING = 3

    # Operations Insights is not enabled.
    NOT_ENABLED = 4

    # Operations Insights failed to enable.
    FAILED_ENABLING = 5

    # Operations Insights failed to disable.
    FAILED_DISABLING = 6
  end
end

#operations_insights_state::Google::Cloud::OracleDatabase::V1::PluggableDatabaseProperties::OperationsInsightsState (readonly)

Returns Output only. The status of Operations Insights for this Database.

Returns:



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb', line 90

class PluggableDatabaseProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Wrapper message for the value of a defined tag.
  # @!attribute [rw] tags
  #   @return [::Google::Protobuf::Map{::String => ::String}]
  #     The tags within the namespace.
  class DefinedTagValue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] key
    #   @return [::String]
    # @!attribute [rw] value
    #   @return [::String]
    class TagsEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::OracleDatabase::V1::PluggableDatabaseProperties::DefinedTagValue]
  class DefinedTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class FreeformTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The various lifecycle states of the PluggableDatabase.
  module PluggableDatabaseLifecycleState
    # The lifecycle state is unspecified.
    PLUGGABLE_DATABASE_LIFECYCLE_STATE_UNSPECIFIED = 0

    # The pluggable database is provisioning.
    PROVISIONING = 1

    # The pluggable database is available.
    AVAILABLE = 2

    # The pluggable database is terminating.
    TERMINATING = 3

    # The pluggable database is terminated.
    TERMINATED = 4

    # The pluggable database is updating.
    UPDATING = 5

    # The pluggable database is in a failed state.
    FAILED = 6

    # The pluggable database is relocating.
    RELOCATING = 7

    # The pluggable database is relocated.
    RELOCATED = 8

    # The pluggable database is refreshing.
    REFRESHING = 9

    # The pluggable database is restoring.
    RESTORE_IN_PROGRESS = 10

    # The pluggable database restore failed.
    RESTORE_FAILED = 11

    # The pluggable database is backing up.
    BACKUP_IN_PROGRESS = 12

    # The pluggable database is disabled.
    DISABLED = 13
  end

  # The status of Operations Insights for this Database.
  module OperationsInsightsState
    # The status is not specified.
    OPERATIONS_INSIGHTS_STATE_UNSPECIFIED = 0

    # Operations Insights is enabling.
    ENABLING = 1

    # Operations Insights is enabled.
    ENABLED = 2

    # Operations Insights is disabling.
    DISABLING = 3

    # Operations Insights is not enabled.
    NOT_ENABLED = 4

    # Operations Insights failed to enable.
    FAILED_ENABLING = 5

    # Operations Insights failed to disable.
    FAILED_DISABLING = 6
  end
end

#pdb_name::String

Returns Required. The database name.

Returns:

  • (::String)

    Required. The database name.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb', line 90

class PluggableDatabaseProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Wrapper message for the value of a defined tag.
  # @!attribute [rw] tags
  #   @return [::Google::Protobuf::Map{::String => ::String}]
  #     The tags within the namespace.
  class DefinedTagValue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] key
    #   @return [::String]
    # @!attribute [rw] value
    #   @return [::String]
    class TagsEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::OracleDatabase::V1::PluggableDatabaseProperties::DefinedTagValue]
  class DefinedTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class FreeformTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The various lifecycle states of the PluggableDatabase.
  module PluggableDatabaseLifecycleState
    # The lifecycle state is unspecified.
    PLUGGABLE_DATABASE_LIFECYCLE_STATE_UNSPECIFIED = 0

    # The pluggable database is provisioning.
    PROVISIONING = 1

    # The pluggable database is available.
    AVAILABLE = 2

    # The pluggable database is terminating.
    TERMINATING = 3

    # The pluggable database is terminated.
    TERMINATED = 4

    # The pluggable database is updating.
    UPDATING = 5

    # The pluggable database is in a failed state.
    FAILED = 6

    # The pluggable database is relocating.
    RELOCATING = 7

    # The pluggable database is relocated.
    RELOCATED = 8

    # The pluggable database is refreshing.
    REFRESHING = 9

    # The pluggable database is restoring.
    RESTORE_IN_PROGRESS = 10

    # The pluggable database restore failed.
    RESTORE_FAILED = 11

    # The pluggable database is backing up.
    BACKUP_IN_PROGRESS = 12

    # The pluggable database is disabled.
    DISABLED = 13
  end

  # The status of Operations Insights for this Database.
  module OperationsInsightsState
    # The status is not specified.
    OPERATIONS_INSIGHTS_STATE_UNSPECIFIED = 0

    # Operations Insights is enabling.
    ENABLING = 1

    # Operations Insights is enabled.
    ENABLED = 2

    # Operations Insights is disabling.
    DISABLING = 3

    # Operations Insights is not enabled.
    NOT_ENABLED = 4

    # Operations Insights failed to enable.
    FAILED_ENABLING = 5

    # Operations Insights failed to disable.
    FAILED_DISABLING = 6
  end
end

#pdb_node_level_details::Array<::Google::Cloud::OracleDatabase::V1::PluggableDatabaseNodeLevelDetails>

Returns Optional. Pluggable Database Node Level Details.

Returns:



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb', line 90

class PluggableDatabaseProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Wrapper message for the value of a defined tag.
  # @!attribute [rw] tags
  #   @return [::Google::Protobuf::Map{::String => ::String}]
  #     The tags within the namespace.
  class DefinedTagValue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] key
    #   @return [::String]
    # @!attribute [rw] value
    #   @return [::String]
    class TagsEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::OracleDatabase::V1::PluggableDatabaseProperties::DefinedTagValue]
  class DefinedTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class FreeformTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The various lifecycle states of the PluggableDatabase.
  module PluggableDatabaseLifecycleState
    # The lifecycle state is unspecified.
    PLUGGABLE_DATABASE_LIFECYCLE_STATE_UNSPECIFIED = 0

    # The pluggable database is provisioning.
    PROVISIONING = 1

    # The pluggable database is available.
    AVAILABLE = 2

    # The pluggable database is terminating.
    TERMINATING = 3

    # The pluggable database is terminated.
    TERMINATED = 4

    # The pluggable database is updating.
    UPDATING = 5

    # The pluggable database is in a failed state.
    FAILED = 6

    # The pluggable database is relocating.
    RELOCATING = 7

    # The pluggable database is relocated.
    RELOCATED = 8

    # The pluggable database is refreshing.
    REFRESHING = 9

    # The pluggable database is restoring.
    RESTORE_IN_PROGRESS = 10

    # The pluggable database restore failed.
    RESTORE_FAILED = 11

    # The pluggable database is backing up.
    BACKUP_IN_PROGRESS = 12

    # The pluggable database is disabled.
    DISABLED = 13
  end

  # The status of Operations Insights for this Database.
  module OperationsInsightsState
    # The status is not specified.
    OPERATIONS_INSIGHTS_STATE_UNSPECIFIED = 0

    # Operations Insights is enabling.
    ENABLING = 1

    # Operations Insights is enabled.
    ENABLED = 2

    # Operations Insights is disabling.
    DISABLING = 3

    # Operations Insights is not enabled.
    NOT_ENABLED = 4

    # Operations Insights failed to enable.
    FAILED_ENABLING = 5

    # Operations Insights failed to disable.
    FAILED_DISABLING = 6
  end
end