Class: Google::Cloud::OracleDatabase::V1::RestIcebergCatalog

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb

Overview

The REST Iceberg catalog.

Instance Attribute Summary collapse

Instance Attribute Details

#properties::String

Returns Optional. The base64 encoded content of the configuration file containing additional properties for the REST catalog.

Returns:

  • (::String)

    Optional. The base64 encoded content of the configuration file containing additional properties for the REST catalog.



1918
1919
1920
1921
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1918

class RestIcebergCatalog
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#uri::String

Returns Required. The REST uri.

Returns:

  • (::String)

    Required. The REST uri.



1918
1919
1920
1921
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1918

class RestIcebergCatalog
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end