Class: Google::Cloud::OracleDatabase::V1::SourceConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb

Overview

The source configuration for the standby Autonomous Database.

Instance Attribute Summary collapse

Instance Attribute Details

#automatic_backups_replication_enabled::Boolean

Returns Optional. This field specifies if the replication of automatic backups is enabled when creating a Data Guard.

Returns:

  • (::Boolean)

    Optional. This field specifies if the replication of automatic backups is enabled when creating a Data Guard.



121
122
123
124
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 121

class SourceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#autonomous_database::String

Returns Optional. The name of the primary Autonomous Database that is used to create a Peer Autonomous Database from a source.

Returns:

  • (::String)

    Optional. The name of the primary Autonomous Database that is used to create a Peer Autonomous Database from a source.



121
122
123
124
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 121

class SourceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end