Class: Google::Cloud::OracleDatabase::V1::StartAutonomousDatabaseRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb

Overview

The request for AutonomousDatabase.Start.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The name of the Autonomous Database in the following format: projects/{project}/locations/{location}/autonomousDatabases/{autonomous_database}.

Returns:

  • (::String)

    Required. The name of the Autonomous Database in the following format: projects/{project}/locations/{location}/autonomousDatabases/{autonomous_database}.



526
527
528
529
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 526

class StartAutonomousDatabaseRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end