Class: Google::Cloud::OracleDatabase::V1::StartGoldengateDeploymentRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb

Overview

The request for GoldengateDeployment.Start.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The name of the Goldengate Deployment in the following format: projects/{project}/locations/{location}/goldengateDeployments/{goldengate_deployment}.

Returns:

  • (::String)

    Required. The name of the Goldengate Deployment in the following format: projects/{project}/locations/{location}/goldengateDeployments/{goldengate_deployment}.



705
706
707
708
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 705

class StartGoldengateDeploymentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end