Class: Google::Cloud::OracleDatabase::V1::StopGoldengateDeploymentRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb

Overview

The request for GoldengateDeployment.Stop.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The name of the Goldengate Deployment in the following format: projects/{project}/locations/{location}/goldengateDeployments/{goldengate_deployment}.

Returns:

  • (::String)

    Required. The name of the Goldengate Deployment in the following format: projects/{project}/locations/{location}/goldengateDeployments/{goldengate_deployment}.



695
696
697
698
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 695

class StopGoldengateDeploymentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end