Class: Google::Cloud::OracleDatabase::V1::TestConnectionAssignmentError

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/goldengate_connection_assignment.rb

Overview

Error details for TestGoldengateConnectionAssignment.

Instance Attribute Summary collapse

Instance Attribute Details

#action::String

Returns The text describing the action required to fix the issue.

Returns:

  • (::String)

    The text describing the action required to fix the issue.



236
237
238
239
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection_assignment.rb', line 236

class TestConnectionAssignmentError
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#code::String

Returns A short error code that defines the error, meant for programmatic parsing.

Returns:

  • (::String)

    A short error code that defines the error, meant for programmatic parsing.



236
237
238
239
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection_assignment.rb', line 236

class TestConnectionAssignmentError
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#issue::String

Returns The text describing the root cause of the reported issue.

Returns:

  • (::String)

    The text describing the root cause of the reported issue.



236
237
238
239
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection_assignment.rb', line 236

class TestConnectionAssignmentError
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#message::String

Returns A human-readable error message.

Returns:

  • (::String)

    A human-readable error message.



236
237
238
239
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection_assignment.rb', line 236

class TestConnectionAssignmentError
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end