Class: Google::Cloud::OracleDatabase::V1::TestGoldengateConnectionAssignmentRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/goldengate_connection_assignment.rb

Overview

Request message for TestGoldengateConnectionAssignment.

Defined Under Namespace

Modules: TestType

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. Name of the connection assignment for which to test connection. projects/{project}/locations/{region}/goldengateConnectionAssignments/{goldengate_connection_assignment}.

Returns:

  • (::String)

    Required. Name of the connection assignment for which to test connection. projects/{project}/locations/{region}/goldengateConnectionAssignments/{goldengate_connection_assignment}



209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection_assignment.rb', line 209

class TestGoldengateConnectionAssignmentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of test to perform.
  module TestType
    # The default value. This value is unused.
    TEST_TYPE_UNSPECIFIED = 0

    # The default connection test.
    DEFAULT = 1
  end
end

#type::Google::Cloud::OracleDatabase::V1::TestGoldengateConnectionAssignmentRequest::TestType

Returns Optional. The type of the test of the assigned connection. The only type actually supported is DEFAULT.

Returns:



209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection_assignment.rb', line 209

class TestGoldengateConnectionAssignmentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of test to perform.
  module TestType
    # The default value. This value is unused.
    TEST_TYPE_UNSPECIFIED = 0

    # The default connection test.
    DEFAULT = 1
  end
end