Class: Google::Cloud::OracleDatabase::V1::UpdateExadbVmClusterRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb

Overview

The request for ExadbVmCluster.Update. We only support adding the Virtual Machine to the ExadbVmCluster. Rest of the fields in ExadbVmCluster are immutable.

Instance Attribute Summary collapse

Instance Attribute Details

#exadb_vm_cluster::Google::Cloud::OracleDatabase::V1::ExadbVmCluster

Returns Required. The resource being updated.

Returns:



885
886
887
888
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 885

class UpdateExadbVmClusterRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns Optional. An optional ID to identify the request. This value is used to identify duplicate requests. If you make a request with the same request ID and the original request is still in progress or completed, the server ignores the second request. This prevents clients from accidentally creating duplicate commitments.

The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).

Returns:

  • (::String)

    Optional. An optional ID to identify the request. This value is used to identify duplicate requests. If you make a request with the same request ID and the original request is still in progress or completed, the server ignores the second request. This prevents clients from accidentally creating duplicate commitments.

    The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).



885
886
887
888
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 885

class UpdateExadbVmClusterRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Optional. A mask specifying which fields in th VM Cluster should be updated. A field specified in the mask is overwritten. If a mask isn't provided then all the fields in the VM Cluster are overwritten.

Returns:

  • (::Google::Protobuf::FieldMask)

    Optional. A mask specifying which fields in th VM Cluster should be updated. A field specified in the mask is overwritten. If a mask isn't provided then all the fields in the VM Cluster are overwritten.



885
886
887
888
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 885

class UpdateExadbVmClusterRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end