Class: Google::Cloud::OracleDatabase::V1::CloudVmClusterProperties
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::CloudVmClusterProperties
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb
Overview
Various properties and settings associated with Exadata VM cluster.
Defined Under Namespace
Modules: DiskRedundancy, LicenseType, State
Instance Attribute Summary collapse
-
#cluster_name ⇒ ::String
Optional.
-
#compartment_id ⇒ ::String
readonly
Output only.
-
#compute_model ⇒ ::Google::Cloud::OracleDatabase::V1::ComputeModel
readonly
Output only.
-
#cpu_core_count ⇒ ::Integer
Required.
-
#data_storage_size_tb ⇒ ::Float
Optional.
-
#db_node_storage_size_gb ⇒ ::Integer
Optional.
-
#db_server_ocids ⇒ ::Array<::String>
Optional.
-
#diagnostics_data_collection_options ⇒ ::Google::Cloud::OracleDatabase::V1::DataCollectionOptions
Optional.
-
#disk_redundancy ⇒ ::Google::Cloud::OracleDatabase::V1::CloudVmClusterProperties::DiskRedundancy
Optional.
-
#dns_listener_ip ⇒ ::String
readonly
Output only.
-
#domain ⇒ ::String
readonly
Output only.
-
#gi_version ⇒ ::String
Optional.
-
#hostname ⇒ ::String
readonly
Output only.
-
#hostname_prefix ⇒ ::String
Optional.
-
#license_type ⇒ ::Google::Cloud::OracleDatabase::V1::CloudVmClusterProperties::LicenseType
Required.
-
#local_backup_enabled ⇒ ::Boolean
Optional.
-
#memory_size_gb ⇒ ::Integer
Optional.
-
#node_count ⇒ ::Integer
Optional.
-
#oci_url ⇒ ::String
readonly
Output only.
-
#ocid ⇒ ::String
readonly
Output only.
-
#ocpu_count ⇒ ::Float
Optional.
-
#scan_dns ⇒ ::String
readonly
Output only.
-
#scan_dns_record_id ⇒ ::String
readonly
Output only.
-
#scan_ip_ids ⇒ ::Array<::String>
readonly
Output only.
-
#scan_listener_port_tcp ⇒ ::Integer
Optional.
-
#scan_listener_port_tcp_ssl ⇒ ::Integer
Optional.
-
#shape ⇒ ::String
readonly
Output only.
-
#sparse_diskgroup_enabled ⇒ ::Boolean
Optional.
-
#ssh_public_keys ⇒ ::Array<::String>
Optional.
-
#state ⇒ ::Google::Cloud::OracleDatabase::V1::CloudVmClusterProperties::State
readonly
Output only.
-
#storage_size_gb ⇒ ::Integer
readonly
Output only.
-
#system_version ⇒ ::String
Optional.
-
#time_zone ⇒ ::Google::Type::TimeZone
Optional.
Instance Attribute Details
#cluster_name ⇒ ::String
Returns Optional. OCI Cluster name.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#compartment_id ⇒ ::String (readonly)
Returns Output only. Compartment ID of cluster.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#compute_model ⇒ ::Google::Cloud::OracleDatabase::V1::ComputeModel (readonly)
Returns Output only. The compute model of the VM Cluster.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#cpu_core_count ⇒ ::Integer
Returns Required. Number of enabled CPU cores.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#data_storage_size_tb ⇒ ::Float
Returns Optional. The data disk group size to be allocated in TBs.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#db_node_storage_size_gb ⇒ ::Integer
Returns Optional. Local storage per VM.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#db_server_ocids ⇒ ::Array<::String>
Returns Optional. OCID of database servers.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#diagnostics_data_collection_options ⇒ ::Google::Cloud::OracleDatabase::V1::DataCollectionOptions
Returns Optional. Data collection options for diagnostics.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#disk_redundancy ⇒ ::Google::Cloud::OracleDatabase::V1::CloudVmClusterProperties::DiskRedundancy
Returns Optional. The type of redundancy.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#dns_listener_ip ⇒ ::String (readonly)
Returns Output only. DNS listener IP.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#domain ⇒ ::String (readonly)
Returns Output only. Parent DNS domain where SCAN DNS and hosts names are qualified. ex: ocispdelegated.ocisp10jvnet.oraclevcn.com.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#gi_version ⇒ ::String
Returns Optional. Grid Infrastructure Version.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#hostname ⇒ ::String (readonly)
Returns Output only. host name without domain.
format: "
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#hostname_prefix ⇒ ::String
Returns Optional. Prefix for VM cluster host names.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#license_type ⇒ ::Google::Cloud::OracleDatabase::V1::CloudVmClusterProperties::LicenseType
Returns Required. License type of VM Cluster.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#local_backup_enabled ⇒ ::Boolean
Returns Optional. Use local backup.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#memory_size_gb ⇒ ::Integer
Returns Optional. Memory allocated in GBs.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#node_count ⇒ ::Integer
Returns Optional. Number of database servers.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#oci_url ⇒ ::String (readonly)
Returns Output only. Deep link to the OCI console to view this resource.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#ocid ⇒ ::String (readonly)
Returns Output only. Oracle Cloud Infrastructure ID of VM Cluster.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#ocpu_count ⇒ ::Float
Returns Optional. OCPU count per VM. Minimum is 0.1.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#scan_dns ⇒ ::String (readonly)
Returns Output only. SCAN DNS name. ex: sp2-yi0xq-scan.ocispdelegated.ocisp10jvnet.oraclevcn.com.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#scan_dns_record_id ⇒ ::String (readonly)
Returns Output only. OCID of scan DNS record.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#scan_ip_ids ⇒ ::Array<::String> (readonly)
Returns Output only. OCIDs of scan IPs.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#scan_listener_port_tcp ⇒ ::Integer
Returns Optional. SCAN listener port - TCP.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#scan_listener_port_tcp_ssl ⇒ ::Integer
Returns Optional. SCAN listener port - TLS.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#shape ⇒ ::String (readonly)
Returns Output only. Shape of VM Cluster.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#sparse_diskgroup_enabled ⇒ ::Boolean
Returns Optional. Use exadata sparse snapshots.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#ssh_public_keys ⇒ ::Array<::String>
Returns Optional. SSH public keys to be stored with cluster.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#state ⇒ ::Google::Cloud::OracleDatabase::V1::CloudVmClusterProperties::State (readonly)
Returns Output only. State of the cluster.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#storage_size_gb ⇒ ::Integer (readonly)
Returns Output only. The storage allocation for the disk group, in gigabytes (GB).
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#system_version ⇒ ::String
Returns Optional. Operating system version of the image.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |
#time_zone ⇒ ::Google::Type::TimeZone
Returns Optional. Time zone of VM Cluster to set. Defaults to UTC if not specified.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'proto_docs/google/cloud/oracledatabase/v1/vm_cluster.rb', line 201 class CloudVmClusterProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different licenses supported. module LicenseType # Unspecified LICENSE_TYPE_UNSPECIFIED = 0 # License included part of offer LICENSE_INCLUDED = 1 # Bring your own license BRING_YOUR_OWN_LICENSE = 2 end # Types of disk redundancy provided by Oracle. module DiskRedundancy # Unspecified. DISK_REDUNDANCY_UNSPECIFIED = 0 # High - 3 way mirror. HIGH = 1 # Normal - 2 way mirror. NORMAL = 2 end # The various lifecycle states of the VM cluster. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in updating state. UPDATING = 3 # Indicates that the resource is in terminating state. TERMINATING = 4 # Indicates that the resource is in terminated state. TERMINATED = 5 # Indicates that the resource is in failed state. FAILED = 6 # Indicates that the resource is in maintenance in progress state. MAINTENANCE_IN_PROGRESS = 7 end end |