Module: Google::Cloud::OracleDatabase::V1::ComputeModel
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/common.rb
Overview
The compute model of the Exadata Infrastructure, VM Cluster and Autonomous Database.
Constant Summary collapse
- COMPUTE_MODEL_UNSPECIFIED =
Unspecified compute model.
0- COMPUTE_MODEL_ECPU =
Abstract measure of compute resources. ECPUs are based on the number of cores elastically allocated from a pool of compute and storage servers.
1- COMPUTE_MODEL_OCPU =
Physical measure of compute resources. OCPUs are based on the physical core of a processor.
2