Class: Google::Cloud::OracleDatabase::V1::CreateOdbNetworkRequest
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::CreateOdbNetworkRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/odb_network.rb
Overview
The request for OdbNetwork.Create.
Instance Attribute Summary collapse
-
#odb_network ⇒ ::Google::Cloud::OracleDatabase::V1::OdbNetwork
Required.
-
#odb_network_id ⇒ ::String
Required.
-
#parent ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
Instance Attribute Details
#odb_network ⇒ ::Google::Cloud::OracleDatabase::V1::OdbNetwork
Returns Required. Details of the OdbNetwork instance to create.
107 108 109 110 |
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_network.rb', line 107 class CreateOdbNetworkRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#odb_network_id ⇒ ::String
Returns Required. The ID of the OdbNetwork to create. This value is restricted to (^a-z?$) and must be a maximum of 63 characters in length. The value must start with a letter and end with a letter or a number.
107 108 109 110 |
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_network.rb', line 107 class CreateOdbNetworkRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent value for the OdbNetwork in the following format: projects/{project}/locations/{location}.
107 108 109 110 |
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_network.rb', line 107 class CreateOdbNetworkRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. An optional ID to identify the request. This value is used to identify duplicate requests. If you make a request with the same request ID and the original request is still in progress or completed, the server ignores the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
107 108 109 110 |
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_network.rb', line 107 class CreateOdbNetworkRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |