Class: Google::Cloud::OracleDatabase::V1::CreateOdbSubnetRequest
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::CreateOdbSubnetRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/odb_subnet.rb
Overview
The request for OdbSubnet.Create.
Instance Attribute Summary collapse
-
#odb_subnet ⇒ ::Google::Cloud::OracleDatabase::V1::OdbSubnet
Required.
-
#odb_subnet_id ⇒ ::String
Required.
-
#parent ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
Instance Attribute Details
#odb_subnet ⇒ ::Google::Cloud::OracleDatabase::V1::OdbSubnet
Returns Required. Details of the OdbSubnet instance to create.
112 113 114 115 |
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_subnet.rb', line 112 class CreateOdbSubnetRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#odb_subnet_id ⇒ ::String
Returns Required. The ID of the OdbSubnet to create. This value is restricted to (^a-z?$) and must be a maximum of 63 characters in length. The value must start with a letter and end with a letter or a number.
112 113 114 115 |
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_subnet.rb', line 112 class CreateOdbSubnetRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent value for the OdbSubnet in the following format: projects/{project}/locations/{location}/odbNetworks/{odb_network}.
112 113 114 115 |
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_subnet.rb', line 112 class CreateOdbSubnetRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. An optional ID to identify the request. This value is used to identify duplicate requests. If you make a request with the same request ID and the original request is still in progress or completed, the server ignores the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
112 113 114 115 |
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_subnet.rb', line 112 class CreateOdbSubnetRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |