Class: Google::Cloud::OracleDatabase::V1::Database
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::Database
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/database.rb
Overview
Details of the Database resource. https://docs.oracle.com/en-us/iaas/api/#/en/database/20160918/Database/
Defined Under Namespace
Modules: OperationsInsightsStatus
Instance Attribute Summary collapse
-
#admin_password ⇒ ::String
Optional.
-
#admin_password_secret_version ⇒ ::String
Optional.
-
#character_set ⇒ ::String
Optional.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#database_id ⇒ ::String
Optional.
-
#db_home_name ⇒ ::String
Optional.
-
#db_name ⇒ ::String
Optional.
-
#db_unique_name ⇒ ::String
Optional.
-
#gcp_oracle_zone ⇒ ::String
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#ncharacter_set ⇒ ::String
Optional.
-
#oci_url ⇒ ::String
readonly
Output only.
-
#ops_insights_status ⇒ ::Google::Cloud::OracleDatabase::V1::Database::OperationsInsightsStatus
readonly
Output only.
-
#pluggable_database_id ⇒ ::String
Optional.
-
#pluggable_database_name ⇒ ::String
Optional.
-
#properties ⇒ ::Google::Cloud::OracleDatabase::V1::DatabaseProperties
Optional.
-
#tde_wallet_password ⇒ ::String
Optional.
-
#tde_wallet_password_secret_version ⇒ ::String
Optional.
Instance Attribute Details
#admin_password ⇒ ::String
Returns Optional. The password for the default ADMIN user.
Note: Only one of admin_password_secret_version or admin_password can
be populated.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 99 class Database include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The Status of Operations Insights for this Database. module OperationsInsightsStatus # Default unspecified value. OPERATIONS_INSIGHTS_STATUS_UNSPECIFIED = 0 # Indicates that the operations insights are being enabled. ENABLING = 1 # Indicates that the operations insights are enabled. ENABLED = 2 # Indicates that the operations insights are being disabled. DISABLING = 3 # Indicates that the operations insights are not enabled. NOT_ENABLED = 4 # Indicates that the operations insights failed to enable. FAILED_ENABLING = 5 # Indicates that the operations insights failed to disable. FAILED_DISABLING = 6 end end |
#admin_password_secret_version ⇒ ::String
Returns Optional. The resource name of a secret version in Secret Manager which
contains the database admin user's password. Format:
projects/{project}/secrets/{secret}/versions/{version}. Note: Only one of
admin_password_secret_version or admin_password can be populated.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 99 class Database include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The Status of Operations Insights for this Database. module OperationsInsightsStatus # Default unspecified value. OPERATIONS_INSIGHTS_STATUS_UNSPECIFIED = 0 # Indicates that the operations insights are being enabled. ENABLING = 1 # Indicates that the operations insights are enabled. ENABLED = 2 # Indicates that the operations insights are being disabled. DISABLING = 3 # Indicates that the operations insights are not enabled. NOT_ENABLED = 4 # Indicates that the operations insights failed to enable. FAILED_ENABLING = 5 # Indicates that the operations insights failed to disable. FAILED_DISABLING = 6 end end |
#character_set ⇒ ::String
Returns Optional. The character set for the database. The default is AL32UTF8.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 99 class Database include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The Status of Operations Insights for this Database. module OperationsInsightsStatus # Default unspecified value. OPERATIONS_INSIGHTS_STATUS_UNSPECIFIED = 0 # Indicates that the operations insights are being enabled. ENABLING = 1 # Indicates that the operations insights are enabled. ENABLED = 2 # Indicates that the operations insights are being disabled. DISABLING = 3 # Indicates that the operations insights are not enabled. NOT_ENABLED = 4 # Indicates that the operations insights failed to enable. FAILED_ENABLING = 5 # Indicates that the operations insights failed to disable. FAILED_DISABLING = 6 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The date and time that the Database was created.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 99 class Database include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The Status of Operations Insights for this Database. module OperationsInsightsStatus # Default unspecified value. OPERATIONS_INSIGHTS_STATUS_UNSPECIFIED = 0 # Indicates that the operations insights are being enabled. ENABLING = 1 # Indicates that the operations insights are enabled. ENABLED = 2 # Indicates that the operations insights are being disabled. DISABLING = 3 # Indicates that the operations insights are not enabled. NOT_ENABLED = 4 # Indicates that the operations insights failed to enable. FAILED_ENABLING = 5 # Indicates that the operations insights failed to disable. FAILED_DISABLING = 6 end end |
#database_id ⇒ ::String
Returns Optional. The database ID of the Database.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 99 class Database include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The Status of Operations Insights for this Database. module OperationsInsightsStatus # Default unspecified value. OPERATIONS_INSIGHTS_STATUS_UNSPECIFIED = 0 # Indicates that the operations insights are being enabled. ENABLING = 1 # Indicates that the operations insights are enabled. ENABLED = 2 # Indicates that the operations insights are being disabled. DISABLING = 3 # Indicates that the operations insights are not enabled. NOT_ENABLED = 4 # Indicates that the operations insights failed to enable. FAILED_ENABLING = 5 # Indicates that the operations insights failed to disable. FAILED_DISABLING = 6 end end |
#db_home_name ⇒ ::String
Returns Optional. The name of the DbHome resource associated with the Database.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 99 class Database include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The Status of Operations Insights for this Database. module OperationsInsightsStatus # Default unspecified value. OPERATIONS_INSIGHTS_STATUS_UNSPECIFIED = 0 # Indicates that the operations insights are being enabled. ENABLING = 1 # Indicates that the operations insights are enabled. ENABLED = 2 # Indicates that the operations insights are being disabled. DISABLING = 3 # Indicates that the operations insights are not enabled. NOT_ENABLED = 4 # Indicates that the operations insights failed to enable. FAILED_ENABLING = 5 # Indicates that the operations insights failed to disable. FAILED_DISABLING = 6 end end |
#db_name ⇒ ::String
Returns Optional. The database name. The name must begin with an alphabetic character and can contain a maximum of eight alphanumeric characters. Special characters are not permitted.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 99 class Database include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The Status of Operations Insights for this Database. module OperationsInsightsStatus # Default unspecified value. OPERATIONS_INSIGHTS_STATUS_UNSPECIFIED = 0 # Indicates that the operations insights are being enabled. ENABLING = 1 # Indicates that the operations insights are enabled. ENABLED = 2 # Indicates that the operations insights are being disabled. DISABLING = 3 # Indicates that the operations insights are not enabled. NOT_ENABLED = 4 # Indicates that the operations insights failed to enable. FAILED_ENABLING = 5 # Indicates that the operations insights failed to disable. FAILED_DISABLING = 6 end end |
#db_unique_name ⇒ ::String
Returns Optional. The DB_UNIQUE_NAME of the Oracle Database being backed up.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 99 class Database include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The Status of Operations Insights for this Database. module OperationsInsightsStatus # Default unspecified value. OPERATIONS_INSIGHTS_STATUS_UNSPECIFIED = 0 # Indicates that the operations insights are being enabled. ENABLING = 1 # Indicates that the operations insights are enabled. ENABLED = 2 # Indicates that the operations insights are being disabled. DISABLING = 3 # Indicates that the operations insights are not enabled. NOT_ENABLED = 4 # Indicates that the operations insights failed to enable. FAILED_ENABLING = 5 # Indicates that the operations insights failed to disable. FAILED_DISABLING = 6 end end |
#gcp_oracle_zone ⇒ ::String (readonly)
Returns Output only. The GCP Oracle zone where the Database is created.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 99 class Database include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The Status of Operations Insights for this Database. module OperationsInsightsStatus # Default unspecified value. OPERATIONS_INSIGHTS_STATUS_UNSPECIFIED = 0 # Indicates that the operations insights are being enabled. ENABLING = 1 # Indicates that the operations insights are enabled. ENABLED = 2 # Indicates that the operations insights are being disabled. DISABLING = 3 # Indicates that the operations insights are not enabled. NOT_ENABLED = 4 # Indicates that the operations insights failed to enable. FAILED_ENABLING = 5 # Indicates that the operations insights failed to disable. FAILED_DISABLING = 6 end end |
#name ⇒ ::String
Returns Identifier. The name of the Database resource in the following format: projects/{project}/locations/{region}/databases/{database}.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 99 class Database include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The Status of Operations Insights for this Database. module OperationsInsightsStatus # Default unspecified value. OPERATIONS_INSIGHTS_STATUS_UNSPECIFIED = 0 # Indicates that the operations insights are being enabled. ENABLING = 1 # Indicates that the operations insights are enabled. ENABLED = 2 # Indicates that the operations insights are being disabled. DISABLING = 3 # Indicates that the operations insights are not enabled. NOT_ENABLED = 4 # Indicates that the operations insights failed to enable. FAILED_ENABLING = 5 # Indicates that the operations insights failed to disable. FAILED_DISABLING = 6 end end |
#ncharacter_set ⇒ ::String
Returns Optional. The national character set for the database. The default is AL16UTF16.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 99 class Database include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The Status of Operations Insights for this Database. module OperationsInsightsStatus # Default unspecified value. OPERATIONS_INSIGHTS_STATUS_UNSPECIFIED = 0 # Indicates that the operations insights are being enabled. ENABLING = 1 # Indicates that the operations insights are enabled. ENABLED = 2 # Indicates that the operations insights are being disabled. DISABLING = 3 # Indicates that the operations insights are not enabled. NOT_ENABLED = 4 # Indicates that the operations insights failed to enable. FAILED_ENABLING = 5 # Indicates that the operations insights failed to disable. FAILED_DISABLING = 6 end end |
#oci_url ⇒ ::String (readonly)
Returns Output only. HTTPS link to OCI resources exposed to Customer via UI Interface.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 99 class Database include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The Status of Operations Insights for this Database. module OperationsInsightsStatus # Default unspecified value. OPERATIONS_INSIGHTS_STATUS_UNSPECIFIED = 0 # Indicates that the operations insights are being enabled. ENABLING = 1 # Indicates that the operations insights are enabled. ENABLED = 2 # Indicates that the operations insights are being disabled. DISABLING = 3 # Indicates that the operations insights are not enabled. NOT_ENABLED = 4 # Indicates that the operations insights failed to enable. FAILED_ENABLING = 5 # Indicates that the operations insights failed to disable. FAILED_DISABLING = 6 end end |
#ops_insights_status ⇒ ::Google::Cloud::OracleDatabase::V1::Database::OperationsInsightsStatus (readonly)
Returns Output only. The Status of Operations Insights for this Database.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 99 class Database include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The Status of Operations Insights for this Database. module OperationsInsightsStatus # Default unspecified value. OPERATIONS_INSIGHTS_STATUS_UNSPECIFIED = 0 # Indicates that the operations insights are being enabled. ENABLING = 1 # Indicates that the operations insights are enabled. ENABLED = 2 # Indicates that the operations insights are being disabled. DISABLING = 3 # Indicates that the operations insights are not enabled. NOT_ENABLED = 4 # Indicates that the operations insights failed to enable. FAILED_ENABLING = 5 # Indicates that the operations insights failed to disable. FAILED_DISABLING = 6 end end |
#pluggable_database_id ⇒ ::String
Returns Optional. The ID of the pluggable database associated with the Database. The ID must be unique within the project and location.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 99 class Database include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The Status of Operations Insights for this Database. module OperationsInsightsStatus # Default unspecified value. OPERATIONS_INSIGHTS_STATUS_UNSPECIFIED = 0 # Indicates that the operations insights are being enabled. ENABLING = 1 # Indicates that the operations insights are enabled. ENABLED = 2 # Indicates that the operations insights are being disabled. DISABLING = 3 # Indicates that the operations insights are not enabled. NOT_ENABLED = 4 # Indicates that the operations insights failed to enable. FAILED_ENABLING = 5 # Indicates that the operations insights failed to disable. FAILED_DISABLING = 6 end end |
#pluggable_database_name ⇒ ::String
Returns Optional. The pluggable database associated with the Database. The name must begin with an alphabetic character and can contain a maximum of thirty alphanumeric characters.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 99 class Database include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The Status of Operations Insights for this Database. module OperationsInsightsStatus # Default unspecified value. OPERATIONS_INSIGHTS_STATUS_UNSPECIFIED = 0 # Indicates that the operations insights are being enabled. ENABLING = 1 # Indicates that the operations insights are enabled. ENABLED = 2 # Indicates that the operations insights are being disabled. DISABLING = 3 # Indicates that the operations insights are not enabled. NOT_ENABLED = 4 # Indicates that the operations insights failed to enable. FAILED_ENABLING = 5 # Indicates that the operations insights failed to disable. FAILED_DISABLING = 6 end end |
#properties ⇒ ::Google::Cloud::OracleDatabase::V1::DatabaseProperties
Returns Optional. The properties of the Database.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 99 class Database include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The Status of Operations Insights for this Database. module OperationsInsightsStatus # Default unspecified value. OPERATIONS_INSIGHTS_STATUS_UNSPECIFIED = 0 # Indicates that the operations insights are being enabled. ENABLING = 1 # Indicates that the operations insights are enabled. ENABLED = 2 # Indicates that the operations insights are being disabled. DISABLING = 3 # Indicates that the operations insights are not enabled. NOT_ENABLED = 4 # Indicates that the operations insights failed to enable. FAILED_ENABLING = 5 # Indicates that the operations insights failed to disable. FAILED_DISABLING = 6 end end |
#tde_wallet_password ⇒ ::String
Returns Optional. The TDE wallet password for the database.
Note: Only one of tde_wallet_password_secret_version or
tde_wallet_password can be populated.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 99 class Database include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The Status of Operations Insights for this Database. module OperationsInsightsStatus # Default unspecified value. OPERATIONS_INSIGHTS_STATUS_UNSPECIFIED = 0 # Indicates that the operations insights are being enabled. ENABLING = 1 # Indicates that the operations insights are enabled. ENABLED = 2 # Indicates that the operations insights are being disabled. DISABLING = 3 # Indicates that the operations insights are not enabled. NOT_ENABLED = 4 # Indicates that the operations insights failed to enable. FAILED_ENABLING = 5 # Indicates that the operations insights failed to disable. FAILED_DISABLING = 6 end end |
#tde_wallet_password_secret_version ⇒ ::String
Returns Optional. The resource name of a secret version in Secret Manager which
contains the TDE wallet password for the database. Format:
projects/{project}/secrets/{secret}/versions/{version}. Note: Only one of
tde_wallet_password_secret_version or tde_wallet_password can be
populated.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 99 class Database include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The Status of Operations Insights for this Database. module OperationsInsightsStatus # Default unspecified value. OPERATIONS_INSIGHTS_STATUS_UNSPECIFIED = 0 # Indicates that the operations insights are being enabled. ENABLING = 1 # Indicates that the operations insights are enabled. ENABLED = 2 # Indicates that the operations insights are being disabled. DISABLING = 3 # Indicates that the operations insights are not enabled. NOT_ENABLED = 4 # Indicates that the operations insights failed to enable. FAILED_ENABLING = 5 # Indicates that the operations insights failed to disable. FAILED_DISABLING = 6 end end |