Class: Google::Cloud::OracleDatabase::V1::DatabaseConnectionStringProfile
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::DatabaseConnectionStringProfile
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb
Overview
The connection string profile to allow clients to group. https://docs.oracle.com/en-us/iaas/api/#/en/database/20160918/datatypes/DatabaseConnectionStringProfile
Defined Under Namespace
Modules: ConsumerGroup, HostFormat, Protocol, SessionMode, SyntaxFormat, TLSAuthentication
Instance Attribute Summary collapse
-
#consumer_group ⇒ ::Google::Cloud::OracleDatabase::V1::DatabaseConnectionStringProfile::ConsumerGroup
readonly
Output only.
-
#display_name ⇒ ::String
readonly
Output only.
-
#host_format ⇒ ::Google::Cloud::OracleDatabase::V1::DatabaseConnectionStringProfile::HostFormat
readonly
Output only.
-
#is_regional ⇒ ::Boolean
readonly
Output only.
-
#protocol ⇒ ::Google::Cloud::OracleDatabase::V1::DatabaseConnectionStringProfile::Protocol
readonly
Output only.
-
#session_mode ⇒ ::Google::Cloud::OracleDatabase::V1::DatabaseConnectionStringProfile::SessionMode
readonly
Output only.
-
#syntax_format ⇒ ::Google::Cloud::OracleDatabase::V1::DatabaseConnectionStringProfile::SyntaxFormat
readonly
Output only.
-
#tls_authentication ⇒ ::Google::Cloud::OracleDatabase::V1::DatabaseConnectionStringProfile::TLSAuthentication
readonly
Output only.
-
#value ⇒ ::String
readonly
Output only.
Instance Attribute Details
#consumer_group ⇒ ::Google::Cloud::OracleDatabase::V1::DatabaseConnectionStringProfile::ConsumerGroup (readonly)
Returns Output only. The current consumer group being used by the connection.
669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 669 class DatabaseConnectionStringProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The various consumer groups available in the connection string profile. module ConsumerGroup # Default unspecified value. CONSUMER_GROUP_UNSPECIFIED = 0 # High consumer group. HIGH = 1 # Medium consumer group. MEDIUM = 2 # Low consumer group. LOW = 3 # TP consumer group. TP = 4 # TPURGENT consumer group. TPURGENT = 5 end # The host name format being used in the connection string. module HostFormat # Default unspecified value. HOST_FORMAT_UNSPECIFIED = 0 # FQDN FQDN = 1 # IP IP = 2 end # The protocol being used by the connection. module Protocol # Default unspecified value. PROTOCOL_UNSPECIFIED = 0 # Tcp TCP = 1 # Tcps TCPS = 2 end # The session mode of the connection. module SessionMode # Default unspecified value. SESSION_MODE_UNSPECIFIED = 0 # Direct DIRECT = 1 # Indirect INDIRECT = 2 end # Specifies syntax of the connection string. module SyntaxFormat # Default unspecified value. SYNTAX_FORMAT_UNSPECIFIED = 0 # Long LONG = 1 # Ezconnect EZCONNECT = 2 # Ezconnectplus EZCONNECTPLUS = 3 end # This field indicates the TLS authentication type of the connection. module TLSAuthentication # Default unspecified value. TLS_AUTHENTICATION_UNSPECIFIED = 0 # Server SERVER = 1 # Mutual MUTUAL = 2 end end |
#display_name ⇒ ::String (readonly)
Returns Output only. The display name for the database connection.
669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 669 class DatabaseConnectionStringProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The various consumer groups available in the connection string profile. module ConsumerGroup # Default unspecified value. CONSUMER_GROUP_UNSPECIFIED = 0 # High consumer group. HIGH = 1 # Medium consumer group. MEDIUM = 2 # Low consumer group. LOW = 3 # TP consumer group. TP = 4 # TPURGENT consumer group. TPURGENT = 5 end # The host name format being used in the connection string. module HostFormat # Default unspecified value. HOST_FORMAT_UNSPECIFIED = 0 # FQDN FQDN = 1 # IP IP = 2 end # The protocol being used by the connection. module Protocol # Default unspecified value. PROTOCOL_UNSPECIFIED = 0 # Tcp TCP = 1 # Tcps TCPS = 2 end # The session mode of the connection. module SessionMode # Default unspecified value. SESSION_MODE_UNSPECIFIED = 0 # Direct DIRECT = 1 # Indirect INDIRECT = 2 end # Specifies syntax of the connection string. module SyntaxFormat # Default unspecified value. SYNTAX_FORMAT_UNSPECIFIED = 0 # Long LONG = 1 # Ezconnect EZCONNECT = 2 # Ezconnectplus EZCONNECTPLUS = 3 end # This field indicates the TLS authentication type of the connection. module TLSAuthentication # Default unspecified value. TLS_AUTHENTICATION_UNSPECIFIED = 0 # Server SERVER = 1 # Mutual MUTUAL = 2 end end |
#host_format ⇒ ::Google::Cloud::OracleDatabase::V1::DatabaseConnectionStringProfile::HostFormat (readonly)
Returns Output only. The host name format being currently used in connection string.
669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 669 class DatabaseConnectionStringProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The various consumer groups available in the connection string profile. module ConsumerGroup # Default unspecified value. CONSUMER_GROUP_UNSPECIFIED = 0 # High consumer group. HIGH = 1 # Medium consumer group. MEDIUM = 2 # Low consumer group. LOW = 3 # TP consumer group. TP = 4 # TPURGENT consumer group. TPURGENT = 5 end # The host name format being used in the connection string. module HostFormat # Default unspecified value. HOST_FORMAT_UNSPECIFIED = 0 # FQDN FQDN = 1 # IP IP = 2 end # The protocol being used by the connection. module Protocol # Default unspecified value. PROTOCOL_UNSPECIFIED = 0 # Tcp TCP = 1 # Tcps TCPS = 2 end # The session mode of the connection. module SessionMode # Default unspecified value. SESSION_MODE_UNSPECIFIED = 0 # Direct DIRECT = 1 # Indirect INDIRECT = 2 end # Specifies syntax of the connection string. module SyntaxFormat # Default unspecified value. SYNTAX_FORMAT_UNSPECIFIED = 0 # Long LONG = 1 # Ezconnect EZCONNECT = 2 # Ezconnectplus EZCONNECTPLUS = 3 end # This field indicates the TLS authentication type of the connection. module TLSAuthentication # Default unspecified value. TLS_AUTHENTICATION_UNSPECIFIED = 0 # Server SERVER = 1 # Mutual MUTUAL = 2 end end |
#is_regional ⇒ ::Boolean (readonly)
Returns Output only. This field indicates if the connection string is regional and is only applicable for cross-region Data Guard.
669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 669 class DatabaseConnectionStringProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The various consumer groups available in the connection string profile. module ConsumerGroup # Default unspecified value. CONSUMER_GROUP_UNSPECIFIED = 0 # High consumer group. HIGH = 1 # Medium consumer group. MEDIUM = 2 # Low consumer group. LOW = 3 # TP consumer group. TP = 4 # TPURGENT consumer group. TPURGENT = 5 end # The host name format being used in the connection string. module HostFormat # Default unspecified value. HOST_FORMAT_UNSPECIFIED = 0 # FQDN FQDN = 1 # IP IP = 2 end # The protocol being used by the connection. module Protocol # Default unspecified value. PROTOCOL_UNSPECIFIED = 0 # Tcp TCP = 1 # Tcps TCPS = 2 end # The session mode of the connection. module SessionMode # Default unspecified value. SESSION_MODE_UNSPECIFIED = 0 # Direct DIRECT = 1 # Indirect INDIRECT = 2 end # Specifies syntax of the connection string. module SyntaxFormat # Default unspecified value. SYNTAX_FORMAT_UNSPECIFIED = 0 # Long LONG = 1 # Ezconnect EZCONNECT = 2 # Ezconnectplus EZCONNECTPLUS = 3 end # This field indicates the TLS authentication type of the connection. module TLSAuthentication # Default unspecified value. TLS_AUTHENTICATION_UNSPECIFIED = 0 # Server SERVER = 1 # Mutual MUTUAL = 2 end end |
#protocol ⇒ ::Google::Cloud::OracleDatabase::V1::DatabaseConnectionStringProfile::Protocol (readonly)
Returns Output only. The protocol being used by the connection.
669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 669 class DatabaseConnectionStringProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The various consumer groups available in the connection string profile. module ConsumerGroup # Default unspecified value. CONSUMER_GROUP_UNSPECIFIED = 0 # High consumer group. HIGH = 1 # Medium consumer group. MEDIUM = 2 # Low consumer group. LOW = 3 # TP consumer group. TP = 4 # TPURGENT consumer group. TPURGENT = 5 end # The host name format being used in the connection string. module HostFormat # Default unspecified value. HOST_FORMAT_UNSPECIFIED = 0 # FQDN FQDN = 1 # IP IP = 2 end # The protocol being used by the connection. module Protocol # Default unspecified value. PROTOCOL_UNSPECIFIED = 0 # Tcp TCP = 1 # Tcps TCPS = 2 end # The session mode of the connection. module SessionMode # Default unspecified value. SESSION_MODE_UNSPECIFIED = 0 # Direct DIRECT = 1 # Indirect INDIRECT = 2 end # Specifies syntax of the connection string. module SyntaxFormat # Default unspecified value. SYNTAX_FORMAT_UNSPECIFIED = 0 # Long LONG = 1 # Ezconnect EZCONNECT = 2 # Ezconnectplus EZCONNECTPLUS = 3 end # This field indicates the TLS authentication type of the connection. module TLSAuthentication # Default unspecified value. TLS_AUTHENTICATION_UNSPECIFIED = 0 # Server SERVER = 1 # Mutual MUTUAL = 2 end end |
#session_mode ⇒ ::Google::Cloud::OracleDatabase::V1::DatabaseConnectionStringProfile::SessionMode (readonly)
Returns Output only. The current session mode of the connection.
669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 669 class DatabaseConnectionStringProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The various consumer groups available in the connection string profile. module ConsumerGroup # Default unspecified value. CONSUMER_GROUP_UNSPECIFIED = 0 # High consumer group. HIGH = 1 # Medium consumer group. MEDIUM = 2 # Low consumer group. LOW = 3 # TP consumer group. TP = 4 # TPURGENT consumer group. TPURGENT = 5 end # The host name format being used in the connection string. module HostFormat # Default unspecified value. HOST_FORMAT_UNSPECIFIED = 0 # FQDN FQDN = 1 # IP IP = 2 end # The protocol being used by the connection. module Protocol # Default unspecified value. PROTOCOL_UNSPECIFIED = 0 # Tcp TCP = 1 # Tcps TCPS = 2 end # The session mode of the connection. module SessionMode # Default unspecified value. SESSION_MODE_UNSPECIFIED = 0 # Direct DIRECT = 1 # Indirect INDIRECT = 2 end # Specifies syntax of the connection string. module SyntaxFormat # Default unspecified value. SYNTAX_FORMAT_UNSPECIFIED = 0 # Long LONG = 1 # Ezconnect EZCONNECT = 2 # Ezconnectplus EZCONNECTPLUS = 3 end # This field indicates the TLS authentication type of the connection. module TLSAuthentication # Default unspecified value. TLS_AUTHENTICATION_UNSPECIFIED = 0 # Server SERVER = 1 # Mutual MUTUAL = 2 end end |
#syntax_format ⇒ ::Google::Cloud::OracleDatabase::V1::DatabaseConnectionStringProfile::SyntaxFormat (readonly)
Returns Output only. The syntax of the connection string.
669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 669 class DatabaseConnectionStringProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The various consumer groups available in the connection string profile. module ConsumerGroup # Default unspecified value. CONSUMER_GROUP_UNSPECIFIED = 0 # High consumer group. HIGH = 1 # Medium consumer group. MEDIUM = 2 # Low consumer group. LOW = 3 # TP consumer group. TP = 4 # TPURGENT consumer group. TPURGENT = 5 end # The host name format being used in the connection string. module HostFormat # Default unspecified value. HOST_FORMAT_UNSPECIFIED = 0 # FQDN FQDN = 1 # IP IP = 2 end # The protocol being used by the connection. module Protocol # Default unspecified value. PROTOCOL_UNSPECIFIED = 0 # Tcp TCP = 1 # Tcps TCPS = 2 end # The session mode of the connection. module SessionMode # Default unspecified value. SESSION_MODE_UNSPECIFIED = 0 # Direct DIRECT = 1 # Indirect INDIRECT = 2 end # Specifies syntax of the connection string. module SyntaxFormat # Default unspecified value. SYNTAX_FORMAT_UNSPECIFIED = 0 # Long LONG = 1 # Ezconnect EZCONNECT = 2 # Ezconnectplus EZCONNECTPLUS = 3 end # This field indicates the TLS authentication type of the connection. module TLSAuthentication # Default unspecified value. TLS_AUTHENTICATION_UNSPECIFIED = 0 # Server SERVER = 1 # Mutual MUTUAL = 2 end end |
#tls_authentication ⇒ ::Google::Cloud::OracleDatabase::V1::DatabaseConnectionStringProfile::TLSAuthentication (readonly)
Returns Output only. This field indicates the TLS authentication type of the connection.
669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 669 class DatabaseConnectionStringProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The various consumer groups available in the connection string profile. module ConsumerGroup # Default unspecified value. CONSUMER_GROUP_UNSPECIFIED = 0 # High consumer group. HIGH = 1 # Medium consumer group. MEDIUM = 2 # Low consumer group. LOW = 3 # TP consumer group. TP = 4 # TPURGENT consumer group. TPURGENT = 5 end # The host name format being used in the connection string. module HostFormat # Default unspecified value. HOST_FORMAT_UNSPECIFIED = 0 # FQDN FQDN = 1 # IP IP = 2 end # The protocol being used by the connection. module Protocol # Default unspecified value. PROTOCOL_UNSPECIFIED = 0 # Tcp TCP = 1 # Tcps TCPS = 2 end # The session mode of the connection. module SessionMode # Default unspecified value. SESSION_MODE_UNSPECIFIED = 0 # Direct DIRECT = 1 # Indirect INDIRECT = 2 end # Specifies syntax of the connection string. module SyntaxFormat # Default unspecified value. SYNTAX_FORMAT_UNSPECIFIED = 0 # Long LONG = 1 # Ezconnect EZCONNECT = 2 # Ezconnectplus EZCONNECTPLUS = 3 end # This field indicates the TLS authentication type of the connection. module TLSAuthentication # Default unspecified value. TLS_AUTHENTICATION_UNSPECIFIED = 0 # Server SERVER = 1 # Mutual MUTUAL = 2 end end |
#value ⇒ ::String (readonly)
Returns Output only. The value of the connection string.
669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 669 class DatabaseConnectionStringProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The various consumer groups available in the connection string profile. module ConsumerGroup # Default unspecified value. CONSUMER_GROUP_UNSPECIFIED = 0 # High consumer group. HIGH = 1 # Medium consumer group. MEDIUM = 2 # Low consumer group. LOW = 3 # TP consumer group. TP = 4 # TPURGENT consumer group. TPURGENT = 5 end # The host name format being used in the connection string. module HostFormat # Default unspecified value. HOST_FORMAT_UNSPECIFIED = 0 # FQDN FQDN = 1 # IP IP = 2 end # The protocol being used by the connection. module Protocol # Default unspecified value. PROTOCOL_UNSPECIFIED = 0 # Tcp TCP = 1 # Tcps TCPS = 2 end # The session mode of the connection. module SessionMode # Default unspecified value. SESSION_MODE_UNSPECIFIED = 0 # Direct DIRECT = 1 # Indirect INDIRECT = 2 end # Specifies syntax of the connection string. module SyntaxFormat # Default unspecified value. SYNTAX_FORMAT_UNSPECIFIED = 0 # Long LONG = 1 # Ezconnect EZCONNECT = 2 # Ezconnectplus EZCONNECTPLUS = 3 end # This field indicates the TLS authentication type of the connection. module TLSAuthentication # Default unspecified value. TLS_AUTHENTICATION_UNSPECIFIED = 0 # Server SERVER = 1 # Mutual MUTUAL = 2 end end |