Class: Google::Cloud::OracleDatabase::V1::DbBackupConfig
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::DbBackupConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/database.rb
Overview
Backup Options for the Database.
Defined Under Namespace
Modules: BackupDeletionPolicy, BackupDestinationType, BackupWindow Classes: BackupDestinationDetails
Instance Attribute Summary collapse
-
#auto_backup_enabled ⇒ ::Boolean
Optional.
-
#auto_full_backup_day ⇒ ::Google::Type::DayOfWeek
Optional.
-
#auto_full_backup_window ⇒ ::Google::Cloud::OracleDatabase::V1::DbBackupConfig::BackupWindow
Optional.
-
#auto_incremental_backup_window ⇒ ::Google::Cloud::OracleDatabase::V1::DbBackupConfig::BackupWindow
Optional.
-
#backup_deletion_policy ⇒ ::Google::Cloud::OracleDatabase::V1::DbBackupConfig::BackupDeletionPolicy
Optional.
-
#backup_destination_details ⇒ ::Array<::Google::Cloud::OracleDatabase::V1::DbBackupConfig::BackupDestinationDetails>
Optional.
-
#retention_period_days ⇒ ::Integer
Optional.
Instance Attribute Details
#auto_backup_enabled ⇒ ::Boolean
Returns Optional. If set to true, enables automatic backups on the database.
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 211 class DbBackupConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The details of the database backup destination. # @!attribute [rw] type # @return [::Google::Cloud::OracleDatabase::V1::DbBackupConfig::BackupDestinationType] # Optional. The type of the database backup destination. class BackupDestinationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of the database backup destination. module BackupDestinationType # Default unspecified value. BACKUP_DESTINATION_TYPE_UNSPECIFIED = 0 # Backup destination type is NFS. NFS = 1 # Backup destination type is Recovery Appliance. RECOVERY_APPLIANCE = 2 # Backup destination type is Object Store. OBJECT_STORE = 3 # Backup destination type is Local. LOCAL = 4 # Backup destination type is DBRS. DBRS = 5 end # The 2 hour window in which the backup should be performed on the database. module BackupWindow # Default unspecified value. BACKUP_WINDOW_UNSPECIFIED = 0 # 12:00 AM - 2:00 AM SLOT_ONE = 1 # 2:00 AM - 4:00 AM SLOT_TWO = 2 # 4:00 AM - 6:00 AM SLOT_THREE = 3 # 6:00 AM - 8:00 AM SLOT_FOUR = 4 # 8:00 AM - 10:00 AM SLOT_FIVE = 5 # 10:00 AM - 12:00 PM SLOT_SIX = 6 # 12:00 PM - 2:00 PM SLOT_SEVEN = 7 # 2:00 PM - 4:00 PM SLOT_EIGHT = 8 # 4:00 PM - 6:00 PM SLOT_NINE = 9 # 6:00 PM - 8:00 PM SLOT_TEN = 10 # 8:00 PM - 10:00 PM SLOT_ELEVEN = 11 # 10:00 PM - 12:00 AM SLOT_TWELVE = 12 end # This defines when the backups will be deleted after Database termination. module BackupDeletionPolicy # Default unspecified value. BACKUP_DELETION_POLICY_UNSPECIFIED = 0 # Keeps the backup for predefined time # i.e. 72 hours and then delete permanently. DELETE_IMMEDIATELY = 1 # Keeps the backups as per the policy defined # for database backups. DELETE_AFTER_RETENTION_PERIOD = 2 end end |
#auto_full_backup_day ⇒ ::Google::Type::DayOfWeek
Returns Optional. The day of the week on which the full backup should be performed on the database. If no value is provided, it will default to Sunday.
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 211 class DbBackupConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The details of the database backup destination. # @!attribute [rw] type # @return [::Google::Cloud::OracleDatabase::V1::DbBackupConfig::BackupDestinationType] # Optional. The type of the database backup destination. class BackupDestinationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of the database backup destination. module BackupDestinationType # Default unspecified value. BACKUP_DESTINATION_TYPE_UNSPECIFIED = 0 # Backup destination type is NFS. NFS = 1 # Backup destination type is Recovery Appliance. RECOVERY_APPLIANCE = 2 # Backup destination type is Object Store. OBJECT_STORE = 3 # Backup destination type is Local. LOCAL = 4 # Backup destination type is DBRS. DBRS = 5 end # The 2 hour window in which the backup should be performed on the database. module BackupWindow # Default unspecified value. BACKUP_WINDOW_UNSPECIFIED = 0 # 12:00 AM - 2:00 AM SLOT_ONE = 1 # 2:00 AM - 4:00 AM SLOT_TWO = 2 # 4:00 AM - 6:00 AM SLOT_THREE = 3 # 6:00 AM - 8:00 AM SLOT_FOUR = 4 # 8:00 AM - 10:00 AM SLOT_FIVE = 5 # 10:00 AM - 12:00 PM SLOT_SIX = 6 # 12:00 PM - 2:00 PM SLOT_SEVEN = 7 # 2:00 PM - 4:00 PM SLOT_EIGHT = 8 # 4:00 PM - 6:00 PM SLOT_NINE = 9 # 6:00 PM - 8:00 PM SLOT_TEN = 10 # 8:00 PM - 10:00 PM SLOT_ELEVEN = 11 # 10:00 PM - 12:00 AM SLOT_TWELVE = 12 end # This defines when the backups will be deleted after Database termination. module BackupDeletionPolicy # Default unspecified value. BACKUP_DELETION_POLICY_UNSPECIFIED = 0 # Keeps the backup for predefined time # i.e. 72 hours and then delete permanently. DELETE_IMMEDIATELY = 1 # Keeps the backups as per the policy defined # for database backups. DELETE_AFTER_RETENTION_PERIOD = 2 end end |
#auto_full_backup_window ⇒ ::Google::Cloud::OracleDatabase::V1::DbBackupConfig::BackupWindow
Returns Optional. The window in which the full backup should be performed on the database. If no value is provided, the default is anytime.
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 211 class DbBackupConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The details of the database backup destination. # @!attribute [rw] type # @return [::Google::Cloud::OracleDatabase::V1::DbBackupConfig::BackupDestinationType] # Optional. The type of the database backup destination. class BackupDestinationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of the database backup destination. module BackupDestinationType # Default unspecified value. BACKUP_DESTINATION_TYPE_UNSPECIFIED = 0 # Backup destination type is NFS. NFS = 1 # Backup destination type is Recovery Appliance. RECOVERY_APPLIANCE = 2 # Backup destination type is Object Store. OBJECT_STORE = 3 # Backup destination type is Local. LOCAL = 4 # Backup destination type is DBRS. DBRS = 5 end # The 2 hour window in which the backup should be performed on the database. module BackupWindow # Default unspecified value. BACKUP_WINDOW_UNSPECIFIED = 0 # 12:00 AM - 2:00 AM SLOT_ONE = 1 # 2:00 AM - 4:00 AM SLOT_TWO = 2 # 4:00 AM - 6:00 AM SLOT_THREE = 3 # 6:00 AM - 8:00 AM SLOT_FOUR = 4 # 8:00 AM - 10:00 AM SLOT_FIVE = 5 # 10:00 AM - 12:00 PM SLOT_SIX = 6 # 12:00 PM - 2:00 PM SLOT_SEVEN = 7 # 2:00 PM - 4:00 PM SLOT_EIGHT = 8 # 4:00 PM - 6:00 PM SLOT_NINE = 9 # 6:00 PM - 8:00 PM SLOT_TEN = 10 # 8:00 PM - 10:00 PM SLOT_ELEVEN = 11 # 10:00 PM - 12:00 AM SLOT_TWELVE = 12 end # This defines when the backups will be deleted after Database termination. module BackupDeletionPolicy # Default unspecified value. BACKUP_DELETION_POLICY_UNSPECIFIED = 0 # Keeps the backup for predefined time # i.e. 72 hours and then delete permanently. DELETE_IMMEDIATELY = 1 # Keeps the backups as per the policy defined # for database backups. DELETE_AFTER_RETENTION_PERIOD = 2 end end |
#auto_incremental_backup_window ⇒ ::Google::Cloud::OracleDatabase::V1::DbBackupConfig::BackupWindow
Returns Optional. The window in which the incremental backup should be performed on the database. If no value is provided, the default is anytime except the auto full backup day.
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 211 class DbBackupConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The details of the database backup destination. # @!attribute [rw] type # @return [::Google::Cloud::OracleDatabase::V1::DbBackupConfig::BackupDestinationType] # Optional. The type of the database backup destination. class BackupDestinationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of the database backup destination. module BackupDestinationType # Default unspecified value. BACKUP_DESTINATION_TYPE_UNSPECIFIED = 0 # Backup destination type is NFS. NFS = 1 # Backup destination type is Recovery Appliance. RECOVERY_APPLIANCE = 2 # Backup destination type is Object Store. OBJECT_STORE = 3 # Backup destination type is Local. LOCAL = 4 # Backup destination type is DBRS. DBRS = 5 end # The 2 hour window in which the backup should be performed on the database. module BackupWindow # Default unspecified value. BACKUP_WINDOW_UNSPECIFIED = 0 # 12:00 AM - 2:00 AM SLOT_ONE = 1 # 2:00 AM - 4:00 AM SLOT_TWO = 2 # 4:00 AM - 6:00 AM SLOT_THREE = 3 # 6:00 AM - 8:00 AM SLOT_FOUR = 4 # 8:00 AM - 10:00 AM SLOT_FIVE = 5 # 10:00 AM - 12:00 PM SLOT_SIX = 6 # 12:00 PM - 2:00 PM SLOT_SEVEN = 7 # 2:00 PM - 4:00 PM SLOT_EIGHT = 8 # 4:00 PM - 6:00 PM SLOT_NINE = 9 # 6:00 PM - 8:00 PM SLOT_TEN = 10 # 8:00 PM - 10:00 PM SLOT_ELEVEN = 11 # 10:00 PM - 12:00 AM SLOT_TWELVE = 12 end # This defines when the backups will be deleted after Database termination. module BackupDeletionPolicy # Default unspecified value. BACKUP_DELETION_POLICY_UNSPECIFIED = 0 # Keeps the backup for predefined time # i.e. 72 hours and then delete permanently. DELETE_IMMEDIATELY = 1 # Keeps the backups as per the policy defined # for database backups. DELETE_AFTER_RETENTION_PERIOD = 2 end end |
#backup_deletion_policy ⇒ ::Google::Cloud::OracleDatabase::V1::DbBackupConfig::BackupDeletionPolicy
Returns Optional. This defines when the backups will be deleted after Database termination.
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 211 class DbBackupConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The details of the database backup destination. # @!attribute [rw] type # @return [::Google::Cloud::OracleDatabase::V1::DbBackupConfig::BackupDestinationType] # Optional. The type of the database backup destination. class BackupDestinationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of the database backup destination. module BackupDestinationType # Default unspecified value. BACKUP_DESTINATION_TYPE_UNSPECIFIED = 0 # Backup destination type is NFS. NFS = 1 # Backup destination type is Recovery Appliance. RECOVERY_APPLIANCE = 2 # Backup destination type is Object Store. OBJECT_STORE = 3 # Backup destination type is Local. LOCAL = 4 # Backup destination type is DBRS. DBRS = 5 end # The 2 hour window in which the backup should be performed on the database. module BackupWindow # Default unspecified value. BACKUP_WINDOW_UNSPECIFIED = 0 # 12:00 AM - 2:00 AM SLOT_ONE = 1 # 2:00 AM - 4:00 AM SLOT_TWO = 2 # 4:00 AM - 6:00 AM SLOT_THREE = 3 # 6:00 AM - 8:00 AM SLOT_FOUR = 4 # 8:00 AM - 10:00 AM SLOT_FIVE = 5 # 10:00 AM - 12:00 PM SLOT_SIX = 6 # 12:00 PM - 2:00 PM SLOT_SEVEN = 7 # 2:00 PM - 4:00 PM SLOT_EIGHT = 8 # 4:00 PM - 6:00 PM SLOT_NINE = 9 # 6:00 PM - 8:00 PM SLOT_TEN = 10 # 8:00 PM - 10:00 PM SLOT_ELEVEN = 11 # 10:00 PM - 12:00 AM SLOT_TWELVE = 12 end # This defines when the backups will be deleted after Database termination. module BackupDeletionPolicy # Default unspecified value. BACKUP_DELETION_POLICY_UNSPECIFIED = 0 # Keeps the backup for predefined time # i.e. 72 hours and then delete permanently. DELETE_IMMEDIATELY = 1 # Keeps the backups as per the policy defined # for database backups. DELETE_AFTER_RETENTION_PERIOD = 2 end end |
#backup_destination_details ⇒ ::Array<::Google::Cloud::OracleDatabase::V1::DbBackupConfig::BackupDestinationDetails>
Returns Optional. Details of the database backup destinations.
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 211 class DbBackupConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The details of the database backup destination. # @!attribute [rw] type # @return [::Google::Cloud::OracleDatabase::V1::DbBackupConfig::BackupDestinationType] # Optional. The type of the database backup destination. class BackupDestinationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of the database backup destination. module BackupDestinationType # Default unspecified value. BACKUP_DESTINATION_TYPE_UNSPECIFIED = 0 # Backup destination type is NFS. NFS = 1 # Backup destination type is Recovery Appliance. RECOVERY_APPLIANCE = 2 # Backup destination type is Object Store. OBJECT_STORE = 3 # Backup destination type is Local. LOCAL = 4 # Backup destination type is DBRS. DBRS = 5 end # The 2 hour window in which the backup should be performed on the database. module BackupWindow # Default unspecified value. BACKUP_WINDOW_UNSPECIFIED = 0 # 12:00 AM - 2:00 AM SLOT_ONE = 1 # 2:00 AM - 4:00 AM SLOT_TWO = 2 # 4:00 AM - 6:00 AM SLOT_THREE = 3 # 6:00 AM - 8:00 AM SLOT_FOUR = 4 # 8:00 AM - 10:00 AM SLOT_FIVE = 5 # 10:00 AM - 12:00 PM SLOT_SIX = 6 # 12:00 PM - 2:00 PM SLOT_SEVEN = 7 # 2:00 PM - 4:00 PM SLOT_EIGHT = 8 # 4:00 PM - 6:00 PM SLOT_NINE = 9 # 6:00 PM - 8:00 PM SLOT_TEN = 10 # 8:00 PM - 10:00 PM SLOT_ELEVEN = 11 # 10:00 PM - 12:00 AM SLOT_TWELVE = 12 end # This defines when the backups will be deleted after Database termination. module BackupDeletionPolicy # Default unspecified value. BACKUP_DELETION_POLICY_UNSPECIFIED = 0 # Keeps the backup for predefined time # i.e. 72 hours and then delete permanently. DELETE_IMMEDIATELY = 1 # Keeps the backups as per the policy defined # for database backups. DELETE_AFTER_RETENTION_PERIOD = 2 end end |
#retention_period_days ⇒ ::Integer
Returns Optional. The number of days an automatic backup is retained before being automatically deleted. This value determines the earliest point in time to which a database can be restored. Min: 1, Max: 60.
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'proto_docs/google/cloud/oracledatabase/v1/database.rb', line 211 class DbBackupConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The details of the database backup destination. # @!attribute [rw] type # @return [::Google::Cloud::OracleDatabase::V1::DbBackupConfig::BackupDestinationType] # Optional. The type of the database backup destination. class BackupDestinationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of the database backup destination. module BackupDestinationType # Default unspecified value. BACKUP_DESTINATION_TYPE_UNSPECIFIED = 0 # Backup destination type is NFS. NFS = 1 # Backup destination type is Recovery Appliance. RECOVERY_APPLIANCE = 2 # Backup destination type is Object Store. OBJECT_STORE = 3 # Backup destination type is Local. LOCAL = 4 # Backup destination type is DBRS. DBRS = 5 end # The 2 hour window in which the backup should be performed on the database. module BackupWindow # Default unspecified value. BACKUP_WINDOW_UNSPECIFIED = 0 # 12:00 AM - 2:00 AM SLOT_ONE = 1 # 2:00 AM - 4:00 AM SLOT_TWO = 2 # 4:00 AM - 6:00 AM SLOT_THREE = 3 # 6:00 AM - 8:00 AM SLOT_FOUR = 4 # 8:00 AM - 10:00 AM SLOT_FIVE = 5 # 10:00 AM - 12:00 PM SLOT_SIX = 6 # 12:00 PM - 2:00 PM SLOT_SEVEN = 7 # 2:00 PM - 4:00 PM SLOT_EIGHT = 8 # 4:00 PM - 6:00 PM SLOT_NINE = 9 # 6:00 PM - 8:00 PM SLOT_TEN = 10 # 8:00 PM - 10:00 PM SLOT_ELEVEN = 11 # 10:00 PM - 12:00 AM SLOT_TWELVE = 12 end # This defines when the backups will be deleted after Database termination. module BackupDeletionPolicy # Default unspecified value. BACKUP_DELETION_POLICY_UNSPECIFIED = 0 # Keeps the backup for predefined time # i.e. 72 hours and then delete permanently. DELETE_IMMEDIATELY = 1 # Keeps the backups as per the policy defined # for database backups. DELETE_AFTER_RETENTION_PERIOD = 2 end end |