Class: Google::Cloud::OracleDatabase::V1::DeleteOdbSubnetRequest
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::DeleteOdbSubnetRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/odb_subnet.rb
Overview
The request for OdbSubnet.Delete.
Instance Attribute Summary collapse
-
#name ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
Instance Attribute Details
#name ⇒ ::String
Returns Required. The name of the resource in the following format: projects/{project}/locations/{region}/odbNetworks/{odb_network}/odbSubnets/{odb_subnet}.
132 133 134 135 |
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_subnet.rb', line 132 class DeleteOdbSubnetRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. An optional ID to identify the request. This value is used to identify duplicate requests. If you make a request with the same request ID and the original request is still in progress or completed, the server ignores the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
132 133 134 135 |
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_subnet.rb', line 132 class DeleteOdbSubnetRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |