Class: Google::Cloud::OracleDatabase::V1::EncryptionKey
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::EncryptionKey
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb
Overview
The encryption key used to encrypt the Autonomous Database.
Defined Under Namespace
Modules: Provider
Instance Attribute Summary collapse
-
#kms_key ⇒ ::String
Optional.
-
#provider ⇒ ::Google::Cloud::OracleDatabase::V1::EncryptionKey::Provider
Optional.
Instance Attribute Details
#kms_key ⇒ ::String
Returns Optional. The KMS key used to encrypt the Autonomous Database.
This field is required if the provider is GOOGLE_MANAGED.
The name of the KMS key resource in the following format:
projects/{project}/locations/{location}/keyRings/{key_ring}/cryptoKeys/{crypto_key}.
575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 |
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 575 class EncryptionKey include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The provider of the encryption key. module Provider # Default unspecified value. PROVIDER_UNSPECIFIED = 0 # Google Managed KMS key, if selected, please provide the KMS key name. GOOGLE_MANAGED = 1 # Oracle Managed. ORACLE_MANAGED = 2 end end |
#provider ⇒ ::Google::Cloud::OracleDatabase::V1::EncryptionKey::Provider
Returns Optional. The provider of the encryption key.
575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 |
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 575 class EncryptionKey include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The provider of the encryption key. module Provider # Default unspecified value. PROVIDER_UNSPECIFIED = 0 # Google Managed KMS key, if selected, please provide the KMS key name. GOOGLE_MANAGED = 1 # Oracle Managed. ORACLE_MANAGED = 2 end end |