Class: Google::Cloud::OracleDatabase::V1::EncryptionKeyHistoryEntry
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::EncryptionKeyHistoryEntry
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb
Overview
The history of the encryption keys used to encrypt the Autonomous Database.
Instance Attribute Summary collapse
-
#activation_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#encryption_key ⇒ ::Google::Cloud::OracleDatabase::V1::EncryptionKey
readonly
Output only.
Instance Attribute Details
#activation_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The date and time when the encryption key was activated on the Autonomous Database..
560 561 562 563 |
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 560 class EncryptionKeyHistoryEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#encryption_key ⇒ ::Google::Cloud::OracleDatabase::V1::EncryptionKey (readonly)
Returns Output only. The encryption key used to encrypt the Autonomous Database.
560 561 562 563 |
# File 'proto_docs/google/cloud/oracledatabase/v1/autonomous_database.rb', line 560 class EncryptionKeyHistoryEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |