Class: Google::Cloud::OracleDatabase::V1::ExadbVmClusterStorageDetails
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::ExadbVmClusterStorageDetails
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb
Overview
The storage allocation for the exadbvmcluster, in gigabytes (GB).
Instance Attribute Summary collapse
-
#size_in_gbs_per_node ⇒ ::Integer
Required.
Instance Attribute Details
#size_in_gbs_per_node ⇒ ::Integer
Returns Required. The storage allocation for the exadbvmcluster per node, in gigabytes (GB). This field is used to calculate the total storage allocation for the exadbvmcluster.
92 93 94 95 |
# File 'proto_docs/google/cloud/oracledatabase/v1/exadb_vm_cluster.rb', line 92 class ExadbVmClusterStorageDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |