Class: Google::Cloud::OracleDatabase::V1::ExascaleDbStorageVault
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::ExascaleDbStorageVault
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/exascale_db_storage_vault.rb
Overview
ExascaleDbStorageVault represents a storage vault exadb vm cluster resource. https://docs.oracle.com/en-us/iaas/api/#/en/database/20160918/ExascaleDbStorageVault/
Defined Under Namespace
Classes: LabelsEntry
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#display_name ⇒ ::String
Required.
-
#entitlement_id ⇒ ::String
readonly
Output only.
-
#gcp_oracle_zone ⇒ ::String
Optional.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#name ⇒ ::String
Identifier.
-
#properties ⇒ ::Google::Cloud::OracleDatabase::V1::ExascaleDbStorageVaultProperties
Required.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The date and time when the ExascaleDbStorageVault was created.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'proto_docs/google/cloud/oracledatabase/v1/exascale_db_storage_vault.rb', line 54 class ExascaleDbStorageVault include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#display_name ⇒ ::String
Returns Required. The display name for the ExascaleDbStorageVault. The name does not have to be unique within your project. The name must be 1-255 characters long and can only contain alphanumeric characters.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'proto_docs/google/cloud/oracledatabase/v1/exascale_db_storage_vault.rb', line 54 class ExascaleDbStorageVault include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#entitlement_id ⇒ ::String (readonly)
Returns Output only. The ID of the subscription entitlement associated with the ExascaleDbStorageVault.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'proto_docs/google/cloud/oracledatabase/v1/exascale_db_storage_vault.rb', line 54 class ExascaleDbStorageVault include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#gcp_oracle_zone ⇒ ::String
Returns Optional. The GCP Oracle zone where Oracle ExascaleDbStorageVault is hosted. Example: us-east4-b-r2. If not specified, the system will pick a zone based on availability.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'proto_docs/google/cloud/oracledatabase/v1/exascale_db_storage_vault.rb', line 54 class ExascaleDbStorageVault include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. The labels or tags associated with the ExascaleDbStorageVault.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'proto_docs/google/cloud/oracledatabase/v1/exascale_db_storage_vault.rb', line 54 class ExascaleDbStorageVault include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Identifier. The resource name of the ExascaleDbStorageVault. Format: projects/{project}/locations/{location}/exascaleDbStorageVaults/{exascale_db_storage_vault}.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'proto_docs/google/cloud/oracledatabase/v1/exascale_db_storage_vault.rb', line 54 class ExascaleDbStorageVault include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#properties ⇒ ::Google::Cloud::OracleDatabase::V1::ExascaleDbStorageVaultProperties
Returns Required. The properties of the ExascaleDbStorageVault.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'proto_docs/google/cloud/oracledatabase/v1/exascale_db_storage_vault.rb', line 54 class ExascaleDbStorageVault include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |