Class: Google::Cloud::OracleDatabase::V1::GoldengateAmazonRedshiftConnectionProperties
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::GoldengateAmazonRedshiftConnectionProperties
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb
Overview
The properties of GoldengateAmazonRedshiftConnection.
Instance Attribute Summary collapse
-
#connection_url ⇒ ::String
Optional.
-
#password ⇒ ::String
Optional.
-
#password_secret_version ⇒ ::String
Optional.
-
#technology_type ⇒ ::String
Optional.
-
#username ⇒ ::String
Optional.
Instance Attribute Details
#connection_url ⇒ ::String
Returns Optional. Connection URL. e.g.: 'jdbc:redshift://aws-redshift-instance.aaaaaaaaaaaa.us-east-2.redshift.amazonaws.com:5439/mydb'.
1480 1481 1482 1483 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1480 class GoldengateAmazonRedshiftConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#password ⇒ ::String
Returns Optional. Input only. The password Oracle Goldengate uses for Amazon Redshift connection in plain text.
Note: The following fields are mutually exclusive: password, password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.
1480 1481 1482 1483 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1480 class GoldengateAmazonRedshiftConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#password_secret_version ⇒ ::String
Returns Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses for Amazon Redshift connection. Format: projects/{project}/secrets/{secret}/versions/{version}.
Note: The following fields are mutually exclusive: password_secret_version, password. If a field in that set is populated, all other fields in the set will automatically be cleared.
1480 1481 1482 1483 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1480 class GoldengateAmazonRedshiftConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#technology_type ⇒ ::String
Returns Optional. The technology type of AmazonRedshiftConnection.
1480 1481 1482 1483 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1480 class GoldengateAmazonRedshiftConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#username ⇒ ::String
Returns Optional. The username Oracle Goldengate uses to connect the associated system of the given technology.
1480 1481 1482 1483 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1480 class GoldengateAmazonRedshiftConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |