Class: Google::Cloud::OracleDatabase::V1::GoldengateAzureDataLakeStorageConnectionProperties
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::GoldengateAzureDataLakeStorageConnectionProperties
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb
Overview
The properties of GoldengateAzureDataLakeStorageConnection.
Defined Under Namespace
Modules: AuthenticationType
Instance Attribute Summary collapse
-
#account ⇒ ::String
Optional.
-
#account_key_secret ⇒ ::String
Optional.
-
#authentication_type ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateAzureDataLakeStorageConnectionProperties::AuthenticationType
Optional.
-
#azure_authority_host ⇒ ::String
Optional.
-
#azure_tenant_id ⇒ ::String
Optional.
-
#client_id ⇒ ::String
Optional.
-
#client_secret ⇒ ::String
Optional.
-
#endpoint ⇒ ::String
Optional.
-
#sas_token_secret ⇒ ::String
Optional.
-
#technology_type ⇒ ::String
Optional.
Instance Attribute Details
#account ⇒ ::String
Returns Optional. Sets the Azure storage account name.
916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 916 class GoldengateAzureDataLakeStorageConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for authentication mechanism to access Azure Data Lake Storage. module AuthenticationType # Authentication type not specified. AUTHENTICATION_TYPE_UNSPECIFIED = 0 # Shared key authentication. SHARED_KEY = 1 # Shared access signature authentication. SHARED_ACCESS_SIGNATURE = 2 # Azure active directory authentication. AZURE_ACTIVE_DIRECTORY = 3 end end |
#account_key_secret ⇒ ::String
Returns Optional. Azure storage account key. This property is required when 'authentication_type' is set to 'SHARED_KEY'.
916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 916 class GoldengateAzureDataLakeStorageConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for authentication mechanism to access Azure Data Lake Storage. module AuthenticationType # Authentication type not specified. AUTHENTICATION_TYPE_UNSPECIFIED = 0 # Shared key authentication. SHARED_KEY = 1 # Shared access signature authentication. SHARED_ACCESS_SIGNATURE = 2 # Azure active directory authentication. AZURE_ACTIVE_DIRECTORY = 3 end end |
#authentication_type ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateAzureDataLakeStorageConnectionProperties::AuthenticationType
Returns Optional. Authentication mechanism to access Azure Data Lake Storage.
916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 916 class GoldengateAzureDataLakeStorageConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for authentication mechanism to access Azure Data Lake Storage. module AuthenticationType # Authentication type not specified. AUTHENTICATION_TYPE_UNSPECIFIED = 0 # Shared key authentication. SHARED_KEY = 1 # Shared access signature authentication. SHARED_ACCESS_SIGNATURE = 2 # Azure active directory authentication. AZURE_ACTIVE_DIRECTORY = 3 end end |
#azure_authority_host ⇒ ::String
Returns Optional. The endpoint used for authentication with Microsoft Entra ID (formerly Azure Active Directory). Default value: https://login.microsoftonline.com.
916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 916 class GoldengateAzureDataLakeStorageConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for authentication mechanism to access Azure Data Lake Storage. module AuthenticationType # Authentication type not specified. AUTHENTICATION_TYPE_UNSPECIFIED = 0 # Shared key authentication. SHARED_KEY = 1 # Shared access signature authentication. SHARED_ACCESS_SIGNATURE = 2 # Azure active directory authentication. AZURE_ACTIVE_DIRECTORY = 3 end end |
#azure_tenant_id ⇒ ::String
Returns Optional. Azure tenant ID of the application. This property is required when 'authentication_type' is set to 'AZURE_ACTIVE_DIRECTORY'.
916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 916 class GoldengateAzureDataLakeStorageConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for authentication mechanism to access Azure Data Lake Storage. module AuthenticationType # Authentication type not specified. AUTHENTICATION_TYPE_UNSPECIFIED = 0 # Shared key authentication. SHARED_KEY = 1 # Shared access signature authentication. SHARED_ACCESS_SIGNATURE = 2 # Azure active directory authentication. AZURE_ACTIVE_DIRECTORY = 3 end end |
#client_id ⇒ ::String
Returns Optional. Azure client ID of the application. This property is required when 'authentication_type' is set to 'AZURE_ACTIVE_DIRECTORY'.
916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 916 class GoldengateAzureDataLakeStorageConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for authentication mechanism to access Azure Data Lake Storage. module AuthenticationType # Authentication type not specified. AUTHENTICATION_TYPE_UNSPECIFIED = 0 # Shared key authentication. SHARED_KEY = 1 # Shared access signature authentication. SHARED_ACCESS_SIGNATURE = 2 # Azure active directory authentication. AZURE_ACTIVE_DIRECTORY = 3 end end |
#client_secret ⇒ ::String
Returns Optional. Azure client secret (aka application password) for authentication.
916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 916 class GoldengateAzureDataLakeStorageConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for authentication mechanism to access Azure Data Lake Storage. module AuthenticationType # Authentication type not specified. AUTHENTICATION_TYPE_UNSPECIFIED = 0 # Shared key authentication. SHARED_KEY = 1 # Shared access signature authentication. SHARED_ACCESS_SIGNATURE = 2 # Azure active directory authentication. AZURE_ACTIVE_DIRECTORY = 3 end end |
#endpoint ⇒ ::String
Returns Optional. Azure Storage service endpoint. e.g: https://test.blob.core.windows.net.
916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 916 class GoldengateAzureDataLakeStorageConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for authentication mechanism to access Azure Data Lake Storage. module AuthenticationType # Authentication type not specified. AUTHENTICATION_TYPE_UNSPECIFIED = 0 # Shared key authentication. SHARED_KEY = 1 # Shared access signature authentication. SHARED_ACCESS_SIGNATURE = 2 # Azure active directory authentication. AZURE_ACTIVE_DIRECTORY = 3 end end |
#sas_token_secret ⇒ ::String
Returns Optional. Credential that uses a shared access signature (SAS) to authenticate to an Azure Service.
916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 916 class GoldengateAzureDataLakeStorageConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for authentication mechanism to access Azure Data Lake Storage. module AuthenticationType # Authentication type not specified. AUTHENTICATION_TYPE_UNSPECIFIED = 0 # Shared key authentication. SHARED_KEY = 1 # Shared access signature authentication. SHARED_ACCESS_SIGNATURE = 2 # Azure active directory authentication. AZURE_ACTIVE_DIRECTORY = 3 end end |
#technology_type ⇒ ::String
Returns Optional. The technology type of AzureDataLakeStorageConnection.
916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 916 class GoldengateAzureDataLakeStorageConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for authentication mechanism to access Azure Data Lake Storage. module AuthenticationType # Authentication type not specified. AUTHENTICATION_TYPE_UNSPECIFIED = 0 # Shared key authentication. SHARED_KEY = 1 # Shared access signature authentication. SHARED_ACCESS_SIGNATURE = 2 # Azure active directory authentication. AZURE_ACTIVE_DIRECTORY = 3 end end |