Class: Google::Cloud::OracleDatabase::V1::GoldengateDatabricksConnectionProperties
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::GoldengateDatabricksConnectionProperties
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb
Overview
The properties of GoldengateDatabricksConnection.
Defined Under Namespace
Modules: DatabricksAuthenticationType
Instance Attribute Summary collapse
-
#authentication_type ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateDatabricksConnectionProperties::DatabricksAuthenticationType
Optional.
-
#client_id ⇒ ::String
Optional.
-
#client_secret ⇒ ::String
Optional.
-
#connection_url ⇒ ::String
Optional.
-
#password ⇒ ::String
Optional.
-
#password_secret_version ⇒ ::String
Optional.
-
#storage_credential ⇒ ::String
Optional.
-
#technology_type ⇒ ::String
Optional.
Instance Attribute Details
#authentication_type ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateDatabricksConnectionProperties::DatabricksAuthenticationType
Returns Optional. Authentication type for Databricks.
1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1780 class GoldengateDatabricksConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for authentication type for Databricks. module DatabricksAuthenticationType # Authentication type not specified. DATABRICKS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # Personal access token authentication. PERSONAL_ACCESS_TOKEN = 1 # OAuth M2M authentication. OAUTH_M2M = 2 end end |
#client_id ⇒ ::String
Returns Optional. OAuth client id, only applicable for authentication_type == OAUTH_M2M.
1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1780 class GoldengateDatabricksConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for authentication type for Databricks. module DatabricksAuthenticationType # Authentication type not specified. DATABRICKS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # Personal access token authentication. PERSONAL_ACCESS_TOKEN = 1 # OAuth M2M authentication. OAUTH_M2M = 2 end end |
#client_secret ⇒ ::String
Returns Optional. OAuth client secret, only applicable for authentication_type == OAUTH_M2M.
1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1780 class GoldengateDatabricksConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for authentication type for Databricks. module DatabricksAuthenticationType # Authentication type not specified. DATABRICKS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # Personal access token authentication. PERSONAL_ACCESS_TOKEN = 1 # OAuth M2M authentication. OAUTH_M2M = 2 end end |
#connection_url ⇒ ::String
Returns Optional. Connection URL. e.g.: 'jdbc:databricks://adb-33934.4.azuredatabricks.net:443/default;transportMode=http;ssl=1;httpPath=sql/protocolv1/o/3393########44/0##3-7-hlrb'.
1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1780 class GoldengateDatabricksConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for authentication type for Databricks. module DatabricksAuthenticationType # Authentication type not specified. DATABRICKS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # Personal access token authentication. PERSONAL_ACCESS_TOKEN = 1 # OAuth M2M authentication. OAUTH_M2M = 2 end end |
#password ⇒ ::String
Returns Optional. Input only. The password used to connect to Databricks in plain text.
Note: The following fields are mutually exclusive: password, password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.
1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1780 class GoldengateDatabricksConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for authentication type for Databricks. module DatabricksAuthenticationType # Authentication type not specified. DATABRICKS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # Personal access token authentication. PERSONAL_ACCESS_TOKEN = 1 # OAuth M2M authentication. OAUTH_M2M = 2 end end |
#password_secret_version ⇒ ::String
Returns Optional. Input only. The resource name of a secret version in Secret Manager which contains the password used to connect to Databricks. Format: projects/{project}/secrets/{secret}/versions/{version}.
Note: The following fields are mutually exclusive: password_secret_version, password. If a field in that set is populated, all other fields in the set will automatically be cleared.
1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1780 class GoldengateDatabricksConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for authentication type for Databricks. module DatabricksAuthenticationType # Authentication type not specified. DATABRICKS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # Personal access token authentication. PERSONAL_ACCESS_TOKEN = 1 # OAuth M2M authentication. OAUTH_M2M = 2 end end |
#storage_credential ⇒ ::String
Returns Optional. External storage credential name to access files on object storage such as ADLS Gen2, S3 or Cloud Storage.
1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1780 class GoldengateDatabricksConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for authentication type for Databricks. module DatabricksAuthenticationType # Authentication type not specified. DATABRICKS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # Personal access token authentication. PERSONAL_ACCESS_TOKEN = 1 # OAuth M2M authentication. OAUTH_M2M = 2 end end |
#technology_type ⇒ ::String
Returns Optional. The technology type of DatabricksConnection.
1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1780 class GoldengateDatabricksConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for authentication type for Databricks. module DatabricksAuthenticationType # Authentication type not specified. DATABRICKS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # Personal access token authentication. PERSONAL_ACCESS_TOKEN = 1 # OAuth M2M authentication. OAUTH_M2M = 2 end end |