Class: Google::Cloud::OracleDatabase::V1::GoldengateDb2ConnectionProperties
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::GoldengateDb2ConnectionProperties
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb
Overview
The properties of GoldengateDb2Connection.
Defined Under Namespace
Modules: Db2SecurityProtocol
Instance Attribute Summary collapse
-
#additional_attributes ⇒ ::Array<::Google::Cloud::OracleDatabase::V1::NameValuePair>
Optional.
-
#database ⇒ ::String
Optional.
-
#host ⇒ ::String
Optional.
-
#password ⇒ ::String
Optional.
-
#password_secret_version ⇒ ::String
Optional.
-
#port ⇒ ::Integer
Optional.
-
#security_protocol ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateDb2ConnectionProperties::Db2SecurityProtocol
Optional.
-
#ssl_client_keystash_file ⇒ ::String
Optional.
-
#ssl_client_keystoredb_file ⇒ ::String
Optional.
-
#ssl_server_certificate_file ⇒ ::String
Optional.
-
#technology_type ⇒ ::String
Optional.
-
#username ⇒ ::String
Optional.
Instance Attribute Details
#additional_attributes ⇒ ::Array<::Google::Cloud::OracleDatabase::V1::NameValuePair>
Returns Optional. An array of name-value pair attribute entries. Used as additional parameters in connection string.
1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1627 class GoldengateDb2ConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for the DB2 database. module Db2SecurityProtocol # Security protocol not specified. DB2_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 end end |
#database ⇒ ::String
Returns Optional. The name of the database.
1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1627 class GoldengateDb2ConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for the DB2 database. module Db2SecurityProtocol # Security protocol not specified. DB2_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 end end |
#host ⇒ ::String
Returns Optional. The name or address of a host.
1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1627 class GoldengateDb2ConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for the DB2 database. module Db2SecurityProtocol # Security protocol not specified. DB2_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 end end |
#password ⇒ ::String
Returns Optional. Input only. The password Oracle Goldengate uses for Db2 connection in plain text.
Note: The following fields are mutually exclusive: password, password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.
1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1627 class GoldengateDb2ConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for the DB2 database. module Db2SecurityProtocol # Security protocol not specified. DB2_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 end end |
#password_secret_version ⇒ ::String
Returns Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses for Db2 connection. Format: projects/{project}/secrets/{secret}/versions/{version}.
Note: The following fields are mutually exclusive: password_secret_version, password. If a field in that set is populated, all other fields in the set will automatically be cleared.
1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1627 class GoldengateDb2ConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for the DB2 database. module Db2SecurityProtocol # Security protocol not specified. DB2_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 end end |
#port ⇒ ::Integer
Returns Optional. The port of an endpoint usually specified for a connection.
1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1627 class GoldengateDb2ConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for the DB2 database. module Db2SecurityProtocol # Security protocol not specified. DB2_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 end end |
#security_protocol ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateDb2ConnectionProperties::Db2SecurityProtocol
Returns Optional. Security protocol for the DB2 database.
1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1627 class GoldengateDb2ConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for the DB2 database. module Db2SecurityProtocol # Security protocol not specified. DB2_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 end end |
#ssl_client_keystash_file ⇒ ::String
Returns Optional. The keystash file which contains the encrypted password to the key database file. Not supported for IBM Db2 for i.
1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1627 class GoldengateDb2ConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for the DB2 database. module Db2SecurityProtocol # Security protocol not specified. DB2_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 end end |
#ssl_client_keystoredb_file ⇒ ::String
Returns Optional. The keystore file created at the client containing the server certificate / CA root certificate. Not supported for IBM Db2 for i.
1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1627 class GoldengateDb2ConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for the DB2 database. module Db2SecurityProtocol # Security protocol not specified. DB2_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 end end |
#ssl_server_certificate_file ⇒ ::String
Returns Optional. The file which contains the self-signed server certificate / Certificate Authority (CA) certificate.
1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1627 class GoldengateDb2ConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for the DB2 database. module Db2SecurityProtocol # Security protocol not specified. DB2_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 end end |
#technology_type ⇒ ::String
Returns Optional. The technology type of Db2Connection.
1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1627 class GoldengateDb2ConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for the DB2 database. module Db2SecurityProtocol # Security protocol not specified. DB2_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 end end |
#username ⇒ ::String
Returns Optional. The username Oracle Goldengate uses to connect to the DB2 database.
1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1627 class GoldengateDb2ConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for the DB2 database. module Db2SecurityProtocol # Security protocol not specified. DB2_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 end end |