Class: Google::Cloud::OracleDatabase::V1::GoldengateDeployment
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::GoldengateDeployment
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb
Overview
GoldengateDeployment Goldengate Deployment resource model.
Defined Under Namespace
Classes: LabelsEntry
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#display_name ⇒ ::String
Required.
-
#entitlement_id ⇒ ::String
readonly
Output only.
-
#gcp_oracle_zone ⇒ ::String
Optional.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#name ⇒ ::String
Identifier.
-
#oci_url ⇒ ::String
readonly
Output only.
-
#odb_network ⇒ ::String
Optional.
-
#odb_subnet ⇒ ::String
Required.
-
#properties ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateDeploymentProperties
Required.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The date and time that the GoldengateDeployment was created.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 63 class GoldengateDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#display_name ⇒ ::String
Returns Required. The display name for the GoldengateDeployment.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 63 class GoldengateDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#entitlement_id ⇒ ::String (readonly)
Returns Output only. The ID of the subscription entitlement associated with the GoldengateDeployment.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 63 class GoldengateDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#gcp_oracle_zone ⇒ ::String
Returns Optional. The GCP Oracle zone where Oracle GoldengateDeployment is hosted. Example: us-east4-b-r2. If not specified, the system will pick a zone based on availability.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 63 class GoldengateDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. The labels or tags associated with the GoldengateDeployment.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 63 class GoldengateDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Identifier. The name of the GoldengateDeployment resource in the following format: projects/{project}/locations/{region}/goldengateDeployments/{goldengate_deployment}.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 63 class GoldengateDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#oci_url ⇒ ::String (readonly)
Returns Output only. HTTPS link to OCI resources exposed to Customer via UI Interface.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 63 class GoldengateDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#odb_network ⇒ ::String
Returns Optional. The name of the OdbNetwork associated with the GoldengateDeployment.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 63 class GoldengateDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#odb_subnet ⇒ ::String
Returns Required. The name of the OdbSubnet associated with the GoldengateDeployment for IP allocation.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 63 class GoldengateDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#properties ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateDeploymentProperties
Returns Required. The properties of the GoldengateDeployment.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 63 class GoldengateDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |