Class: Google::Cloud::OracleDatabase::V1::GoldengateDeploymentEnvironment
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::GoldengateDeploymentEnvironment
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_environment.rb
Overview
Details of the Goldengate Deployment Environment resource.
Defined Under Namespace
Modules: DeploymentCategory, DeploymentEnvironmentType
Instance Attribute Summary collapse
-
#auto_scaling_enabled ⇒ ::Boolean
readonly
Output only.
-
#category ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateDeploymentEnvironment::DeploymentCategory
readonly
Output only.
-
#default_cpu_core_count ⇒ ::Integer
readonly
Output only.
-
#display_name ⇒ ::String
The display name of the Goldengate Deployment Environment resource.
-
#environment_type ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateDeploymentEnvironment::DeploymentEnvironmentType
readonly
Output only.
-
#max_cpu_core_count ⇒ ::Integer
readonly
Output only.
-
#memory_gb_per_cpu_core ⇒ ::Integer
readonly
Output only.
-
#min_cpu_core_count ⇒ ::Integer
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#network_bandwidth_gbps_per_cpu_core ⇒ ::Integer
readonly
Output only.
-
#storage_usage_limit_gb_per_cpu_core ⇒ ::Integer
readonly
Output only.
Instance Attribute Details
#auto_scaling_enabled ⇒ ::Boolean (readonly)
Returns Output only. Whether auto scaling is enabled by default for the Goldengate Deployment Environment resource.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_environment.rb', line 69 class GoldengateDeploymentEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Deployment category of the Goldengate Deployment resource. module DeploymentCategory # Default unspecified value. DEPLOYMENT_CATEGORY_UNSPECIFIED = 0 # Goldengate Deployment Environment category is DATA_REPLICATION_CATEGORY. DATA_REPLICATION_CATEGORY = 1 # Goldengate Deployment Environment category is DATA_TRANSFORMS_CATEGORY. DATA_TRANSFORMS_CATEGORY = 2 end # The environment type of the Goldengate Deployment Environment resource. module DeploymentEnvironmentType # Default unspecified value. DEPLOYMENT_ENVIRONMENT_TYPE_UNSPECIFIED = 0 # Goldengate Deployment Environment type is PRODUCTION. PRODUCTION = 1 # Goldengate Deployment Environment type is DEVELOPMENT_OR_TESTING. DEVELOPMENT_OR_TESTING = 2 end end |
#category ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateDeploymentEnvironment::DeploymentCategory (readonly)
Returns Output only. The category of the Goldengate Deployment Environment resource.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_environment.rb', line 69 class GoldengateDeploymentEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Deployment category of the Goldengate Deployment resource. module DeploymentCategory # Default unspecified value. DEPLOYMENT_CATEGORY_UNSPECIFIED = 0 # Goldengate Deployment Environment category is DATA_REPLICATION_CATEGORY. DATA_REPLICATION_CATEGORY = 1 # Goldengate Deployment Environment category is DATA_TRANSFORMS_CATEGORY. DATA_TRANSFORMS_CATEGORY = 2 end # The environment type of the Goldengate Deployment Environment resource. module DeploymentEnvironmentType # Default unspecified value. DEPLOYMENT_ENVIRONMENT_TYPE_UNSPECIFIED = 0 # Goldengate Deployment Environment type is PRODUCTION. PRODUCTION = 1 # Goldengate Deployment Environment type is DEVELOPMENT_OR_TESTING. DEVELOPMENT_OR_TESTING = 2 end end |
#default_cpu_core_count ⇒ ::Integer (readonly)
Returns Output only. The default CPU core count of the Goldengate Deployment Environment resource.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_environment.rb', line 69 class GoldengateDeploymentEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Deployment category of the Goldengate Deployment resource. module DeploymentCategory # Default unspecified value. DEPLOYMENT_CATEGORY_UNSPECIFIED = 0 # Goldengate Deployment Environment category is DATA_REPLICATION_CATEGORY. DATA_REPLICATION_CATEGORY = 1 # Goldengate Deployment Environment category is DATA_TRANSFORMS_CATEGORY. DATA_TRANSFORMS_CATEGORY = 2 end # The environment type of the Goldengate Deployment Environment resource. module DeploymentEnvironmentType # Default unspecified value. DEPLOYMENT_ENVIRONMENT_TYPE_UNSPECIFIED = 0 # Goldengate Deployment Environment type is PRODUCTION. PRODUCTION = 1 # Goldengate Deployment Environment type is DEVELOPMENT_OR_TESTING. DEVELOPMENT_OR_TESTING = 2 end end |
#display_name ⇒ ::String
Returns The display name of the Goldengate Deployment Environment resource.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_environment.rb', line 69 class GoldengateDeploymentEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Deployment category of the Goldengate Deployment resource. module DeploymentCategory # Default unspecified value. DEPLOYMENT_CATEGORY_UNSPECIFIED = 0 # Goldengate Deployment Environment category is DATA_REPLICATION_CATEGORY. DATA_REPLICATION_CATEGORY = 1 # Goldengate Deployment Environment category is DATA_TRANSFORMS_CATEGORY. DATA_TRANSFORMS_CATEGORY = 2 end # The environment type of the Goldengate Deployment Environment resource. module DeploymentEnvironmentType # Default unspecified value. DEPLOYMENT_ENVIRONMENT_TYPE_UNSPECIFIED = 0 # Goldengate Deployment Environment type is PRODUCTION. PRODUCTION = 1 # Goldengate Deployment Environment type is DEVELOPMENT_OR_TESTING. DEVELOPMENT_OR_TESTING = 2 end end |
#environment_type ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateDeploymentEnvironment::DeploymentEnvironmentType (readonly)
Returns Output only. The environment type of the Goldengate Deployment Environment resource.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_environment.rb', line 69 class GoldengateDeploymentEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Deployment category of the Goldengate Deployment resource. module DeploymentCategory # Default unspecified value. DEPLOYMENT_CATEGORY_UNSPECIFIED = 0 # Goldengate Deployment Environment category is DATA_REPLICATION_CATEGORY. DATA_REPLICATION_CATEGORY = 1 # Goldengate Deployment Environment category is DATA_TRANSFORMS_CATEGORY. DATA_TRANSFORMS_CATEGORY = 2 end # The environment type of the Goldengate Deployment Environment resource. module DeploymentEnvironmentType # Default unspecified value. DEPLOYMENT_ENVIRONMENT_TYPE_UNSPECIFIED = 0 # Goldengate Deployment Environment type is PRODUCTION. PRODUCTION = 1 # Goldengate Deployment Environment type is DEVELOPMENT_OR_TESTING. DEVELOPMENT_OR_TESTING = 2 end end |
#max_cpu_core_count ⇒ ::Integer (readonly)
Returns Output only. The max CPU core count of the Goldengate Deployment Environment resource.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_environment.rb', line 69 class GoldengateDeploymentEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Deployment category of the Goldengate Deployment resource. module DeploymentCategory # Default unspecified value. DEPLOYMENT_CATEGORY_UNSPECIFIED = 0 # Goldengate Deployment Environment category is DATA_REPLICATION_CATEGORY. DATA_REPLICATION_CATEGORY = 1 # Goldengate Deployment Environment category is DATA_TRANSFORMS_CATEGORY. DATA_TRANSFORMS_CATEGORY = 2 end # The environment type of the Goldengate Deployment Environment resource. module DeploymentEnvironmentType # Default unspecified value. DEPLOYMENT_ENVIRONMENT_TYPE_UNSPECIFIED = 0 # Goldengate Deployment Environment type is PRODUCTION. PRODUCTION = 1 # Goldengate Deployment Environment type is DEVELOPMENT_OR_TESTING. DEVELOPMENT_OR_TESTING = 2 end end |
#memory_gb_per_cpu_core ⇒ ::Integer (readonly)
Returns Output only. The memory per CPU core in GBs of the Goldengate Deployment Environment resource.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_environment.rb', line 69 class GoldengateDeploymentEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Deployment category of the Goldengate Deployment resource. module DeploymentCategory # Default unspecified value. DEPLOYMENT_CATEGORY_UNSPECIFIED = 0 # Goldengate Deployment Environment category is DATA_REPLICATION_CATEGORY. DATA_REPLICATION_CATEGORY = 1 # Goldengate Deployment Environment category is DATA_TRANSFORMS_CATEGORY. DATA_TRANSFORMS_CATEGORY = 2 end # The environment type of the Goldengate Deployment Environment resource. module DeploymentEnvironmentType # Default unspecified value. DEPLOYMENT_ENVIRONMENT_TYPE_UNSPECIFIED = 0 # Goldengate Deployment Environment type is PRODUCTION. PRODUCTION = 1 # Goldengate Deployment Environment type is DEVELOPMENT_OR_TESTING. DEVELOPMENT_OR_TESTING = 2 end end |
#min_cpu_core_count ⇒ ::Integer (readonly)
Returns Output only. The min CPU core count of the Goldengate Deployment Environment resource.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_environment.rb', line 69 class GoldengateDeploymentEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Deployment category of the Goldengate Deployment resource. module DeploymentCategory # Default unspecified value. DEPLOYMENT_CATEGORY_UNSPECIFIED = 0 # Goldengate Deployment Environment category is DATA_REPLICATION_CATEGORY. DATA_REPLICATION_CATEGORY = 1 # Goldengate Deployment Environment category is DATA_TRANSFORMS_CATEGORY. DATA_TRANSFORMS_CATEGORY = 2 end # The environment type of the Goldengate Deployment Environment resource. module DeploymentEnvironmentType # Default unspecified value. DEPLOYMENT_ENVIRONMENT_TYPE_UNSPECIFIED = 0 # Goldengate Deployment Environment type is PRODUCTION. PRODUCTION = 1 # Goldengate Deployment Environment type is DEVELOPMENT_OR_TESTING. DEVELOPMENT_OR_TESTING = 2 end end |
#name ⇒ ::String
Returns Identifier. The name of the Goldengate Deployment Environment resource with the format: projects/{project}/locations/{location}/goldengateDeploymentEnvironments/{goldengate_deployment_environment}.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_environment.rb', line 69 class GoldengateDeploymentEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Deployment category of the Goldengate Deployment resource. module DeploymentCategory # Default unspecified value. DEPLOYMENT_CATEGORY_UNSPECIFIED = 0 # Goldengate Deployment Environment category is DATA_REPLICATION_CATEGORY. DATA_REPLICATION_CATEGORY = 1 # Goldengate Deployment Environment category is DATA_TRANSFORMS_CATEGORY. DATA_TRANSFORMS_CATEGORY = 2 end # The environment type of the Goldengate Deployment Environment resource. module DeploymentEnvironmentType # Default unspecified value. DEPLOYMENT_ENVIRONMENT_TYPE_UNSPECIFIED = 0 # Goldengate Deployment Environment type is PRODUCTION. PRODUCTION = 1 # Goldengate Deployment Environment type is DEVELOPMENT_OR_TESTING. DEVELOPMENT_OR_TESTING = 2 end end |
#network_bandwidth_gbps_per_cpu_core ⇒ ::Integer (readonly)
Returns Output only. The network bandwidth per CPU core in Gbps of the Goldengate Deployment Environment resource.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_environment.rb', line 69 class GoldengateDeploymentEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Deployment category of the Goldengate Deployment resource. module DeploymentCategory # Default unspecified value. DEPLOYMENT_CATEGORY_UNSPECIFIED = 0 # Goldengate Deployment Environment category is DATA_REPLICATION_CATEGORY. DATA_REPLICATION_CATEGORY = 1 # Goldengate Deployment Environment category is DATA_TRANSFORMS_CATEGORY. DATA_TRANSFORMS_CATEGORY = 2 end # The environment type of the Goldengate Deployment Environment resource. module DeploymentEnvironmentType # Default unspecified value. DEPLOYMENT_ENVIRONMENT_TYPE_UNSPECIFIED = 0 # Goldengate Deployment Environment type is PRODUCTION. PRODUCTION = 1 # Goldengate Deployment Environment type is DEVELOPMENT_OR_TESTING. DEVELOPMENT_OR_TESTING = 2 end end |
#storage_usage_limit_gb_per_cpu_core ⇒ ::Integer (readonly)
Returns Output only. The storage usage limit per CPU core in GBs of the Goldengate Deployment Environment resource.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_environment.rb', line 69 class GoldengateDeploymentEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Deployment category of the Goldengate Deployment resource. module DeploymentCategory # Default unspecified value. DEPLOYMENT_CATEGORY_UNSPECIFIED = 0 # Goldengate Deployment Environment category is DATA_REPLICATION_CATEGORY. DATA_REPLICATION_CATEGORY = 1 # Goldengate Deployment Environment category is DATA_TRANSFORMS_CATEGORY. DATA_TRANSFORMS_CATEGORY = 2 end # The environment type of the Goldengate Deployment Environment resource. module DeploymentEnvironmentType # Default unspecified value. DEPLOYMENT_ENVIRONMENT_TYPE_UNSPECIFIED = 0 # Goldengate Deployment Environment type is PRODUCTION. PRODUCTION = 1 # Goldengate Deployment Environment type is DEVELOPMENT_OR_TESTING. DEVELOPMENT_OR_TESTING = 2 end end |