Class: Google::Cloud::OracleDatabase::V1::GoldengateDeploymentVersion
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::GoldengateDeploymentVersion
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_version.rb
Overview
Details of the Goldengate Deployment Version resource.
Instance Attribute Summary collapse
-
#name ⇒ ::String
Identifier.
-
#ocid ⇒ ::String
readonly
Output only.
-
#properties ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateDeploymentVersionProperties
readonly
Output only.
Instance Attribute Details
#name ⇒ ::String
Returns Identifier. The name of the Goldengate Deployment Version resource with the format: projects/{project}/locations/{location}/goldengateDeploymentVersions/{goldengate_deployment_version}.
38 39 40 41 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_version.rb', line 38 class GoldengateDeploymentVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ocid ⇒ ::String (readonly)
Returns Output only. The deployment version ocid of the Goldengate Deployment Version resource.
38 39 40 41 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_version.rb', line 38 class GoldengateDeploymentVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#properties ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateDeploymentVersionProperties (readonly)
Returns Output only. The technology type of the Goldengate Deployment Version resource.
38 39 40 41 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment_version.rb', line 38 class GoldengateDeploymentVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |