Class: Google::Cloud::OracleDatabase::V1::GoldengateGoogleCloudStorageConnectionProperties
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::GoldengateGoogleCloudStorageConnectionProperties
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb
Overview
The properties of GoldengateGoogleCloudStorageConnectionProperties.
Instance Attribute Summary collapse
-
#service_account_key_file ⇒ ::String
Optional.
-
#technology_type ⇒ ::String
Optional.
Instance Attribute Details
#service_account_key_file ⇒ ::String
Returns Optional. The base64 encoded content of the service account key file containing the credentials required to use Google Cloud Storage.
517 518 519 520 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 517 class GoldengateGoogleCloudStorageConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#technology_type ⇒ ::String
Returns Optional. The technology type.
517 518 519 520 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 517 class GoldengateGoogleCloudStorageConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |