Class: Google::Cloud::OracleDatabase::V1::GoldengateJavaMessageServiceConnectionProperties
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::GoldengateJavaMessageServiceConnectionProperties
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb
Overview
The properties of GoldengateJavaMessageServiceConnection.
Defined Under Namespace
Modules: JmsAuthenticationType, JmsSecurityProtocol
Instance Attribute Summary collapse
-
#authentication_type ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateJavaMessageServiceConnectionProperties::JmsAuthenticationType
Optional.
-
#connection_factory ⇒ ::String
Optional.
-
#connection_url ⇒ ::String
Optional.
-
#jndi_connection_factory ⇒ ::String
Optional.
-
#jndi_initial_context_factory ⇒ ::String
Optional.
-
#jndi_provider_url ⇒ ::String
Optional.
-
#jndi_security_credentials_secret ⇒ ::String
Optional.
-
#jndi_security_principal ⇒ ::String
Optional.
-
#key_store_file ⇒ ::String
Optional.
-
#key_store_password ⇒ ::String
Optional.
-
#key_store_password_secret_version ⇒ ::String
Optional.
-
#password ⇒ ::String
Optional.
-
#password_secret_version ⇒ ::String
Optional.
-
#security_protocol ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateJavaMessageServiceConnectionProperties::JmsSecurityProtocol
Optional.
-
#ssl_key_password ⇒ ::String
Optional.
-
#ssl_key_password_secret_version ⇒ ::String
Optional.
-
#technology_type ⇒ ::String
Optional.
-
#trust_store_file ⇒ ::String
Optional.
-
#trust_store_password ⇒ ::String
Optional.
-
#trust_store_password_secret_version ⇒ ::String
Optional.
-
#use_jndi ⇒ ::Boolean
Optional.
-
#username ⇒ ::String
Optional.
Instance Attribute Details
#authentication_type ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateJavaMessageServiceConnectionProperties::JmsAuthenticationType
Returns Optional. Authentication type for Java Message Service.
1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1263 class GoldengateJavaMessageServiceConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Java Message Service. module JmsSecurityProtocol # Security protocol not specified. JMS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Java Message Service. module JmsAuthenticationType # Authentication type not specified. JMS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#connection_factory ⇒ ::String
Returns Optional. The Java class implementing javax.jms.ConnectionFactory interface supplied by the JMS provider.
1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1263 class GoldengateJavaMessageServiceConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Java Message Service. module JmsSecurityProtocol # Security protocol not specified. JMS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Java Message Service. module JmsAuthenticationType # Authentication type not specified. JMS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#connection_url ⇒ ::String
Returns Optional. Connection URL of the Java Message Service, specifying the protocol, host, and port. e.g.: 'mq://myjms.host.domain:7676'.
1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1263 class GoldengateJavaMessageServiceConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Java Message Service. module JmsSecurityProtocol # Security protocol not specified. JMS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Java Message Service. module JmsAuthenticationType # Authentication type not specified. JMS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#jndi_connection_factory ⇒ ::String
Returns Optional. The Connection Factory can be looked up using this name. e.g.: 'ConnectionFactory'.
1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1263 class GoldengateJavaMessageServiceConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Java Message Service. module JmsSecurityProtocol # Security protocol not specified. JMS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Java Message Service. module JmsAuthenticationType # Authentication type not specified. JMS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#jndi_initial_context_factory ⇒ ::String
Returns Optional. The implementation of javax.naming.spi.InitialContextFactory interface used to obtain initial naming context.
1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1263 class GoldengateJavaMessageServiceConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Java Message Service. module JmsSecurityProtocol # Security protocol not specified. JMS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Java Message Service. module JmsAuthenticationType # Authentication type not specified. JMS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#jndi_provider_url ⇒ ::String
Returns Optional. The URL that Java Message Service will use to contact the JNDI provider. e.g.: 'tcp://myjms.host.domain:61616?jms.prefetchPolicy.all=1000'.
1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1263 class GoldengateJavaMessageServiceConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Java Message Service. module JmsSecurityProtocol # Security protocol not specified. JMS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Java Message Service. module JmsAuthenticationType # Authentication type not specified. JMS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#jndi_security_credentials_secret ⇒ ::String
Returns Optional. The password associated to the principal.
1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1263 class GoldengateJavaMessageServiceConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Java Message Service. module JmsSecurityProtocol # Security protocol not specified. JMS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Java Message Service. module JmsAuthenticationType # Authentication type not specified. JMS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#jndi_security_principal ⇒ ::String
Returns Optional. Specifies the identity of the principal (user) to be authenticated.
1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1263 class GoldengateJavaMessageServiceConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Java Message Service. module JmsSecurityProtocol # Security protocol not specified. JMS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Java Message Service. module JmsAuthenticationType # Authentication type not specified. JMS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#key_store_file ⇒ ::String
Returns Optional. The base64 encoded content of the KeyStore file.
1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1263 class GoldengateJavaMessageServiceConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Java Message Service. module JmsSecurityProtocol # Security protocol not specified. JMS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Java Message Service. module JmsAuthenticationType # Authentication type not specified. JMS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#key_store_password ⇒ ::String
Returns Optional. Input only. The KeyStore password in plain text.
Note: The following fields are mutually exclusive: key_store_password, key_store_password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.
1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1263 class GoldengateJavaMessageServiceConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Java Message Service. module JmsSecurityProtocol # Security protocol not specified. JMS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Java Message Service. module JmsAuthenticationType # Authentication type not specified. JMS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#key_store_password_secret_version ⇒ ::String
Returns Optional. Input only. The resource name of a secret version in Secret Manager which contains the KeyStore password. Format: projects/{project}/secrets/{secret}/versions/{version}.
Note: The following fields are mutually exclusive: key_store_password_secret_version, key_store_password. If a field in that set is populated, all other fields in the set will automatically be cleared.
1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1263 class GoldengateJavaMessageServiceConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Java Message Service. module JmsSecurityProtocol # Security protocol not specified. JMS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Java Message Service. module JmsAuthenticationType # Authentication type not specified. JMS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#password ⇒ ::String
Returns Optional. Input only. The password Oracle Goldengate uses to connect the Java Message Service in plain text.
Note: The following fields are mutually exclusive: password, password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.
1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1263 class GoldengateJavaMessageServiceConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Java Message Service. module JmsSecurityProtocol # Security protocol not specified. JMS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Java Message Service. module JmsAuthenticationType # Authentication type not specified. JMS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#password_secret_version ⇒ ::String
Returns Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses to connect the associated Java Message Service. Format: projects/{project}/secrets/{secret}/versions/{version}.
Note: The following fields are mutually exclusive: password_secret_version, password. If a field in that set is populated, all other fields in the set will automatically be cleared.
1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1263 class GoldengateJavaMessageServiceConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Java Message Service. module JmsSecurityProtocol # Security protocol not specified. JMS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Java Message Service. module JmsAuthenticationType # Authentication type not specified. JMS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#security_protocol ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateJavaMessageServiceConnectionProperties::JmsSecurityProtocol
Returns Optional. Security protocol for Java Message Service.
1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1263 class GoldengateJavaMessageServiceConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Java Message Service. module JmsSecurityProtocol # Security protocol not specified. JMS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Java Message Service. module JmsAuthenticationType # Authentication type not specified. JMS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#ssl_key_password ⇒ ::String
Returns Optional. Input only. The password for the cert inside of the KeyStore in plain text.
Note: The following fields are mutually exclusive: ssl_key_password, ssl_key_password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.
1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1263 class GoldengateJavaMessageServiceConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Java Message Service. module JmsSecurityProtocol # Security protocol not specified. JMS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Java Message Service. module JmsAuthenticationType # Authentication type not specified. JMS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#ssl_key_password_secret_version ⇒ ::String
Returns Optional. Input only. The resource name of a secret version in Secret Manager which contains the password for the cert inside of the KeyStore. Format: projects/{project}/secrets/{secret}/versions/{version}.
Note: The following fields are mutually exclusive: ssl_key_password_secret_version, ssl_key_password. If a field in that set is populated, all other fields in the set will automatically be cleared.
1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1263 class GoldengateJavaMessageServiceConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Java Message Service. module JmsSecurityProtocol # Security protocol not specified. JMS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Java Message Service. module JmsAuthenticationType # Authentication type not specified. JMS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#technology_type ⇒ ::String
Returns Optional. The technology type of JavaMessageServiceConnection.
1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1263 class GoldengateJavaMessageServiceConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Java Message Service. module JmsSecurityProtocol # Security protocol not specified. JMS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Java Message Service. module JmsAuthenticationType # Authentication type not specified. JMS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#trust_store_file ⇒ ::String
Returns Optional. The base64 encoded content of the TrustStore file.
1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1263 class GoldengateJavaMessageServiceConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Java Message Service. module JmsSecurityProtocol # Security protocol not specified. JMS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Java Message Service. module JmsAuthenticationType # Authentication type not specified. JMS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#trust_store_password ⇒ ::String
Returns Optional. Input only. The TrustStore password in plain text.
Note: The following fields are mutually exclusive: trust_store_password, trust_store_password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.
1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1263 class GoldengateJavaMessageServiceConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Java Message Service. module JmsSecurityProtocol # Security protocol not specified. JMS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Java Message Service. module JmsAuthenticationType # Authentication type not specified. JMS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#trust_store_password_secret_version ⇒ ::String
Returns Optional. Input only. The resource name of a secret version in Secret Manager which contains the TrustStore password. Format: projects/{project}/secrets/{secret}/versions/{version}.
Note: The following fields are mutually exclusive: trust_store_password_secret_version, trust_store_password. If a field in that set is populated, all other fields in the set will automatically be cleared.
1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1263 class GoldengateJavaMessageServiceConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Java Message Service. module JmsSecurityProtocol # Security protocol not specified. JMS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Java Message Service. module JmsAuthenticationType # Authentication type not specified. JMS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#use_jndi ⇒ ::Boolean
Returns Optional. If set to true, Java Naming and Directory Interface (JNDI) properties should be provided.
1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1263 class GoldengateJavaMessageServiceConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Java Message Service. module JmsSecurityProtocol # Security protocol not specified. JMS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Java Message Service. module JmsAuthenticationType # Authentication type not specified. JMS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#username ⇒ ::String
Returns Optional. The username Oracle Goldengate uses to connect to the Java Message Service.
1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1263 class GoldengateJavaMessageServiceConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Java Message Service. module JmsSecurityProtocol # Security protocol not specified. JMS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Java Message Service. module JmsAuthenticationType # Authentication type not specified. JMS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |