Class: Google::Cloud::OracleDatabase::V1::GoldengateOggDeployment
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::GoldengateOggDeployment
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb
Overview
The Ogg data of the GoldengateDeployment.
Defined Under Namespace
Modules: CredentialStore
Instance Attribute Summary collapse
-
#admin_password ⇒ ::String
Optional.
-
#admin_password_secret_version ⇒ ::String
Optional.
-
#admin_username ⇒ ::String
Required.
-
#certificate ⇒ ::String
readonly
Output only.
-
#credential_store ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateOggDeployment::CredentialStore
readonly
Output only.
-
#deployment ⇒ ::String
Required.
-
#group_roles_mapping ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateGroupToRolesMapping
readonly
Output only.
-
#identity_domain_id ⇒ ::String
readonly
Output only.
-
#ogg_version ⇒ ::String
Optional.
-
#password_secret_id ⇒ ::String
readonly
Output only.
Instance Attribute Details
#admin_password ⇒ ::String
Returns Optional. The Goldengate deployment console password in plain text.
Note: The following fields are mutually exclusive: admin_password, admin_password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.
373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 373 class GoldengateOggDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The credential store of the GoldengateDeployment. module CredentialStore # The credential store is unspecified. CREDENTIAL_STORE_UNSPECIFIED = 0 # The credential store is Goldengate. GOLDENGATE = 1 # The credential store is IAM. IAM = 2 end end |
#admin_password_secret_version ⇒ ::String
Returns Optional. Input only. The Goldengate deployment console password secret version.
Note: The following fields are mutually exclusive: admin_password_secret_version, admin_password. If a field in that set is populated, all other fields in the set will automatically be cleared.
373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 373 class GoldengateOggDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The credential store of the GoldengateDeployment. module CredentialStore # The credential store is unspecified. CREDENTIAL_STORE_UNSPECIFIED = 0 # The credential store is Goldengate. GOLDENGATE = 1 # The credential store is IAM. IAM = 2 end end |
#admin_username ⇒ ::String
Returns Required. The Goldengate deployment console username.
373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 373 class GoldengateOggDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The credential store of the GoldengateDeployment. module CredentialStore # The credential store is unspecified. CREDENTIAL_STORE_UNSPECIFIED = 0 # The credential store is Goldengate. GOLDENGATE = 1 # The credential store is IAM. IAM = 2 end end |
#certificate ⇒ ::String (readonly)
Returns Output only. The certificate of the GoldengateDeployment.
373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 373 class GoldengateOggDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The credential store of the GoldengateDeployment. module CredentialStore # The credential store is unspecified. CREDENTIAL_STORE_UNSPECIFIED = 0 # The credential store is Goldengate. GOLDENGATE = 1 # The credential store is IAM. IAM = 2 end end |
#credential_store ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateOggDeployment::CredentialStore (readonly)
Returns Output only. The credential store of the GoldengateDeployment.
373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 373 class GoldengateOggDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The credential store of the GoldengateDeployment. module CredentialStore # The credential store is unspecified. CREDENTIAL_STORE_UNSPECIFIED = 0 # The credential store is Goldengate. GOLDENGATE = 1 # The credential store is IAM. IAM = 2 end end |
#deployment ⇒ ::String
Returns Required. The name given to the Goldengate service deployment. The name must be 1 to 32 characters long, must contain only alphanumeric characters and must start with a letter.
373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 373 class GoldengateOggDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The credential store of the GoldengateDeployment. module CredentialStore # The credential store is unspecified. CREDENTIAL_STORE_UNSPECIFIED = 0 # The credential store is Goldengate. GOLDENGATE = 1 # The credential store is IAM. IAM = 2 end end |
#group_roles_mapping ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateGroupToRolesMapping (readonly)
Returns Output only. The group to roles mapping of the GoldengateDeployment.
373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 373 class GoldengateOggDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The credential store of the GoldengateDeployment. module CredentialStore # The credential store is unspecified. CREDENTIAL_STORE_UNSPECIFIED = 0 # The credential store is Goldengate. GOLDENGATE = 1 # The credential store is IAM. IAM = 2 end end |
#identity_domain_id ⇒ ::String (readonly)
Returns Output only. The identity domain id of the GoldengateDeployment.
373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 373 class GoldengateOggDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The credential store of the GoldengateDeployment. module CredentialStore # The credential store is unspecified. CREDENTIAL_STORE_UNSPECIFIED = 0 # The credential store is Goldengate. GOLDENGATE = 1 # The credential store is IAM. IAM = 2 end end |
#ogg_version ⇒ ::String
Returns Optional. Version of OGG.
373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 373 class GoldengateOggDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The credential store of the GoldengateDeployment. module CredentialStore # The credential store is unspecified. CREDENTIAL_STORE_UNSPECIFIED = 0 # The credential store is Goldengate. GOLDENGATE = 1 # The credential store is IAM. IAM = 2 end end |
#password_secret_id ⇒ ::String (readonly)
Returns Output only. The password secret id of the GoldengateDeployment.
373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 373 class GoldengateOggDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The credential store of the GoldengateDeployment. module CredentialStore # The credential store is unspecified. CREDENTIAL_STORE_UNSPECIFIED = 0 # The credential store is Goldengate. GOLDENGATE = 1 # The credential store is IAM. IAM = 2 end end |