Class: Google::Cloud::OracleDatabase::V1::GoldengatePostgresqlConnectionProperties
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::GoldengatePostgresqlConnectionProperties
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb
Overview
The properties of GoldengatePostgresqlConnection.
Defined Under Namespace
Modules: PostgresqlSecurityProtocol, PostgresqlSslMode
Instance Attribute Summary collapse
-
#additional_attributes ⇒ ::Array<::Google::Cloud::OracleDatabase::V1::NameValuePair>
Optional.
-
#database ⇒ ::String
Optional.
-
#db_system_id ⇒ ::String
Optional.
-
#host ⇒ ::String
Optional.
-
#password ⇒ ::String
Optional.
-
#password_secret_version ⇒ ::String
Optional.
-
#port ⇒ ::Integer
Optional.
-
#security_protocol ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengatePostgresqlConnectionProperties::PostgresqlSecurityProtocol
Optional.
-
#ssl_ca_file ⇒ ::String
Optional.
-
#ssl_cert_file ⇒ ::String
Optional.
-
#ssl_crl_file ⇒ ::String
Optional.
-
#ssl_key_file ⇒ ::String
Optional.
-
#ssl_mode ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengatePostgresqlConnectionProperties::PostgresqlSslMode
Optional.
-
#technology_type ⇒ ::String
Optional.
-
#username ⇒ ::String
Optional.
Instance Attribute Details
#additional_attributes ⇒ ::Array<::Google::Cloud::OracleDatabase::V1::NameValuePair>
Returns Optional. An array of name-value pair attribute entries. Used as additional parameters in connection string.
1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1026 class GoldengatePostgresqlConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for PostgreSQL. module PostgresqlSecurityProtocol # Security protocol not specified. POSTGRESQL_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for SSL modes for PostgreSQL. module PostgresqlSslMode # SSL mode not specified. POSTGRESQL_SSL_MODE_UNSPECIFIED = 0 # Prefer SSL. PREFER = 1 # Require SSL. REQUIRE = 2 # Verify Certificate Authority. VERIFY_CA = 3 # Verify Full. VERIFY_FULL = 4 end end |
#database ⇒ ::String
Returns Optional. The name of the database.
1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1026 class GoldengatePostgresqlConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for PostgreSQL. module PostgresqlSecurityProtocol # Security protocol not specified. POSTGRESQL_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for SSL modes for PostgreSQL. module PostgresqlSslMode # SSL mode not specified. POSTGRESQL_SSL_MODE_UNSPECIFIED = 0 # Prefer SSL. PREFER = 1 # Require SSL. REQUIRE = 2 # Verify Certificate Authority. VERIFY_CA = 3 # Verify Full. VERIFY_FULL = 4 end end |
#db_system_id ⇒ ::String
Returns Optional. The OCID of the database system being referenced.
1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1026 class GoldengatePostgresqlConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for PostgreSQL. module PostgresqlSecurityProtocol # Security protocol not specified. POSTGRESQL_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for SSL modes for PostgreSQL. module PostgresqlSslMode # SSL mode not specified. POSTGRESQL_SSL_MODE_UNSPECIFIED = 0 # Prefer SSL. PREFER = 1 # Require SSL. REQUIRE = 2 # Verify Certificate Authority. VERIFY_CA = 3 # Verify Full. VERIFY_FULL = 4 end end |
#host ⇒ ::String
Returns Optional. The name or address of a host.
1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1026 class GoldengatePostgresqlConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for PostgreSQL. module PostgresqlSecurityProtocol # Security protocol not specified. POSTGRESQL_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for SSL modes for PostgreSQL. module PostgresqlSslMode # SSL mode not specified. POSTGRESQL_SSL_MODE_UNSPECIFIED = 0 # Prefer SSL. PREFER = 1 # Require SSL. REQUIRE = 2 # Verify Certificate Authority. VERIFY_CA = 3 # Verify Full. VERIFY_FULL = 4 end end |
#password ⇒ ::String
Returns Optional. Input only. The password Oracle Goldengate uses for PostgreSQL connection in plain text.
Note: The following fields are mutually exclusive: password, password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.
1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1026 class GoldengatePostgresqlConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for PostgreSQL. module PostgresqlSecurityProtocol # Security protocol not specified. POSTGRESQL_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for SSL modes for PostgreSQL. module PostgresqlSslMode # SSL mode not specified. POSTGRESQL_SSL_MODE_UNSPECIFIED = 0 # Prefer SSL. PREFER = 1 # Require SSL. REQUIRE = 2 # Verify Certificate Authority. VERIFY_CA = 3 # Verify Full. VERIFY_FULL = 4 end end |
#password_secret_version ⇒ ::String
Returns Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses for PostgreSQL connection. Format: projects/{project}/secrets/{secret}/versions/{version}.
Note: The following fields are mutually exclusive: password_secret_version, password. If a field in that set is populated, all other fields in the set will automatically be cleared.
1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1026 class GoldengatePostgresqlConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for PostgreSQL. module PostgresqlSecurityProtocol # Security protocol not specified. POSTGRESQL_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for SSL modes for PostgreSQL. module PostgresqlSslMode # SSL mode not specified. POSTGRESQL_SSL_MODE_UNSPECIFIED = 0 # Prefer SSL. PREFER = 1 # Require SSL. REQUIRE = 2 # Verify Certificate Authority. VERIFY_CA = 3 # Verify Full. VERIFY_FULL = 4 end end |
#port ⇒ ::Integer
Returns Optional. The port of an endpoint usually specified for a connection.
1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1026 class GoldengatePostgresqlConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for PostgreSQL. module PostgresqlSecurityProtocol # Security protocol not specified. POSTGRESQL_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for SSL modes for PostgreSQL. module PostgresqlSslMode # SSL mode not specified. POSTGRESQL_SSL_MODE_UNSPECIFIED = 0 # Prefer SSL. PREFER = 1 # Require SSL. REQUIRE = 2 # Verify Certificate Authority. VERIFY_CA = 3 # Verify Full. VERIFY_FULL = 4 end end |
#security_protocol ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengatePostgresqlConnectionProperties::PostgresqlSecurityProtocol
Returns Optional. Security protocol for PostgreSQL.
1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1026 class GoldengatePostgresqlConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for PostgreSQL. module PostgresqlSecurityProtocol # Security protocol not specified. POSTGRESQL_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for SSL modes for PostgreSQL. module PostgresqlSslMode # SSL mode not specified. POSTGRESQL_SSL_MODE_UNSPECIFIED = 0 # Prefer SSL. PREFER = 1 # Require SSL. REQUIRE = 2 # Verify Certificate Authority. VERIFY_CA = 3 # Verify Full. VERIFY_FULL = 4 end end |
#ssl_ca_file ⇒ ::String
Returns Optional. The base64 encoded certificate of the trusted certificate authorities (Trusted CA) for PostgreSQL.
1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1026 class GoldengatePostgresqlConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for PostgreSQL. module PostgresqlSecurityProtocol # Security protocol not specified. POSTGRESQL_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for SSL modes for PostgreSQL. module PostgresqlSslMode # SSL mode not specified. POSTGRESQL_SSL_MODE_UNSPECIFIED = 0 # Prefer SSL. PREFER = 1 # Require SSL. REQUIRE = 2 # Verify Certificate Authority. VERIFY_CA = 3 # Verify Full. VERIFY_FULL = 4 end end |
#ssl_cert_file ⇒ ::String
Returns Optional. The base64 encoded certificate of the PostgreSQL server.
1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1026 class GoldengatePostgresqlConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for PostgreSQL. module PostgresqlSecurityProtocol # Security protocol not specified. POSTGRESQL_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for SSL modes for PostgreSQL. module PostgresqlSslMode # SSL mode not specified. POSTGRESQL_SSL_MODE_UNSPECIFIED = 0 # Prefer SSL. PREFER = 1 # Require SSL. REQUIRE = 2 # Verify Certificate Authority. VERIFY_CA = 3 # Verify Full. VERIFY_FULL = 4 end end |
#ssl_crl_file ⇒ ::String
Returns Optional. The base64 encoded list of certificates revoked by the trusted certificate authorities (Trusted CA).
1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1026 class GoldengatePostgresqlConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for PostgreSQL. module PostgresqlSecurityProtocol # Security protocol not specified. POSTGRESQL_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for SSL modes for PostgreSQL. module PostgresqlSslMode # SSL mode not specified. POSTGRESQL_SSL_MODE_UNSPECIFIED = 0 # Prefer SSL. PREFER = 1 # Require SSL. REQUIRE = 2 # Verify Certificate Authority. VERIFY_CA = 3 # Verify Full. VERIFY_FULL = 4 end end |
#ssl_key_file ⇒ ::String
Returns Optional. The base64 encoded private key of the PostgreSQL server.
1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1026 class GoldengatePostgresqlConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for PostgreSQL. module PostgresqlSecurityProtocol # Security protocol not specified. POSTGRESQL_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for SSL modes for PostgreSQL. module PostgresqlSslMode # SSL mode not specified. POSTGRESQL_SSL_MODE_UNSPECIFIED = 0 # Prefer SSL. PREFER = 1 # Require SSL. REQUIRE = 2 # Verify Certificate Authority. VERIFY_CA = 3 # Verify Full. VERIFY_FULL = 4 end end |
#ssl_mode ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengatePostgresqlConnectionProperties::PostgresqlSslMode
Returns Optional. SSL modes for PostgreSQL.
1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1026 class GoldengatePostgresqlConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for PostgreSQL. module PostgresqlSecurityProtocol # Security protocol not specified. POSTGRESQL_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for SSL modes for PostgreSQL. module PostgresqlSslMode # SSL mode not specified. POSTGRESQL_SSL_MODE_UNSPECIFIED = 0 # Prefer SSL. PREFER = 1 # Require SSL. REQUIRE = 2 # Verify Certificate Authority. VERIFY_CA = 3 # Verify Full. VERIFY_FULL = 4 end end |
#technology_type ⇒ ::String
Returns Optional. The technology type of PostgresqlConnection.
1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1026 class GoldengatePostgresqlConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for PostgreSQL. module PostgresqlSecurityProtocol # Security protocol not specified. POSTGRESQL_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for SSL modes for PostgreSQL. module PostgresqlSslMode # SSL mode not specified. POSTGRESQL_SSL_MODE_UNSPECIFIED = 0 # Prefer SSL. PREFER = 1 # Require SSL. REQUIRE = 2 # Verify Certificate Authority. VERIFY_CA = 3 # Verify Full. VERIFY_FULL = 4 end end |
#username ⇒ ::String
Returns Optional. The username Oracle Goldengate uses to connect the associated system of the given technology.
1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1026 class GoldengatePostgresqlConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for PostgreSQL. module PostgresqlSecurityProtocol # Security protocol not specified. POSTGRESQL_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for SSL modes for PostgreSQL. module PostgresqlSslMode # SSL mode not specified. POSTGRESQL_SSL_MODE_UNSPECIFIED = 0 # Prefer SSL. PREFER = 1 # Require SSL. REQUIRE = 2 # Verify Certificate Authority. VERIFY_CA = 3 # Verify Full. VERIFY_FULL = 4 end end |