Class: Google::Cloud::OracleDatabase::V1::GoldengateRedisConnectionProperties
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::GoldengateRedisConnectionProperties
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb
Overview
The properties of GoldengateRedisConnection.
Defined Under Namespace
Modules: RedisAuthenticationType, RedisSecurityProtocol
Instance Attribute Summary collapse
-
#authentication_type ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateRedisConnectionProperties::RedisAuthenticationType
Optional.
-
#key_store_file ⇒ ::String
Optional.
-
#key_store_password ⇒ ::String
Optional.
-
#key_store_password_secret_version ⇒ ::String
Optional.
-
#password ⇒ ::String
Optional.
-
#password_secret_version ⇒ ::String
Optional.
-
#redis_cluster_id ⇒ ::String
Optional.
-
#security_protocol ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateRedisConnectionProperties::RedisSecurityProtocol
Optional.
-
#servers ⇒ ::String
Optional.
-
#technology_type ⇒ ::String
Optional.
-
#trust_store_file ⇒ ::String
Optional.
-
#trust_store_password ⇒ ::String
Optional.
-
#trust_store_password_secret_version ⇒ ::String
Optional.
-
#username ⇒ ::String
Optional.
Instance Attribute Details
#authentication_type ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateRedisConnectionProperties::RedisAuthenticationType
Returns Optional. Authentication type for Redis.
1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1711 class GoldengateRedisConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Redis. module RedisSecurityProtocol # Security protocol not specified. REDIS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Redis. module RedisAuthenticationType # Authentication type not specified. REDIS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#key_store_file ⇒ ::String
Returns Optional. The base64 encoded content of the KeyStore file.
1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1711 class GoldengateRedisConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Redis. module RedisSecurityProtocol # Security protocol not specified. REDIS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Redis. module RedisAuthenticationType # Authentication type not specified. REDIS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#key_store_password ⇒ ::String
Returns Optional. Input only. The KeyStore password in plain text.
Note: The following fields are mutually exclusive: key_store_password, key_store_password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.
1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1711 class GoldengateRedisConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Redis. module RedisSecurityProtocol # Security protocol not specified. REDIS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Redis. module RedisAuthenticationType # Authentication type not specified. REDIS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#key_store_password_secret_version ⇒ ::String
Returns Optional. Input only. The resource name of a secret version in Secret Manager which contains the KeyStore password. Format: projects/{project}/secrets/{secret}/versions/{version}.
Note: The following fields are mutually exclusive: key_store_password_secret_version, key_store_password. If a field in that set is populated, all other fields in the set will automatically be cleared.
1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1711 class GoldengateRedisConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Redis. module RedisSecurityProtocol # Security protocol not specified. REDIS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Redis. module RedisAuthenticationType # Authentication type not specified. REDIS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#password ⇒ ::String
Returns Optional. Input only. The password Oracle Goldengate uses for Redis connection in plain text.
Note: The following fields are mutually exclusive: password, password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.
1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1711 class GoldengateRedisConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Redis. module RedisSecurityProtocol # Security protocol not specified. REDIS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Redis. module RedisAuthenticationType # Authentication type not specified. REDIS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#password_secret_version ⇒ ::String
Returns Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses for Redis connection. Format: projects/{project}/secrets/{secret}/versions/{version}.
Note: The following fields are mutually exclusive: password_secret_version, password. If a field in that set is populated, all other fields in the set will automatically be cleared.
1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1711 class GoldengateRedisConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Redis. module RedisSecurityProtocol # Security protocol not specified. REDIS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Redis. module RedisAuthenticationType # Authentication type not specified. REDIS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#redis_cluster_id ⇒ ::String
Returns Optional. The OCID of the Redis cluster.
1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1711 class GoldengateRedisConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Redis. module RedisSecurityProtocol # Security protocol not specified. REDIS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Redis. module RedisAuthenticationType # Authentication type not specified. REDIS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#security_protocol ⇒ ::Google::Cloud::OracleDatabase::V1::GoldengateRedisConnectionProperties::RedisSecurityProtocol
Returns Optional. Security protocol for Redis.
1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1711 class GoldengateRedisConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Redis. module RedisSecurityProtocol # Security protocol not specified. REDIS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Redis. module RedisAuthenticationType # Authentication type not specified. REDIS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#servers ⇒ ::String
Returns Optional. Comma separated list of Redis server addresses, specified as host:port entries, where :port is optional. If port is not specified, it defaults to 6379. Example: "server1.example.com:6379,server2.example.com:6379".
1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1711 class GoldengateRedisConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Redis. module RedisSecurityProtocol # Security protocol not specified. REDIS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Redis. module RedisAuthenticationType # Authentication type not specified. REDIS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#technology_type ⇒ ::String
Returns Optional. The technology type of RedisConnection.
1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1711 class GoldengateRedisConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Redis. module RedisSecurityProtocol # Security protocol not specified. REDIS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Redis. module RedisAuthenticationType # Authentication type not specified. REDIS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#trust_store_file ⇒ ::String
Returns Optional. The base64 encoded content of the TrustStore file.
1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1711 class GoldengateRedisConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Redis. module RedisSecurityProtocol # Security protocol not specified. REDIS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Redis. module RedisAuthenticationType # Authentication type not specified. REDIS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#trust_store_password ⇒ ::String
Returns Optional. Input only. The TrustStore password in plain text.
Note: The following fields are mutually exclusive: trust_store_password, trust_store_password_secret_version. If a field in that set is populated, all other fields in the set will automatically be cleared.
1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1711 class GoldengateRedisConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Redis. module RedisSecurityProtocol # Security protocol not specified. REDIS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Redis. module RedisAuthenticationType # Authentication type not specified. REDIS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#trust_store_password_secret_version ⇒ ::String
Returns Optional. Input only. The resource name of a secret version in Secret Manager which contains the TrustStore password. Format: projects/{project}/secrets/{secret}/versions/{version}.
Note: The following fields are mutually exclusive: trust_store_password_secret_version, trust_store_password. If a field in that set is populated, all other fields in the set will automatically be cleared.
1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1711 class GoldengateRedisConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Redis. module RedisSecurityProtocol # Security protocol not specified. REDIS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Redis. module RedisAuthenticationType # Authentication type not specified. REDIS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |
#username ⇒ ::String
Returns Optional. The username Oracle Goldengate uses to connect the associated system of the given technology.
1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1711 class GoldengateRedisConnectionProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum for Security protocol for Redis. module RedisSecurityProtocol # Security protocol not specified. REDIS_SECURITY_PROTOCOL_UNSPECIFIED = 0 # Plain text communication. PLAIN = 1 # Transport Layer Security. TLS = 2 # Mutual Transport Layer Security. MTLS = 3 end # Enum for Authentication type for Redis. module RedisAuthenticationType # Authentication type not specified. REDIS_AUTHENTICATION_TYPE_UNSPECIFIED = 0 # No authentication. NONE = 1 # Basic authentication. BASIC = 2 end end |