Class: Google::Cloud::OracleDatabase::V1::IcebergCatalog
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::IcebergCatalog
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb
Overview
The Iceberg catalog details.
Defined Under Namespace
Modules: CatalogType
Instance Attribute Summary collapse
-
#catalog_type ⇒ ::Google::Cloud::OracleDatabase::V1::IcebergCatalog::CatalogType
Required.
-
#glue_iceberg_catalog ⇒ ::Google::Cloud::OracleDatabase::V1::GlueIcebergCatalog
The Glue Iceberg catalog.
-
#nessie_iceberg_catalog ⇒ ::Google::Cloud::OracleDatabase::V1::NessieIcebergCatalog
The Nessie Iceberg catalog.
-
#polaris_iceberg_catalog ⇒ ::Google::Cloud::OracleDatabase::V1::PolarisIcebergCatalog
The Polaris Iceberg catalog.
-
#rest_iceberg_catalog ⇒ ::Google::Cloud::OracleDatabase::V1::RestIcebergCatalog
The REST Iceberg catalog.
Instance Attribute Details
#catalog_type ⇒ ::Google::Cloud::OracleDatabase::V1::IcebergCatalog::CatalogType
Returns Required. The type of Iceberg catalog.
1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1947 class IcebergCatalog include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of Iceberg catalog. module CatalogType # Catalog type not specified. CATALOG_TYPE_UNSPECIFIED = 0 # Glue catalog. GLUE = 1 # Hadoop catalog. HADOOP = 2 # Nessie catalog. NESSIE = 3 # Polaris catalog. POLARIS = 4 # REST catalog. REST = 5 end end |
#glue_iceberg_catalog ⇒ ::Google::Cloud::OracleDatabase::V1::GlueIcebergCatalog
Returns The Glue Iceberg catalog.
Note: The following fields are mutually exclusive: glue_iceberg_catalog, nessie_iceberg_catalog, polaris_iceberg_catalog, rest_iceberg_catalog. If a field in that set is populated, all other fields in the set will automatically be cleared.
1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1947 class IcebergCatalog include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of Iceberg catalog. module CatalogType # Catalog type not specified. CATALOG_TYPE_UNSPECIFIED = 0 # Glue catalog. GLUE = 1 # Hadoop catalog. HADOOP = 2 # Nessie catalog. NESSIE = 3 # Polaris catalog. POLARIS = 4 # REST catalog. REST = 5 end end |
#nessie_iceberg_catalog ⇒ ::Google::Cloud::OracleDatabase::V1::NessieIcebergCatalog
Returns The Nessie Iceberg catalog.
Note: The following fields are mutually exclusive: nessie_iceberg_catalog, glue_iceberg_catalog, polaris_iceberg_catalog, rest_iceberg_catalog. If a field in that set is populated, all other fields in the set will automatically be cleared.
1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1947 class IcebergCatalog include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of Iceberg catalog. module CatalogType # Catalog type not specified. CATALOG_TYPE_UNSPECIFIED = 0 # Glue catalog. GLUE = 1 # Hadoop catalog. HADOOP = 2 # Nessie catalog. NESSIE = 3 # Polaris catalog. POLARIS = 4 # REST catalog. REST = 5 end end |
#polaris_iceberg_catalog ⇒ ::Google::Cloud::OracleDatabase::V1::PolarisIcebergCatalog
Returns The Polaris Iceberg catalog.
Note: The following fields are mutually exclusive: polaris_iceberg_catalog, glue_iceberg_catalog, nessie_iceberg_catalog, rest_iceberg_catalog. If a field in that set is populated, all other fields in the set will automatically be cleared.
1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1947 class IcebergCatalog include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of Iceberg catalog. module CatalogType # Catalog type not specified. CATALOG_TYPE_UNSPECIFIED = 0 # Glue catalog. GLUE = 1 # Hadoop catalog. HADOOP = 2 # Nessie catalog. NESSIE = 3 # Polaris catalog. POLARIS = 4 # REST catalog. REST = 5 end end |
#rest_iceberg_catalog ⇒ ::Google::Cloud::OracleDatabase::V1::RestIcebergCatalog
Returns The REST Iceberg catalog.
Note: The following fields are mutually exclusive: rest_iceberg_catalog, glue_iceberg_catalog, nessie_iceberg_catalog, polaris_iceberg_catalog. If a field in that set is populated, all other fields in the set will automatically be cleared.
1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 1947 class IcebergCatalog include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of Iceberg catalog. module CatalogType # Catalog type not specified. CATALOG_TYPE_UNSPECIFIED = 0 # Glue catalog. GLUE = 1 # Hadoop catalog. HADOOP = 2 # Nessie catalog. NESSIE = 3 # Polaris catalog. POLARIS = 4 # REST catalog. REST = 5 end end |