Class: Google::Cloud::OracleDatabase::V1::IcebergStorage
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::IcebergStorage
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb
Overview
The Iceberg storage details.
Defined Under Namespace
Modules: StorageType
Instance Attribute Summary collapse
-
#amazon_s3_iceberg_storage ⇒ ::Google::Cloud::OracleDatabase::V1::AmazonS3IcebergStorage
The Amazon S3 Iceberg storage.
-
#azure_data_lake_storage_iceberg_storage ⇒ ::Google::Cloud::OracleDatabase::V1::AzureDataLakeStorageIcebergStorage
The Azure Data Lake Storage Iceberg storage.
-
#google_cloud_storage_iceberg_storage ⇒ ::Google::Cloud::OracleDatabase::V1::GoogleCloudStorageIcebergStorage
The Google Cloud Storage Iceberg storage.
-
#storage_type ⇒ ::Google::Cloud::OracleDatabase::V1::IcebergStorage::StorageType
Required.
Instance Attribute Details
#amazon_s3_iceberg_storage ⇒ ::Google::Cloud::OracleDatabase::V1::AmazonS3IcebergStorage
Returns The Amazon S3 Iceberg storage.
Note: The following fields are mutually exclusive: amazon_s3_iceberg_storage, google_cloud_storage_iceberg_storage, azure_data_lake_storage_iceberg_storage. If a field in that set is populated, all other fields in the set will automatically be cleared.
2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 2062 class IcebergStorage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of Iceberg storage. module StorageType # Storage type not specified. STORAGE_TYPE_UNSPECIFIED = 0 # Amazon S3 storage. AMAZON_S3 = 1 # Google Cloud Storage storage. GOOGLE_CLOUD_STORAGE = 2 # Azure Data Lake Storage storage. AZURE_DATA_LAKE_STORAGE = 3 end end |
#azure_data_lake_storage_iceberg_storage ⇒ ::Google::Cloud::OracleDatabase::V1::AzureDataLakeStorageIcebergStorage
Returns The Azure Data Lake Storage Iceberg storage.
Note: The following fields are mutually exclusive: azure_data_lake_storage_iceberg_storage, amazon_s3_iceberg_storage, google_cloud_storage_iceberg_storage. If a field in that set is populated, all other fields in the set will automatically be cleared.
2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 2062 class IcebergStorage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of Iceberg storage. module StorageType # Storage type not specified. STORAGE_TYPE_UNSPECIFIED = 0 # Amazon S3 storage. AMAZON_S3 = 1 # Google Cloud Storage storage. GOOGLE_CLOUD_STORAGE = 2 # Azure Data Lake Storage storage. AZURE_DATA_LAKE_STORAGE = 3 end end |
#google_cloud_storage_iceberg_storage ⇒ ::Google::Cloud::OracleDatabase::V1::GoogleCloudStorageIcebergStorage
Returns The Google Cloud Storage Iceberg storage.
Note: The following fields are mutually exclusive: google_cloud_storage_iceberg_storage, amazon_s3_iceberg_storage, azure_data_lake_storage_iceberg_storage. If a field in that set is populated, all other fields in the set will automatically be cleared.
2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 2062 class IcebergStorage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of Iceberg storage. module StorageType # Storage type not specified. STORAGE_TYPE_UNSPECIFIED = 0 # Amazon S3 storage. AMAZON_S3 = 1 # Google Cloud Storage storage. GOOGLE_CLOUD_STORAGE = 2 # Azure Data Lake Storage storage. AZURE_DATA_LAKE_STORAGE = 3 end end |
#storage_type ⇒ ::Google::Cloud::OracleDatabase::V1::IcebergStorage::StorageType
Returns Required. The type of Iceberg storage.
2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 2062 class IcebergStorage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of Iceberg storage. module StorageType # Storage type not specified. STORAGE_TYPE_UNSPECIFIED = 0 # Amazon S3 storage. AMAZON_S3 = 1 # Google Cloud Storage storage. GOOGLE_CLOUD_STORAGE = 2 # Azure Data Lake Storage storage. AZURE_DATA_LAKE_STORAGE = 3 end end |