Class: Google::Cloud::OracleDatabase::V1::KafkaBootstrapServer
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::KafkaBootstrapServer
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb
Overview
Represents a Kafka bootstrap server with host name, optional port defaults to 9092, and an optional private ip.
Instance Attribute Summary collapse
-
#host ⇒ ::String
Required.
-
#port ⇒ ::Integer
Optional.
-
#private_ip_address ⇒ ::String
Optional.
Instance Attribute Details
#host ⇒ ::String
Returns Required. The name or address of a host.
2231 2232 2233 2234 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 2231 class KafkaBootstrapServer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#port ⇒ ::Integer
Returns Optional. The port of an endpoint usually specified for a connection.
2231 2232 2233 2234 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 2231 class KafkaBootstrapServer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#private_ip_address ⇒ ::String
Returns Optional. The private IP address of the connection's endpoint in the customer's VCN, typically a database endpoint or a big data endpoint (e.g. Kafka bootstrap server). In case the privateIp is provided, the subnetId must also be provided. In case the privateIp (and the subnetId) is not provided it is assumed the datasource is publicly accessible. In case the connection is accessible only privately, the lack of privateIp will result in not being able to access the connection.
2231 2232 2233 2234 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 2231 class KafkaBootstrapServer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |