Class: Google::Cloud::OracleDatabase::V1::ListGoldengateConnectionAssignmentsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::ListGoldengateConnectionAssignmentsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/goldengate_connection_assignment.rb
Overview
Response message for listing GoldengateConnectionAssignments.
Instance Attribute Summary collapse
-
#goldengate_connection_assignments ⇒ ::Array<::Google::Cloud::OracleDatabase::V1::GoldengateConnectionAssignment>
The list of GoldengateConnectionAssignments.
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page. -
#unreachable ⇒ ::Array<::String>
Unreachable locations when listing resources across all locations using wildcard location '-'.
Instance Attribute Details
#goldengate_connection_assignments ⇒ ::Array<::Google::Cloud::OracleDatabase::V1::GoldengateConnectionAssignment>
Returns The list of GoldengateConnectionAssignments.
153 154 155 156 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection_assignment.rb', line 153 class ListGoldengateConnectionAssignmentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
153 154 155 156 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection_assignment.rb', line 153 class ListGoldengateConnectionAssignmentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Unreachable locations when listing resources across all locations using wildcard location '-'.
153 154 155 156 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection_assignment.rb', line 153 class ListGoldengateConnectionAssignmentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |