Class: Google::Cloud::OracleDatabase::V1::ListGoldengateConnectionsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::ListGoldengateConnectionsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb
Overview
The response for GoldengateConnection.List.
Instance Attribute Summary collapse
-
#goldengate_connections ⇒ ::Array<::Google::Cloud::OracleDatabase::V1::GoldengateConnection>
The list of GoldengateConnections.
-
#next_page_token ⇒ ::String
A token identifying a page of results the server should return.
-
#unreachable ⇒ ::Array<::String>
Optional.
Instance Attribute Details
#goldengate_connections ⇒ ::Array<::Google::Cloud::OracleDatabase::V1::GoldengateConnection>
Returns The list of GoldengateConnections.
2196 2197 2198 2199 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 2196 class ListGoldengateConnectionsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token identifying a page of results the server should return.
2196 2197 2198 2199 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 2196 class ListGoldengateConnectionsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Optional. Locations that could not be reached.
2196 2197 2198 2199 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_connection.rb', line 2196 class ListGoldengateConnectionsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |