Class: Google::Cloud::OracleDatabase::V1::ListGoldengateDeploymentsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::ListGoldengateDeploymentsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb
Overview
The response for GoldengateDeployment.List.
Instance Attribute Summary collapse
-
#goldengate_deployments ⇒ ::Array<::Google::Cloud::OracleDatabase::V1::GoldengateDeployment>
The list of GoldengateDeployments.
-
#next_page_token ⇒ ::String
A token identifying a page of results the server should return.
-
#unreachable ⇒ ::Array<::String>
Optional.
Instance Attribute Details
#goldengate_deployments ⇒ ::Array<::Google::Cloud::OracleDatabase::V1::GoldengateDeployment>
Returns The list of GoldengateDeployments.
685 686 687 688 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 685 class ListGoldengateDeploymentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token identifying a page of results the server should return.
685 686 687 688 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 685 class ListGoldengateDeploymentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Optional. Locations that could not be reached.
685 686 687 688 |
# File 'proto_docs/google/cloud/oracledatabase/v1/goldengate_deployment.rb', line 685 class ListGoldengateDeploymentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |