Class: Google::Cloud::OracleDatabase::V1::ListOdbNetworksRequest
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::ListOdbNetworksRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/odb_network.rb
Overview
The request for OdbNetwork.List.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#order_by ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. An expression for filtering the results of the request.
151 152 153 154 |
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_network.rb', line 151 class ListOdbNetworksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#order_by ⇒ ::String
Returns Optional. An expression for ordering the results of the request.
151 152 153 154 |
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_network.rb', line 151 class ListOdbNetworksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. The maximum number of items to return. If unspecified, at most 50 ODB Networks will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.
151 152 153 154 |
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_network.rb', line 151 class ListOdbNetworksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A token identifying a page of results the server should return.
151 152 153 154 |
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_network.rb', line 151 class ListOdbNetworksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent value for the ODB Network in the following format: projects/{project}/locations/{location}.
151 152 153 154 |
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_network.rb', line 151 class ListOdbNetworksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |