Class: Google::Cloud::OracleDatabase::V1::ListOdbNetworksResponse
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::ListOdbNetworksResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/odb_network.rb
Overview
The response for OdbNetwork.List.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token identifying a page of results the server should return.
-
#odb_networks ⇒ ::Array<::Google::Cloud::OracleDatabase::V1::OdbNetwork>
The list of ODB Networks.
-
#unreachable ⇒ ::Array<::String>
Unreachable locations when listing resources across all locations using wildcard location '-'.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token identifying a page of results the server should return.
167 168 169 170 |
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_network.rb', line 167 class ListOdbNetworksResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#odb_networks ⇒ ::Array<::Google::Cloud::OracleDatabase::V1::OdbNetwork>
Returns The list of ODB Networks.
167 168 169 170 |
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_network.rb', line 167 class ListOdbNetworksResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Unreachable locations when listing resources across all locations using wildcard location '-'.
167 168 169 170 |
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_network.rb', line 167 class ListOdbNetworksResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |