Class: Google::Cloud::OracleDatabase::V1::ListOdbSubnetsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::ListOdbSubnetsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/odb_subnet.rb
Overview
The response for OdbSubnet.List.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token identifying a page of results the server should return.
-
#odb_subnets ⇒ ::Array<::Google::Cloud::OracleDatabase::V1::OdbSubnet>
The list of ODB Subnets.
-
#unreachable ⇒ ::Array<::String>
Unreachable locations when listing resources across all locations using wildcard location '-'.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token identifying a page of results the server should return.
172 173 174 175 |
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_subnet.rb', line 172 class ListOdbSubnetsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#odb_subnets ⇒ ::Array<::Google::Cloud::OracleDatabase::V1::OdbSubnet>
Returns The list of ODB Subnets.
172 173 174 175 |
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_subnet.rb', line 172 class ListOdbSubnetsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Unreachable locations when listing resources across all locations using wildcard location '-'.
172 173 174 175 |
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_subnet.rb', line 172 class ListOdbSubnetsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |