Class: Google::Cloud::OracleDatabase::V1::ListPluggableDatabasesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::ListPluggableDatabasesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb
Overview
The request for PluggableDatabase.List.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. An expression for filtering the results of the request. List for
pluggable databases is supported only with a valid container database (full
resource name) filter in this format:
database="projects/{project}/locations/{location}/databases/{database}".
347 348 349 350 |
# File 'proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb', line 347 class ListPluggableDatabasesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. The maximum number of PluggableDatabases to return. The service may return fewer than this value.
347 348 349 350 |
# File 'proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb', line 347 class ListPluggableDatabasesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A page token, received from a previous ListPluggableDatabases
call. Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to ListPluggableDatabases
must match the call that provided the page token.
347 348 349 350 |
# File 'proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb', line 347 class ListPluggableDatabasesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent, which owns this collection of PluggableDatabases. Format: projects/{project}/locations/{location}.
347 348 349 350 |
# File 'proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb', line 347 class ListPluggableDatabasesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |