Class: Google::Cloud::OracleDatabase::V1::OdbNetwork
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::OdbNetwork
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/odb_network.rb
Overview
Represents OdbNetwork resource.
Defined Under Namespace
Modules: State Classes: LabelsEntry
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#entitlement_id ⇒ ::String
readonly
Output only.
-
#gcp_oracle_zone ⇒ ::String
Optional.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#name ⇒ ::String
Identifier.
-
#network ⇒ ::String
Required.
-
#state ⇒ ::Google::Cloud::OracleDatabase::V1::OdbNetwork::State
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The date and time that the OdbNetwork was created.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_network.rb', line 51 class OdbNetwork include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The various lifecycle states of the ODB Network. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in terminating state. TERMINATING = 3 # Indicates that the resource is in failed state. FAILED = 4 end end |
#entitlement_id ⇒ ::String (readonly)
Returns Output only. The ID of the subscription entitlement associated with the OdbNetwork.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_network.rb', line 51 class OdbNetwork include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The various lifecycle states of the ODB Network. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in terminating state. TERMINATING = 3 # Indicates that the resource is in failed state. FAILED = 4 end end |
#gcp_oracle_zone ⇒ ::String
Returns Optional. The GCP Oracle zone where OdbNetwork is hosted. Example: us-east4-b-r2. If not specified, the system will pick a zone based on availability.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_network.rb', line 51 class OdbNetwork include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The various lifecycle states of the ODB Network. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in terminating state. TERMINATING = 3 # Indicates that the resource is in failed state. FAILED = 4 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Labels or tags associated with the resource.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_network.rb', line 51 class OdbNetwork include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The various lifecycle states of the ODB Network. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in terminating state. TERMINATING = 3 # Indicates that the resource is in failed state. FAILED = 4 end end |
#name ⇒ ::String
Returns Identifier. The name of the OdbNetwork resource in the following format: projects/{project}/locations/{region}/odbNetworks/{odb_network}.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_network.rb', line 51 class OdbNetwork include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The various lifecycle states of the ODB Network. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in terminating state. TERMINATING = 3 # Indicates that the resource is in failed state. FAILED = 4 end end |
#network ⇒ ::String
Returns Required. The name of the VPC network in the following format: projects/{project}/global/networks/{network}.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_network.rb', line 51 class OdbNetwork include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The various lifecycle states of the ODB Network. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in terminating state. TERMINATING = 3 # Indicates that the resource is in failed state. FAILED = 4 end end |
#state ⇒ ::Google::Cloud::OracleDatabase::V1::OdbNetwork::State (readonly)
Returns Output only. State of the ODB Network.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'proto_docs/google/cloud/oracledatabase/v1/odb_network.rb', line 51 class OdbNetwork include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The various lifecycle states of the ODB Network. module State # Default unspecified value. STATE_UNSPECIFIED = 0 # Indicates that the resource is in provisioning state. PROVISIONING = 1 # Indicates that the resource is in available state. AVAILABLE = 2 # Indicates that the resource is in terminating state. TERMINATING = 3 # Indicates that the resource is in failed state. FAILED = 4 end end |