Class: Google::Cloud::OracleDatabase::V1::PluggableDatabaseNodeLevelDetails
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::PluggableDatabaseNodeLevelDetails
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb
Overview
The Pluggable Database Node Level Details.
Defined Under Namespace
Modules: PluggableDatabaseOpenMode
Instance Attribute Summary collapse
-
#node_name ⇒ ::String
Required.
-
#open_mode ⇒ ::Google::Cloud::OracleDatabase::V1::PluggableDatabaseNodeLevelDetails::PluggableDatabaseOpenMode
Required.
-
#pluggable_database_id ⇒ ::String
Required.
Instance Attribute Details
#node_name ⇒ ::String
Returns Required. The Node name of the Database home.
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb', line 237 class PluggableDatabaseNodeLevelDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The mode that the pluggable database is in to open it. module PluggableDatabaseOpenMode # The open mode is unspecified. PLUGGABLE_DATABASE_OPEN_MODE_UNSPECIFIED = 0 # The pluggable database is opened in read-only mode. READ_ONLY = 1 # The pluggable database is opened in read-write mode. READ_WRITE = 2 # The pluggable database is mounted. MOUNTED = 3 # The pluggable database is migrated. MIGRATE = 4 end end |
#open_mode ⇒ ::Google::Cloud::OracleDatabase::V1::PluggableDatabaseNodeLevelDetails::PluggableDatabaseOpenMode
Returns Required. The mode that the pluggable database is in to open it.
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb', line 237 class PluggableDatabaseNodeLevelDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The mode that the pluggable database is in to open it. module PluggableDatabaseOpenMode # The open mode is unspecified. PLUGGABLE_DATABASE_OPEN_MODE_UNSPECIFIED = 0 # The pluggable database is opened in read-only mode. READ_ONLY = 1 # The pluggable database is opened in read-write mode. READ_WRITE = 2 # The pluggable database is mounted. MOUNTED = 3 # The pluggable database is migrated. MIGRATE = 4 end end |
#pluggable_database_id ⇒ ::String
Returns Required. The OCID of the Pluggable Database.
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'proto_docs/google/cloud/oracledatabase/v1/pluggable_database.rb', line 237 class PluggableDatabaseNodeLevelDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The mode that the pluggable database is in to open it. module PluggableDatabaseOpenMode # The open mode is unspecified. PLUGGABLE_DATABASE_OPEN_MODE_UNSPECIFIED = 0 # The pluggable database is opened in read-only mode. READ_ONLY = 1 # The pluggable database is opened in read-write mode. READ_WRITE = 2 # The pluggable database is mounted. MOUNTED = 3 # The pluggable database is migrated. MIGRATE = 4 end end |