Class: Google::Cloud::OracleDatabase::V1::RemoveVirtualMachineExadbVmClusterRequest
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::RemoveVirtualMachineExadbVmClusterRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb
Overview
The request for ExadbVmCluster.RemoveVirtualMachine.
Instance Attribute Summary collapse
-
#hostnames ⇒ ::Array<::String>
Required.
-
#name ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
Instance Attribute Details
#hostnames ⇒ ::Array<::String>
Returns Required. The list of host names of db nodes to be removed from the ExadbVmCluster.
909 910 911 912 |
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 909 class RemoveVirtualMachineExadbVmClusterRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The name of the ExadbVmCluster in the following format: projects/{project}/locations/{location}/exadbVmClusters/{exadb_vm_cluster}.
909 910 911 912 |
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 909 class RemoveVirtualMachineExadbVmClusterRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. An optional ID to identify the request. This value is used to identify duplicate requests. If you make a request with the same request ID and the original request is still in progress or completed, the server ignores the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
909 910 911 912 |
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 909 class RemoveVirtualMachineExadbVmClusterRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |