Class: Google::Cloud::OracleDatabase::V1::StorageSizeDetails
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::StorageSizeDetails
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/db_system_initial_storage_size.rb
Overview
The initial storage size, in gigabytes, that is applicable for virtual machine DBSystem.
Instance Attribute Summary collapse
-
#data_storage_size_in_gbs ⇒ ::Integer
readonly
Output only.
-
#reco_storage_size_in_gbs ⇒ ::Integer
readonly
Output only.
Instance Attribute Details
#data_storage_size_in_gbs ⇒ ::Integer (readonly)
Returns Output only. The data storage size, in gigabytes, that is applicable for virtual machine DBSystem.
86 87 88 89 |
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system_initial_storage_size.rb', line 86 class StorageSizeDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#reco_storage_size_in_gbs ⇒ ::Integer (readonly)
Returns Output only. The RECO/REDO storage size, in gigabytes, that is applicable for virtual machine DBSystem.
86 87 88 89 |
# File 'proto_docs/google/cloud/oracledatabase/v1/db_system_initial_storage_size.rb', line 86 class StorageSizeDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |