Class: Google::Cloud::OracleDatabase::V1::UpdateAutonomousDatabaseRequest
- Inherits:
-
Object
- Object
- Google::Cloud::OracleDatabase::V1::UpdateAutonomousDatabaseRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb
Overview
The request for AutonomousDatabase.Update.
Instance Attribute Summary collapse
-
#autonomous_database ⇒ ::Google::Cloud::OracleDatabase::V1::AutonomousDatabase
Required.
-
#request_id ⇒ ::String
Optional.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
Optional.
Instance Attribute Details
#autonomous_database ⇒ ::Google::Cloud::OracleDatabase::V1::AutonomousDatabase
Returns Required. The resource being updated.
528 529 530 531 |
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 528 class UpdateAutonomousDatabaseRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. An optional ID to identify the request. This value is used to identify duplicate requests. If you make a request with the same request ID and the original request is still in progress or completed, the server ignores the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
528 529 530 531 |
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 528 class UpdateAutonomousDatabaseRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns Optional. Field mask is used to specify the fields to be overwritten in the Exadata resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then all fields will be overwritten.
528 529 530 531 |
# File 'proto_docs/google/cloud/oracledatabase/v1/oracledatabase.rb', line 528 class UpdateAutonomousDatabaseRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |